@@ -47,6 +47,7 @@
 
 #include <abinit.h>
 
+#include <support.h>
 #include <visu_object.h>
 #include <visu_gtk.h>
 #include <gtk_main.h>
@@ -87,8 +88,9 @@ static guint timeout = 0;
 static VisuInteractive *inter;
 static GtkListStore *symList;
 
-static void onSelection(VisuInteractive *inter _U_,
-                        VisuInteractivePick pick, VisuNode *nodes[3], gpointer data);
+static void onSelection(VisuInteractive *inter,
+                        VisuInteractivePick pick, VisuNode *node0,
+                        VisuNode *node1, VisuNode *node2, gpointer data);
 static void onSymmetryToggled(GtkToggleButton *toggle, gpointer data);
 static void onSymmetryClicked(GtkButton *button, gpointer data);
 static void onTolChanged(GtkSpinButton *spin, gpointer data);
@@ -107,15 +109,15 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
 {
   GtkWidget *wd, *hbox, *bt, *scroll;
   VisuData *data;
-  VisuRenderingWindow *window;
+  VisuUiRenderingWindow *window;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
 
-  window = visu_uiMainClass_getDefaultRendering();
-  data = visu_rendering_window_getVisuData(window);
+  window = visu_ui_main_class_getDefaultRendering();
+  data = visu_ui_rendering_window_getData(window);
   g_return_val_if_fail(data, (GtkWidget*)0);
 
-  inter = visuInteractiveNew(interactive_pick);
+  inter = visu_interactive_new(interactive_pick);
   g_object_ref(G_OBJECT(inter));
   g_signal_connect(G_OBJECT(inter), "stop",
 		   G_CALLBACK(onPickClickStop), (gpointer)window);
@@ -262,7 +264,7 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
   gtk_widget_show_all(vbox);
   gtk_widget_hide(lblSymWarning);
     
-  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
+  g_signal_connect(VISU_OBJECT_INSTANCE, "dataRendered",
 		   G_CALLBACK(onVisuDataChanged), (gpointer)0);
 
   onVisuDataChanged((VisuObject*)0, data, (gpointer)0);
@@ -311,25 +313,26 @@ static void formatSymOperators(GtkTreeViewColumn *column _U_, GtkCellRenderer *c
     }
 }
 
-void startSelect(VisuRenderingWindow *window)
+void startSelect(VisuUiRenderingWindow *window)
 {
-  renderingWindowPush_interactive(window, inter);
+  visu_ui_rendering_window_pushInteractive(window, inter);
 }
-void stopSelect(VisuRenderingWindow *window)
+void stopSelect(VisuUiRenderingWindow *window)
 {
-  renderingWindowPop_interactive(window, inter);
+  visu_ui_rendering_window_popInteractive(window, inter);
 }
 
 static void onPickClickStop(VisuInteractive *inter _U_, gpointer data _U_)
 {
 }
 
-static void onSelection(VisuInteractive *inter _U_, VisuInteractivePick pick _U_,
-			VisuNode *nodes[3], gpointer data)
+static void onSelection(VisuInteractive *inter _U_,
+                        VisuInteractivePick pick _U_, VisuNode *node0,
+                        VisuNode *node1 _U_, VisuNode *node2 _U_, gpointer data)
 {
-  getEquivalents(visu_rendering_window_getVisuData(RENDERING_WINDOW(data)), nodes[0]);
+  getEquivalents(visu_ui_rendering_window_getData(VISU_UI_RENDERING_WINDOW(data)), node0);
   g_signal_handler_block(G_OBJECT(spinNode), onSpin_id);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinNode), nodes[0]->number + 1);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinNode), node0->number + 1);
   g_signal_handler_unblock(G_OBJECT(spinNode), onSpin_id);
 }
 
@@ -341,7 +344,7 @@ static void onSymmetryClicked(GtkButton *button _U_, gpointer spin)
   VisuData *dataObj;
 
   /* Get the current VisuData object. */
-  dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
+  dataObj = visu_ui_rendering_window_getData(visu_ui_main_class_getDefaultRendering());
 
   updateSymmetries(dataObj, gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)));
 }
@@ -350,14 +353,14 @@ static void onTolChanged(GtkSpinButton *spin, gpointer data _U_)
   VisuData *dataObj;
 
   /* Get the current VisuData object. */
-  dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
+  dataObj = visu_ui_rendering_window_getData(visu_ui_main_class_getDefaultRendering());
 
   updateSymmetries(dataObj, gtk_spin_button_get_value(spin));
 }
 static void onVisuDataChanged(VisuObject *visu _U_, VisuData *dataObj,
 			      gpointer data _U_)
 {
-  VisuDataIter iter;
+  VisuNodeArrayIter iter;
 
   gtk_widget_set_sensitive(vbox, (dataObj !=(VisuData*)0));
 
@@ -365,13 +368,13 @@ static void onVisuDataChanged(VisuObject *visu _U_, VisuData *dataObj,
   
   if (dataObj)
     {
-      visu_data_iterNew(dataObj, &iter);
+      visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
       gtk_spin_button_set_range(GTK_SPIN_BUTTON(spinNode), 0, iter.idMax + 1);
     }
 }
 static void onSpinNode(GtkSpinButton *button, gpointer data _U_)
 {
-  VisuRenderingWindow *window;
+  VisuUiRenderingWindow *window;
   VisuData *dataObj;
   VisuNode *node;
 
@@ -379,10 +382,10 @@ static void onSpinNode(GtkSpinButton *button, gpointer data _U_)
     return;
 
   /* Get the current VisuData object. */
-  window = visu_uiMainClass_getDefaultRendering();
-  dataObj = visu_rendering_window_getVisuData(window);
-  node = visu_data_getNodeFromNumber(dataObj,
-				    (int)gtk_spin_button_get_value(button) - 1);
+  window = visu_ui_main_class_getDefaultRendering();
+  dataObj = visu_ui_rendering_window_getData(window);
+  node = visu_node_array_getFromId(VISU_NODE_ARRAY(dataObj),
+                                   (int)gtk_spin_button_get_value(button) - 1);
 
   getEquivalents(dataObj, node);
 }
@@ -393,18 +396,18 @@ static gboolean onRemoveEquivalents(gpointer data _U_)
 
 static void removeEquivalents(gpointer data)
 {
-  VisuMarks *marks;
+  VisuGlExtMarks *marks;
   GList *lst;
 
   lst = (GList*)data;
 
   /* Get the current VisuData object. */
-  marks = visu_rendering_window_getMarks(visu_uiMainClass_getDefaultRendering());
+  marks = visu_ui_rendering_window_getMarks(visu_ui_main_class_getDefaultRendering());
 
-  visu_marks_setHighlightedList(marks, lst, MARKS_STATUS_TOGGLE);
+  visu_gl_ext_marks_setHighlightedList(marks, lst, MARKS_STATUS_TOGGLE);
   g_list_free(lst);
 
-  VISU_FORCE_REDRAW;
+  VISU_REDRAW_FORCE;
 }
 static void getEquivalents(VisuData *dataObj, VisuNode *node)
 {
@@ -443,8 +446,8 @@ static void getEquivalents(VisuData *dataObj, VisuNode *node)
 	g_source_remove(timeout);
 
       /* Set the new highlights. */
-      visu_marks_setHighlightedList
-	(visu_rendering_window_getMarks(visu_uiMainClass_getDefaultRendering()),
+      visu_gl_ext_marks_setHighlightedList
+	(visu_ui_rendering_window_getMarks(visu_ui_main_class_getDefaultRendering()),
 	 lst, MARKS_STATUS_SET);
 
       /* Add the new timeout. */
@@ -452,18 +455,18 @@ static void getEquivalents(VisuData *dataObj, VisuNode *node)
 				   onRemoveEquivalents, lst, removeEquivalents);
       /* lst will be freed in the timeout. */
 				 
-      VISU_FORCE_REDRAW;
+      VISU_REDRAW_FORCE;
     }
 }
 
 gpointer startThreadSymmetry(gpointer data _U_)
 {
-  float xred0[3];
+  float xred0[3], xyz[3];
   char *spGrp;
   double box[3][3], genAfm[3], *xred;
   int i, *typat, grpId, grpMagnId;
   Ab6Error errno;
-  VisuDataIter iter;
+  VisuNodeArrayIter iter;
 
   AbinitData *dt;
 
@@ -471,18 +474,19 @@ gpointer startThreadSymmetry(gpointer data _U_)
               (gpointer)g_thread_self());
   dt = abinit_getDt();
 
-  visu_data_getBoxMatrixD0(dt->data, box);
+  visu_box_getCellMatrix(visu_boxed_getBox(VISU_BOXED(dt->data)), box);
   ab6_symmetry_set_lattice(dt->sym, box);
       
-  visu_data_iterNew(dt->data, &iter);
+  visu_node_array_iterNew(VISU_NODE_ARRAY(dt->data), &iter);
   i = 0;
   typat = g_malloc(sizeof(int) * iter.nAllStoredNodes);
   xred = g_malloc(sizeof(double) * 3 * iter.nAllStoredNodes);
-  for (visu_data_iterStart(dt->data, &iter); iter.node;
-       visu_data_iterNext(dt->data, &iter))
+  for (visu_node_array_iterStart(VISU_NODE_ARRAY(dt->data), &iter); iter.node;
+       visu_node_array_iterNext(VISU_NODE_ARRAY(dt->data), &iter))
     {
       typat[i] = iter.iElement;
-      visu_data_getReducedNodePosition(dt->data, iter.node, xred0);
+      visu_data_getNodePosition(dt->data, iter.node, xyz);
+      visu_box_convertXYZtoBoxCoordinates(visu_boxed_getBox(VISU_BOXED(dt->data)), xred0, xyz);
       xred[3 * i + 0] = (double)xred0[0];
       xred[3 * i + 1] = (double)xred0[1];
       xred[3 * i + 2] = (double)xred0[2];
@@ -637,7 +641,7 @@ static void updateSymmetries(VisuData *dataObj, gdouble tol)
 	}
       else
 	{
-	  visuGtkRaise_warning(_("ABINIT symmetry calculation"),
+	  visu_ui_raiseWarning(_("ABINIT symmetry calculation"),
 			       dt->error->message, (GtkWindow*)0);
 	  g_error_free(dt->error);
 	  ab6_symmetry_free(dt->sym);
