@@ -46,6 +46,8 @@
 
 #include "abinit.h"
 
+#include <string.h>
+
 #include <config.h>
 #include <visu_tools.h>
 #include <visu_basic.h>
@@ -81,13 +83,16 @@
 static void abStructuralInit(VisuRendering *method);
 static void abSpinInit(VisuRendering *method);
 static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
-			     ToolFileFormat *format, int nSet, GError **error);
+			     ToolFileFormat *format, int nSet,
+                             GCancellable *cancel, GError **error);
 static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
-			       ToolFileFormat *format, int nSet, GError **error);
+			       ToolFileFormat *format, int nSet,
+                               GCancellable *cancel, GError **error);
 static gpointer parseAbinitThread(gpointer data);
 static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet);
 static gboolean waitDt(gpointer data);
 static void freeDt(gpointer dt);
+static gchar** readPseudoFiles(AbinitData *dt);
 
 /* Local variables */
 static gchar *iconPath;
@@ -105,6 +110,8 @@ gboolean abinitInit()
 
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "abinit.png", NULL);
 
+  ab6_mpi_init();
+
   return TRUE;
 }
 
@@ -112,7 +119,7 @@ gboolean abinitInitGtk()
 {
   DBG_fprintf(stderr, "Abinit: declare a new interactive tab.\n");
 #ifdef HAVE_ABINIT_SYMMETRY
-  gtkInteractiveAdd_action(buildTab, startSelect, stopSelect);
+  visu_ui_interactive_addAction(buildTab, startSelect, stopSelect);
 #endif
 
   return TRUE;
@@ -135,12 +142,16 @@ const char* abinitGet_icon()
 
 static void abStructuralInit(VisuRendering *method)
 {
-  char *type[] = {"*.in", (char*)0};
+#ifdef HAVE_NEW_WITH_PSEUDO
+  const gchar *type[] = {"*.in", "*.files", (char*)0};
+#else
+  const gchar *type[] = {"*.in", (char*)0};
+#endif
   
   visu_rendering_addFileFormat(method, 0,
                                tool_file_format_new(_("ABINIT input file format"),
                                                     type),
-                               95, loadAbinitIn, (GDestroyNotify)0);
+                               95, loadAbinitIn);
 }
 
 static GMutex *dt_mutex = (GMutex*)0;
@@ -176,7 +187,8 @@ AbinitData* abinit_getDirectDt()
 }
 
 static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
-			     ToolFileFormat *format _U_, int nSet, GError **error)
+			     ToolFileFormat *format _U_, int nSet,
+                             GCancellable *cancel, GError **error)
 {
 #ifdef G_THREADS_ENABLED
   GThread *ld_thread;
@@ -197,7 +209,7 @@ static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
   /* Read the file, since it's the first time. */
   dt = abinit_getDirectDt();
   dt->dt          = (Ab6Invars*)0;
-  dt->filename    = filename;
+  dt->filename    = g_strdup(filename);
   dt->error       = (GError*)0;
   dt->isABFormat  = FALSE;
   dt->data        = data;
@@ -206,6 +218,7 @@ static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
   dt->messages    = g_async_queue_new();
   dt->useSignals  = TRUE;
   dt->signals     = g_async_queue_new();
+  dt->cancel      = cancel;
 #ifdef G_THREADS_ENABLED
   abinit_mutexInit();
   ld_thread = g_thread_create(parseAbinitThread, (gpointer)0, FALSE, error);
@@ -234,6 +247,8 @@ static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
   g_async_queue_unref(dt->messages);
   abinit_mutexRelease();
 
+  g_free(dt->filename);
+
   DBG_fprintf(stderr, "AB structure: file parsed, returns %d.\n", dt->isABFormat);
   return dt->isABFormat;
 }
@@ -242,6 +257,7 @@ static gpointer parseAbinitThread(gpointer data _U_)
 {
   AbinitData *dt;
   Ab6Invars *dt_;
+  gchar **pseudos;
 
   DBG_fprintf(stderr, "AB(%p) main: get the dt structure.\n",
               (gpointer)g_thread_self());
@@ -251,14 +267,32 @@ static gpointer parseAbinitThread(gpointer data _U_)
   /* Send a signal to V_Sim to say that parsing will start. */
   g_async_queue_push(dt->signals, GINT_TO_POINTER(TRUE));
 
-  /* Read the file and store its contain as a string. */
-  DBG_fprintf(stderr, "AB(%p) main: read and store input file.\n",
+  /* Try to see if the provided file is a *.files with pseudo
+     information. */
+  pseudos = readPseudoFiles(dt);
+  if (!dt->error)
+    {
+      /* Read the file and store its contain as a string. */
+      DBG_fprintf(stderr, "AB(%p) main: read and store input file '%s'.\n",
+                  (gpointer)g_thread_self(), dt->filename);
+#ifdef HAVE_NEW_WITH_PSEUDO
+      DBG_fprintf(stderr, "AB(%p) main: pseudo list %p.\n",
+                  (gpointer)g_thread_self(), (gpointer)pseudos);
+      dt_ = ab6_invars_new_from_file_with_pseudo(dt->filename, (const char**)pseudos);
+#else
+      dt_ = ab6_invars_new_from_file(dt->filename);
+      if (pseudos)
+        g_warning("Unsupported ABINIT input file with pseudo-potential information.");
+#endif
+      if (pseudos)
+        g_strfreev(pseudos);
+
+      /* If we reach here, it means that no error happened. */
+      dt->dt = dt_;
+    }
+
+  DBG_fprintf(stderr, "AB(%p) main: unlock mutex, other thread can access dt.\n",
               (gpointer)g_thread_self());
-  dt_ = ab6_invars_new_from_file(dt->filename);
-
-  /* If we reach here, it means that no error happened. */
-  dt->dt = dt_;
-
   abinit_mutexUnlock();
 
   return (gpointer)0;
@@ -272,9 +306,8 @@ static gboolean waitDt(gpointer data _U_)
   dt = abinit_getDirectDt();
 
   /* We stop on cancel, without error. */
-  if (visu_basic_getLoadCancel())
+  if (g_cancellable_is_cancelled(dt->cancel))
     {
-      visu_basic_setLoadCancel(FALSE);
       /* We push a message in the queue to be tested by ABINIT. */
       g_async_queue_push(dt->signals, GINT_TO_POINTER(TRUE));
       return TRUE;
@@ -283,7 +316,7 @@ static gboolean waitDt(gpointer data _U_)
   mess = g_async_queue_try_pop(dt->messages);
   if (mess)
     {
-      visu_basic_setLoadMessage((const gchar*)mess);
+      visu_object_setLoadMessage(VISU_OBJECT_INSTANCE, (const gchar*)mess);
       g_free(mess);
     }
 
@@ -335,6 +368,92 @@ static void freeDt(gpointer dt)
   ab6_invars_free((Ab6Invars*)dt);
 }
 
+static gchar** readPseudoFiles(AbinitData *dt)
+{
+  GIOChannel *ioFile;
+  GString *line= (GString*)0;
+  gchar *inFile;
+  GList *lst, *tmpLst;
+  gchar **out;
+  int i;
+
+  DBG_fprintf(stderr, "AB(%p) main: read '%s' to find pseudo files.\n",
+              (gpointer)g_thread_self(), dt->filename);
+  
+  ioFile = g_io_channel_new_file(dt->filename, "r", NULL);
+  if (!ioFile)
+    return (gchar**)0;
+
+  line = g_string_new("");
+  if (g_io_channel_read_line_string(ioFile, line, NULL, NULL) != G_IO_STATUS_NORMAL)
+    {
+      g_io_channel_shutdown(ioFile, FALSE, NULL);
+      g_io_channel_unref(ioFile);
+      g_string_free(line, TRUE);
+
+      return (gchar**)0;
+    }
+  inFile = g_strstrip(g_strdup(line->str));
+  /* We test inFile in case. */
+  DBG_fprintf(stderr, "AB(%p) main: testing '%s' as input file.\n",
+              (gpointer)g_thread_self(), inFile);
+  if (!g_file_test(inFile, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
+    {
+      g_io_channel_shutdown(ioFile, FALSE, NULL);
+      g_io_channel_unref(ioFile);
+      g_string_free(line, TRUE);
+      g_free(inFile);
+
+      return (gchar**)0;
+    }
+
+  /* From now on, we consider that we have a valid *.files file. */
+  for (i = 0; i < 4; i++)
+    if (g_io_channel_read_line_string(ioFile, line, NULL, &dt->error) != G_IO_STATUS_NORMAL)
+      {
+        g_io_channel_shutdown(ioFile, FALSE, NULL);
+        g_io_channel_unref(ioFile);
+        g_string_free(line, TRUE);
+        g_free(inFile);
+
+        return (gchar**)0;
+      }
+
+  lst = (GList*)0;
+  while (g_io_channel_read_line_string(ioFile, line, NULL, &dt->error) == G_IO_STATUS_NORMAL)
+    {
+      lst = g_list_append(lst, (gpointer)g_strstrip(g_strdup(line->str)));
+      DBG_fprintf(stderr, "AB(%p) main: testing '%s' as a pseudo.\n",
+                  (gpointer)g_thread_self(), (gchar*)lst->data);
+      if (!g_file_test((const gchar*)lst->data, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
+        {
+          dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+                                  "Invalid psedo-potential file '%s'.",
+                                  (const gchar*)lst->data);
+          g_io_channel_shutdown(ioFile, FALSE, NULL);
+          g_io_channel_unref(ioFile);
+          g_string_free(line, TRUE);
+          g_free(inFile);
+          for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
+            g_free(tmpLst->data);
+          g_list_free(lst);
+
+          return (gchar**)0;
+        }
+    }
+  g_string_free(line, TRUE);
+
+  out = g_malloc(sizeof(gchar*) * (g_list_length(lst) + 1));
+  for (i = 0, tmpLst = lst; tmpLst; i++, tmpLst = g_list_next(tmpLst))
+    out[i] = tmpLst->data;
+  out[i] = (gchar*)0;
+  g_list_free(lst);
+  g_free(dt->filename);
+  dt->filename = inFile;
+
+  return out;
+}
+
 void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500], char mode_paral[4])
 {
   gchar *buf, *ptError, *ptInvars0, *ptInstrng, *ptSize, *ptLen, *ptMinus;
@@ -363,6 +482,8 @@ void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500], char mode_paral[4])
   ptError = strstr(buf, "ERROR");
   if (!ptError)
     ptError = strstr(buf, "BUG");
+  if (!ptError)
+    ptError = strstr(buf, "Error");
   ptInvars0 = strstr(buf, "Input natom must be defined");
   ptInstrng = strstr(buf, "The occurence of a tab");
   ptSize    = strstr(buf, "The size of your input file");
@@ -428,19 +549,24 @@ void FC_FUNC(leave_new, LEAVE_NEW)(char mode_paral[4])
 void FC_FUNC(timab, TIMAB)()
 {
 }
+void FC_FUNC(psp_from_data, PSP_FROM_DATA)()
+{
+}
 
 static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
 {
-  int ndtset, i, res;
+  int ndtset, i;
   int ntypat, natom, nzero, *index;
   int *typat;
   double *znucl, rprimd[3][3], *coord, *spinat;
-  VisuElement **types, **ntypes;
+  VisuElement **ntypes;
+  VisuElement *ele;
   float rcov, red[3];
   char *ptChar, *name;
-  unsigned int *nattyp;
+  GArray *nattyp, *types;
   Ab6Error error;
   gboolean newEle;
+  VisuBox *boxObj;
 
   g_return_val_if_fail(dt, (GError*)0);
 
@@ -487,38 +613,39 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
     }
 
   znucl = g_malloc(sizeof(double) * ntypat);
-  types = g_malloc(sizeof(VisuElement*) * ntypat);
-  nattyp = g_malloc(sizeof(unsigned int) * ntypat);
   error = ab6_invars_get_real_array(dt, znucl, ntypat,
 				    AB6_INVARS_ZNUCL, nSet + 1);
   if (error != AB6_NO_ERROR)
     {
-      g_free(typat); g_free(znucl); g_free(types); g_free(nattyp);
+      g_free(typat); g_free(znucl);
       return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
 			 AB6_INVARS_STR(AB6_INVARS_ZNUCL));
     }
   DBG_fprintf(stderr, "AB structure: read znucl OK.\n");
+  types = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), ntypat);
   for (i = 0; i < ntypat; i++)
     {
       /* Try to find a name instead of a z number. */
-      tool_physic_getElementFromZ(&ptChar, &rcov, znucl[i]);
+      tool_physic_getSymbolFromZ(&ptChar, &rcov, znucl[i]);
       name = g_strdup(ptChar);
       /* adding name to the hashtable */
-      types[i] = visu_element_retrieveFromName(name, &newEle);
+      ele = visu_element_retrieveFromName(name, &newEle);
+      g_array_insert_val(types, i, ele);
       if (newEle)
-        visu_renderingAtomic_setRadius(types[i], rcov);
+        visu_rendering_atomic_setRadius(ele, rcov);
       g_free(name);
     }
   g_free(znucl);
   DBG_fprintf(stderr, "AB structure: all new elements created.\n");
-  memset(nattyp, 0, sizeof(unsigned int) * ntypat);
+  nattyp = g_array_sized_new(FALSE, TRUE, sizeof(guint), ntypat);
+  g_array_set_size(nattyp, ntypat);
   ntypes = g_malloc(sizeof(VisuElement*) * natom);
   for (i = 0; i < natom; i++)
     {
-      nattyp[typat[i] - 1] += 1;
-      ntypes[i] = types[typat[i] - 1];
+      g_array_index(nattyp, guint, typat[i] - 1) += 1;
+      ntypes[i] = g_array_index(types, VisuElement*, typat[i] - 1);
     }
   /* Reduce the arrays when nattyp is 0. */
   nzero = 0;
@@ -527,11 +654,11 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
     {
       if (i > nzero)
 	{
-	  nattyp[nzero] = nattyp[i];
-	  types[nzero]  = types[i];
+	  g_array_index(nattyp, guint, nzero)       = g_array_index(nattyp, guint, i);
+	  g_array_index(types, VisuElement*, nzero) = g_array_index(types, VisuElement*, i);
 	}
       index[i] = nzero;
-      if (nattyp[i] > 0)
+      if (g_array_index(nattyp, guint, i) > 0)
 	nzero += 1;
     }
   DBG_fprintf(stderr, "AB structure: removing null types.\n");
@@ -539,26 +666,25 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
     {
       DBG_fprintf(stderr, "AB structure: atom %d (%d)", i, typat[i] - 1);
       DBG_fprintf(stderr, " -> %d.\n", index[typat[i] - 1]);
-      ntypes[i] = types[index[typat[i] - 1]];
+      ntypes[i] = g_array_index(types, VisuElement*, index[typat[i] - 1]);
     }
   g_free(typat);
   g_free(index);
   ntypat = nzero;
+  g_array_set_size(types, ntypat);
+  g_array_set_size(nattyp, ntypat);
 
   DBG_fprintf(stderr, "AB structure: there are %d types in this file.\n", ntypat);
   if (DEBUG)
     for (i = 0; i < ntypat; i++)
-      fprintf(stderr, " | %d atom(s) for type %d.\n", nattyp[i], i);
+      fprintf(stderr, " | %d atom(s) for type %d.\n",
+              g_array_index(nattyp, guint, i), i);
   if (DEBUG)
     for (i = 0; i < natom; i++)
       fprintf(stderr, " | atom %d of type %p.\n", i, (gpointer)ntypes[i]);
-  res = visu_data_setPopulation(data, ntypat, nattyp, types);
-  if (!res)
-    {
-      g_error("Can't store the nodes in the VisuData object.");
-    }
-  g_free(nattyp);
-  g_free(types);
+  visu_node_array_allocate(VISU_NODE_ARRAY(data), types, nattyp);
+  g_array_free(nattyp, TRUE);
+  g_array_free(types, TRUE);
 
   error = ab6_invars_get_real_array(dt, (double*)rprimd, 9,
 				    AB6_INVARS_RPRIMD_ORIG, nSet + 1);
@@ -576,7 +702,9 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
 	      rprimd[1][0], rprimd[1][1], rprimd[1][2]);
   DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
 	      rprimd[2][0], rprimd[2][1], rprimd[2][2]);
-  visu_data_setBoxGeometryFull(data, rprimd, VISU_DATA_BOX_PERIODIC);
+  boxObj = visu_box_new_full(rprimd, VISU_BOX_PERIODIC);
+  visu_data_setBox(data, boxObj);
+  g_object_unref(boxObj);
   
   coord = g_malloc(sizeof(double) * 3 * natom);
   error = ab6_invars_get_real_array(dt, coord, 3 * natom,
@@ -601,12 +729,13 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
     }
   /* We reset the box size after we set all the coordinates to get the
      OpenGL box right. */
-  visu_data_applyBoxGeometry(data);
+  visu_box_setMargin(boxObj, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
+                     visu_data_getAllNodeExtens(data, boxObj), TRUE);
   g_free(ntypes);
   g_free(coord);
 
   /* We set the units. */
-  visu_data_setUnit(data, unit_bohr);
+  visu_box_setUnit(boxObj, TOOL_UNITS_BOHR);
 
   /* We store the spinat array as a property to be used later by the spin
      loading method. */
@@ -628,12 +757,12 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
 
 static void abSpinInit(VisuRendering *method)
 {
-  char *type[] = {"*.in", (char*)0};
+  const gchar *type[] = {"*.in", (char*)0};
   
   visu_rendering_addFileFormat(method, FILE_KIND_SPIN,
                                tool_file_format_new(_("ABINIT input file format"),
                                                     type),
-                               95, loadAbinitSpin, (GDestroyNotify)0);
+                               95, loadAbinitSpin);
 }
 
 static void freeSpin(gpointer obj, gpointer data _U_)
@@ -661,16 +790,26 @@ static gpointer newOrCopySpin(gconstpointer obj, gpointer data _U_)
   return (gpointer)spinData;
 }
 
+static void initMaxModulus(VisuElement *ele _U_, GValue *val)
+{
+  DBG_fprintf(stderr, " | init max modulus of val %p.\n", (gpointer)val);
+  g_value_init(val, G_TYPE_FLOAT);
+  g_value_set_float(val, -G_MAXFLOAT);
+}
+
 static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
-			       ToolFileFormat *format _U_, int nSet _U_, GError **error)
+			       ToolFileFormat *format _U_, int nSet _U_,
+                               GCancellable *cancel _U_, GError **error)
 {
   double *spinat;
   float spins[3];
-  float *svgMaxSpinModulus, *svgSpinValues;
+  float *svgSpinValues;
   float sph[3], vals[3];
   VisuNodeProperty *spin;
-  VisuDataIter iter;
+  VisuNodeArrayIter iter;
   GValue spinValue = {0, {{0}, {0}}};
+  GValueArray *svgMaxSpinModulus;
+  GValue *val;
 
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
   g_return_val_if_fail(data && filename, FALSE);
@@ -683,17 +822,16 @@ static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
   /* TODO... */
 
   /* Create a storage for max values of spin modulus for each element. */
-  svgMaxSpinModulus = g_malloc(sizeof(float) * data->ntype);
-  memset(svgMaxSpinModulus, 0, sizeof(float) * data->ntype);
-  g_object_set_data_full(G_OBJECT(data), SPINMAXMODULUS_ID,
-			 (gpointer)svgMaxSpinModulus, g_free);
-  spin = visu_node_property_newPointer(visu_data_getNodeArray(data), SPINVALUES_ID,
-				     freeSpin, newOrCopySpin, (gpointer)0);
+  svgMaxSpinModulus = visu_node_array_setElementProperty(VISU_NODE_ARRAY(data),
+                                                         VISU_RENDERING_SPIN_MAX_MODULUS_ID,
+                                                         initMaxModulus);
+  spin = visu_node_array_property_newPointer(VISU_NODE_ARRAY(data), VISU_RENDERING_SPIN_VALUES_ID,
+                                       freeSpin, newOrCopySpin, (gpointer)0);
 
   g_value_init(&spinValue, G_TYPE_POINTER);
-  visu_data_iterNew(data, &iter);
-  for(visu_data_iterStartNumber(data, &iter); iter.node;
-      visu_data_iterNextNodeNumber(data, &iter))
+  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
+  for(visu_node_array_iterStartNumber(VISU_NODE_ARRAY(data), &iter); iter.node;
+      visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(data), &iter))
     {
       spins[0] = (float)(spinat + iter.node->number * 3)[0];
       spins[1] = (float)(spinat + iter.node->number * 3)[1];
@@ -705,8 +843,9 @@ static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
       svgSpinValues = newOrCopySpin(vals, (gpointer)0);
       g_value_set_pointer(&spinValue, svgSpinValues);
       visu_node_property_setValue(spin, iter.node, &spinValue);
-      svgMaxSpinModulus[iter.iElement] = MAX(vals[TOOL_MATRIX_SPHERICAL_MODULUS],
-					     svgMaxSpinModulus[iter.iElement]);
+      val = g_value_array_get_nth(svgMaxSpinModulus, iter.iElement);
+      g_value_set_float(val, MAX(vals[TOOL_MATRIX_SPHERICAL_MODULUS],
+                                 g_value_get_float(val)));
     }
 
   /* We kill the temporary spinat property. */
