@@ -2,6 +2,7 @@
 #define ABINIT_H
 
 #include <glib.h>
+#include <gio/gio.h>
 #include <config.h>
 #include <visu_data.h>
 
@@ -13,6 +14,7 @@
 struct _abinitData
 {
   VisuData *data;
+  GCancellable *cancel;
   GError *error;
 
   /* Queue to send messages from V_Sim to ABINIT thread. */
@@ -26,7 +28,7 @@ struct _abinitData
 
   /* Data for the invars part. */
   Ab6Invars *dt;
-  const gchar *filename;
+  gchar *filename;
   int nSet;
   gboolean isABFormat;
 
