@@ -57,34 +57,19 @@
 #include <visu_basic.h>
 
 /* Local methods. */
-gboolean nqDensityLoad(const gchar *filename, GList **fieldList,
-                       GError **error, GHashTable *table);
+gboolean nqDensityLoad(VisuScalarFieldMethod *meth, const gchar *filename, GList **fieldList,
+                       GError **error);
 
 void nqDensityInit()
 {
-  char *type[] = {"*.nc", "*-etsf.nc", (char*)0};
-  char *descr = _("Nanoquanta NETCDF format");
-  ToolFileFormat *fmt;
+  const gchar *type[] = {"*.nc", "*-etsf.nc", (char*)0};
+  const gchar *descr = _("Nanoquanta NETCDF format");
   
-  fmt = tool_file_format_new(descr, type);
-  scalarFieldAdd_loadMethod("Nanoquanta file", nqDensityLoad,
-			    fmt, G_PRIORITY_HIGH);
+  visu_scalar_field_method_new(descr, type, nqDensityLoad, G_PRIORITY_HIGH);
 }
 
-static void grepOptionValues(GHashTable *table, int *spinValue, int *realOrComplex)
-{
-  ToolOption *option;
-
-  option = (ToolOption*)g_hash_table_lookup(table, "number_of_components");
-  if (option)
-    *spinValue = g_value_get_int(tool_option_getValue(option));
-  option = (ToolOption*)g_hash_table_lookup(table, "real_or_complex");
-  if (option)
-    *realOrComplex = g_value_get_int(tool_option_getValue(option));
-}
-
-gboolean nqDensityLoad(const gchar *filename, GList **fieldList,
-                       GError **error, GHashTable *table)
+gboolean nqDensityLoad(VisuScalarFieldMethod *meth _U_, const gchar *filename, GList **fieldList,
+                       GError **error)
 {
   gboolean res;
   int netcdfId, varId, status, i, j;
@@ -98,12 +83,13 @@ gboolean nqDensityLoad(const gchar *filename, GList **fieldList,
   size_t startDensity[] = {0, 0, 0, 0, 0};
   int varIdDensity;
   size_t dimsDensity[5];
-  double *density;
+  GArray *density;
   double boxGeometry[6];
-  int size[3];
+  VisuBox *box;
+  guint size[3];
   int option_spin, option_realOrComplex;
   ToolOption *option;
-  ScalarField *field;
+  VisuScalarField *field;
   nc_type ncType;
   size_t sizeTitle;
   char title[256];
@@ -141,9 +127,15 @@ gboolean nqDensityLoad(const gchar *filename, GList **fieldList,
 
   /* We parse a first time the options, if given. */
   option_spin = -1;
+  option = tool_file_format_getPropertyByName(TOOL_FILE_FORMAT(meth),
+                                              "number_of_components");
+  if (option)
+    option_spin = g_value_get_int(tool_option_getValue(option));
   option_realOrComplex = -1;
-  if (table)
-    grepOptionValues(table, &option_spin, &option_realOrComplex);
+  option = tool_file_format_getPropertyByName(TOOL_FILE_FORMAT(meth),
+                                              "real_or_complex");
+  if (option)
+    option_realOrComplex = g_value_get_int(tool_option_getValue(option));
 
   /* We now have a valid NetCDF file.
      We check the existence and the shape of all
@@ -243,7 +235,9 @@ gboolean nqDensityLoad(const gchar *filename, GList **fieldList,
     }
   
   /* Get one part of the density. */
-  density = g_malloc(sizeof(double) * gridSize[2] * gridSize[1] * gridSize[0]);
+  density = g_array_sized_new(FALSE, FALSE, sizeof(double),
+                              gridSize[2] * gridSize[1] * gridSize[0]);
+  density = g_array_set_size(density, gridSize[2] * gridSize[1] * gridSize[0]);
   
   for (i = (option_spin < 0)?0:option_spin ;
        i < ((option_spin < 0)?(int)spinDim:option_spin + 1) ; i++)
@@ -254,28 +248,31 @@ gboolean nqDensityLoad(const gchar *filename, GList **fieldList,
 	startDensity[4] = j;
 	dimsDensity[0] = 1;
 	dimsDensity[4] = 1;
-	status = nc_get_vara_double(netcdfId, varIdDensity, startDensity, dimsDensity, &density[0]);
+	status = nc_get_vara_double(netcdfId, varIdDensity, startDensity, dimsDensity,
+                                    (double*)density->data);
 	if (status != NC_NOERR)
 	  {
 	    *error = g_error_new(NQ_ERROR, NQ_ERROR_FILE_FORMAT,
 				 _("Retrieve value for variable 'density': %s."),
 				 nc_strerror(status));
 	    nqClose_netcdfFile(netcdfId);
-	    g_free(density);
+	    g_array_unref(density);
 	    return TRUE;
 	  }
 	/* Ok, now everything is in memory, we can populate the field object. */
-	field = scalarFieldNew(filename);
+	field = visu_scalar_field_new(filename);
 	if (!field)
-	  g_warning("impossible to create a ScalarField object.");
+	  g_warning("impossible to create a VisuScalarField object.");
 	else
 	  {
-	    scalarFieldSet_periodic(field, TRUE);
-	    scalarFieldSet_commentary(field, comment);
-	    scalarFieldSet_box(field, boxGeometry);
-	    scalarFieldSet_gridSize(field, size);
+	    visu_scalar_field_setCommentary(field, comment);
+            box = visu_box_new(boxGeometry, VISU_BOX_PERIODIC);
+            visu_box_setMargin(box, 0.f, FALSE);
+            visu_boxed_setBox(VISU_BOXED(field), VISU_BOXED(box), FALSE);
+            g_object_unref(box);
+	    visu_scalar_field_setGridSize(field, size);
 	    DBG_fprintf(stderr, "NQ Density : transfer density into field object.\n");
-	    scalarFieldSet_data(field, density, TRUE);
+	    visu_scalar_field_setData(field, density, TRUE);
 	    if ((int)spinDim == 1)
 	      option = tool_option_new("number_of_components",
 				      _("1, no spin information"), G_TYPE_INT);
@@ -290,11 +287,11 @@ gboolean nqDensityLoad(const gchar *filename, GList **fieldList,
 	      option = tool_option_new("number_of_components",
 				      _("unknown value"), G_TYPE_INT);
 	    g_value_set_int(tool_option_getValue(option), i + 1);
-	    scalarFieldAdd_option(field, option);
+	    visu_scalar_field_addOption(field, option);
 	    *fieldList = g_list_append(*fieldList, (gpointer)field);
 	  }
       }
-  g_free(density);
+  g_array_unref(density);
   if (comment)
     g_free(comment);
 
