@@ -44,6 +44,9 @@
 
 #include "xsf.h"
 #include "xsf_density.h"
+
+#include <string.h>
+
 #include <visu_tools.h>
 #include <visu_basic.h>
 #include <renderingMethods/renderingAtomic.h>
@@ -60,9 +63,11 @@
 
 /* Local methods */
 static gboolean loadXsfIn(VisuData *data, const gchar* filename,
-			  ToolFileFormat *format _U_, int nSet, GError **error);
+			  ToolFileFormat *format, int nSet,
+                          GCancellable *cancel, GError **error);
 static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
-			    ToolFileFormat *format _U_, int nSet _U_, GError **error);
+			    ToolFileFormat *format, int nSet,
+                            GCancellable *cancel, GError **error);
 static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **error);
 static void xsfStructuralInit(VisuRendering *method);
 static void xsfSpinInit(VisuRendering *method);
@@ -105,16 +110,17 @@ const char* xsfGet_icon()
 
 static void xsfStructuralInit(VisuRendering *method)
 {
-  char *type[] = {"*.xsf", "*.axsf", (char*)0};
+  const gchar *type[] = {"*.xsf", "*.axsf", (char*)0};
   
   visu_rendering_addFileFormat(method, 0,
                                tool_file_format_new(_("XCrysDen Structure File format"),
                                                     type),
-                               90, loadXsfIn, (GDestroyNotify)0);
+                               90, loadXsfIn);
 }
 
 static gboolean loadXsfIn(VisuData *data, const gchar* filename,
-			  ToolFileFormat *format _U_, int nSet, GError **error)
+			  ToolFileFormat *format _U_, int nSet,
+                          GCancellable *cancel _U_, GError **error)
 {
   int res;
   GIOChannel *readFrom;
@@ -148,7 +154,7 @@ void xsf_reader_new(struct xsf_reader *rd)
   rd->ntype     = 0;
   rd->elements  = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
   rd->nodeTypes = (VisuElement**)0;
-  rd->bc        = VISU_DATA_BOX_FREE;
+  rd->bc        = VISU_BOX_FREE;
 
   rd->coords    = (float*)0;
   rd->forces    = (float*)0;
@@ -245,17 +251,17 @@ static gboolean read_periodicity(struct xsf_reader *rd, GError **error)
   if (!xsf_reader_get_flag(rd, &found, "MOLECULE", (int*)0, FALSE, error))
     return FALSE;
   if (found)
-    rd->bc = VISU_DATA_BOX_FREE;
+    rd->bc = VISU_BOX_FREE;
 
   if (!xsf_reader_get_flag(rd, &found, "SLAB", (int*)0, FALSE, error))
     return FALSE;
   if (found)
-    rd->bc = VISU_DATA_BOX_SURFACE_XY;
+    rd->bc = VISU_BOX_SURFACE_XY;
 
   if (!xsf_reader_get_flag(rd, &found, "CRYSTAL", (int*)0, FALSE, error))
     return FALSE;
   if (found)
-    rd->bc = VISU_DATA_BOX_PERIODIC;
+    rd->bc = VISU_BOX_PERIODIC;
 
   return TRUE;
 }
@@ -315,7 +321,8 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
       if (!ptChar)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			       _("Wrong XSF format, can't read coordinates.\n"));
+			       _("Wrong XSF format, can't read coordinates at line '%s'.\n"),
+                               name);
 	  return FALSE;
 	}
       *ptChar = '\0';
@@ -326,7 +333,8 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
       if (nb != 3 && nb != 6)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			       _("Wrong XSF format, can't read coordinates.\n"));
+			       _("Wrong XSF format, can't read coordinates from '%s' (only %d read).\n"),
+                               ptChar + 1, nb);
 	  return FALSE;
 	}
       if (nb == 6)
@@ -341,7 +349,7 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
       /* Try to find a z number instead of a name. */
       rcov = -1.f;
       if (sscanf(name, "%d", &zele) == 1 &&
-	  tool_physic_getElementFromZ(&ptChar, &rcov, zele))
+	  tool_physic_getSymbolFromZ(&ptChar, &rcov, zele))
 	{
 	  g_free(name);
 	  name = g_strdup(ptChar);
@@ -377,9 +385,10 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
   int valInt;
   double box[3][3];
   int i;
-  int res, nSets, iNodes;
-  VisuElement **types;
-  unsigned int *nattyp;
+  int nSets, iNodes;
+  GArray *nattyp, *types;
+  VisuBox *boxObj;
+  float xyz[3];
 
   /* We read every line that corresponds to this schema : "%s %f %f %f" */
   DBG_fprintf(stderr, "XSF: reading file as an xsf file.\n");
@@ -436,7 +445,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	}
       if (found && (valInt < 0 || (valInt - 1) == nSet))
 	{
-	  if (rd.bc == VISU_DATA_BOX_FREE)
+	  if (rd.bc == VISU_BOX_FREE)
 	    {
 	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 				   _("Wrong XSF format, primitive vectors found"
@@ -466,7 +475,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	}
       if (found && (valInt < 0 || (valInt - 1) == nSet))
 	{
-	  if (rd.bc == VISU_DATA_BOX_FREE)
+	  if (rd.bc == VISU_BOX_FREE)
 	    {
 	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 				   _("Wrong XSF format, primitive coordinates found"
@@ -495,7 +504,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	}
       if (found && (valInt < 0 || (valInt - 1) == nSet))
 	{
-	  if (rd.bc != VISU_DATA_BOX_FREE)
+	  if (rd.bc != VISU_BOX_FREE)
 	    {
 	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 				   _("Wrong XSF format, atom coordinates found"
@@ -533,39 +542,45 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
     }
 
   /* Allocate the space for the nodes. */
-  types  = g_malloc(sizeof(VisuElement*) * rd.ntype);
-  nattyp = g_malloc(sizeof(int) * rd.ntype);
-  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
-  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
+  types  = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), rd.ntype);
+  nattyp = g_array_sized_new(FALSE, FALSE, sizeof(guint), rd.ntype);
+  g_array_set_size(types, rd.ntype);
+  g_array_set_size(nattyp, rd.ntype);
+  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToType, (gpointer)types);
+  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)nattyp);
 
   DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
   /* Begin the storage into VisuData. */
   visu_data_setNSubset(data, nSets);
 
-  res = visu_data_setPopulation(data, rd.ntype, nattyp, types);
-  if (!res)
-    {
-      g_error("Can't store the nodes in the VisuData object.");
-    }
+  visu_node_array_allocate(VISU_NODE_ARRAY(data), types, nattyp);
   DBG_fprintf(stderr, "XSF: there are %d types in this file.\n", rd.ntype);
   if (DEBUG)
     for (i = 0; i < rd.ntype; i++)
-      fprintf(stderr, " | %d atom(s) for type %d.\n", nattyp[i], i);
-  g_free(nattyp);
-  g_free(types);
+      fprintf(stderr, " | %d atom(s) for type %d.\n",
+              g_array_index(nattyp, guint, i), i);
+  g_array_free(nattyp, TRUE);
+  g_array_free(types, TRUE);
          
   /* Store the coordinates */
-  visu_data_setBoxGeometryFull(data, box, rd.bc);
+  boxObj = visu_box_new_full(box, rd.bc);
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj), FALSE);
+  g_object_unref(boxObj);
   for(iNodes = 0; iNodes < rd.nNodes; iNodes++)
-    visu_data_addNodeFromElement(data, rd.nodeTypes[iNodes],
-                                 rd.coords + 3 * iNodes, FALSE, FALSE);
-  visu_data_applyBoxGeometry(data);
-  visu_data_setUnit(data, unit_angstroem);
+    {
+      visu_box_convertFullToCell(boxObj, xyz, rd.coords + 3 * iNodes);
+      visu_data_addNodeFromElement(data, rd.nodeTypes[iNodes],
+                                   xyz, FALSE, FALSE);
+    }
+  visu_box_setMargin(boxObj, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
+                     visu_data_getAllNodeExtens(data, boxObj), TRUE);
+  visu_box_setUnit(boxObj, TOOL_UNITS_ANGSTROEM);
 
   /* We store the forces as a property to be used later by the spin
      loading method. */
   if (rd.forces)
     {
+      visu_rendering_atomic_setForces(data, rd.forces);
       g_object_set_data_full(G_OBJECT(data), "XSF_forces",
 			     (gpointer)rd.forces, g_free);
       /* We nullify the rd.forces pointer to avoid its deletion. */
@@ -605,22 +620,32 @@ static gpointer newOrCopySpin(gconstpointer obj, gpointer data _U_)
 
 static void xsfSpinInit(VisuRendering *method)
 {
-  char *type[] = {"*.xsf", "*.axsf", (char*)0};
+  const gchar *type[] = {"*.xsf", "*.axsf", (char*)0};
 
   visu_rendering_addFileFormat(method, FILE_KIND_SPIN,
                                tool_file_format_new(_("XCrysDen Structure File format"),
                                                     type),
-                               40, loadXsfSpin, (GDestroyNotify)0);
+                               40, loadXsfSpin);
+}
+
+static void initMaxModulus(VisuElement *ele _U_, GValue *val)
+{
+  DBG_fprintf(stderr, " | init max modulus of val %p.\n", (gpointer)val);
+  g_value_init(val, G_TYPE_FLOAT);
+  g_value_set_float(val, -G_MAXFLOAT);
 }
 
 static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
-			    ToolFileFormat *format _U_, int nSet _U_, GError **error)
+			    ToolFileFormat *format _U_, int nSet _U_,
+                            GCancellable *cancel _U_, GError **error)
 {
-  float *forces, *svgMaxSpinModulus, *svgSpinValues;
+  float *forces, *svgSpinValues;
+  GValueArray *svgMaxSpinModulus;
   float sph[3], vals[3];
   VisuNodeProperty *spin;
-  VisuDataIter iter;
+  VisuNodeArrayIter iter;
   GValue spinValue = {0, {{0}, {0}}};
+  GValue *val;
 
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
   g_return_val_if_fail(data && filename, FALSE);
@@ -633,27 +658,26 @@ static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
   /* TODO... */
 
   /* Create a storage for max values of spin modulus for each element. */
-  svgMaxSpinModulus = g_malloc(sizeof(float) * data->ntype);
-  memset(svgMaxSpinModulus, 0, sizeof(float) * data->ntype);
-  g_object_set_data_full(G_OBJECT(data), SPINMAXMODULUS_ID,
-			 (gpointer)svgMaxSpinModulus, g_free);
-  spin = visu_node_property_newPointer(visu_data_getNodeArray(data), SPINVALUES_ID,
-				     freeSpin, newOrCopySpin, (gpointer)0);
+  svgMaxSpinModulus = visu_node_array_setElementProperty(VISU_NODE_ARRAY(data),
+                                                         VISU_RENDERING_SPIN_MAX_MODULUS_ID,
+                                                         initMaxModulus);
+  spin = visu_node_array_property_newPointer(VISU_NODE_ARRAY(data), VISU_RENDERING_SPIN_VALUES_ID,
+                                       freeSpin, newOrCopySpin, (gpointer)0);
 
   g_value_init(&spinValue, G_TYPE_POINTER);
-  visu_data_iterNew(data, &iter);
-  for(visu_data_iterStartNumber(data, &iter); iter.node;
-      visu_data_iterNextNodeNumber(data, &iter))
+  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
+  for(visu_node_array_iterStartNumber(VISU_NODE_ARRAY(data), &iter); iter.node;
+      visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(data), &iter))
     {
-      visu_data_convertFullCartesianToSpherical(data, sph, forces + iter.node->number * 3);
-      vals[TOOL_MATRIX_SPHERICAL_MODULUS] = sph[0];
-      vals[TOOL_MATRIX_SPHERICAL_THETA]   = sph[1];
-      vals[TOOL_MATRIX_SPHERICAL_PHI]     = sph[2];
-      svgSpinValues = newOrCopySpin(vals, (gpointer)0);
+      visu_box_convertFullToCell(visu_boxed_getBox(VISU_BOXED(data)), vals,
+                                 forces + iter.node->number * 3);
+      tool_matrix_cartesianToSpherical(sph, vals);
+      svgSpinValues = newOrCopySpin(sph, (gpointer)0);
       g_value_set_pointer(&spinValue, svgSpinValues);
       visu_node_property_setValue(spin, iter.node, &spinValue);
-      svgMaxSpinModulus[iter.iElement] = MAX(vals[TOOL_MATRIX_SPHERICAL_MODULUS],
-					     svgMaxSpinModulus[iter.iElement]);
+      val = g_value_array_get_nth(svgMaxSpinModulus, iter.iElement);
+      g_value_set_float(val, MAX(vals[TOOL_MATRIX_SPHERICAL_MODULUS],
+                                 g_value_get_float(val)));
     }
 
   /* We kill the temporary forces property. */
