@@ -44,6 +44,8 @@
 
 #include "toolColor.h"
 
+#include <string.h>
+
 #include <glib.h>
 
 #include <visu_tools.h>
@@ -65,12 +67,37 @@
  * tool_color_getByValues() or tool_color_getByColor().</para>
  */
 
+static ToolColor* color_copy(ToolColor *boxed);
+
 /******************/
 /* Storing colors */
 /******************/
 #define COLOR_NB_MAX 10
 GList *color_storageArray = (GList*)0;
 
+#define N_BRIGHT_COLORS 20
+static ToolColor brightColors[N_BRIGHT_COLORS] =
+  {{{1,0,0, 1.f}, (gpointer)0},
+   {{0,1,0, 1.f}, (gpointer)0},
+   {{0,0,1, 1.f}, (gpointer)0},
+   {{1,0,1, 1.f}, (gpointer)0},
+   {{0,1,1, 1.f}, (gpointer)0},
+   {{1,1,0, 1.f}, (gpointer)0},
+   {{1,0.5,0, 1.f}, (gpointer)0},
+   {{0.5,0,0.5, 1.f}, (gpointer)0},
+   {{0,0.5,0.5, 1.f}, (gpointer)0},
+   {{0.5,0.5,0, 1.f}, (gpointer)0},
+   {{0.5,0,0, 1.f}, (gpointer)0},
+   {{0,0.5,0, 1.f}, (gpointer)0},
+   {{0,0,0.5, 1.f}, (gpointer)0},
+   {{0.5,0.5,0.5, 1.f}, (gpointer)0},
+   {{1,0,0.5, 1.f}, (gpointer)0},
+   {{0.5,1,0, 1.f}, (gpointer)0},
+   {{0.5,0,1, 1.f}, (gpointer)0},
+   {{0,1,0.5, 1.f}, (gpointer)0},
+   {{0,0.5,1, 1.f}, (gpointer)0},
+   {{0,0,0, 1.f}, (gpointer)0}};
+
 /******************/
 /* Storing colors */
 /******************/
@@ -89,6 +116,42 @@ void tool_color_freeAll(void)
     g_list_free(lst);
 }
 
+/**
+ * tool_color_new_bright:
+ * @id: an index
+ *
+ * V_Sim has a list of 20 bright colors. One can get one by calling
+ * this routine. The @id is taken modulo the number of available colors.
+ *
+ * Since: 3.7
+ *
+ * Returns: (transfer none): a bright color.
+ **/
+const ToolColor* tool_color_new_bright(guint id)
+{
+  return brightColors + (id % N_BRIGHT_COLORS);
+}
+
+/**
+ * tool_color_get_type:
+ *
+ * Create and retrieve a #GType for a #ToolColor object.
+ *
+ * Since: 3.7
+ *
+ * Returns: a new type for #ToolColor structures.
+ */
+GType tool_color_get_type(void)
+{
+  static GType g_define_type_id = 0;
+
+  if (g_define_type_id == 0)
+    g_define_type_id = g_boxed_type_register_static("ToolColor", 
+                                                    (GBoxedCopyFunc)color_copy,
+                                                    (GBoxedFreeFunc)g_free);
+  return g_define_type_id;
+}
+
 /**
  * tool_color_new:
  * @rgba: four values between 0. and 1. that represent [Red, Green, Blue, Alpha].
@@ -131,6 +194,7 @@ gboolean tool_color_equal(ToolColor *color1, ToolColor *color2)
 	  color1->rgba[1] == color2->rgba[1] &&
 	  color1->rgba[2] == color2->rgba[2]);
 }
+
 /**
  * tool_color_getById:
  * @num: an integer (>0).
@@ -223,6 +287,17 @@ GList* tool_color_getStoredColors(void)
 {
   return color_storageArray;
 }
+static ToolColor* color_copy(ToolColor *boxed)
+{
+  ToolColor *color;
+
+  if (!boxed)
+    return (ToolColor*)0;
+
+  color = g_malloc(sizeof(ToolColor));
+  tool_color_copy(color, boxed);
+  return color;
+}
 /**
  * tool_color_copy:
  * @color: an allocated #ToolColor object to receive values ;
@@ -256,15 +331,14 @@ ToolColor* tool_color_addColor(ToolColor* color)
       color_storageArray = g_list_append(color_storageArray, (gpointer)color);
       DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
 		  (gpointer)color_storageArray, g_list_length(color_storageArray));
-      g_signal_emit(VISU_INSTANCE, VISU_SIGNALS[COLORNEWAVAILABLE_SIGNAL],
-		    0 , (gpointer)color, NULL);
+      g_signal_emit_by_name(VISU_OBJECT_INSTANCE, "colorNewAvailable", (gpointer)color, NULL);
     }
   return color;
 }
 /**
  * tool_color_addFloatRGBA:
  * @rgba: four values between 0. and 1. that represent [Red, Green, Blue, Alpha] ;
- * @position: (out caller-allocates): an int pointer to store the position
+ * @position: (out caller-allocates) (allow-none): an int pointer to store the position
  *  of the returned colour.
  *
  * This method adds a new color in the list of stored colors with the given values.
@@ -293,8 +367,7 @@ ToolColor* tool_color_addFloatRGBA(float rgba[4], int *position)
     *position = g_list_length(color_storageArray);
   DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
 	      (gpointer)color_storageArray, g_list_length(color_storageArray));
-  g_signal_emit(VISU_INSTANCE, VISU_SIGNALS[COLORNEWAVAILABLE_SIGNAL],
-		0 , (gpointer)color, NULL);
+  g_signal_emit_by_name(VISU_OBJECT_INSTANCE, "colorNewAvailable", (gpointer)color, NULL);
   return color;
 }
 /**
@@ -327,8 +400,7 @@ ToolColor* tool_color_addIntRGBA(int rgba[4])
   color_storageArray = g_list_append(color_storageArray, (gpointer)color);
   DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
 	      (gpointer)color_storageArray, g_list_length(color_storageArray));
-  g_signal_emit(VISU_INSTANCE, VISU_SIGNALS[COLORNEWAVAILABLE_SIGNAL],
-		0 , (gpointer)color, NULL);
+  g_signal_emit_by_name(VISU_OBJECT_INSTANCE, "colorNewAvailable", (gpointer)color, NULL);
   return color;
 }
 /**
