@@ -45,6 +45,7 @@
 #define TOOLCOLOR_H
 
 #include <glib.h>
+#include <glib-object.h>
 
 G_BEGIN_DECLS
 
@@ -107,8 +108,10 @@ struct _ToolColor
   gpointer userData;
 };
 
-
+#define    TOOL_TYPE_COLOR (tool_color_get_type())
+GType      tool_color_get_type(void);
 ToolColor* tool_color_new(float rgba[4]);
+const ToolColor* tool_color_new_bright(guint id);
 gboolean   tool_color_equal(ToolColor *color1, ToolColor *color2);
 void       tool_color_copy(ToolColor *color, ToolColor *color_old);
 
