@@ -58,6 +58,42 @@
  * cartesian and spherical.</para>
  */
 
+/**
+ * VisuBoxVertices:
+ * @vertices: (array fixed-size=8) (element-type ToolVector):
+ *
+ * Structure used for bindings.
+ *
+ * Since: 3.7
+ */
+
+/**
+ * VisuBoxCell:
+ * @box: (array fixed-size=6) (element-type gdouble):
+ *
+ * Structure used for bindings.
+ *
+ * Since: 3.7
+ */
+
+/**
+ * ToolVector:
+ * @vect: (array fixed-size=3) (element-type gfloat):
+ *
+ * Structure used for bindings.
+ *
+ * Since: 3.7
+ */
+
+/**
+ * ToolGridSize:
+ * @grid: (array fixed-size=3) (element-type guint):
+ *
+ * Structure used for bindings.
+ *
+ * Since: 3.7
+ */
+
 /**
  * tool_matrix_reducePrimitiveVectors:
  * @reduced: (out caller-allocates) (array fixed-size=6): a storage for 6 floating point values ;
@@ -210,6 +246,45 @@ gboolean tool_matrix_reducePrimitiveVectors(double reduced[6], double full[3][3]
   return TRUE;
 }
 
+/**
+ * tool_matrix_dtof:
+ * @mf: a matrix in single precision.
+ * @md: a matrix in double precision.
+ *
+ * Cast @md into @mf.
+ *
+ * Since: 3.7
+ **/
+void tool_matrix_dtof(float mf[3][3], double md[3][3])
+{
+  int i, j;
+
+  for (i = 0; i < 3; i++)
+    for (j = 0; j < 3; j++)
+      mf[i][j] = md[i][j];
+}
+
+/**
+ * tool_matrix_setIdentity:
+ * @mat: (array fixed-size=9): a matrix location.
+ *
+ * Initialise @mat with the identity.
+ *
+ * Since: 3.7
+ **/
+void tool_matrix_setIdentity(float mat[3][3])
+{
+  mat[0][0] = 1.f;
+  mat[0][1] = 0.f;
+  mat[0][2] = 0.f;
+  mat[1][0] = 0.f;
+  mat[1][1] = 1.f;
+  mat[1][2] = 0.f;
+  mat[2][0] = 0.f;
+  mat[2][1] = 0.f;
+  mat[2][2] = 1.f;
+}
+
 /**
  * tool_matrix_productMatrix:
  * @matRes: an array of floating point values of size 3x3 ;
@@ -366,81 +441,6 @@ gboolean tool_matrix_getRotationFromFull(float rot[3][3],
 	      rot[2][0], rot[2][1], rot[2][2]);
   return TRUE;
 }
-/**
- * tool_matrix_constrainInBox:
- * @translat: a translation in cartesian coordinates (out values).
- * @xyz: a set of cartesian coordinates.
- * @extension: the box expansion in the three directions.
- * @XYZToBox: the transformation matrix to go from cartesian to
- * reduced coordinates.
- * @boxToXYZ: the reverse transformation matrix.
- *
- * Given the box difintion as the transformation matrices @XYZToBox
- * and @boxToXYZ and the initial @xyz cartesian coordinates, it
- * returns the translation @translat to be applied to @xyz to move the
- * node into the box.
- *
- * Since: 3.6
- *
- * Returns: TRUE if @translat is not (0;0;0).
- */
-gboolean tool_matrix_constrainInBox(float translat[3], float xyz[3], float extension[3],
-                                    double XYZToBox[3][3], double boxToXYZ[3][3])
-{
-  float boxCoord[3], bounds[3], size[3];
-  gboolean moved;
-  int i, k;
-
-  bounds[0] = ceil(extension[0]);
-  bounds[1] = ceil(extension[1]);
-  bounds[2] = ceil(extension[2]);
-  size[0]   = 1. + 2. * bounds[0];
-  size[1]   = 1. + 2. * bounds[1];
-  size[2]   = 1. + 2. * bounds[2];
-
-  for (i = 0; i < 3; i++)
-    {
-      boxCoord[i]  = (float)XYZToBox[i][0] * xyz[0];
-      boxCoord[i] += (float)XYZToBox[i][1] * xyz[1];
-      boxCoord[i] += (float)XYZToBox[i][2] * xyz[2];
-    }
-  moved = FALSE;
-  for (k = 0; k < 3; k++)
-    {
-      while (boxCoord[k] < - bounds[k])
-	{
-	  moved = TRUE;
-	  boxCoord[k] += size[k];
-	}
-      while (boxCoord[k] >= 1. + bounds[k])
-	{
-	  moved = TRUE;
-	  boxCoord[k] -= size[k];
-	}
-    }
-  if (moved)
-    {
-      for (i = 0; i < 3; i++)
-	{
-	  translat[i]  = (float)boxToXYZ[i][0] * boxCoord[0];
-	  translat[i] += (float)boxToXYZ[i][1] * boxCoord[1];
-	  translat[i] += (float)boxToXYZ[i][2] * boxCoord[2];
-	}
-      translat[0] -= xyz[0];
-      translat[1] -= xyz[1];
-      translat[2] -= xyz[2];
-      DBG_fprintf(stderr, "Tool Matrix: move coord. from %gx%gx%g to %gx%gx%g.\n",
-		  xyz[0], xyz[1], xyz[2],
-		  boxCoord[0], boxCoord[1], boxCoord[2]);
-    }
-  else
-    {
-      translat[0] = 0.f;
-      translat[1] = 0.f;
-      translat[2] = 0.f;
-    }
-  return moved;
-}
 
 #ifndef RAD2DEG
 #define RAD2DEG(x) (57.29577951308232311 * x)
@@ -484,7 +484,7 @@ void tool_matrix_cartesianToSpherical(float *spherical, float *cartesian)
   if(c[0] == 0 && c[1] == 0)
     theta = (c[2] > 0) ? 0 : G_PI;
   else 
-    theta = acos(c[2]/rho);
+    theta = acos(CLAMP(c[2]/rho, -1., 1.));
 
   if(c[0] != 0)
     {
@@ -501,8 +501,8 @@ void tool_matrix_cartesianToSpherical(float *spherical, float *cartesian)
     }
 
   s[0] = rho;
-  s[1] = /*fModulo(RAD2DEG(theta), 180);*/ RAD2DEG(theta);
-  s[2] = fModulo(RAD2DEG(phi), 360);
+  s[1] = /*tool_modulo_float(RAD2DEG(theta), 180);*/ RAD2DEG(theta);
+  s[2] = tool_modulo_float(RAD2DEG(phi), 360);
 }
 
 /**
@@ -523,7 +523,7 @@ void tool_matrix_sphericalToCartesian(float *cartesian, float *spherical)
 }
 
 /**
- * matrixGet_inter2D:
+ * tool_matrix_getInter2D:
  * @lambda: a location to store a float.
  * @a: a point.
  * @b: another point.
@@ -534,7 +534,7 @@ void tool_matrix_sphericalToCartesian(float *cartesian, float *spherical)
  *
  * Returns: TRUE if [ab] and [AB] have an intersection.
  */
-gboolean matrixGet_inter2D(float *lambda,
+gboolean tool_matrix_getInter2D(float *lambda,
 			   float a[2], float b[2], float A[2], float B[2])
 {
   float denom;
@@ -548,19 +548,19 @@ gboolean matrixGet_inter2D(float *lambda,
   return TRUE;
 }
 /**
- * matrixGet_inter2DFromList:
+ * tool_matrix_getInter2DFromList: (skip)
  * @i: a location to store a point.
  * @lambda: a location to store a float.
  * @a: a point.
  * @b: another point.
  * @set: a list of points.
  *
- * Same as matrixGet_inter2D(), but from a list of points.
+ * Same as tool_matrix_getInter2D(), but from a list of points.
  *
  * Returns: TRUE if an intersection exists.
  */
-gboolean matrixGet_inter2DFromList(float i[2], float *lambda,
-				   float a[2], float b[2], GList *set)
+gboolean tool_matrix_getInter2DFromList(float i[2], float *lambda,
+                                        float a[2], float b[2], GList *set)
 {
   float *pt1, *pt2;
   float l, min;
@@ -572,7 +572,7 @@ gboolean matrixGet_inter2DFromList(float i[2], float *lambda,
   for (pt1 = (float*)(g_list_last(set)->data); set; set = g_list_next(set))
     {
       pt2 = (float*)set->data;
-      if (matrixGet_inter2D(&l, a, b, pt1, pt2))
+      if (tool_matrix_getInter2D(&l, a, b, pt1, pt2))
 	min = (l >= 0.f)?MIN(min, l):min;
       pt1 = pt2;
     }
@@ -587,11 +587,9 @@ gboolean matrixGet_inter2DFromList(float i[2], float *lambda,
 }
 
 #define FLAG_PARAMETER_THRESHOLD "scale_log_threshold"
-#define DESC_PARAMETER_THRESHOLD "Value of the threshold used in the zero centred logarithm scaling function ; a positive float (1e-3)"
+#define DESC_PARAMETER_THRESHOLD "Value of the threshold used in the zero centred TOOL_MATRIX_SCALING_LOG scaling function ; a positive float (1e-3)"
 static float threshold = 1e-3;
-static void exportParameters(GString *data, VisuData *dataObj);
-static gboolean readThreshold(gchar **lines, int nbLines,
-			      int position, VisuData *dataObj, GError **error);
+static void exportParameters(GString *data, VisuData *dataObj, VisuGlView *view);
 
 /**
  * tool_matrix_getScaledLinear:
@@ -705,50 +703,30 @@ double tool_matrix_getScaledZeroCentredLogInv(double x, double minmax[2])
   return out;
 }
 
-static void exportParameters(GString *data, VisuData *dataObj _U_)
+static void exportParameters(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
 {
   g_string_append_printf(data, "# %s\n", DESC_PARAMETER_THRESHOLD);
   g_string_append_printf(data, "%s: %f\n\n", FLAG_PARAMETER_THRESHOLD,
 			 threshold);
 }
-static gboolean readThreshold(gchar **lines, int nbLines,
-			      int position, VisuData *dataObj _U_, GError **error)
-{
-  float val;
-
-  g_return_val_if_fail(nbLines == 1, FALSE);
-
-  if (sscanf(lines[0],"%f", &val) != 1 || val <= 0.f)
-    {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
-			   _("Parse error at line %d,"
-			     " 1 positive float value must appear"
-			     " after the %s markup.\n"),
-			   position, FLAG_PARAMETER_THRESHOLD);
-      return FALSE;
-    }
-  else
-    threshold = val;
-
-  return TRUE;
-}
 /**
- * initToolMatrix: (skip)
+ * tool_matrix_init: (skip)
  *
  * This method is used by V_Sim internally and should not be called.
  *
  * Since: 3.5
  */
-void initToolMatrix(void)
+void tool_matrix_init(void)
 {
+  float rg[2] = {G_MINFLOAT, G_MAXFLOAT};
   VisuConfigFileEntry *entry;
 
   /* Set private variables. */
-  entry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
-				  FLAG_PARAMETER_THRESHOLD,
-				  DESC_PARAMETER_THRESHOLD,
-				  1, readThreshold);
-  visu_configFile_entry_setVersion(entry, 3.5f);
-  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
+  entry = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_PARAMETER,
+                                              FLAG_PARAMETER_THRESHOLD,
+                                              DESC_PARAMETER_THRESHOLD,
+                                              1, &threshold, rg);
+  visu_config_file_entry_setVersion(entry, 3.5f);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
 				   exportParameters);
 }
