@@ -52,6 +52,8 @@
 #include <extraFunctions/extraNode.h>
 #include <extraFunctions/geometry.h>
 
+static VisuDump *ascii = NULL;
+
 /**
  * SECTION:dumpToAscii
  * @short_description: add an export capability of current positions.
@@ -68,36 +70,27 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 static gpointer waitData;
 static ToolVoidDataFunc waitFunc;
 
-VisuDump* dumpToAscii_init()
+const VisuDump* visu_dump_ascii_getStatic()
 {
-  VisuDump *ascii;
-  char *typeASCII[] = {"*.ascii", (char*)0};
+  const gchar *typeASCII[] = {"*.ascii", (char*)0};
 #define descrASCII _("ASCII file (current positions)")
-  ToolFileFormat* fmt;
 
-  ascii = g_malloc(sizeof(VisuDump));
-  fmt = tool_file_format_new(descrASCII, typeASCII);
-  if (!fmt)
-    {
-      g_error("Can't initialize the ASCII dump module, aborting.\n");
-    }
+  if (ascii)
+    return ascii;
 
-  ascii->bitmap = FALSE;
-  ascii->glRequired = FALSE;
-  ascii->fileType = fmt;
-  ascii->writeFunc = writeDataInAscii;
+  ascii = visu_dump_new(descrASCII, typeASCII, writeDataInAscii, FALSE);
   
-  tool_file_format_addPropertyBoolean(fmt, "delete_hidden_nodes",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "delete_hidden_nodes",
 				_("Don't output hidden nodes"), FALSE);
-  tool_file_format_addPropertyBoolean(fmt, "comment_hidden_nodes",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "comment_hidden_nodes",
 				_("Comment hidden nodes (if output)"), TRUE);
-  tool_file_format_addPropertyBoolean(fmt, "expand_box",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "expand_box",
 				_("Keep primitive box (in case of node expansion)"), FALSE);
-  tool_file_format_addPropertyBoolean(fmt, "reduced_coordinates",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "reduced_coordinates",
 				_("Export positions in reduced coordinates"), FALSE);
-  tool_file_format_addPropertyBoolean(fmt, "angdeg_box",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "angdeg_box",
 				_("Export box as lengths and angles"), FALSE);
-  tool_file_format_addPropertyBoolean(fmt, "type_alignment",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "type_alignment",
 				_("Export nodes sorted by elements"), FALSE);
 
   waitData = (gpointer)0;
@@ -111,15 +104,18 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 				 guchar* imageData _U_, GError **error,
 				 ToolVoidDataFunc functionWait, gpointer data)
 {
-  gchar *nom, *prevFile;
+  const gchar *nom;
+  gchar *prevFile;
   char tmpChr;
   gchar *diff;
   gboolean suppr, comment, expand, reduced, angdeg, eleSort;
   float xyz[3], ext[3], uvw[3], vertices[8][3], box[6];
-  VisuDataIter iter;
+  double ene;
+  VisuNodeArrayIter iter;
   GString *output;
   const gchar *nodeComment;
   ToolFileFormatIter it;
+  VisuBox *boxObj;
 
   g_return_val_if_fail(error && !*error, FALSE);
 
@@ -174,7 +170,8 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
       g_string_append(output, "# V_Sim export to ascii\n");
     }
 
-  visu_data_getBoxVertices(dataObj, vertices, expand);
+  boxObj = visu_boxed_getBox(VISU_BOXED(dataObj));
+  visu_box_getVertices(boxObj, vertices, expand);
   if (angdeg)
     {
       box[0] = sqrt((vertices[1][0] - vertices[0][0]) *
@@ -233,29 +230,29 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
     g_string_append(output, "#keyword: angdeg\n");
   if (reduced)
     g_string_append(output, "#keyword: reduced\n");
-  switch (visu_data_getUnit(dataObj))
+  switch (visu_box_getUnit(boxObj))
     {
-    case unit_angstroem:
+    case TOOL_UNITS_ANGSTROEM:
       g_string_append(output, "#keyword: angstroem\n");
       break;
-    case unit_bohr:
+    case TOOL_UNITS_BOHR:
       g_string_append(output, "#keyword: atomic\n");
       break;
     default:
       break;
     }
-  switch (visu_data_getBoundaryConditions(dataObj))
+  switch (visu_box_getBoundary(boxObj))
     {
-    case VISU_DATA_BOX_SURFACE_XY:
+    case VISU_BOX_SURFACE_XY:
       g_string_append(output, "#keyword: surfaceXY\n");
       break;
-    case VISU_DATA_BOX_SURFACE_YZ:
+    case VISU_BOX_SURFACE_YZ:
       g_string_append(output, "#keyword: surfaceYZ\n");
       break;
-    case VISU_DATA_BOX_SURFACE_ZX:
+    case VISU_BOX_SURFACE_ZX:
       g_string_append(output, "#keyword: surface\n");
       break;
-    case VISU_DATA_BOX_FREE:
+    case VISU_BOX_FREE:
       if (reduced)
 	g_warning("Using reduced coordinates in free boundary conditions"
 		  " is possible but not not adviced. The given box will be"
@@ -265,10 +262,13 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
     default:
       break;
     }
+  g_object_get(G_OBJECT(dataObj), "totalEnergy", &ene, NULL);
+  if (ene != G_MAXFLOAT)
+    g_string_append_printf(output, "#metaData: totalEnergy=%22.16feV\n", ene);
 
-  visu_data_getBoxVertices(dataObj, vertices, FALSE);
+  visu_box_getVertices(boxObj, vertices, FALSE);
   if (expand)
-    visu_data_getExtension(dataObj, ext);
+    visu_box_getExtension(boxObj, ext);
   else
     {
       ext[0] = 0.;
@@ -290,13 +290,13 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
       g_string_append(output, "# Statistics are valid for all nodes (hidden or not).\n");
       g_string_append(output, "# Hidden nodes are printed, but commented.\n");
     }
-  visu_data_iterNew(dataObj, &iter);
+  visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
   g_string_append_printf(output, "# Box contains %d element(s).\n", iter.nElements);
   g_string_append_printf(output, "# Box contains %d nodes.\n", iter.nAllStoredNodes);
-  for (visu_data_iterStart(dataObj, &iter); iter.element;
-       visu_data_iterNextElement(dataObj, &iter))
+  for (visu_node_array_iterStart(VISU_NODE_ARRAY(dataObj), &iter); iter.element;
+       visu_node_array_iterNextElement(VISU_NODE_ARRAY(dataObj), &iter))
     g_string_append_printf(output, "#  | %d nodes for element '%s'.\n",
-	    iter.nStoredNodes[iter.iElement], iter.element->name);
+	    iter.nStoredNodes, iter.element->name);
   if (suppr)
     g_string_append(output, "# Hidden nodes have been suppressed.\n");
   if (visu_geodiff_hasData(dataObj))
@@ -306,11 +306,11 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
       g_free(diff);
     }
 
-  for ((eleSort)?visu_data_iterStart(dataObj, &iter):
-	 visu_data_iterStartNumber(dataObj, &iter);
+  for ((eleSort)?visu_node_array_iterStart(VISU_NODE_ARRAY(dataObj), &iter):
+	 visu_node_array_iterStartNumber(VISU_NODE_ARRAY(dataObj), &iter);
        iter.node && iter.element;
-       (eleSort)?visu_data_iterNext(dataObj, &iter):
-	 visu_data_iterNextNodeNumber(dataObj, &iter))
+       (eleSort)?visu_node_array_iterNext(VISU_NODE_ARRAY(dataObj), &iter):
+	 visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(dataObj), &iter))
     {
       if ((iter.element->rendered && iter.node->rendered) || !comment)
 	tmpChr = ' ';
@@ -330,7 +330,7 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 	  
 	  if (reduced)
 	    {
-	      visu_data_convertXYZtoBoxCoordinates(dataObj, uvw, xyz);
+	      visu_box_convertXYZtoBoxCoordinates(boxObj, uvw, xyz);
 	      uvw[0] /= (1.f + 2.f * ext[0]);
 	      uvw[1] /= (1.f + 2.f * ext[1]);
 	      uvw[2] /= (1.f + 2.f * ext[2]);
@@ -341,11 +341,13 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 	      uvw[1] = xyz[1];
 	      uvw[2] = xyz[2];
 	    }
-	  g_string_append_printf(output, "%c%17.8g %17.8g %17.8g %s", tmpChr,
-		  uvw[0], uvw[1], uvw[2], iter.element->name);
-	  nodeComment = extraNodeGet_label(dataObj, iter.node);
+	  g_string_append_printf(output, "%c%17.8g %17.8g %17.8g %c%s", tmpChr,
+                                 uvw[0], uvw[1], uvw[2],
+                                 (visu_element_getPhysical(iter.element))?' ':'%',
+                                 iter.element->name);
+	  nodeComment = visu_extra_node_getLabel(dataObj, iter.node);
 	  if (nodeComment)
-	    g_string_append_printf(output, " # %s", nodeComment);
+	    g_string_append_printf(output, " %s", nodeComment);
 	  g_string_append(output, "\n");
 	}
     }
