@@ -55,12 +55,12 @@
  * a way to go from data to strings and reverse, callbacks when the
  * properties is changed...</para>
  * <para>When creating a node property calling
- * visu_node_property_newPointer() for instance, a #VisuDataNode can be created using
+ * visu_node_array_property_newPointer() for instance, a #VisuDataNode can be created using
  * visu_data_node_new(). A #VisuDataNode may not be attached to a specific
  * #VisuData and is a global property found on each #VisuData (or
  * potentialy found). The advantage of doing this is to keep track of
  * available properties for #VisuData objects. To get all public
- * properties, call nodeDataGet_list().</para>
+ * properties, call visu_data_node_class_getAll().</para>
  */
 
 struct _VisuDataNodeClass
@@ -229,7 +229,7 @@ static void visu_data_node_init(VisuDataNode *obj)
               (gpointer)obj, (gpointer)storedData);
 #if DEBUG == 1
   for (tmpLst = storedData; tmpLst; tmpLst = g_list_next(tmpLst))
-    g_return_if_fail(IS_VISU_DATA_NODE_TYPE(tmpLst->data));
+    g_return_if_fail(VISU_IS_DATA_NODE_TYPE(tmpLst->data));
 #endif
 }
 
@@ -276,7 +276,7 @@ static void data_node_finalize(GObject* obj)
  *
  * This method creates a new #VisuDataNode and registers it. A #VisuDataNode is
  * characterised by a string used as a key to store it as a node property
- * (see visu_node_property_newPointer()). The stored data can be arrays or not.
+ * (see visu_node_array_property_newPointer()). The stored data can be arrays or not.
  * Notice that @name is copied.
  *
  * Returns: (transfer full): a newly created #VisuDataNode.
@@ -334,23 +334,46 @@ GObject* visu_data_node_newWithCallbacks(const gchar *name,
 
   return G_OBJECT(data);
 }
-
-GList* nodeDataGet_list(void)
+/**
+ * visu_data_node_class_getAll:
+ *
+ * All registered #VisuDataNode are stored in an intern list. This method is
+ * used to retrieve it.
+ *
+ * Returns: (transfer none) (element-type VisuDataNode*): a #GList of
+ * all registereed #VisuDataNode (this list is owned by V_Sim).
+ */
+GList* visu_data_node_class_getAll(void)
 {
   DBG_fprintf(stderr, "Visu DataNode: get list of DataNode properties (%p %d).\n",
               (gpointer)storedData, g_list_length(storedData));
   return storedData;
 }
-
+/**
+ * visu_data_node_setLabel:
+ * @data: a #VisuDataNode ;
+ * @label: an UTF8 string (may be translated).
+ *
+ * A #VisuDataNode can have a label, if not its name is used.
+ * Notice that @label is not copied.
+ */
 void visu_data_node_setLabel(VisuDataNode *data, const gchar *label)
 {
-  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data));
+  g_return_if_fail(VISU_IS_DATA_NODE_TYPE(data));
 
   data->label = label;
 }
+/**
+ * visu_data_node_getLabel:
+ * @data: a #VisuDataNode ;
+ *
+ * A #VisuDataNode can have a label, if not its name is used.
+ *
+ * Returns: the label of the node (in UTF8), this string is owned by V_Sim.
+ */
 const gchar* visu_data_node_getLabel(VisuDataNode *data)
 {
-  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data), (const gchar*)0);
+  g_return_val_if_fail(VISU_IS_DATA_NODE_TYPE(data), (const gchar*)0);
 
   if (data->label)
     return data->label;
@@ -373,12 +396,25 @@ static struct internalUsedVisuData_struct *getInternalStorage(VisuDataNode *data
     }
   return storage;
 }
-
+/**
+ * visu_data_node_setUsed:
+ * @data: a #VisuDataNode ;
+ * @dataObj: a #VisuData object ;
+ * @nb: a positive or null integer.
+ *
+ * A #VisuDataNode stores data for each node of a given #VisuData. The number of data stored for
+ * each node is set with this method. When some part wants to set a new node property
+ * and wants to make it public, this method can be called. It also can be called when
+ * the node property is removed (using a null @nb argument).
+ * If @nb is changed for a positive value, the "propertyUsed"
+ * signal is emitted with @dataObj as argument, instead if the value is changed
+ * for null, the "propertyUnused" signal is triggered also with @dataObj as argument.
+ */
 void visu_data_node_setUsed(VisuDataNode *data, VisuData *dataObj, gint nb)
 {
   struct internalUsedVisuData_struct *storage;
 
-  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data) && IS_VISU_DATA_TYPE(dataObj));
+  g_return_if_fail(VISU_IS_DATA_NODE_TYPE(data) && VISU_IS_DATA(dataObj));
 
   storage = getInternalStorage(data, dataObj);
   if (nb > 0)
@@ -427,29 +463,63 @@ void visu_data_node_setUsed(VisuDataNode *data, VisuData *dataObj, gint nb)
 		    0 , dataObj, NULL);
     }
 }
+/**
+ * visu_data_node_getUsed:
+ * @data: a #VisuDataNode ;
+ * @dataObj: a #VisuData object.
+ *
+ * Access method to know if the given @dataObj has a public node property of the type
+ * @data.
+ *
+ * Returns: TRUE if @dataObj has a node property of the given type.
+ */
 gboolean visu_data_node_getUsed(VisuDataNode *data, VisuData *dataObj)
 {
   struct internalUsedVisuData_struct *storage;
 
-  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) && IS_VISU_DATA_TYPE(dataObj), FALSE);
+  g_return_val_if_fail(VISU_IS_DATA_NODE_TYPE(data) && VISU_IS_DATA(dataObj), FALSE);
 
   storage = getInternalStorage(data, dataObj);
   return (storage != (struct internalUsedVisuData_struct *)0);
 }
+/**
+ * visu_data_node_emitValueChanged:
+ * @data: a #VisuDataNode ;
+ * @dataObj: a #VisuData object.
+ *
+ * Emit the 'valueChanged' signal. This method should be called after
+ * all changes have been done to a node property set of nodes. Then routines
+ * using this property can update itself.
+ */
 void visu_data_node_emitValueChanged(VisuDataNode *data, VisuData *dataObj)
 {
   DBG_fprintf(stderr, "Data Node: %p emit the 'valueChanged'.\n", (gpointer)data);
   g_signal_emit(data, dataNode_signals[VISU_DATA_NODE_VALUE_CHANGED_SIGNAL],
 		0 , dataObj, NULL);
 }
-
+/**
+ * visu_data_node_setValueAsString:
+ * @data: a #VisuDataNode ;
+ * @dataObj: a #VisuData object ;
+ * @node: a #VisuNode ;
+ * @labelIn: a formatted string ;
+ * @labelOut: a pointer to store a string.
+ *
+ * If the string is correctly formatted (that means it has the same format as
+ * the string returned by visu_data_node_getValueAsString()) the stored values are modified.
+ * The resulting string is created and put into @labelOut. If the input string @labelIn
+ * is unparsable, @labelOut will contain current values. Notice that this method is
+ * callable only if the @data is editable (see visu_data_node_getEditable()).
+ *
+ * Returns: TRUE if the string was correctly parsed.
+ */
 gboolean visu_data_node_setValueAsString(VisuDataNode *data, VisuData *dataObj,
 				   VisuNode *node, gchar *labelIn, gchar **labelOut)
 {
   gboolean valid, modify;
 
-  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) &&
-		       IS_VISU_DATA_TYPE(dataObj) && node, FALSE);
+  g_return_val_if_fail(VISU_IS_DATA_NODE_TYPE(data) &&
+		       VISU_IS_DATA(dataObj) && node, FALSE);
   g_return_val_if_fail(labelIn && labelOut, FALSE);
   g_return_val_if_fail(data->setAsString, FALSE);
 
@@ -471,10 +541,20 @@ gboolean visu_data_node_setValueAsString(VisuDataNode *data, VisuData *dataObj,
 
   return valid;
 }
+/**
+ * visu_data_node_getValueAsString:
+ * @data: a #VisuDataNode ;
+ * @dataObj: a #VisuData object ;
+ * @node: a #VisuNode.
+ *
+ * For the given node, the values stored are printed into a string.
+ *
+ * Returns: a newly created string.
+ */
 gchar* visu_data_node_getValueAsString(VisuDataNode *data, VisuData *dataObj,
 				 VisuNode *node)
 {
-  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
+  g_return_val_if_fail(VISU_IS_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
   g_return_val_if_fail(data->getAsString, (gchar*)0);
   
   return data->getAsString(data, dataObj, node);
@@ -492,22 +572,37 @@ gchar* visu_data_node_getValueAsString(VisuDataNode *data, VisuData *dataObj,
 void visu_data_node_setCallback(VisuDataNode *data, VisuDataNodeCallbackMethod callback,
                                 gpointer user_data)
 {
-  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data));
+  g_return_if_fail(VISU_IS_DATA_NODE_TYPE(data));
 
   data->editable = TRUE;
   data->callback = callback;
   data->data = user_data;
 }
-
+/**
+ * visu_data_node_getEditable:
+ * @data: a #VisuDataNode.
+ *
+ * If some callback method has been given with visu_data_node_setCallback(), then
+ * the values are considered editable.
+ *
+ * Returns: TRUE if values are editable.
+ */
 gboolean visu_data_node_getEditable(VisuDataNode *data)
 {
-  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data), FALSE);
+  g_return_val_if_fail(VISU_IS_DATA_NODE_TYPE(data), FALSE);
 
   return data->editable;
 }
+/**
+ * visu_data_node_setEditable:
+ * @data: a #VisuDataNode ;
+ * @status: a boolean value.
+ *
+ * Set if the values are modifiable.
+ */
 void visu_data_node_setEditable(VisuDataNode *data, gboolean status)
 {
-  g_return_if_fail(IS_VISU_DATA_NODE_TYPE(data));
+  g_return_if_fail(VISU_IS_DATA_NODE_TYPE(data));
 
   data->editable = status;
 }
@@ -536,7 +631,7 @@ static gchar* valueAsString(VisuDataNode *data, VisuData *dataObj,
   struct internalUsedVisuData_struct *storage;
   GValue val = {0, {{0}, {0}}};
 
-  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
+  g_return_val_if_fail(VISU_IS_DATA_NODE_TYPE(data) && dataObj && node, (gchar*)0);
 
   /* Check if the given property has an association with the given VisuData. */
   DBG_fprintf(stderr, "Data Node: get label for node property '%s'.\n", data->id);
@@ -548,7 +643,7 @@ static gchar* valueAsString(VisuDataNode *data, VisuData *dataObj,
     }
 
   g_value_init(&val, G_TYPE_POINTER);
-  visu_node_array_getPropertyValue(visu_data_getNodeArray(dataObj), node,
+  visu_node_array_getPropertyValue(VISU_NODE_ARRAY(dataObj), node,
                                    data->id, &val);
   dataValues = g_value_get_pointer(&val);
   if (!dataValues)
@@ -571,7 +666,7 @@ static gchar* valueAsString(VisuDataNode *data, VisuData *dataObj,
 	  g_string_append_printf(str, "%d", ((int*)dataValues)[i]);
 	  break;
 	case G_TYPE_FLOAT:
-	  g_string_append_printf(str, "%g", ((float*)dataValues)[i]);
+	  g_string_append_printf(str, "%.3g", ((float*)dataValues)[i]);
 	  break;
 	case G_TYPE_BOOLEAN:
 	  if (((gboolean*)dataValues)[i])
@@ -611,8 +706,8 @@ static gboolean valueFromString(VisuDataNode *data, VisuData *dataObj,
   float valueFloat;
   GValue val = {0, {{0}, {0}}};
 
-  g_return_val_if_fail(IS_VISU_DATA_NODE_TYPE(data) &&
-		       IS_VISU_DATA_TYPE(dataObj) && node, FALSE);
+  g_return_val_if_fail(VISU_IS_DATA_NODE_TYPE(data) &&
+		       VISU_IS_DATA(dataObj) && node, FALSE);
   g_return_val_if_fail(labelIn && labelOut && modify, FALSE);
 
   if (!data->editable)
@@ -635,7 +730,7 @@ static gboolean valueFromString(VisuDataNode *data, VisuData *dataObj,
   
   /* Grep the property from the low level storage in the VisuData. */
   g_value_init(&val, G_TYPE_POINTER);
-  visu_node_array_getPropertyValue(visu_data_getNodeArray(dataObj), node,
+  visu_node_array_getPropertyValue(VISU_NODE_ARRAY(dataObj), node,
                                    data->id, &val);
   dataValues = g_value_get_pointer(&val);
   if (data->type != G_TYPE_STRING && !dataValues)
@@ -709,7 +804,7 @@ static gboolean valueFromString(VisuDataNode *data, VisuData *dataObj,
 	  str = g_strdup(datas[i]);
 	  g_strstrip(str);
 	  g_value_set_pointer(&val, (gpointer)str);
-	  visu_node_setpropertyValue(visu_data_getNodeArray(dataObj), node,
+	  visu_node_setpropertyValue(VISU_NODE_ARRAY(dataObj), node,
                                      data->id, &val);
 	  break;
 	default:
@@ -728,7 +823,7 @@ static gboolean valueFromString(VisuDataNode *data, VisuData *dataObj,
   if (data->type == G_TYPE_STRING && i == 0)
     {
       g_value_set_pointer(&val, (gpointer)0);
-      visu_node_setpropertyValue(visu_data_getNodeArray(dataObj), node,
+      visu_node_setpropertyValue(VISU_NODE_ARRAY(dataObj), node,
                                  data->id, &val);
       i = 1;
     }
