@@ -63,19 +63,28 @@ static void freeLabel(gpointer obj, gpointer data _U_)
 }
 static gpointer newOrCopyLabel(gconstpointer orig, gpointer user_data _U_)
 {
-  return g_strdup(orig);
+  if (orig)
+    return g_strdup(orig);
+  else
+    return (gpointer)0;
 }
 
-void extraNodeAdd_label(VisuData *data)
+/**
+ * visu_extra_node_addLabel:
+ * @data: a #VisuData object.
+ * 
+ * Add the possibility to store labels for nodes.
+ */
+void visu_extra_node_addLabel(VisuData *data)
 {
   VisuNodeProperty* nodeProp;
 
   /* Test if the property is already set or not. */
-  nodeProp = visu_node_array_getProperty(visu_data_getNodeArray(data), LABEL_ID);
+  nodeProp = visu_node_array_getProperty(VISU_NODE_ARRAY(data), LABEL_ID);
   if (!nodeProp)
     /* If not, create it. */
-    visu_node_property_newPointer(visu_data_getNodeArray(data),
-				LABEL_ID, freeLabel, newOrCopyLabel, (gpointer)0);
+    visu_node_array_property_newPointer(VISU_NODE_ARRAY(data),
+                                  LABEL_ID, freeLabel, newOrCopyLabel, (gpointer)0);
 
   /* Register a new NodeData, if not already. */
   if (!dataNodeLabel)
@@ -90,26 +99,46 @@ void extraNodeAdd_label(VisuData *data)
   /* Make this property used. */
   visu_data_node_setUsed(dataNodeLabel, data, 1);
 }
-
-void extraNodeSet_label(VisuData *data, unsigned int nodeId, const gchar *label)
+/**
+ * visu_extra_node_setLabel:
+ * @data: a #VisuData object.
+ * @nodeId: the id of a node.
+ * @label: (allow-none): the label to set (will be copied).
+ *
+ * Set a @label to the node @nodeId.
+ */
+void visu_extra_node_setLabel(VisuData *data, guint nodeId, const gchar *label)
 {
   VisuNode *node;
   gchar *lbl;
 
-  node = visu_data_getNodeFromNumber(data, nodeId);
+  node = visu_node_array_getFromId(VISU_NODE_ARRAY(data), nodeId);
   g_return_if_fail(node);
 
   /* Associates the values to the node. */
-  lbl = g_strdup(label);
+  if (label && label[0])
+    lbl = g_strdup(label);
+  else
+    lbl = (gchar*)0;
   g_value_set_pointer(&dataLabel, (gpointer)lbl);
-  visu_node_setpropertyValue(visu_data_getNodeArray(data), node, LABEL_ID, &dataLabel);
+  visu_node_setpropertyValue(VISU_NODE_ARRAY(data), node, LABEL_ID, &dataLabel);
 }
-const gchar* extraNodeGet_label(VisuData *data, VisuNode *node)
+/**
+ * visu_extra_node_getLabel:
+ * @data: a #VisuData object.
+ * @node: a given node
+ *
+ * Retrieve the label of @node. If @node has no label, NULL is
+ * returned.
+ *
+ * Returns: (transfer none): a label, private value, do not freed.
+ */
+const gchar* visu_extra_node_getLabel(VisuData *data, VisuNode *node)
 {
   VisuNodeProperty* nodeProp;
   gchar *lbl;
 
-  nodeProp = visu_node_array_getProperty(visu_data_getNodeArray(data), LABEL_ID);
+  nodeProp = visu_node_array_getProperty(VISU_NODE_ARRAY(data), LABEL_ID);
   if (!nodeProp)
     return (const gchar*)0;
 
