@@ -45,32 +45,8 @@
 
 #include <visu_data.h>
 
-/**
- * extraNodeAdd_label:
- * @data: a #VisuData object.
- * 
- * Add the possibility to store labels for nodes.
- */
-void extraNodeAdd_label(VisuData *data);
-/**
- * extraNodeSet_label:
- * @data: a #VisuData object.
- * @nodeId: the id of a node.
- * @label: the label to set (will be copied).
- *
- * Set a @label to the node @nodeId.
- */
-void extraNodeSet_label(VisuData *data, unsigned int nodeId, const gchar *label);
-/**
- * extraNodeGet_label:
- * @data: a #VisuData object.
- * @node: a given node
- *
- * Retrieve the label of @node. If @node has no label, NULL is
- * returned.
- *
- * Returns: a label, private value, do not freed.
- */
-const gchar* extraNodeGet_label(VisuData *data, VisuNode *node);
+void visu_extra_node_addLabel(VisuData *data);
+void visu_extra_node_setLabel(VisuData *data, guint nodeId, const gchar *label);
+const gchar* visu_extra_node_getLabel(VisuData *data, VisuNode *node);
 
 #endif
