@@ -45,41 +45,52 @@
 #ifndef GEOMETRY_H
 #define GEOMETRY_H
 
+#include <glib-object.h>
+
 #include <visu_data.h>
 #include <coreTools/toolShade.h>
 
-typedef struct VisuPathes_ VisuPathes;
+typedef struct _VisuPaths VisuPaths;
 
-VisuPathes* visu_pathes_new(float translation[3]);
-void        visu_pathes_free(VisuPathes *pathes);
-void        visu_pathes_empty(VisuPathes *pathes);
+#define VISU_TYPE_PATHS (visu_paths_get_type())
+GType       visu_paths_get_type(void);
 
-gboolean    visu_pathes_addFromDiff(VisuPathes *pathes, VisuData *data);
-gboolean    visu_pathes_addNodeStep(VisuPathes *pathes, guint time, guint nodeId,
+VisuPaths* visu_paths_new(float translation[3]);
+VisuPaths* visu_paths_ref(VisuPaths *paths);
+void        visu_paths_unref(VisuPaths *paths);
+void        visu_paths_free(VisuPaths *paths);
+void        visu_paths_empty(VisuPaths *paths);
+
+gboolean    visu_paths_addFromDiff(VisuPaths *paths, VisuData *data);
+gboolean    visu_paths_addNodeStep(VisuPaths *paths, guint time, guint nodeId,
                                     float xyz[3], float dxyz[3], float energy);
-void        visu_pathes_pinPositions(VisuPathes *pathes, VisuData *data);
+void        visu_paths_pinPositions(VisuPaths *paths, VisuData *data);
 
-void        visu_pathes_draw(VisuPathes *pathes);
-void        visu_pathes_constrainInBox(VisuPathes *pathes, VisuData *data);
-gboolean    visu_pathes_exportToXML(const VisuPathes *pathes,
+void        visu_paths_draw(VisuPaths *paths);
+void        visu_paths_constrainInBox(VisuPaths *paths, VisuData *data);
+gboolean    visu_paths_exportXMLFile(const VisuPaths *paths,
                                     const gchar *filename, GError **error);
-gboolean    visu_pathes_parseFromXML(const gchar* filename, VisuPathes *pathes,
+gboolean    visu_paths_parseFromXML(const gchar* filename, VisuPaths *paths,
                                      GError **error);
 
-void        visu_pathes_setTranslation(VisuPathes *pathes, float cartCoord[3]);
-gboolean    visu_pathes_setShade(VisuPathes *pathes, Shade* shade);
-Shade*      visu_pathes_getShade(VisuPathes *pathes);
-guint       visu_pathes_getLength(VisuPathes *pathes);
-
+void        visu_paths_setTranslation(VisuPaths *paths, float cartCoord[3]);
+gboolean    visu_paths_setToolShade(VisuPaths *paths, ToolShade* shade);
+ToolShade*      visu_paths_getToolShade(VisuPaths *paths);
+guint       visu_paths_getLength(VisuPaths *paths);
 
+/**
+ * VISU_GEODIFF_ID:
+ *
+ * The default name used for the #VisuGlExt representing
+ * displacements, see visu_gl_ext_getFromName().
+ */
+#define VISU_GEODIFF_ID        "geometry_diff"
 gboolean visu_geodiff_new(VisuData *dataRef, VisuData *data, gboolean reorder);
-gboolean visu_geodiff_setActive(gboolean value);
-void     visu_geodiff_rebuildList(VisuData *dataObj);
 gboolean visu_geodiff_hasData(VisuData *data);
 gchar*   visu_geodiff_export(VisuData *data);
 void     visu_geodiff_getPeriodicDistance(float diff[3], VisuData *data,
                                           VisuNode *node1, VisuNode *node2);
 
-void geometryInit();
+void visu_geometry_init();
 
 #endif
