@@ -52,7 +52,8 @@
 #include <glib.h>
 #include <string.h>
 
-#include <openGLFunctions/objectList.h>
+#include <coreTools/toolConfigFile.h>
+#include <visu_configFile.h>
 
 #ifdef HAVE_CAIRO
 #include <cairo.h>
@@ -105,9 +106,12 @@ typedef struct _Triangle
 
 struct _VisuMap
 {
+  guint refCount;
+
   /* Pointers to building objects. */
-  Plane *plane;
-  ScalarField *field;
+  VisuPlane *plane;
+  glong moved_signal;
+  VisuScalarField *field;
 
   /* Transformation values. */
   tool_matrix_getScaledValue get_val;
@@ -124,27 +128,35 @@ struct _VisuMap
   /* The min/max values in scalarfield unit. */
   float valMinMax[2];
 
-  /* The OpenGL list for this map. */
-  int glListId;
-
   guint nLines;
   VisuLine **lines;
 };
 
+#define FLAG_RESOURCE_LEG_SCALE "map_legendScale"
+#define DESC_RESOURCE_LEG_SCALE "Choose the scale to draw the legend for coloured maps ; float (positive)"
+#define DEFT_RESOURCE_LEG_SCALE 1.f
+
+#define FLAG_RESOURCE_LEG_POS "map_legendPosition"
+#define DESC_RESOURCE_LEG_POS "Choose the legend position ; two floats (between 0 and 1)"
+#define DEFT_RESOURCE_LEG_POS 0.f
+
+static void exportResources(GString *data, VisuData *dataObj, VisuGlView *view);
 
 static Triangle* triangle_new(float ABC[3][3], guint level);
 static void triangle_free(Triangle *T);
 static void triangle_getDataAtLevel(Triangle *T, guint level, float **data, guint *pos);
-static void triangle_setValues(Triangle *T, ScalarField *field,
+static void triangle_setValues(Triangle *T, VisuScalarField *field,
                                tool_matrix_getScaledValue get_val, double minmax[2],
                                float extension[3]);
-static void triangle_draw(Triangle *T, float thresh, const Shade *shade);
-static void triangle_drawWithAlpha(Triangle *T, float thresh, const Shade *shade);
+static void triangle_draw(Triangle *T, float thresh, const ToolShade *shade);
+static void triangle_drawWithAlpha(Triangle *T, float thresh, const ToolShade *shade);
 #ifdef HAVE_CAIRO
 static void triangle_drawToCairo(Triangle *T, cairo_t *cr, float thresh,
-                                 const Shade *shade, float basis[2][3], float center[3]);
+                                 const ToolShade *shade, float basis[2][3], float center[3]);
 #endif
 
+static void onPlaneMoved(VisuPlane *plane, gpointer data);
+
 static Triangle* triangle_new(float ABC[3][3], guint level)
 {
   Triangle *T;
@@ -158,7 +170,7 @@ static Triangle* triangle_new(float ABC[3][3], guint level)
   T->minmax[1] = -G_MAXFLOAT;
   T->level = level;
   memcpy(T->vertices, ABC, sizeof(float) * 9);
-  /* DBG_fprintf(stderr, "ScalarField: create Triangle %p (%d).\n", (gpointer)T, level); */
+  /* DBG_fprintf(stderr, "VisuScalarField: create Triangle %p (%d).\n", (gpointer)T, level); */
 
   return T;
 }
@@ -194,13 +206,13 @@ static void triangle_getDataAtLevel(Triangle *T, guint level, float **data, guin
     triangle_getDataAtLevel(T->children[3], level, data, pos);
 }
 
-static void _3DToPlane(float uv[2], float xyz[3],
+static void _3DToVisuPlane(float uv[2], float xyz[3],
                        float basis[2][3], float origin[3])
 {
   uv[0] = basis[0][0] * (xyz[0] - origin[0]) + basis[0][1] * (xyz[1] - origin[1]) +  basis[0][2] * (xyz[2] - origin[2]);
   uv[1] = basis[1][0] * (xyz[0] - origin[0]) + basis[1][1] * (xyz[1] - origin[1]) +  basis[1][2] * (xyz[2] - origin[2]);
 }
-static void triangle_setValues(Triangle *T, ScalarField *field,
+static void triangle_setValues(Triangle *T, VisuScalarField *field,
                                tool_matrix_getScaledValue get_val, double minmax[2],
                                float extension[3])
 {
@@ -214,16 +226,16 @@ static void triangle_setValues(Triangle *T, ScalarField *field,
   if (field)
     for (i = 0; i < 3; i++)
       {
-        if (!scalarFieldGet_value(field, T->vertices[i], &value, extension))
-          if (!scalarFieldGet_value(field, T->vertices[(i + 1) % 3], &value, extension))
-            scalarFieldGet_value(field, T->vertices[(i + 2) % 3], &value, extension);
+        if (!visu_scalar_field_getValue(field, T->vertices[i], &value, extension))
+          if (!visu_scalar_field_getValue(field, T->vertices[(i + 1) % 3], &value, extension))
+            visu_scalar_field_getValue(field, T->vertices[(i + 2) % 3], &value, extension);
         T->value[i]  = (float)get_val(value, minmax);
         T->minmax[0] = MIN(T->minmax[0], T->value[i]);
         T->minmax[1] = MAX(T->minmax[1], T->value[i]);
       }
 }
 
-static void triangle_draw(Triangle *T, float thresh, const Shade *shade)
+static void triangle_draw(Triangle *T, float thresh, const ToolShade *shade)
 {
   /* gchar str[32]; */
   float rgba[4];
@@ -232,25 +244,25 @@ static void triangle_draw(Triangle *T, float thresh, const Shade *shade)
       (!T->children[0] && !T->children[1] && !T->children[2] && !T->children[3]))
     {
       glBegin(GL_TRIANGLE_STRIP);
-      shadeGet_valueTransformedInRGB(shade, rgba, T->value[0]);
+      tool_shade_valueToRGB(shade, rgba, T->value[0]);
       glColor3fv(rgba);
       glVertex3fv(T->vertices[0]);
-      shadeGet_valueTransformedInRGB(shade, rgba, T->value[1]);
+      tool_shade_valueToRGB(shade, rgba, T->value[1]);
       glColor3fv(rgba);
       glVertex3fv(T->vertices[1]);
-      shadeGet_valueTransformedInRGB(shade, rgba, T->value[2]);
+      tool_shade_valueToRGB(shade, rgba, T->value[2]);
       glColor3fv(rgba);
       glVertex3fv(T->vertices[2]);
       glEnd();
       /* sprintf(str, "%6.5f", T->value[0]); */
       /* glColor3fv(T->rgba[0]); */
-      /* glRasterPos3fv(T->vertices[0]); openGLText_drawChars(str, TEXT_SMALL); */
+      /* glRasterPos3fv(T->vertices[0]); visu_gl_text_drawChars(str, VISU_GL_TEXT_SMALL); */
       /* sprintf(str, "%6.5f", T->value[1]); */
       /* glColor3fv(T->rgba[1]); */
-      /* glRasterPos3fv(T->vertices[1]); openGLText_drawChars(str, TEXT_SMALL); */
+      /* glRasterPos3fv(T->vertices[1]); visu_gl_text_drawChars(str, VISU_GL_TEXT_SMALL); */
       /* sprintf(str, "%6.5f", T->value[2]); */
       /* glColor3fv(T->rgba[2]); */
-      /* glRasterPos3fv(T->vertices[2]); openGLText_drawChars(str, TEXT_SMALL); */
+      /* glRasterPos3fv(T->vertices[2]); visu_gl_text_drawChars(str, VISU_GL_TEXT_SMALL); */
       return;
     }
 
@@ -263,7 +275,7 @@ static void triangle_draw(Triangle *T, float thresh, const Shade *shade)
   if (T->children[3])
     triangle_draw(T->children[3], thresh, shade);
 }
-static void triangle_drawWithAlpha(Triangle *T, float thresh, const Shade *shade)
+static void triangle_drawWithAlpha(Triangle *T, float thresh, const ToolShade *shade)
 {
   /* gchar str[32]; */
   float rgba[4];
@@ -272,15 +284,15 @@ static void triangle_drawWithAlpha(Triangle *T, float thresh, const Shade *shade
       (!T->children[0] && !T->children[1] && !T->children[2] && !T->children[3]))
     {
       glBegin(GL_TRIANGLE_STRIP);
-      shadeGet_valueTransformedInRGB(shade, rgba, T->value[0]);
+      tool_shade_valueToRGB(shade, rgba, T->value[0]);
       rgba[3] = T->value[0];
       glColor4fv(rgba);
       glVertex3fv(T->vertices[0]);
-      shadeGet_valueTransformedInRGB(shade, rgba, T->value[1]);
+      tool_shade_valueToRGB(shade, rgba, T->value[1]);
       rgba[3] = T->value[1];
       glColor4fv(rgba);
       glVertex3fv(T->vertices[1]);
-      shadeGet_valueTransformedInRGB(shade, rgba, T->value[2]);
+      tool_shade_valueToRGB(shade, rgba, T->value[2]);
       rgba[3] = T->value[2];
       glColor4fv(rgba);
       glVertex3fv(T->vertices[2]);
@@ -299,7 +311,7 @@ static void triangle_drawWithAlpha(Triangle *T, float thresh, const Shade *shade
 }
 #ifdef HAVE_CAIRO
 static void triangle_drawToCairo(Triangle *T, cairo_t *cr, float thresh,
-                                 const Shade *shade, float basis[2][3], float center[3])
+                                 const ToolShade *shade, float basis[2][3], float center[3])
 {
   float uv[2];
   float v, rgba[4];
@@ -308,15 +320,15 @@ static void triangle_drawToCairo(Triangle *T, cairo_t *cr, float thresh,
       (!T->children[0] && !T->children[1] && !T->children[2] && !T->children[3]))
     {
       v = (T->value[0] + T->value[1] + T->value[2]) / 3.f;
-      shadeGet_valueTransformedInRGB(shade, rgba, v);
+      tool_shade_valueToRGB(shade, rgba, v);
       cairo_set_source_rgba(cr, rgba[0], rgba[1], rgba[2], 1.f);
-      _3DToPlane(uv, T->vertices[0], basis, center);
+      _3DToVisuPlane(uv, T->vertices[0], basis, center);
       cairo_move_to(cr, uv[0], uv[1]);
-      _3DToPlane(uv, T->vertices[1], basis, center);
+      _3DToVisuPlane(uv, T->vertices[1], basis, center);
       cairo_line_to(cr, uv[0], uv[1]);
-      _3DToPlane(uv, T->vertices[2], basis, center);
+      _3DToVisuPlane(uv, T->vertices[2], basis, center);
       cairo_line_to(cr, uv[0], uv[1]);
-      _3DToPlane(uv, T->vertices[0], basis, center);
+      _3DToVisuPlane(uv, T->vertices[0], basis, center);
       cairo_line_to(cr, uv[0], uv[1]);
       cairo_fill_preserve(cr);
       /* cairo_set_source_rgb(cr, 0., 0., 0.); */
@@ -340,6 +352,56 @@ static void triangle_drawToCairo(Triangle *T, cairo_t *cr, float thresh,
 /**************************/
 /* The Map object itself. */
 /**************************/
+/**
+ * visu_map_get_type:
+ * @void: 
+ *
+ * Create and retrieve a #GType for a #VisuMap object.
+ *
+ * Since: 3.7
+ *
+ * Returns: a new type for #VisuMap structures.
+ **/
+GType visu_map_get_type(void)
+{
+  static GType g_define_type_id = 0;
+
+  if (g_define_type_id == 0)
+    g_define_type_id =
+      g_boxed_type_register_static("VisuMap", 
+                                   (GBoxedCopyFunc)visu_map_ref,
+                                   (GBoxedFreeFunc)visu_map_unref);
+  return g_define_type_id;
+}
+/**
+ * visu_map_ref:
+ * @map: a #VisuMap object.
+ *
+ * Increase the ref counter.
+ *
+ * Since: 3.7
+ *
+ * Returns: itself.
+ **/
+VisuMap* visu_map_ref(VisuMap *map)
+{
+  map->refCount += 1;
+  return map;
+}
+/**
+ * visu_map_unref:
+ * @map: a #VisuMap object.
+ *
+ * Decrease the ref counter, free all memory if counter reachs zero.
+ *
+ * Since: 3.7
+ **/
+void visu_map_unref(VisuMap *map)
+{
+  map->refCount -= 1;
+  if (!map->refCount)
+    visu_map_free(map);
+}
 /**
  * visu_map_new:
  *
@@ -347,7 +409,7 @@ static void triangle_drawToCairo(Triangle *T, cairo_t *cr, float thresh,
  *
  * Since: 3.6
  *
- * Returns: a newly created #VisuMap object.
+ * Returns: (transfer full): a newly created #VisuMap object.
  */
 VisuMap* visu_map_new()
 {
@@ -355,8 +417,9 @@ VisuMap* visu_map_new()
 
   map = g_malloc(sizeof(VisuMap));
 
-  map->plane = (Plane*)0;
-  map->field = (ScalarField*)0;
+  map->plane = (VisuPlane*)0;
+  map->moved_signal = 0;
+  map->field = (VisuScalarField*)0;
 
   map->level     = 0;
   map->minmax[0] =  G_MAXFLOAT;
@@ -366,14 +429,12 @@ VisuMap* visu_map_new()
   map->nLines    = 0;
   map->lines     = (VisuLine**)0;
 
-  map->glListId  = visu_openGL_objectList_new(1);
-
   DBG_fprintf(stderr, "Map: create a new map object at %p.\n", (gpointer)map);
   return map;
 }
 /**
  * visu_map_newFromPlane:
- * @plane: a #Plane object.
+ * @plane: a #VisuPlane object.
  *
  * Creates a new #VisuMap object, projected on @plane.
  *
@@ -381,41 +442,12 @@ VisuMap* visu_map_new()
  *
  * Returns: a newly created #VisuMap object.
  */
-VisuMap* visu_map_newFromPlane(Plane *plane)
+VisuMap* visu_map_newFromPlane(VisuPlane *plane)
 {
   VisuMap *map;
-  GList *inter;
-  float xyz[2][3], ABC[3][3];
-  int i;
-
-  inter = planeGet_intersection(plane);
-  planeGet_basis(plane, xyz, ABC[0]);
-  if (!inter)
-    return (VisuMap*)0;
 
   map = visu_map_new();
-  map->plane = plane;
-  g_object_ref(plane);
-  map->triangles = (GList*)0;
-  i = 1;
-  ABC[i][0] = ((float*)inter->data)[0];
-  ABC[i][1] = ((float*)inter->data)[1];
-  ABC[i][2] = ((float*)inter->data)[2];
-  for (inter = g_list_next(inter); inter; inter = g_list_next(inter))
-    {
-      i = i % 2 + 1;
-      ABC[i][0] = ((float*)inter->data)[0];
-      ABC[i][1] = ((float*)inter->data)[1];
-      ABC[i][2] = ((float*)inter->data)[2];
-      map->triangles = g_list_append(map->triangles, triangle_new(ABC, 0));
-    }
-  inter = planeGet_intersection(plane);
-  i = i % 2 + 1;
-  ABC[i][0] = ((float*)inter->data)[0];
-  ABC[i][1] = ((float*)inter->data)[1];
-  ABC[i][2] = ((float*)inter->data)[2];
-  map->triangles = g_list_append(map->triangles, triangle_new(ABC, 0));
-
+  visu_map_setPlane(map, plane);
   return map;
 }
 /**
@@ -428,19 +460,9 @@ VisuMap* visu_map_newFromPlane(Plane *plane)
  */
 void visu_map_free(VisuMap *map)
 {
-  GList *lst;
-  guint i;
-  
   DBG_fprintf(stderr, "Map: free object %p.\n", (gpointer)map);
-  for (lst = map->triangles; lst; lst = g_list_next(lst))
-    triangle_free((Triangle*)lst->data);
-  g_list_free(map->triangles);
-  for (i = 0; i < map->nLines; i++)
-    visu_line_free(map->lines[i]);
-  if (map->lines)
-    g_free(map->lines);
-  if (map->plane)
-    g_object_unref(map->plane);
+  visu_map_setPlane(map, (VisuPlane*)0);
+  visu_map_setField(map, (VisuScalarField*)0, 0, (float*)0);
   g_free(map);
 }
 
@@ -458,20 +480,97 @@ static float** map_getDataAtLevel(VisuMap *map, guint level, guint *n)
   if (n)
     *n = m;
 
-  DBG_fprintf(stderr, "ScalarField: generate the triangle data for %d triangles.\n", m);
+  DBG_fprintf(stderr, "VisuScalarField: generate the triangle data for %d triangles.\n", m);
   i = 0;
   for (lst = map->triangles; lst; lst = g_list_next(lst))
     triangle_getDataAtLevel((Triangle*)lst->data, level, data, &i);
 
   return data;
 }
+/**
+ * visu_map_setPlane:
+ * @map: a #VisuMap object.
+ * @plane: (transfer full) (allow-none): a #VisuPlane object.
+ *
+ * Set the internal #VisuPlane of @map to @plane. All changed to
+ * @plane will be automatically propagated to @map. Use
+ * visu_map_setField() to choose the field to take values from, set
+ * the level precision with visu_map_setLevel() and finally call
+ * visu_map_compute() to get the map.
+ *
+ * Since: 3.7
+ *
+ * Returns: TRUE if internal plane is changed.
+ **/
+gboolean visu_map_setPlane(VisuMap *map, VisuPlane *plane)
+{
+  GList *inter, *lst;
+  float xyz[2][3], ABC[3][3];
+  guint i;
+
+  g_return_val_if_fail(map, FALSE);
+
+  /* Free currently allocated triangles. */
+  for (lst = map->triangles; lst; lst = g_list_next(lst))
+    triangle_free((Triangle*)lst->data);
+  g_list_free(map->triangles);
+  map->triangles = (GList*)0;
+  for (i = 0; i < map->nLines; i++)
+    visu_line_free(map->lines[i]);
+  if (map->lines)
+    g_free(map->lines);
+  map->lines = (VisuLine**)0;
+  map->nLines = 0;
+  /* Free previous handle on plane. */
+  if (map->plane)
+    {
+      g_signal_handler_disconnect(G_OBJECT(map->plane), map->moved_signal);
+      g_object_unref(map->plane);
+    }
+  
+  map->plane = plane;
+  if (!plane)
+    return TRUE;
+
+  /* Reallocate everyone. */
+  g_object_ref(plane);
+  map->moved_signal = g_signal_connect(G_OBJECT(plane), "moved",
+                                       G_CALLBACK(onPlaneMoved), (gpointer)map);
+
+  inter = visu_plane_getIntersection(plane);
+  visu_plane_getBasis(plane, xyz, ABC[0]);
+  if (!inter)
+    return TRUE;
+  
+  i = 1;
+  ABC[i][0] = ((float*)inter->data)[0];
+  ABC[i][1] = ((float*)inter->data)[1];
+  ABC[i][2] = ((float*)inter->data)[2];
+  for (inter = g_list_next(inter); inter; inter = g_list_next(inter))
+    {
+      i = i % 2 + 1;
+      ABC[i][0] = ((float*)inter->data)[0];
+      ABC[i][1] = ((float*)inter->data)[1];
+      ABC[i][2] = ((float*)inter->data)[2];
+      map->triangles = g_list_append(map->triangles, triangle_new(ABC, 0));
+    }
+  inter = visu_plane_getIntersection(plane);
+  i = i % 2 + 1;
+  ABC[i][0] = ((float*)inter->data)[0];
+  ABC[i][1] = ((float*)inter->data)[1];
+  ABC[i][2] = ((float*)inter->data)[2];
+  map->triangles = g_list_append(map->triangles, triangle_new(ABC, 0));
+
+  visu_box_getExtension(visu_boxed_getBox(VISU_BOXED(map->plane)), map->extension);
+
+  return TRUE;
+}
 /**
  * visu_map_setField:
  * @map: a #VisuMap object.
- * @field: a #ScalarField object.
+ * @field: a #VisuScalarField object.
  * @scale: a flag.
  * @inputMinMax: two floats or NULL.
- * @ext: the box extension.
  *
  * It associates the values of @field to @map. The calculation is not
  * directly done, and a call to visu_map_compute() is necessary. If
@@ -481,19 +580,27 @@ static float** map_getDataAtLevel(VisuMap *map, guint level, guint *n)
  *
  * Since: 3.6
  *
- * Returns: a newly created #VisuMap object.
+ * Returns: TRUE if @field is changed.
  */
-gboolean visu_map_setField(VisuMap *map, ScalarField *field,
-                           ToolMatrixScalingFlag scale, float *inputMinMax, float ext[3])
+gboolean visu_map_setField(VisuMap *map, VisuScalarField *field,
+                           ToolMatrixScalingFlag scale, float *inputMinMax)
 {
-  g_return_val_if_fail(map && field, FALSE);
+  g_return_val_if_fail(map, FALSE);
+
+  if (map->field)
+    g_object_unref(G_OBJECT(map->field));
 
   map->field = field;
   map->minmax[0] =  G_MAXFLOAT;
   map->minmax[1] = -G_MAXFLOAT;
 
+  if (!field)
+    return TRUE;
+
+  g_object_ref(G_OBJECT(field));
+
   if (!inputMinMax)
-    scalarFieldGet_minMax(field, map->scaleminmax);
+    visu_scalar_field_getMinMax(field, map->scaleminmax);
   else
     {
       map->scaleminmax[0] = inputMinMax[0];
@@ -503,15 +610,15 @@ gboolean visu_map_setField(VisuMap *map, ScalarField *field,
   /* In log scale, we need the second minimum value. */
   switch (scale)
     {
-    case linear:
+    case TOOL_MATRIX_SCALING_LINEAR:
       map->get_val = tool_matrix_getScaledLinear;
       map->get_inv = tool_matrix_getScaledLinearInv;
       break;
-    case logarithm:
+    case TOOL_MATRIX_SCALING_LOG:
       map->get_val = tool_matrix_getScaledLog;
       map->get_inv = tool_matrix_getScaledLogInv;
       break;
-    case zeroCentredLog:
+    case TOOL_MATRIX_SCALING_ZERO_CENTRED_LOG:
       map->get_val = tool_matrix_getScaledZeroCentredLog;
       map->get_inv = tool_matrix_getScaledZeroCentredLogInv;
       break;
@@ -520,17 +627,15 @@ gboolean visu_map_setField(VisuMap *map, ScalarField *field,
       map->get_inv = tool_matrix_getScaledLinearInv;
       break;
     }
-  map->extension[0] = ext[0];
-  map->extension[1] = ext[1];
-  map->extension[2] = ext[2];
 
   return TRUE;
 }
 /**
  * visu_map_setLevel:
  * @map: a #VisuMap object.
+ * @glPrec: the global OpenGL precision for drawing (default is 1.).
  * @gross: current zoom level.
- * @boxSpan: the size of the rendering box.
+ * @refLength: a reference length (see visu_gl_camera_getRefLength()).
  *
  * Setup the level of recursivity in triangle calculation, depending
  * on the current zoom level.
@@ -539,7 +644,7 @@ gboolean visu_map_setField(VisuMap *map, ScalarField *field,
  *
  * Returns: TRUE if the level is actually changed.
  */
-gboolean visu_map_setLevel(VisuMap *map, float gross, float boxSpan)
+gboolean visu_map_setLevel(VisuMap *map, float glPrec, float gross, float refLength)
 {
   float length, mLength, *xyz, basis[2][3], center[3];
   GList *inter;
@@ -547,10 +652,10 @@ gboolean visu_map_setLevel(VisuMap *map, float gross, float boxSpan)
 
   g_return_val_if_fail(map && map->plane, FALSE);
 
-  planeGet_basis(map->plane, basis, center);
+  visu_plane_getBasis(map->plane, basis, center);
   mLength = 0.f;
   /* In case of no intersections, we build an empty list. */
-  for (inter = planeGet_intersection(map->plane); inter; inter = g_list_next(inter))
+  for (inter = visu_plane_getIntersection(map->plane); inter; inter = g_list_next(inter))
     {
       xyz = (float*)inter->data;
       mLength = MAX(mLength,
@@ -561,7 +666,7 @@ gboolean visu_map_setLevel(VisuMap *map, float gross, float boxSpan)
 
   /* We put by default (precision and gross = 1) 300 triangles along
      the longest line. */
-  length = boxSpan / (300. * VisuOpenGLViewGet_precision() * (gross * .5 + .5));
+  length = refLength / (300. * glPrec * (gross * .5 + .5));
   level = MIN(12, MAX((guint)(log(sqrt(mLength) / length) / log(2)), 1) - 1);
   DBG_fprintf(stderr, "Map: number of division %d for map %p.\n", level, (gpointer)map);
 
@@ -569,6 +674,8 @@ gboolean visu_map_setLevel(VisuMap *map, float gross, float boxSpan)
     return FALSE;
 
   map->level = level;
+  if (level > 20)
+    g_warning("Important level for triangle refining in maps.");
   return TRUE;
 }
 /**
@@ -588,6 +695,8 @@ gboolean visu_map_setLines(VisuMap *map, guint nIsoLines, float minmax[2])
   float v, **data;
   guint i, j, n;
 
+  g_return_val_if_fail(map, FALSE);
+
   DBG_fprintf(stderr, "Map: free old lines (%d).\n", map->nLines);
   for (i = 0; i < map->nLines; i++)
     visu_line_free(map->lines[i]);
@@ -692,7 +801,7 @@ static void map_refine(VisuMap *map, Triangle *T)
  * visu_map_compute:
  * @map: a #VisuMap object.
  *
- * After a #Plane and a #ScalarField has been defined (see
+ * After a #VisuPlane and a #VisuScalarField has been defined (see
  * visu_map_newFromPlane() and visu_map_setField()), the map is
  * computed by refining a triangle approximation up to level defined
  * by visu_map_setLevel(). The evaluation is lazy and calculation is
@@ -707,7 +816,8 @@ void visu_map_compute(VisuMap *map)
 
   g_return_if_fail(map && map->plane && map->field);
 
-  DBG_fprintf(stderr, "Map: refine all triangles of map %p.\n", (gpointer)map);
+  DBG_fprintf(stderr, "Map: refine all triangles of map %p (%d).\n",
+              (gpointer)map, g_list_length(map->triangles));
   for (inter = map->triangles; inter; inter = g_list_next(inter))
     {
       map_refine(map, (Triangle*)inter->data);
@@ -723,36 +833,43 @@ void visu_map_compute(VisuMap *map)
               sizeof(Triangle) / 1024.f);
   DBG_fprintf(stderr, " | %d lines.\n", map->nLines);
 }
+static void onPlaneMoved(VisuPlane *plane, gpointer data)
+{
+  VisuMap *map = (VisuMap*)data;
+
+  /* We reset the plane. */
+  visu_map_setPlane(map, plane);
+  /* We recompute. */
+  if (map->field)
+    visu_map_compute(map);
+}
 /**
  * visu_map_draw:
  * @map: a #VisuMap object.
  * @prec: a pourcentage value.
- * @shade: a #Shade object.
+ * @shade: a #ToolShade object.
  * @rgb: a colour or NULL.
  * @alpha: a boolean.
- * @direct: a boolean.
  *
  * It draws the @map with the given @shade. @prec give the level of
  * refinement used to draw the map, 100 means normal and 200 means
  * twice smaller level. If @rgb is present, this colour is used for
  * possible isolines. If @alpha is TRUE, an alpha channel is added as
- * a linear variation of the value of each vertex. If @direct is
- * FALSE, the drawing is compiled in a list available by calling
- * visu_map_getGlListId().
+ * a linear variation of the value of each vertex.
  * 
  * Since: 3.6
  */
-void visu_map_draw(VisuMap *map, float prec, Shade *shade, float *rgb,
-                   gboolean alpha, gboolean direct)
+void visu_map_draw(VisuMap *map, float prec, ToolShade *shade, float *rgb,
+                   gboolean alpha)
 {
   GList *inter;
   float thresh;
   guint i;
   float rgba[4];
 
-  if (!direct)
-    glNewList(map->glListId, GL_COMPILE);
-
+  if (!map->plane || !map->field)
+    return;
+  
   glDisable(GL_CULL_FACE);
   glDisable(GL_LIGHTING);
 
@@ -771,7 +888,7 @@ void visu_map_draw(VisuMap *map, float prec, Shade *shade, float *rgb,
     {
       if (!rgb)
         {
-          shadeGet_valueTransformedInRGB(shade, rgba, visu_line_getValue(map->lines[i]));
+          tool_shade_valueToRGB(shade, rgba, visu_line_getValue(map->lines[i]));
           rgba[0] = 1.f - rgba[0];
           rgba[1] = 1.f - rgba[1];
           rgba[2] = 1.f - rgba[2];
@@ -780,19 +897,35 @@ void visu_map_draw(VisuMap *map, float prec, Shade *shade, float *rgb,
       visu_line_draw(map->lines[i], rgb);
     }
 
-  DBG_fprintf(stderr, "Map: plot box.\n");
-  glLineWidth(1.f);
-  glColor3f(0.f, 0.f, 0.f);
-  glBegin(GL_LINE_LOOP);
-  for (inter = planeGet_intersection(map->plane); inter; inter = g_list_next(inter))
-    glVertex3fv((float*)inter->data);
-  glEnd();
+  if (!alpha)
+    {
+      DBG_fprintf(stderr, "Map: plot box.\n");
+      glLineWidth(1.f);
+      glColor3f(0.f, 0.f, 0.f);
+      glBegin(GL_LINE_LOOP);
+      for (inter = visu_plane_getIntersection(map->plane); inter; inter = g_list_next(inter))
+        glVertex3fv((float*)inter->data);
+      glEnd();
+    }
 
   glEnable(GL_CULL_FACE);
   glEnable(GL_LIGHTING);
+}
+/**
+ * visu_map_getPlane:
+ * @map: a #VisuMap object.
+ *
+ * Retrieves the plane @map is based on.
+ *
+ * Since: 3.7
+ *
+ * Returns: (transfer none) (allow-none): a #VisuPlane or %NULL.
+ **/
+VisuPlane* visu_map_getPlane(VisuMap *map)
+{
+  g_return_val_if_fail(map, (VisuPlane*)0);
 
-  if (!direct)
-    glEndList();
+  return map->plane;
 }
 /**
  * visu_map_getScaledMinMax:
@@ -830,28 +963,11 @@ float* visu_map_getFieldMinMax(VisuMap *map)
 
   return map->valMinMax;
 }
-/**
- * visu_map_getGlListId:
- * @map: a #VisuMap object.
- *
- * When visu_map_draw() is called with direct being FALSE, one can
- * access the OpenGL list used to draw the map with this routine.
- *
- * Since: 3.6
- *
- * Returns: the OpenGL list id for this map.
- */
-int visu_map_getGlListId(VisuMap *map)
-{
-  g_return_val_if_fail(map, -1);
-
-  return map->glListId;
-}
 
 /**
  * visu_map_export:
  * @map: a #VisuMap object.
- * @shade: a #Shade object.
+ * @shade: a #ToolShade object.
  * @rgb: a colour (can be NULL).
  * @precision: a pourcentage for rendering quality.
  * @filename: the location to export to.
@@ -866,7 +982,7 @@ int visu_map_getGlListId(VisuMap *map)
  *
  * Returns: TRUE if no error.
  */
-gboolean visu_map_export(VisuMap *map, Shade *shade, float *rgb, float precision,
+gboolean visu_map_export(VisuMap *map, ToolShade *shade, float *rgb, float precision,
                          gchar *filename, VisuMapExportFormat format, GError **error)
 {
 #ifdef HAVE_CAIRO
@@ -886,10 +1002,10 @@ gboolean visu_map_export(VisuMap *map, Shade *shade, float *rgb, float precision
 
   viewport[0] = viewport[2] =  G_MAXFLOAT;
   viewport[1] = viewport[3] = -G_MAXFLOAT;
-  planeGet_basis(map->plane, basis, center);
-  for (lst = planeGet_intersection(map->plane); lst; lst = g_list_next(lst))
+  visu_plane_getBasis(map->plane, basis, center);
+  for (lst = visu_plane_getIntersection(map->plane); lst; lst = g_list_next(lst))
     {
-      _3DToPlane(uv, (float*)lst->data, basis, center);
+      _3DToVisuPlane(uv, (float*)lst->data, basis, center);
       viewport[0] = MIN(viewport[0], uv[0]);
       viewport[1] = MAX(viewport[1], uv[0]);
       viewport[2] = MIN(viewport[2], uv[1]);
@@ -952,7 +1068,7 @@ gboolean visu_map_export(VisuMap *map, Shade *shade, float *rgb, float precision
     {
       if (!rgb)
         {
-          shadeGet_valueTransformedInRGB(shade, rgba, visu_line_getValue(map->lines[i]));
+          tool_shade_valueToRGB(shade, rgba, visu_line_getValue(map->lines[i]));
           rgba[0] = 1.f - rgba[0];
           rgba[1] = 1.f - rgba[1];
           rgba[2] = 1.f - rgba[2];
@@ -961,7 +1077,7 @@ gboolean visu_map_export(VisuMap *map, Shade *shade, float *rgb, float precision
         }
       cairo_set_source_rgb(cr, rgb[0], rgb[1], rgb[2]);
 
-      DBG_fprintf(stderr, "ScalarFields: project line on plane %p.\n",
+      DBG_fprintf(stderr, "VisuScalarFields: project line on plane %p.\n",
                   (gpointer)map->plane);
       uvs = visu_line_project(map->lines[i], map->plane, &nVals);
       for (j = 0; j < nVals; j++)
@@ -975,7 +1091,7 @@ gboolean visu_map_export(VisuMap *map, Shade *shade, float *rgb, float precision
 
   /* Add frame. */
   DBG_fprintf(stderr, "Map: export the frame.\n");
-  uvs = planeGet_reducedIntersection(map->plane, &nVals);
+  uvs = visu_plane_getReducedIntersection(map->plane, &nVals);
   if (uvs)
     {
       cairo_set_source_rgb(cr, 0., 0., 0.);
@@ -1002,3 +1118,56 @@ gboolean visu_map_export(VisuMap *map, Shade *shade, float *rgb, float precision
   return FALSE;
 #endif
 }
+
+/*****************/
+/* Init routine. */
+/*****************/
+/**
+ * visu_map_init: (skip)
+ *
+ * Initialise the map routines. Should not be called except at
+ * initialisation time.
+ *
+ * Since: 3.7
+ */
+void visu_map_init()
+{
+  float rgWidth[2] = {0.01f, 10.f};
+  float rgPos[2] = {0.f, 1.f};
+  VisuConfigFileEntry *conf;
+
+  DBG_fprintf(stderr, "Map: set the conf entries for this module.\n");
+  conf = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_RESOURCE,
+                                             FLAG_RESOURCE_LEG_SCALE,
+                                             DESC_RESOURCE_LEG_SCALE,
+                                             1, &visu_map_legendScale, rgWidth);
+  visu_config_file_entry_setVersion(conf, 3.7f);
+  conf = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_RESOURCE,
+                                             FLAG_RESOURCE_LEG_POS,
+                                             DESC_RESOURCE_LEG_POS,
+                                             2, visu_map_legendPosition, rgPos);
+  visu_config_file_entry_setVersion(conf, 3.7f);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_RESOURCE,
+				   exportResources);
+
+  visu_map_legendScale = DEFT_RESOURCE_LEG_SCALE;
+  visu_map_legendPosition[0] = DEFT_RESOURCE_LEG_POS;
+  visu_map_legendPosition[1] = DEFT_RESOURCE_LEG_POS;
+}
+
+/*************************/
+/* Resources management. */
+/*************************/
+static void exportResources(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
+{
+  visu_config_file_exportComment(data, DESC_RESOURCE_LEG_SCALE);
+  visu_config_file_exportEntry(data, FLAG_RESOURCE_LEG_SCALE, NULL,
+                               "%f", visu_map_legendScale);
+
+  visu_config_file_exportComment(data, DESC_RESOURCE_LEG_POS);
+  visu_config_file_exportEntry(data, FLAG_RESOURCE_LEG_POS, NULL,
+                               "%f %f", visu_map_legendPosition[0],
+                               visu_map_legendPosition[1]);
+
+  visu_config_file_exportComment(data, "");
+}
