@@ -41,6 +41,8 @@
 */
 #include <gtk/gtk.h>
 
+#include <string.h>
+
 #include "gtk_elementComboBox.h"
 #include <visu_tools.h>
 #include <visu_object.h>
@@ -76,19 +78,19 @@ enum
     N_COLUMN_ELEMENT
   };
 
-static void elementComboBox_dispose (GObject *obj);
-static void elementComboBox_finalize(GObject *obj);
+static void visu_ui_element_combobox_dispose (GObject *obj);
+static void visu_ui_element_combobox_finalize(GObject *obj);
 
-static guint elementComboBox_signals[LAST_SIGNAL] = { 0 };
+static guint visu_ui_element_combobox_signals[LAST_SIGNAL] = { 0 };
 
 /**
- * ElementComboBox:
+ * VisuUiElementCombobox:
  *
- * An opaque structure defining a #ElementComboBox widget.
+ * An opaque structure defining a #VisuUiElementCombobox widget.
  *
  * Since: 3.6
  */
-struct _ElementComboBox
+struct _VisuUiElementCombobox
 {
   GtkComboBox comboElement;
   GtkTreeModel *filter;
@@ -98,6 +100,7 @@ struct _ElementComboBox
 
   gboolean hasAllSelector;
   gboolean hasNoneSelector;
+  gboolean showUnPhysical;
   gchar *format;
 
   /* Memory gestion. */
@@ -105,66 +108,78 @@ struct _ElementComboBox
 };
 
 /**
- * ElementComboBoxClass:
+ * VisuUiElementComboboxClass:
  *
- * An opaque structure defining the class of a #ElementComboBox widget.
+ * An opaque structure defining the class of a #VisuUiElementCombobox widget.
  *
  * Since: 3.6
  */
-struct _ElementComboBoxClass
+struct _VisuUiElementComboboxClass
 {
   GtkComboBoxClass parent_class;
 
-  void (*elementComboBox) (ElementComboBox *shadeCombo);
+  void (*elementComboBox) (VisuUiElementCombobox *shadeCombo);
 
   /* This listStore contains all the elements
      known by widgets of this class. It is used
      as TreeModel for the combobox in the widget. */
   GtkListStore *storedElements;
 
-  gulong newElementSignalId;
+  gulong newElementSignalId, popDef_signal;
   gboolean disableChangeSignal;
 };
-static ElementComboBoxClass *my_class = (ElementComboBoxClass*)0;
+static VisuUiElementComboboxClass *my_class = (VisuUiElementComboboxClass*)0;
 
 /* Local callbacks. */
 static void onChanged(GtkComboBox *widget, gpointer user_data);
 static gboolean onElementNewHook(GSignalInvocationHint *ihint, guint nvalues,
                                  const GValue *param_values, gpointer data);
-static void onDataReady(ElementComboBoxClass *klass, VisuData *data, gpointer user_data);
-static void onDataReadySelection(ElementComboBox *combo, VisuData *data,
-                                 gpointer user_data _U_);
+static void onDataReady(VisuUiElementComboboxClass *klass, VisuData *data,
+                        VisuGlView *view, gpointer user_data);
+static void onDataNotReady(VisuUiElementComboboxClass *klass, VisuData *data,
+                           VisuGlView *view, gpointer user_data);
+static void onPopulationDefined(VisuNodeArray *array, guint nEle, gpointer data);
+static void onDataReadySelection(VisuUiElementCombobox *combo, VisuData *data,
+                                 VisuGlView *view, gpointer user_data);
 
 /* Local methods. */
-static void addElementToModel(GtkTreeIter *iter, ElementComboBoxClass* klass,
+static void addElementToModel(GtkTreeIter *iter, VisuUiElementComboboxClass* klass,
                               gpointer element);
 static void printLabel(GtkCellLayout *layout, GtkCellRenderer *cell,
                        GtkTreeModel *model, GtkTreeIter *iter, gpointer data);
 static gboolean showLabel(GtkTreeModel *model, GtkTreeIter *iter, gpointer data);
 
-G_DEFINE_TYPE(ElementComboBox, elementComboBox, GTK_TYPE_COMBO_BOX)
+/**
+ * visu_ui_element_combobox_get_type:
+ *
+ * Internal routine, retrieves the type of #VisuUiElementCombobox
+ * objects. Use VISU_UI_TYPE_ELEMENT_COMBOBOX macro instead.
+ *
+ * Since: 3.6
+ */
+G_DEFINE_TYPE(VisuUiElementCombobox, visu_ui_element_combobox, GTK_TYPE_COMBO_BOX)
 
-static void elementComboBox_class_init(ElementComboBoxClass *klass)
+static void visu_ui_element_combobox_class_init(VisuUiElementComboboxClass *klass)
 {
   GtkTreeIter iter;
   GList *elementLst;
   
-  DBG_fprintf(stderr, "Gtk ElementComboBox: creating the class of the widget.\n");
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: creating the class of the widget.\n");
   DBG_fprintf(stderr, "                     - adding new signals ;\n");
   /**
-   * ElementComboBox::element-selected:
-   * @combo: the #ElementComboBox that emits the signal ;
+   * VisuUiElementCombobox::element-selected:
+   * @combo: the #VisuUiElementCombobox that emits the signal ;
    * @element: the newly selected #VisuElement.
    *
    * This signal is emitted when a new element is selected.
    *
    * Since: 3.6
    */
-  elementComboBox_signals[ELEMENT_SELECTED_SIGNAL] =
+  visu_ui_element_combobox_signals[ELEMENT_SELECTED_SIGNAL] =
     g_signal_new ("element-selected",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
-		  G_STRUCT_OFFSET (ElementComboBoxClass, elementComboBox),
+		  G_STRUCT_OFFSET (VisuUiElementComboboxClass, elementComboBox),
 		  NULL, 
 		  NULL,                
 		  g_cclosure_marshal_VOID__POINTER,
@@ -183,66 +198,68 @@ static void elementComboBox_class_init(ElementComboBoxClass *klass)
     addElementToModel(&iter, klass, elementLst->data);
 
   /* Connect freeing methods. */
-  G_OBJECT_CLASS(klass)->dispose  = elementComboBox_dispose;
-  G_OBJECT_CLASS(klass)->finalize = elementComboBox_finalize;
+  G_OBJECT_CLASS(klass)->dispose  = visu_ui_element_combobox_dispose;
+  G_OBJECT_CLASS(klass)->finalize = visu_ui_element_combobox_finalize;
 
-  g_signal_add_emission_hook(g_signal_lookup("ElementNew", VISU_ELEMENT_TYPE),
+  g_signal_add_emission_hook(g_signal_lookup("ElementNew", VISU_TYPE_ELEMENT),
                              0, onElementNewHook, (gpointer)klass, (GDestroyNotify)0);
-  g_signal_connect_swapped(VISU_INSTANCE, "dataReadyForRendering",
+  g_signal_connect_swapped(VISU_OBJECT_INSTANCE, "dataRendered",
                            G_CALLBACK(onDataReady), (gpointer)klass);
+  g_signal_connect_swapped(VISU_OBJECT_INSTANCE, "dataUnRendered",
+                           G_CALLBACK(onDataNotReady), (gpointer)klass);
 
   my_class = klass;
   klass->disableChangeSignal = FALSE;
 }
 
-static void elementComboBox_dispose(GObject *obj)
+static void visu_ui_element_combobox_dispose(GObject *obj)
 {
-  DBG_fprintf(stderr, "Gtk ElementComboBox: dispose object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: dispose object %p.\n", (gpointer)obj);
 
-  if (ELEMENT_COMBOX(obj)->dispose_has_run)
+  if (VISU_UI_ELEMENT_COMBOBOX(obj)->dispose_has_run)
     return;
 
-  ELEMENT_COMBOX(obj)->dispose_has_run = TRUE;
+  VISU_UI_ELEMENT_COMBOBOX(obj)->dispose_has_run = TRUE;
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(elementComboBox_parent_class)->dispose(obj);
+  G_OBJECT_CLASS(visu_ui_element_combobox_parent_class)->dispose(obj);
 }
-static void elementComboBox_finalize(GObject *obj)
+static void visu_ui_element_combobox_finalize(GObject *obj)
 {
   g_return_if_fail(obj);
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: finalize object %p.\n", (gpointer)obj);
-  if (ELEMENT_COMBOX(obj)->format)
-    g_free(ELEMENT_COMBOX(obj)->format);
-  g_object_unref(ELEMENT_COMBOX(obj)->filter);
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: finalize object %p.\n", (gpointer)obj);
+  if (VISU_UI_ELEMENT_COMBOBOX(obj)->format)
+    g_free(VISU_UI_ELEMENT_COMBOBOX(obj)->format);
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(elementComboBox_parent_class)->finalize(obj);
+  G_OBJECT_CLASS(visu_ui_element_combobox_parent_class)->finalize(obj);
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
 
 
-static void elementComboBox_init(ElementComboBox *elementComboBox)
+static void visu_ui_element_combobox_init(VisuUiElementCombobox *elementComboBox)
 {
-  DBG_fprintf(stderr, "Gtk ElementComboBox: initializing new object (%p).\n",
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: initializing new object (%p).\n",
 	      (gpointer)elementComboBox);
 
   elementComboBox->hasAllSelector    = FALSE;
   elementComboBox->hasNoneSelector   = FALSE;
+  elementComboBox->showUnPhysical    = FALSE;
   elementComboBox->format            = g_strdup("%s");
   elementComboBox->dispose_has_run   = FALSE;
   elementComboBox->previousSelection = (gpointer)0;
 
-  g_signal_connect_swapped(VISU_INSTANCE, "dataReadyForRendering",
+  g_signal_connect_swapped(VISU_OBJECT_INSTANCE, "dataRendered",
                            G_CALLBACK(onDataReadySelection),
                            (gpointer)elementComboBox);
 }
 
 /**
- * elementComboBox_new:
+ * visu_ui_element_combobox_new:
  * @hasAllSelector: a boolean.
  * @hasNoneSelector: a boolean.
- * @format: a string (can be NULL).
+ * @format: (allow-none): a string (can be NULL).
  *
  * Creates a #GtkComboBox with a list of available #VisuElement. This
  * list can contain in addition a "all" value if @hasAllSelector is
@@ -252,18 +269,18 @@ static void elementComboBox_init(ElementComboBox *elementComboBox)
  * 
  * Since: 3.6
  *
- * Returns: a newly created widget.
+ * Returns: (transfer full): a newly created widget.
  */
-GtkWidget* elementComboBox_new(gboolean hasAllSelector, gboolean hasNoneSelector,
+GtkWidget* visu_ui_element_combobox_new(gboolean hasAllSelector, gboolean hasNoneSelector,
                                const gchar *format)
 {
-  ElementComboBox *wd;
+  VisuUiElementCombobox *wd;
   GObjectClass *klass;
   GtkCellRenderer *renderer;
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: creating new object with format: '%s'.\n",
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: creating new object with format: '%s'.\n",
 	      format);
-  wd = ELEMENT_COMBOX(g_object_new(elementComboBox_get_type (), NULL));
+  wd = VISU_UI_ELEMENT_COMBOBOX(g_object_new(visu_ui_element_combobox_get_type (), NULL));
   wd->hasAllSelector  = hasAllSelector;
   wd->hasNoneSelector = hasNoneSelector;
   if (format)
@@ -272,15 +289,16 @@ GtkWidget* elementComboBox_new(gboolean hasAllSelector, gboolean hasNoneSelector
       wd->format = g_strdup(format);
     }
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: build widgets.\n");
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: build widgets.\n");
   klass = G_OBJECT_GET_CLASS(wd);
   wd->filter = gtk_tree_model_filter_new
-    (GTK_TREE_MODEL(ELEMENT_COMBOX_CLASS(klass)->storedElements), (GtkTreePath*)0);
+    (GTK_TREE_MODEL(VISU_UI_ELEMENT_COMBOBOX_CLASS(klass)->storedElements), (GtkTreePath*)0);
   gtk_combo_box_set_model(GTK_COMBO_BOX(wd), wd->filter);
+  g_object_unref(wd->filter);
   gtk_tree_model_filter_set_visible_func(GTK_TREE_MODEL_FILTER(wd->filter),
                                          showLabel, wd, (GDestroyNotify)0);
   gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(wd->filter));
-  DBG_fprintf(stderr, "Gtk ElementComboBox: use filter %p.\n", (gpointer)wd->filter);
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: use filter %p.\n", (gpointer)wd->filter);
 
   renderer = gtk_cell_renderer_text_new();
   gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(wd), renderer, TRUE);
@@ -290,7 +308,7 @@ GtkWidget* elementComboBox_new(gboolean hasAllSelector, gboolean hasNoneSelector
 
   wd->onChanged = g_signal_connect(G_OBJECT(wd), "changed",
                                    G_CALLBACK(onChanged), (gpointer)wd);
-  gtk_combo_box_set_active(GTK_COMBO_BOX(wd), 0);
+  gtk_combo_box_set_active(GTK_COMBO_BOX(wd), (hasAllSelector)?1:0);
 
   return GTK_WIDGET(wd);
 }
@@ -299,10 +317,11 @@ static gboolean onElementNewHook(GSignalInvocationHint *ihint _U_, guint nvalues
                                  const GValue *param_values, gpointer data)
 {
   GtkTreeIter iter;
+  VisuElement *ele;
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: found a new element.\n");
-  addElementToModel(&iter, ELEMENT_COMBOX_CLASS(data),
-                    (gpointer)VISU_ELEMENT(g_value_get_object(param_values)));
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: found a new element.\n");
+  ele = VISU_ELEMENT(g_value_get_object(param_values));
+  addElementToModel(&iter, VISU_UI_ELEMENT_COMBOBOX_CLASS(data), (gpointer)ele);
   return TRUE;
 }
 
@@ -312,25 +331,25 @@ static void onChanged(GtkComboBox *widget, gpointer user_data _U_)
   gpointer *data;
   GList *lst;
 
-  if (ELEMENT_COMBOX_GET_CLASS(widget)->disableChangeSignal)
+  if (VISU_UI_ELEMENT_COMBOBOX_GET_CLASS(widget)->disableChangeSignal)
     return;
 
   if (!gtk_combo_box_get_active_iter(widget, &iter))
     return;
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: internal combobox changed signal.\n");
-  gtk_tree_model_get(ELEMENT_COMBOX(widget)->filter, &iter,
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: internal combobox changed signal.\n");
+  gtk_tree_model_get(VISU_UI_ELEMENT_COMBOBOX(widget)->filter, &iter,
                      COLUMN_ELEMENT_POINTER_TO, &data, -1);
 
-  if (data != ELEMENT_COMBOX(widget)->previousSelection)
+  if (data != VISU_UI_ELEMENT_COMBOBOX(widget)->previousSelection)
     {
-      ELEMENT_COMBOX(widget)->previousSelection = data;
+      VISU_UI_ELEMENT_COMBOBOX(widget)->previousSelection = data;
 
-      lst = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(widget));
-      DBG_fprintf(stderr, "Gtk ElementComboBox: emitting 'element-selected'"
+      lst = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(widget));
+      DBG_fprintf(stderr, "VisuUi ElementCombobox: emitting 'element-selected'"
                   " signal with list %p.\n", (gpointer)lst);
       g_signal_emit(G_OBJECT(widget),
-		    elementComboBox_signals[ELEMENT_SELECTED_SIGNAL],
+		    visu_ui_element_combobox_signals[ELEMENT_SELECTED_SIGNAL],
                     0, (gpointer)lst, NULL);
       DBG_fprintf(stderr, " | free list\n");
       if (lst)
@@ -338,17 +357,17 @@ static void onChanged(GtkComboBox *widget, gpointer user_data _U_)
       DBG_fprintf(stderr, " | OK\n");
     }
   else
-    DBG_fprintf(stderr, "Gtk ElementComboBox: aborting 'element-selected' signal.\n");
+    DBG_fprintf(stderr, "VisuUi ElementCombobox: aborting 'element-selected' signal.\n");
 }
 
-static void addElementToModel(GtkTreeIter *iter, ElementComboBoxClass* klass,
+static void addElementToModel(GtkTreeIter *iter, VisuUiElementComboboxClass* klass,
                               gpointer element)
 {
   gboolean visible;
 
   g_return_if_fail(iter && klass);
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: appending a new element '%p'.\n",
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: appending a new element '%p'.\n",
 	      element);
   visible = (element && GPOINTER_TO_INT(element) != 1)?FALSE:TRUE;
   gtk_list_store_append(klass->storedElements, iter);
@@ -371,7 +390,7 @@ static void printLabel(GtkCellLayout *layout _U_, GtkCellRenderer *cell,
     g_object_set(G_OBJECT(cell), "text", _("All elements"), NULL);
   else
     {
-      str = g_strdup_printf(ELEMENT_COMBOX(data)->format, ((VisuElement*)pt)->name);
+      str = g_strdup_printf(VISU_UI_ELEMENT_COMBOBOX(data)->format, ((VisuElement*)pt)->name);
       g_object_set(G_OBJECT(cell), "text", str, NULL);
       g_free(str);
     }
@@ -384,17 +403,22 @@ static gboolean showLabel(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 
   gtk_tree_model_get(model, iter, COLUMN_ELEMENT_POINTER_TO, &pt,
                      COLUMN_ELEMENT_VISIBLE, &visible, -1);
-  DBG_fprintf(stderr, "Gtk ElementComboBox: filter entry '%s' for model %p.\n",
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: filter entry '%s' %p for model %p -> %d.\n",
               (GPOINTER_TO_INT(pt) != 0 &&
-               GPOINTER_TO_INT(pt) != 1)?VISU_ELEMENT(pt)->name:"None", (gpointer)model);
-  return (!pt && ELEMENT_COMBOX(data)->hasNoneSelector) ||
-    (pt && GPOINTER_TO_INT(pt) == 1 && ELEMENT_COMBOX(data)->hasAllSelector) ||
-    (pt && GPOINTER_TO_INT(pt) != 1 && visible);
+               GPOINTER_TO_INT(pt) != 1)?VISU_ELEMENT(pt)->name:"None", (gpointer)pt,
+              (gpointer)model, (!pt && VISU_UI_ELEMENT_COMBOBOX(data)->hasNoneSelector) ||
+              (pt && GPOINTER_TO_INT(pt) == 1 && VISU_UI_ELEMENT_COMBOBOX(data)->hasAllSelector) ||
+              (pt && GPOINTER_TO_INT(pt) != 1 && visible));
+  return (!pt && VISU_UI_ELEMENT_COMBOBOX(data)->hasNoneSelector) ||
+    (pt && GPOINTER_TO_INT(pt) == 1 && VISU_UI_ELEMENT_COMBOBOX(data)->hasAllSelector) ||
+    (pt && GPOINTER_TO_INT(pt) != 1 &&
+     visible && (VISU_UI_ELEMENT_COMBOBOX(data)->showUnPhysical ||
+                 visu_element_getPhysical(VISU_ELEMENT(pt))));
 }
 
 /**
- * elementComboBoxSet_selection:
- * @wd: a #ElementComboBox widget.
+ * visu_ui_element_combobox_setSelection:
+ * @wd: a #VisuUiElementCombobox widget.
  * @name: a string.
  *
  * Select a #VisuElement by providing its name.
@@ -403,15 +427,15 @@ static gboolean showLabel(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
  *
  * Returns: TRUE if the given element exists.
  */
-gboolean elementComboBoxSet_selection(ElementComboBox* wd, const gchar *name)
+gboolean visu_ui_element_combobox_setSelection(VisuUiElementCombobox* wd, const gchar *name)
 {
   GtkTreeIter iter;
   gboolean valid;
   gpointer *pt;
 
-  g_return_val_if_fail(IS_ELEMENT_COMBOX(wd) && name, FALSE);
+  g_return_val_if_fail(VISU_UI_IS_ELEMENT_COMBOBOX(wd) && name, FALSE);
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: select a new element '%s'.\n",
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: select a new element '%s'.\n",
               name);
 
   for (valid = gtk_tree_model_get_iter_first(wd->filter, &iter);
@@ -427,24 +451,25 @@ gboolean elementComboBoxSet_selection(ElementComboBox* wd, const gchar *name)
   return FALSE;
 }
 /**
- * elementComboBoxGet_selectedElement:
- * @wd: a #ElementComboBox widget.
+ * visu_ui_element_combobox_getSelection:
+ * @wd: a #VisuUiElementCombobox widget.
  *
  * Provide a list of selected elements.
  *
  * Since: 3.6
  *
- * Returns: (transfer container): a newly created list of
- * #VisuElement. It should be freed later with g_list_free().
+ * Returns: (transfer container) (element-type VisuElement*): a newly
+ * created list of #VisuElement. It should be freed later with
+ * g_list_free().
  */
-GList* elementComboBoxGet_selectedElement(ElementComboBox *wd)
+GList* visu_ui_element_combobox_getSelection(VisuUiElementCombobox *wd)
 {
   GtkTreeIter iter;
   gpointer *data;
   GList *lst;
   gboolean valid;
 
-  g_return_val_if_fail(IS_ELEMENT_COMBOX(wd), (GList*)0);
+  g_return_val_if_fail(VISU_UI_IS_ELEMENT_COMBOBOX(wd), (GList*)0);
 
   if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(wd), &iter))
     return (GList*)0;
@@ -459,64 +484,98 @@ GList* elementComboBoxGet_selectedElement(ElementComboBox *wd)
       {
         gtk_tree_model_get(wd->filter, &iter,
                            COLUMN_ELEMENT_POINTER_TO, &data, -1);
-        if (data && GPOINTER_TO_INT(data) != 1)
+        if (data && GPOINTER_TO_INT(data) != 1 &&
+            visu_element_getPhysical(VISU_ELEMENT(data)))
           lst = g_list_prepend(lst, data);
       }
   else if (data)
     lst = g_list_prepend(lst, data);
 
-  DBG_fprintf(stderr, "Gtk ElementComboBox: return a list of %d elements.\n",
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: return a list of %d elements.\n",
               g_list_length(lst));
 
   return lst;
 }
-static void onDataReady(ElementComboBoxClass *klass, VisuData *data,
-                        gpointer user_data _U_)
+
+static void refreshCombo(VisuUiElementComboboxClass *klass, VisuNodeArray *array)
 {
   gboolean valid;
   GtkTreeIter child;
-  guint i;
   GtkTreeModel *model;
   gpointer pt;
-  
-  DBG_fprintf(stderr, "Gtk ElementComboBox: set visible elements from data %p.\n",
-              (gpointer)data);
 
   klass->disableChangeSignal = TRUE;
 
   model = GTK_TREE_MODEL(klass->storedElements);
   for (valid = gtk_tree_model_get_iter_first(model, &child); valid;
        valid = gtk_tree_model_iter_next(model, &child))
-    gtk_list_store_set(klass->storedElements, &child,
-                       COLUMN_ELEMENT_VISIBLE, FALSE, -1);
-
-  if (data)
     {
-      for (valid = gtk_tree_model_get_iter_first(model, &child); valid;
-           valid = gtk_tree_model_iter_next(model, &child))
-        {
-          gtk_tree_model_get(model, &child, COLUMN_ELEMENT_POINTER_TO, &pt, -1);
-          if (pt && GPOINTER_TO_INT(pt) != 1)
-            for (i = 0; i < data->ntype; i++)
-              if (pt == data->fromIntToVisuElement[i])
-                {
-                  gtk_list_store_set(klass->storedElements,
-                                     &child, COLUMN_ELEMENT_VISIBLE, TRUE, -1);
-                  break;
-                }
-        }
+      gtk_tree_model_get(model, &child, COLUMN_ELEMENT_POINTER_TO, &pt, -1);
+      if (pt && GPOINTER_TO_INT(pt) != 1 && array &&
+          visu_node_array_getElementId(array, VISU_ELEMENT(pt)) >= 0)
+        gtk_list_store_set(klass->storedElements, &child,
+                           COLUMN_ELEMENT_VISIBLE, TRUE, -1);
+      else
+        gtk_list_store_set(klass->storedElements, &child,
+                           COLUMN_ELEMENT_VISIBLE, FALSE, -1);
     }
 
   klass->disableChangeSignal = FALSE;
 }
+static void onDataReady(VisuUiElementComboboxClass *klass, VisuData *data,
+                        VisuGlView *view _U_, gpointer user_data _U_)
+{  
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: set visible elements from data %p.\n",
+              (gpointer)data);
 
-static void onDataReadySelection(ElementComboBox *combo, VisuData *data,
-                                 gpointer user_data _U_)
+  if (data)
+    refreshCombo(klass, VISU_NODE_ARRAY(data));
+  else
+  refreshCombo(klass, (VisuNodeArray*)0);
+  if (data)
+    klass->popDef_signal =
+      g_signal_connect(G_OBJECT(data), "PopulationDefined",
+                       G_CALLBACK(onPopulationDefined), (gpointer)klass);
+}
+static void onDataNotReady(VisuUiElementComboboxClass *klass, VisuData *data,
+                           VisuGlView *view _U_, gpointer user_data _U_)
+{  
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: unset visible elements from data %p.\n",
+              (gpointer)data);
+  g_signal_handler_disconnect(G_OBJECT(data), klass->popDef_signal);
+}
+static void onPopulationDefined(VisuNodeArray *array, guint nEle _U_, gpointer data)
+{
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: refresh list on population defined.\n");
+  refreshCombo(VISU_UI_ELEMENT_COMBOBOX_CLASS(data), array);
+}
+
+static void onDataReadySelection(VisuUiElementCombobox *combo, VisuData *data,
+                                 VisuGlView *view _U_, gpointer user_data _U_)
 {
   if (!data)
     return;
 
-  gtk_combo_box_set_active(GTK_COMBO_BOX(combo),
-                           MIN((combo->hasAllSelector)?1:0,
-                               gtk_tree_model_iter_n_children(combo->filter, (GtkTreeIter*)0) - 1));;
+  if (gtk_combo_box_get_active(GTK_COMBO_BOX(combo)) < 0)
+    gtk_combo_box_set_active(GTK_COMBO_BOX(combo),
+                             MIN((combo->hasAllSelector)?1:0,
+                                 gtk_tree_model_iter_n_children(combo->filter,
+                                                                (GtkTreeIter*)0) - 1));
+}
+/**
+ * visu_ui_element_combobox_setUnphysicalStatus:
+ * @wd: a #VisuUiElementCombobox object ;
+ * @status: a boolean
+ *
+ * If @status is TRUE, the combobox will also show elements that are
+ * tagged unphysical, see visu_element_getPhysical().
+ *
+ * Since: 3.7
+ */
+void visu_ui_element_combobox_setUnphysicalStatus(VisuUiElementCombobox* wd,
+                                                  gboolean status)
+{
+  g_return_if_fail(VISU_UI_IS_ELEMENT_COMBOBOX(wd));
+
+  wd->showUnPhysical = status;
 }
