@@ -58,10 +58,17 @@
  * Since: 3.5
  */
 
-static void valueIO_dispose (GObject *obj);
-static void valueIO_finalize(GObject *obj);
+static void visu_ui_value_io_dispose (GObject *obj);
+static void visu_ui_value_io_finalize(GObject *obj);
 
-struct _ValueIO
+/**
+ * VisuUiValueIo:
+ *
+ * Private structure to store informations of a #VisuUiValueIo object.
+ *
+ * Since: 3.5
+ */
+struct _VisuUiValueIo
 {
   GtkHBox hbox;
 
@@ -71,21 +78,27 @@ struct _ValueIO
 #endif
   GtkWindow *parent;
 
-  ValueIOCallback ioOpen;
+  VisuUiValueIoCallback ioOpen;
   gulong openSignalId;
-  ValueIOCallback ioSave;
+  VisuUiValueIoCallback ioSave;
   gulong saveSignalId;
   gulong saveAsSignalId;
 
   /* Memory gestion. */
   gboolean dispose_has_run;
 };
-
-struct _ValueIOClass
+/**
+ * VisuUiValueIoClass
+ *
+ * Private structure to store informations of a #VisuUiValueIoClass object.
+ *
+ * Since: 3.5
+ */
+struct _VisuUiValueIoClass
 {
   GtkComboBoxClass parent_class;
 
-  void (*valueio) (ValueIO *hbox);
+  void (*valueio) (VisuUiValueIo *hbox);
 };
 
 /* Local callbacks. */
@@ -101,54 +114,63 @@ static void onExportXML(GtkButton *button, gpointer data);
 
 /* Local methods. */
 
-G_DEFINE_TYPE(ValueIO, valueIO, GTK_TYPE_HBOX)
+/**
+ * visu_ui_value_io_get_type
+ *
+ * #GType are unique numbers to identify objects.
+ *
+ * Returns: the #GType associated with #VisuUiValueIo objects.
+ *
+ * Since: 3.5
+ */
+G_DEFINE_TYPE(VisuUiValueIo, visu_ui_value_io, GTK_TYPE_HBOX)
 
-static void valueIO_class_init(ValueIOClass *klass)
+static void visu_ui_value_io_class_init(VisuUiValueIoClass *klass)
 {
-  DBG_fprintf(stderr, "Gtk ValueIO: creating the class of the widget.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: creating the class of the widget.\n");
   
   /* Connect freeing methods. */
-  G_OBJECT_CLASS(klass)->dispose = valueIO_dispose;
-  G_OBJECT_CLASS(klass)->finalize = valueIO_finalize;
+  G_OBJECT_CLASS(klass)->dispose = visu_ui_value_io_dispose;
+  G_OBJECT_CLASS(klass)->finalize = visu_ui_value_io_finalize;
 }
 
-static void valueIO_dispose(GObject *obj)
+static void visu_ui_value_io_dispose(GObject *obj)
 {
-  DBG_fprintf(stderr, "Gtk ValueIO: dispose object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: dispose object %p.\n", (gpointer)obj);
 
-  if (VALUE_IO(obj)->dispose_has_run)
+  if (VISU_UI_VALUE_IO(obj)->dispose_has_run)
     return;
 
-  VALUE_IO(obj)->dispose_has_run = TRUE;
+  VISU_UI_VALUE_IO(obj)->dispose_has_run = TRUE;
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(valueIO_parent_class)->dispose(obj);
+  G_OBJECT_CLASS(visu_ui_value_io_parent_class)->dispose(obj);
 }
-static void valueIO_finalize(GObject *obj)
+static void visu_ui_value_io_finalize(GObject *obj)
 {
   g_return_if_fail(obj);
 
-  DBG_fprintf(stderr, "Gtk ValueIO: finalize object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: finalize object %p.\n", (gpointer)obj);
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(valueIO_parent_class)->finalize(obj);
+  G_OBJECT_CLASS(visu_ui_value_io_parent_class)->finalize(obj);
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
 
 
-static void valueIO_init(ValueIO *valueio)
+static void visu_ui_value_io_init(VisuUiValueIo *valueio)
 {
-  DBG_fprintf(stderr, "Gtk ValueIO: initializing new object (%p).\n",
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: initializing new object (%p).\n",
 	      (gpointer)valueio);
 
-  valueio->ioOpen         = (ValueIOCallback)0;
+  valueio->ioOpen         = (VisuUiValueIoCallback)0;
   valueio->openSignalId   = 0;
-  valueio->ioSave         = (ValueIOCallback)0;
+  valueio->ioSave         = (VisuUiValueIoCallback)0;
   valueio->saveSignalId   = 0;
   valueio->saveAsSignalId = 0;
 }
 
-static void buildWidgets(ValueIO *valueio, GtkWindow *parent,
+static void buildWidgets(VisuUiValueIo *valueio, GtkWindow *parent,
 			 const gchar*tipsOpen, const gchar*tipsSave,
 			 const gchar*tipsSaveAs)
 {
@@ -206,7 +228,7 @@ static void buildWidgets(ValueIO *valueio, GtkWindow *parent,
 #endif
 #endif
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
-  directory = visuGtkGet_lastOpenDirectory();
+  directory = visu_ui_getLastOpenDirectory();
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(valueio->btExportOpen),
 					directory);
@@ -220,48 +242,48 @@ static void buildWidgets(ValueIO *valueio, GtkWindow *parent,
 }
 
 /**
- * valueIONew:
+ * visu_ui_value_io_new:
  * @parent: the parent used to show the file dialog.
  * @tipsOpen: a tooltip to show on open button.
  * @tipsSave: a tooltip to show on save button.
  * @tipsSaveAs: a tooltip to show on save-as button.
  *
- * A #ValueIO widget is like a #GtkComboBox widget, but it is already filled
+ * A #VisuUiValueIo widget is like a #GtkComboBox widget, but it is already filled
  * with predefined line patterns (call stipple). Using this widget is
  * a convienient way to share stipples between all part of V_Sim and
  * to give a consistent look of all stipple selection.
  *
  * Since: 3.5
  *
- * Returns: a newly created #ValueIO widget.
+ * Returns: (transfer full): a newly created #VisuUiValueIo widget.
  */
-GtkWidget* valueIONew(GtkWindow *parent, const gchar*tipsOpen,
-		      const gchar*tipsSave, const gchar*tipsSaveAs)
+GtkWidget* visu_ui_value_io_new(GtkWindow *parent, const gchar*tipsOpen,
+                                const gchar*tipsSave, const gchar*tipsSaveAs)
 {
-  ValueIO *valueio;
+  VisuUiValueIo *valueio;
 
-  DBG_fprintf(stderr, "Gtk ValueIO: creating new object.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: creating new object.\n");
 
-  valueio = VALUE_IO(g_object_new(valueIO_get_type (), NULL));
+  valueio = VISU_UI_VALUE_IO(g_object_new(visu_ui_value_io_get_type (), NULL));
 
-  DBG_fprintf(stderr, "Gtk ValueIO: build widgets.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: build widgets.\n");
 
   buildWidgets(valueio, parent, tipsOpen, tipsSave, tipsSaveAs);
 
   return GTK_WIDGET(valueio);
 }
 /**
- * valueIOConnect_open:
- * @valueio: a #ValueIO widget.
+ * visu_ui_value_io_connectOnOpen:
+ * @valueio: a #VisuUiValueIo widget.
  * @open: a method.
  * 
  * Set the function to call when the open button is clicked.
  * 
  * Since: 3.5
  */
-void valueIOConnect_open(ValueIO *valueio, ValueIOCallback open)
+void visu_ui_value_io_connectOnOpen(VisuUiValueIo *valueio, VisuUiValueIoCallback open)
 {
-  g_return_if_fail(IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
 
   if (valueio->openSignalId)
     {
@@ -297,17 +319,17 @@ void valueIOConnect_open(ValueIO *valueio, ValueIOCallback open)
 #endif
 }
 /**
- * valueIOConnect_save:
- * @valueio: a #ValueIO widget.
+ * visu_ui_value_io_connectOnSave:
+ * @valueio: a #VisuUiValueIo widget.
  * @save: a method.
  * 
  * Set the function to call when the save or save-as button is clicked.
  * 
  * Since: 3.5
  */
-void valueIOConnect_save(ValueIO *valueio, ValueIOCallback save)
+void visu_ui_value_io_connectOnSave(VisuUiValueIo *valueio, VisuUiValueIoCallback save)
 {
-  g_return_if_fail(IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
 
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   if (valueio->saveSignalId)
@@ -334,22 +356,22 @@ static gboolean loadXMLFile(gpointer data)
   gchar *filename;
   GError *error;
 
-  g_return_val_if_fail(IS_VALUE_IO(data), FALSE);
-  g_return_val_if_fail(VALUE_IO(data)->ioOpen, FALSE);
+  g_return_val_if_fail(VISU_UI_IS_VALUE_IO(data), FALSE);
+  g_return_val_if_fail(VISU_UI_VALUE_IO(data)->ioOpen, FALSE);
 
   filename = g_object_get_data(G_OBJECT(data), "filename");
   g_return_val_if_fail(filename, FALSE);
 
   error = (GError*)0;
-  if (!VALUE_IO(data)->ioOpen(filename, &error))
+  if (!VISU_UI_VALUE_IO(data)->ioOpen(filename, &error))
     {
-      visuGtkRaise_warning
+      visu_ui_raiseWarning
 	(_("Import V_Sim values from a file."),
-	 error->message, VALUE_IO(data)->parent);
+	 error->message, VISU_UI_VALUE_IO(data)->parent);
       g_error_free(error);
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
-      gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(VALUE_IO(data)->btExportOpen));
-      gtk_widget_set_sensitive(VALUE_IO(data)->btExportSave, FALSE);
+      gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(VISU_UI_VALUE_IO(data)->btExportOpen));
+      gtk_widget_set_sensitive(VISU_UI_VALUE_IO(data)->btExportSave, FALSE);
 #endif
     }
   g_free(filename);
@@ -389,28 +411,28 @@ static void onOpenXMLClicked(GtkButton *bt _U_, gpointer data)
 {
   gchar *filename;
 
-  if (gtk_dialog_run(GTK_DIALOG(VALUE_IO(data)->dialog)) != GTK_RESPONSE_ACCEPT)
+  if (gtk_dialog_run(GTK_DIALOG(VISU_UI_VALUE_IO(data)->dialog)) != GTK_RESPONSE_ACCEPT)
     return;
 
-  filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(VALUE_IO(data)->dialog));
+  filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(VISU_UI_VALUE_IO(data)->dialog));
 
   g_object_set_data(G_OBJECT(data), "filename", filename);
   g_idle_add(loadXMLFile, (gpointer)data);
 }
 #endif
 /**
- * valueIOGet_saveFilename:
+ * visu_ui_value_io_getFilename:
  * @parent: a parent to display the dialog on.
  *
  * Open a save dialog window  with XML filter to choose the name of a
- * file. This is the default action that can be connect to a #ValueIO
- * widget using valueIOConnect_save().
+ * file. This is the default action that can be connect to a #VisuUiValueIo
+ * widget using visu_ui_value_io_connectOnSave().
  *
  * Since: 3.5
  *
- * Returns: a filename taht should be freed later with g_free() by the caller.
+ * Returns: a filename that should be freed later with g_free() by the caller.
  */
-gchar* valueIOGet_saveFilename(GtkWindow *parent)
+gchar* visu_ui_value_io_getFilename(GtkWindow *parent)
 {
   GtkWidget *saveDialog;
   gchar *filename, *directory;
@@ -424,7 +446,7 @@ gchar* valueIOGet_saveFilename(GtkWindow *parent)
   gtk_window_set_modal(GTK_WINDOW(saveDialog), TRUE);
   gtk_window_set_transient_for(GTK_WINDOW(saveDialog), GTK_WINDOW(parent));
   gtk_window_set_position(GTK_WINDOW(saveDialog), GTK_WIN_POS_CENTER_ON_PARENT);
-  directory = visuGtkGet_lastOpenDirectory();
+  directory = visu_ui_getLastOpenDirectory();
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(saveDialog), directory);
   gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(saveDialog), FALSE);
@@ -459,32 +481,32 @@ static gboolean saveXMLFile(gpointer data)
   gchar *filename;
   GError *error;
 
-  g_return_val_if_fail(IS_VALUE_IO(data), FALSE);
-  g_return_val_if_fail(VALUE_IO(data)->ioSave, FALSE);
+  g_return_val_if_fail(VISU_UI_IS_VALUE_IO(data), FALSE);
+  g_return_val_if_fail(VISU_UI_VALUE_IO(data)->ioSave, FALSE);
 
   filename = g_object_get_data(G_OBJECT(data), "filename");
   g_return_val_if_fail(filename, FALSE);
 
   error = (GError*)0;
-  if (!VALUE_IO(data)->ioSave(filename, &error))
+  if (!VISU_UI_VALUE_IO(data)->ioSave(filename, &error))
     {
-      visuGtkRaise_warning
+      visu_ui_raiseWarning
 	(_("Export V_Sim values to a file."),
-	 error->message, VALUE_IO(data)->parent);
+	 error->message, VISU_UI_VALUE_IO(data)->parent);
       g_error_free(error);
     }
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   else
     {
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
-      g_signal_handler_block(G_OBJECT(VALUE_IO(data)->btExportOpen),
-			     VALUE_IO(data)->openSignalId);
+      g_signal_handler_block(G_OBJECT(VISU_UI_VALUE_IO(data)->btExportOpen),
+			     VISU_UI_VALUE_IO(data)->openSignalId);
 #endif
       gtk_file_chooser_set_filename
-	(GTK_FILE_CHOOSER(VALUE_IO(data)->btExportOpen), filename);
+	(GTK_FILE_CHOOSER(VISU_UI_VALUE_IO(data)->btExportOpen), filename);
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
-      g_signal_handler_unblock(G_OBJECT(VALUE_IO(data)->btExportOpen),
-			       VALUE_IO(data)->openSignalId);
+      g_signal_handler_unblock(G_OBJECT(VISU_UI_VALUE_IO(data)->btExportOpen),
+			       VISU_UI_VALUE_IO(data)->openSignalId);
 #endif
     }
 #endif
@@ -498,12 +520,12 @@ static void onExportXML(GtkButton *button, gpointer data)
 {
   gchar *filename;
 
-  if (button == GTK_BUTTON(VALUE_IO(data)->btExportSave))
+  if (button == GTK_BUTTON(VISU_UI_VALUE_IO(data)->btExportSave))
     filename =
-      gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(VALUE_IO(data)->btExportOpen));
+      gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(VISU_UI_VALUE_IO(data)->btExportOpen));
   else
     filename =
-      valueIOGet_saveFilename(VALUE_IO(data)->parent);
+      visu_ui_value_io_getFilename(VISU_UI_VALUE_IO(data)->parent);
 
   if (filename)
     {
@@ -512,34 +534,34 @@ static void onExportXML(GtkButton *button, gpointer data)
     }
 }
 /**
- * valueIOSet_openSensitive:
- * @valueio: a #ValueIO widget.
+ * visu_ui_value_io_setSensitiveOpen:
+ * @valueio: a #VisuUiValueIo widget.
  * @status: a boolean.
  *
  * Modify the sensitivity of the open button, depending on @status.
  * 
  * Since: 3.5
  */
-void valueIOSet_openSensitive(ValueIO *valueio, gboolean status)
+void visu_ui_value_io_setSensitiveOpen(VisuUiValueIo *valueio, gboolean status)
 {
-  g_return_if_fail(IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
 
   gtk_widget_set_sensitive(valueio->btExportOpen, status);
 }
 /**
- * valueIOSet_saveSensitive:
- * @valueio: a #ValueIO widget.
+ * visu_ui_value_io_setSensitiveSave:
+ * @valueio: a #VisuUiValueIo widget.
  * @status: a boolean.
  *
  * Modify the sensitivity of the save button, depending on @status.
  * 
  * Since: 3.5
  */
-void valueIOSet_saveSensitive(ValueIO *valueio, gboolean status)
+void visu_ui_value_io_setSensitiveSave(VisuUiValueIo *valueio, gboolean status)
 {
   gchar *filename;
 
-  g_return_if_fail(IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
 
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(valueio->btExportOpen));
@@ -550,30 +572,30 @@ void valueIOSet_saveSensitive(ValueIO *valueio, gboolean status)
   gtk_widget_set_sensitive(valueio->btExportSaveAs, status);
 }
 /**
- * valueIOSet_filename:
- * @valueio: a #ValueIO widget.
+ * visu_ui_value_io_setFilename:
+ * @valueio: a #VisuUiValueIo widget.
  * @filename: a location on disk.
  *
- * Call the open routine previously set by valueIOConnect_open() on
+ * Call the open routine previously set by visu_ui_value_io_connectOnOpen() on
  * @filename and update the buttons accordingly.
  *
  * Since: 3.5
  *
  * Returns: TRUE on success of the open routine.
  */
-gboolean valueIOSet_filename(ValueIO *valueio, const gchar *filename)
+gboolean visu_ui_value_io_setFilename(VisuUiValueIo *valueio, const gchar *filename)
 {
   gboolean valid;
   GError *error;
 
-  g_return_val_if_fail(IS_VALUE_IO(valueio), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_VALUE_IO(valueio), FALSE);
   g_return_val_if_fail(valueio->ioOpen, FALSE);
   
   error = (GError*)0;
   valid = valueio->ioOpen(filename, &error);
   if (!valid)
     {
-      visuGtkRaise_warning
+      visu_ui_raiseWarning
 	(_("Export V_Sim values to a file."),
 	 error->message, valueio->parent);
       g_error_free(error);
