@@ -43,6 +43,9 @@
 */
 #include "gtk_about.h"
 
+#include <string.h>
+#include <stdlib.h>
+
 #include "interface.h"
 #include "support.h"
 
@@ -55,15 +58,22 @@
  * SECTION: gtk_about
  * @short_description: The about dialog with a readme, the copyright,
  * the author list, the plug-in list and the version notes.
+ *
+ * <para>The about dialog window is activated when clicking on the V_Sim
+ * icon on bottom right part of the command panel. It contains a
+ * summary of V_Sim purpose and capabilities, the list of authors, the
+ * list of loaded plug-ins, the list of changes since the previous
+ * version, and the licence file. It displays also the version of
+ * V_Sim and provide a link to the web site.</para>
  */
 
-#define V_SIM_LICENCE_FILE   _("licence.en.txt")
+#define VISU_UI_ABOUT_LICENCE_FILE   _("licence.en.txt")
 /* Translate if there is a authors file in another language. */
-#define V_SIM_AUTHORS_FILE   _("authors")
+#define VISU_UI_ABOUT_AUTHORS_FILE   _("authors")
 /* Translate if there is a readme file in another language. */
-#define V_SIM_README_FILE    _("readme")
+#define VISU_UI_ABOUT_README_FILE    _("readme")
 /* Translate if there is a readme file in another language. */
-#define V_SIM_CHANGELOG_FILE _("ChangeLog.en")
+#define VISU_UI_ABOUT_CHANGELOG_FILE _("ChangeLog.en")
 
 enum
   {
@@ -82,15 +92,20 @@ static void buildPluginsTab();
 static void setChangelog(const gchar* buffer, gssize size, GtkTextBuffer *text);
 
 
-/* create the window. */
-void gtkAboutBuild_window(VisuUiMain *main)
+/**
+ * visu_ui_about_initBuild: (skip)
+ * @main: the command panel the about dialog is associated to.
+ *
+ * Create the about window.
+ */
+void visu_ui_about_initBuild(VisuUiMain *main)
 {
   GtkWidget *wd, *note;
   gchar *buffer, *utf8Buffer, *start, *end;
   GtkTextBuffer *text;
   GtkTextIter startIter, endIter;
   GtkTextTag *monoTag, *boldTag, *linkTag;
-  gsize taille, size;
+  gsize taille;
   GError *err;
   gchar *chemin;
 
@@ -118,7 +133,7 @@ void gtkAboutBuild_window(VisuUiMain *main)
   gtk_widget_set_name(note, "message_notebook");
 
   /* Create the interior of the tabs. */
-  chemin = g_build_filename(V_SIM_LEGAL_DIR, V_SIM_LICENCE_FILE, NULL);
+  chemin = g_build_filename(V_SIM_LEGAL_DIR, VISU_UI_ABOUT_LICENCE_FILE, NULL);
   buffer = (gchar*)0;
   err = (GError*)0;
   if (!g_file_get_contents(chemin, &buffer, &taille, &err))
@@ -140,7 +155,7 @@ void gtkAboutBuild_window(VisuUiMain *main)
     }
   g_free(chemin);
 
-  chemin = g_build_filename(V_SIM_LEGAL_DIR, V_SIM_README_FILE, NULL);
+  chemin = g_build_filename(V_SIM_LEGAL_DIR, VISU_UI_ABOUT_README_FILE, NULL);
   buffer = (gchar*)0;
   err = (GError*)0;
   if (!g_file_get_contents(chemin, &buffer, &taille, &err))
@@ -177,7 +192,7 @@ void gtkAboutBuild_window(VisuUiMain *main)
     }
   g_free(chemin);
 
-  chemin = g_build_filename(V_SIM_LEGAL_DIR, V_SIM_CHANGELOG_FILE, NULL);
+  chemin = g_build_filename(V_SIM_LEGAL_DIR, VISU_UI_ABOUT_CHANGELOG_FILE, NULL);
   buffer = (gchar*)0;
   err = (GError*)0;
   if (!g_file_get_contents(chemin, &buffer, &taille, &err))
@@ -185,22 +200,18 @@ void gtkAboutBuild_window(VisuUiMain *main)
 	      " it should be in '%s'.\n", chemin);
   else
     {
-      utf8Buffer = g_convert(buffer, taille, "UTF-8", "ISO-8859-1", NULL, &size, NULL);
-      g_free(buffer);
-
-
       wd = lookup_widget(main->aboutDialog, "textviewChangelog");
       gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(wd), GTK_WRAP_WORD);
       gtk_text_view_set_justification (GTK_TEXT_VIEW(wd), GTK_JUSTIFY_LEFT);
       text = gtk_text_view_get_buffer(GTK_TEXT_VIEW(wd));
       
       /* Parse here the XML to get only the relevant entries. */
-      setChangelog(utf8Buffer, size, text);
+      setChangelog(buffer, taille, text);
 
-      g_free(utf8Buffer);
+      g_free(buffer);
     }  
 
-  chemin = g_build_filename(V_SIM_LEGAL_DIR, V_SIM_AUTHORS_FILE, NULL);
+  chemin = g_build_filename(V_SIM_LEGAL_DIR, VISU_UI_ABOUT_AUTHORS_FILE, NULL);
   buffer = (gchar*)0;
   err = (GError*)0;
   if (!g_file_get_contents(chemin, &buffer, &taille, &err))
@@ -526,7 +537,6 @@ static void setChangelog(const gchar* buffer, gssize size, GtkTextBuffer *text)
 {
   GMarkupParseContext* xmlContext;
   GMarkupParser parser;
-  GtkTextTag *tag;
   gboolean status;
   GError *error;
 
@@ -539,10 +549,10 @@ static void setChangelog(const gchar* buffer, gssize size, GtkTextBuffer *text)
   parser.error         = NULL;
   xmlContext = g_markup_parse_context_new(&parser, 0, text, NULL);
 
-  tag = gtk_text_buffer_create_tag(text, "bold",
-				   "weight", PANGO_WEIGHT_BOLD, NULL);
-  tag = gtk_text_buffer_create_tag(text, "italic",
-				   "style", PANGO_STYLE_ITALIC, NULL);
+  gtk_text_buffer_create_tag(text, "bold",
+                             "weight", PANGO_WEIGHT_BOLD, NULL);
+  gtk_text_buffer_create_tag(text, "italic",
+                             "style", PANGO_STYLE_ITALIC, NULL);
 
   /* Parse data. */
   startAbout = FALSE;
