@@ -60,6 +60,15 @@
 /**
  * SECTION: gtk_interactive
  * @short_description: The interactive dialog.
+ *
+ * <para>This is the second main interface for V_Sim after the command
+ * panel. It provides widgets to interact with the nodes. There is
+ * three built-in interactive modes : the observe one (as in normal
+ * behaviour), the pick one and the move one.</para>
+ * <para>It is possible to add new action thanks to
+ * visu_ui_interactive_addAction() function. It is also possible to
+ * show a small warning message with visu_ui_interactive_setMessage()
+ * that shows a GtkInfoBar.</para>
  */
 
 /* Local types. */
@@ -72,9 +81,9 @@ typedef struct ActionInterface_
 
   GtkWidget *radio;
 
-  GtkInteractiveBuild build;
+  VisuUiInteractiveBuild build;
   VisuInteractiveId mode;
-  GtkInteractiveStartStop onStart, onStop;
+  VisuUiInteractiveStartStop onStart, onStop;
 } ActionInterface;
 
 /* Local variables. */
@@ -82,19 +91,22 @@ static ActionInterface* currentAction;
 static guint n_actions = 0;
 static GList *actions;
 static VisuInteractive *interObserve;
+static gulong angles_signal, trans_signal, gross_signal, persp_signal;
 
 /* Callbacks. */
 static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
 			      gpointer data);
-static void onNewData(GObject *obj, VisuData *dataObj, gpointer data);
-static void onVisuData(GObject *obj, VisuData *dataObj, gpointer data);
+static void onDataReady(GObject *obj, VisuData *dataObj,
+                        VisuGlView *view, gpointer data);
+static void onDataNotReady(GObject *obj, VisuData *dataObj,
+                           VisuGlView *view, gpointer data);
 static void observeMethodChanged(GtkToggleButton* button, gpointer data);
 static void radioObserveToggled(GtkToggleButton *togglebutton, gpointer user_data);
 static void onCloseButtonClicked(GtkButton *button, gpointer user_data);
-static void refreshCameraSpinValues(VisuData *obj, VisuOpenGLView *view, gpointer data);
+static void onCameraChanged(VisuGlView *view, gpointer data);
 static void onTabActionChanged(GtkNotebook *book, GtkWidget *child,
 			       gint num, gpointer data);
-static void onOrientationChooser(GtkButton *button, gpointer data);
+static void onVisuUiOrientationChooser(GtkButton *button, gpointer data);
 static void onAngleChanged(GtkSpinButton *spin, gpointer data);
 static void onTranslationChanged(GtkSpinButton *spin, gpointer data);
 static void onZoomChanged(GtkSpinButton *spin, gpointer data);
@@ -102,8 +114,8 @@ static void onPerspChanged(GtkSpinButton *spin, gpointer data);
 static gboolean onKillWindowEvent(GtkWidget *widget, GdkEvent *event,
 				  gpointer user_data);
 static void onRadioToggled(GtkToggleButton *toggle, gpointer data);
-static void onObserveStart(VisuRenderingWindow *window);
-static void onObserveStop(VisuRenderingWindow *window);
+static void onObserveStart(VisuUiRenderingWindow *window);
+static void onObserveStop(VisuUiRenderingWindow *window);
 static void onObserveClickStop(VisuInteractive *inter _U_, gpointer data);
 
 /* Local methods. */
@@ -130,27 +142,31 @@ static GtkWidget *spinPersp;
     "key 's' / 'r'\t\t\t\t\t: save/restore camera position\n"		\
     "right-button\t\t\t\t\t: switch to current tabbed action")
 
-/* Initialise the observe/pick window, connect the
-   signals, give names to widgets... */
-void gtkInteractiveInit()
+/**
+ * visu_ui_interactive_init: (skip)
+ *
+ * Initialise the observe/pick window, connect the
+ * signals, give names to widgets...
+ */
+void visu_ui_interactive_init()
 {
   orientationChooser = (GtkWidget*)0;
   /* Set the actions tabs. */
   actions = (GList*)0;
 
-  gtkInteractiveAdd_action(gtkObserveBuild_interface,
+  visu_ui_interactive_addAction(gtkObserveBuild_interface,
 			   onObserveStart, onObserveStop);
   currentAction = (ActionInterface*)actions->data;
 
-  gtkInteractiveAdd_action(gtkPickBuild_interface,
-			   gtkPickStart, gtkPickStop);
+  visu_ui_interactive_addAction(visu_ui_interactive_pick_initBuild,
+			   visu_ui_interactive_pick_start, visu_ui_interactive_pick_stop);
 
-  gtkInteractiveAdd_action(gtkMoveBuild_interface,
-			   gtkMoveStart, gtkMoveStop);
+  visu_ui_interactive_addAction(visu_ui_interactive_move_initBuild,
+			   visu_ui_interactive_move_start, visu_ui_interactive_move_stop);
 }
 
 /**
- * gtkInteractiveAdd_action:
+ * visu_ui_interactive_addAction:
  * @build: a routine to build a tab.
  * @start: a routine to run when session is selected.
  * @stop: a routine to run when session is stopped.
@@ -162,9 +178,9 @@ void gtkInteractiveInit()
  *
  * Returns: an id for this new action.
  */
-guint gtkInteractiveAdd_action(GtkInteractiveBuild build,
-			       GtkInteractiveStartStop start,
-			       GtkInteractiveStartStop stop)
+guint visu_ui_interactive_addAction(VisuUiInteractiveBuild build,
+			       VisuUiInteractiveStartStop start,
+			       VisuUiInteractiveStartStop stop)
 {
   ActionInterface *action;
 
@@ -191,22 +207,28 @@ static GtkWidget* gtkObserveBuild_interface(VisuUiMain *main _U_, gchar **label,
 
   return (GtkWidget*)0;
 }
-
-void gtkInteractiveBuild_window(VisuUiMain *main)
+/**
+ * visu_ui_interactive_initBuild: (skip)
+ * @main: the command panel the about dialog is associated to.
+ *
+ * create the window.
+ */
+void visu_ui_interactive_initBuild(VisuUiMain *main)
 {
   GtkWidget *labelHelp, *wd;
-  VisuRenderingWindow *window;
+  VisuUiRenderingWindow *window;
   VisuData *data;
+  VisuGlView *view;
   GList *tmpLst;
   ActionInterface *action;
   gchar *msg;
   GSList *lst;
  
-  window = visu_uiMainClass_getDefaultRendering();
-  data = visu_rendering_window_getVisuData(window);
-  g_return_if_fail(data);
+  window = visu_ui_main_class_getDefaultRendering();
+  data = visu_ui_rendering_window_getData(window);
+  view = visu_ui_rendering_window_getGlView(window);
 
-  interObserve = visuInteractiveNew(interactive_observe);
+  interObserve = visu_interactive_new(interactive_observe);
   g_object_ref(G_OBJECT(interObserve));
   g_signal_connect(G_OBJECT(interObserve), "stop",
 		   G_CALLBACK(onObserveClickStop), (gpointer)window);
@@ -271,45 +293,54 @@ void gtkInteractiveBuild_window(VisuUiMain *main)
   connectSignalsObservePick(main);
 
   DBG_fprintf(stderr, "Gtk Interactive: Setup initial values.\n");
-  onNewData((GObject*)0, data, (gpointer)0);
+  if (data)
+    {
+      visu_interactive_apply(interObserve, VISU_NODE_ARRAY(data));
+      onDataReady((GObject*)0, data, view, (gpointer)0);
+    }
   /* set the initial values for the spins. */
-  refreshCameraSpinValues((VisuData*)0, visu_data_getOpenGLView(data), (gpointer)0);
+  onCameraChanged(view, (gpointer)0);
 }
 
 /**
- * gtkInteractiveToggle:
+ * visu_ui_interactive_toggle:
  *
  * The user can switch between a current specific interactive action
  * and the observe mode. This routine is used to do this.*
  *
  * Since: 3.6
  */
-void gtkInteractiveToggle()
+void visu_ui_interactive_toggle()
 {
   GtkWidget *wd;
   guint id;
   ActionInterface *action;
 
-  if (currentAction->id == action_observe)
+  if (currentAction->id == VISU_UI_ACTION_OBSERVE)
     {
       wd = lookup_widget(observeWindow, "notebookAction");
       id = gtk_notebook_get_current_page(GTK_NOTEBOOK(wd)) + 1;
     }
   else
-    id = action_observe;
+    id = VISU_UI_ACTION_OBSERVE;
   action = (ActionInterface*)g_list_nth_data(actions, id);
 
   /* We toggle on the radio of the new action. */
   if (action->radio)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(action->radio), TRUE);
 }
-
-void gtkInteractiveInit_session(VisuRenderingWindow *window)
+/**
+ * visu_ui_interactive_start:
+ * @window: the current rendering widget.
+ * 
+ * Start the observe & pick session.
+ */
+void visu_ui_interactive_start(VisuUiRenderingWindow *window)
 {
   DBG_fprintf(stderr, "Gtk Interactive: initialise session.\n");
 
   /* We empty the status bar. */
-  renderingWindowPush_message(window, "");
+  visu_ui_rendering_window_pushMessage(window, "");
 
   /* We start the new mode. */
   currentAction->onStart(window);
@@ -317,15 +348,15 @@ void gtkInteractiveInit_session(VisuRenderingWindow *window)
 
 static void gtkInteractiveStop()
 {
-  VisuRenderingWindow *window;
+  VisuUiRenderingWindow *window;
 
-  window = visu_uiMainClass_getDefaultRendering();
+  window = visu_ui_main_class_getDefaultRendering();
 
-  renderingWindowPop_message(window);
+  visu_ui_rendering_window_popMessage(window);
   currentAction->onStop(window);
 }
 /**
- * gtkInteractive_setMessage:
+ * visu_ui_interactive_setMessage:
  * @message: a string.
  * @type: the type of message.
  *
@@ -333,7 +364,7 @@ static void gtkInteractiveStop()
  *
  * Since: 3.6
  */
-void gtkInteractive_setMessage(const gchar *message, GtkMessageType type)
+void visu_ui_interactive_setMessage(const gchar *message, GtkMessageType type)
 {
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 17 
   GList *lst;
@@ -348,14 +379,14 @@ void gtkInteractive_setMessage(const gchar *message, GtkMessageType type)
   gtk_widget_show(infoBar);
 }
 /**
- * gtkInteractive_unsetMessage:
+ * visu_ui_interactive_unsetMessage:
  *
  * Hide any message from the interactive dialog. See also
- * gtkInteractive_setMessage().
+ * visu_ui_interactive_setMessage().
  *
  * Since: 3.6
  */
-void gtkInteractive_unsetMessage()
+void visu_ui_interactive_unsetMessage()
 {
   gtk_widget_hide(infoBar);
 }
@@ -387,9 +418,6 @@ static void connectSignalsObservePick()
 {
   GtkWidget *wd;
 
-  g_signal_connect(VISU_INSTANCE, "dataNew",
-		   G_CALLBACK(onNewData), (gpointer)0);
-
   g_signal_connect(G_OBJECT(observeWindow), "delete-event",
 		   G_CALLBACK(onKillWindowEvent), (gpointer)0);
   g_signal_connect(G_OBJECT(observeWindow), "destroy-event",
@@ -398,32 +426,34 @@ static void connectSignalsObservePick()
   wd = lookup_widget(observeWindow, "buttonBackToCommandPanel");
   g_signal_connect(G_OBJECT(wd), "clicked",
 		   G_CALLBACK(onCloseButtonClicked), (gpointer)0);
-  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
-		   G_CALLBACK(onVisuData), (gpointer)wd);
+  g_signal_connect(VISU_OBJECT_INSTANCE, "dataRendered",
+		   G_CALLBACK(onDataReady), (gpointer)wd);
+  g_signal_connect(VISU_OBJECT_INSTANCE, "dataUnRendered",
+		   G_CALLBACK(onDataNotReady), (gpointer)wd);
   wd = lookup_widget(observeWindow, "radioObserve");
   g_signal_connect(G_OBJECT(wd), "toggled",
 		   G_CALLBACK(radioObserveToggled), (gpointer)0);
 
-  wd = lookup_widget(observeWindow, "buttonOrientationChooser");
+  wd = lookup_widget(observeWindow, "buttonVisuUiOrientationChooser");
   g_signal_connect(G_OBJECT(wd), "clicked",
-		   G_CALLBACK(onOrientationChooser), (gpointer)0);
+		   G_CALLBACK(onVisuUiOrientationChooser), (gpointer)0);
 
   /* The observe widgets. */
   wd = lookup_widget(observeWindow, "spinTheta");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_CAMERA_THETA));
+		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_GL_CAMERA_THETA));
   wd = lookup_widget(observeWindow, "spinPhi");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_CAMERA_PHI));
+		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_GL_CAMERA_PHI));
   wd = lookup_widget(observeWindow, "spinOmega");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_CAMERA_OMEGA));
+		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_GL_CAMERA_OMEGA));
   wd = lookup_widget(observeWindow, "spinDx");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onTranslationChanged), GINT_TO_POINTER(MASK_XS));
+		   G_CALLBACK(onTranslationChanged), GINT_TO_POINTER(VISU_GL_CAMERA_XS));
   wd = lookup_widget(observeWindow, "spinDy");
   g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onTranslationChanged), GINT_TO_POINTER(MASK_YS));
+		   G_CALLBACK(onTranslationChanged), GINT_TO_POINTER(VISU_GL_CAMERA_YS));
   wd = lookup_widget(observeWindow, "spinGross");
   g_signal_connect(G_OBJECT(wd), "value_changed",
 		   G_CALLBACK(onZoomChanged), (gpointer)0);
@@ -442,34 +472,49 @@ static void connectSignalsObservePick()
 		   G_CALLBACK(onTabActionChanged), (gpointer)0);
 }
 
-static void onNewData(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
-{
-  g_signal_connect(G_OBJECT(dataObj), "OpenGLThetaPhiOmega",
-		   G_CALLBACK(refreshCameraSpinValues), (gpointer)0);
-  g_signal_connect(G_OBJECT(dataObj), "OpenGLXsYs",
-		   G_CALLBACK(refreshCameraSpinValues), (gpointer)0);
-  g_signal_connect(G_OBJECT(dataObj), "OpenGLGross",
-		   G_CALLBACK(refreshCameraSpinValues), (gpointer)0);
-  g_signal_connect(G_OBJECT(dataObj), "OpenGLPersp",
-		   G_CALLBACK(refreshCameraSpinValues), (gpointer)0);
-}
-static void onVisuData(GObject *obj _U_, VisuData *dataObj, gpointer data)
+static void onDataReady(GObject *obj _U_, VisuData *dataObj,
+                        VisuGlView *view, gpointer data)
 {
   if (!dataObj)
     gtk_button_clicked(GTK_BUTTON(data));
+
+  if (dataObj && view)
+    {
+      angles_signal =
+        g_signal_connect(G_OBJECT(view), "ThetaPhiOmegaChanged",
+                         G_CALLBACK(onCameraChanged), (gpointer)0);
+      trans_signal =
+        g_signal_connect(G_OBJECT(view), "XsYsChanged",
+                         G_CALLBACK(onCameraChanged), (gpointer)0);
+      gross_signal =
+        g_signal_connect(G_OBJECT(view), "GrossChanged",
+                         G_CALLBACK(onCameraChanged), (gpointer)0);
+      persp_signal =
+        g_signal_connect(G_OBJECT(view), "PerspChanged",
+                         G_CALLBACK(onCameraChanged), (gpointer)0);
+    }
+}
+static void onDataNotReady(GObject *obj _U_, VisuData *dataObj _U_,
+                           VisuGlView *view, gpointer data _U_)
+{
+  DBG_fprintf(stderr, "Gtk Interactive: caught the 'dataUnRendered' signal.\n");
+  g_signal_handler_disconnect(G_OBJECT(view), angles_signal);
+  g_signal_handler_disconnect(G_OBJECT(view), trans_signal);
+  g_signal_handler_disconnect(G_OBJECT(view), gross_signal);
+  g_signal_handler_disconnect(G_OBJECT(view), persp_signal);
 }
 
 static void onObserveClickStop(VisuInteractive *inter _U_, gpointer data)
 {
-  gtkInteractiveToggle(RENDERING_WINDOW(data));
+  visu_ui_interactive_toggle(VISU_UI_RENDERING_WINDOW(data));
 }
-static void onObserveStart(VisuRenderingWindow *window)
+static void onObserveStart(VisuUiRenderingWindow *window)
 {
-  renderingWindowPush_interactive(window, interObserve);
+  visu_ui_rendering_window_pushInteractive(window, interObserve);
 }
-static void onObserveStop(VisuRenderingWindow *window)
+static void onObserveStop(VisuUiRenderingWindow *window)
 {
-  renderingWindowPop_interactive(window, interObserve);
+  visu_ui_rendering_window_popInteractive(window, interObserve);
 }
 
 static void observeMethodChanged(GtkToggleButton* button, gpointer data)
@@ -480,14 +525,14 @@ static void observeMethodChanged(GtkToggleButton* button, gpointer data)
     return;
 
   method = (VisuInteractiveMethod)GPOINTER_TO_INT(data);
-  visuInteractiveClassSet_preferedObserveMethod(method);
+  visu_interactive_class_setPreferedObserveMethod(method);
   if (method == interactive_constrained)
     {
       gtk_widget_set_sensitive(spinOmega, FALSE);
-      if (visu_data_setAngleOfView(visu_rendering_window_getVisuData
-				  (visu_uiMainClass_getDefaultRendering()),
-				  0., 0., 0., VISU_CAMERA_OMEGA))
-	VISU_ADD_REDRAW;
+      if (visu_gl_view_setThetaPhiOmega(visu_ui_rendering_window_getGlView
+                                        (visu_ui_main_class_getDefaultRendering()),
+                                        0., 0., 0., VISU_GL_CAMERA_OMEGA))
+	VISU_REDRAW_ADD;
     }
   else
     gtk_widget_set_sensitive(spinOmega, TRUE);
@@ -496,8 +541,7 @@ static void observeMethodChanged(GtkToggleButton* button, gpointer data)
 
 /* Ask the OpenGL server to refresh the values of the spins
    controlling the position of the camera. */
-static void refreshCameraSpinValues(VisuData *obj _U_, VisuOpenGLView *view,
-				    gpointer data _U_)
+static void onCameraChanged(VisuGlView *view, gpointer data _U_)
 {
   g_return_if_fail(view && view->camera);
 
@@ -544,7 +588,7 @@ static void setNamesGtkWidgetObservePick(VisuUiMain *main)
   spinGross = lookup_widget(main->interactiveDialog, "spinGross");
   spinPersp = lookup_widget(main->interactiveDialog, "spinPersp");
 
-  method = visuInteractiveClassGet_preferedObserveMethod();
+  method = visu_interactive_class_getPreferedObserveMethod();
   if (method == interactive_constrained)
     gtk_widget_set_sensitive(spinOmega, FALSE);
 
@@ -568,7 +612,7 @@ static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
   DBG_fprintf(stderr, "Gtk Interactive: get key pressed.\n");
   if(event->keyval == GDK_KEY_Home)
     {
-      window = visuGtkGet_render();
+      window = visu_ui_getRenderWindow();
       g_return_val_if_fail(window, FALSE);
       /* We raised the rendering window, if required. */
       gtk_window_present(window);
@@ -583,14 +627,15 @@ static void onAngleChanged(GtkSpinButton *spin, gpointer data)
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  reDrawNeeded = visu_data_setAngleOfView(visu_rendering_window_getVisuData
-					 (visu_uiMainClass_getDefaultRendering()),
-					 (float)gtk_spin_button_get_value(spin),
-					 (float)gtk_spin_button_get_value(spin),
-					 (float)gtk_spin_button_get_value(spin),
-					 GPOINTER_TO_INT(data));
+  reDrawNeeded =
+    visu_gl_view_setThetaPhiOmega(visu_ui_rendering_window_getGlView
+                                  (visu_ui_main_class_getDefaultRendering()),
+                                  (float)gtk_spin_button_get_value(spin),
+                                  (float)gtk_spin_button_get_value(spin),
+                                  (float)gtk_spin_button_get_value(spin),
+                                  GPOINTER_TO_INT(data));
   if (reDrawNeeded)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 static void onTranslationChanged(GtkSpinButton *spin, gpointer data)
 {
@@ -599,13 +644,14 @@ static void onTranslationChanged(GtkSpinButton *spin, gpointer data)
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  reDrawNeeded = visu_data_setPositionOfView(visu_rendering_window_getVisuData
-					    (visu_uiMainClass_getDefaultRendering()),
-					    (float)gtk_spin_button_get_value(spin),
-					    (float)gtk_spin_button_get_value(spin),
-					    GPOINTER_TO_INT(data));
+  reDrawNeeded =
+    visu_gl_view_setXsYs(visu_ui_rendering_window_getGlView
+                         (visu_ui_main_class_getDefaultRendering()),
+                         (float)gtk_spin_button_get_value(spin),
+                         (float)gtk_spin_button_get_value(spin),
+                         GPOINTER_TO_INT(data));
   if (reDrawNeeded)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 static void onZoomChanged(GtkSpinButton *spin, gpointer data _U_)
 {
@@ -614,11 +660,12 @@ static void onZoomChanged(GtkSpinButton *spin, gpointer data _U_)
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  reDrawNeeded = visu_data_setZoomOfView(visu_rendering_window_getVisuData
-					(visu_uiMainClass_getDefaultRendering()),
-					(float)gtk_spin_button_get_value(spin));
+  reDrawNeeded =
+    visu_gl_view_setGross(visu_ui_rendering_window_getGlView
+                          (visu_ui_main_class_getDefaultRendering()),
+                          (float)gtk_spin_button_get_value(spin));
   if (reDrawNeeded)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 static void onPerspChanged(GtkSpinButton *spin, gpointer data _U_)
 {
@@ -627,22 +674,23 @@ static void onPerspChanged(GtkSpinButton *spin, gpointer data _U_)
   if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
     return;
 
-  reDrawNeeded = visu_data_setPerspectiveOfView(visu_rendering_window_getVisuData
-					       (visu_uiMainClass_getDefaultRendering()),
-					       (float)gtk_spin_button_get_value(spin));
+  reDrawNeeded =
+    visu_gl_view_setPersp(visu_ui_rendering_window_getGlView
+                          (visu_ui_main_class_getDefaultRendering()),
+                          (float)gtk_spin_button_get_value(spin));
   if (reDrawNeeded)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 
 static void onRadioToggled(GtkToggleButton *toggle, gpointer data)
 {
   GtkWidget *labelHelp;
-  VisuRenderingWindow *window;
+  VisuUiRenderingWindow *window;
 
   if (!gtk_toggle_button_get_active(toggle))
     return;
 
-  window = visu_uiMainClass_getDefaultRendering();
+  window = visu_ui_main_class_getDefaultRendering();
   
   /* Before setting up the current action, we pop
      the previous one. */
@@ -671,7 +719,7 @@ static void radioObserveToggled(GtkToggleButton *togglebutton, gpointer user_dat
   gtk_widget_set_sensitive(wd, value);
   wd = lookup_widget(observeWindow, "tableObserve");
   gtk_widget_set_sensitive(wd, value);
-  if (visuInteractiveClassGet_preferedObserveMethod() == interactive_constrained)
+  if (visu_interactive_class_getPreferedObserveMethod() == interactive_constrained)
     gtk_widget_set_sensitive(spinOmega, FALSE);
   else
     gtk_widget_set_sensitive(spinOmega, value);
@@ -688,39 +736,45 @@ static void onTabActionChanged(GtkNotebook *book _U_, GtkWidget *child _U_,
   if (action->radio)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(action->radio), TRUE);
 }
-static void onOrientationChanged(OrientationChooser *orientationChooser,
+static void onOrientationChanged(VisuUiOrientationChooser *orientationChooser,
 				 gpointer data _U_)
 {
   float values[2];
   gboolean reDrawNeeded;
 
   DBG_fprintf(stderr, "Gtk Observe: orientation changed.\n");
-  orientationChooserGet_anglesValues(orientationChooser, values);
+  visu_ui_orientation_chooser_getAnglesValues(orientationChooser, values);
 
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinTheta), values[0]);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPhi), values[1]);
 
-  reDrawNeeded = visu_data_setAngleOfView
-    (visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering()),
-     values[0], values[1], 0., VISU_CAMERA_THETA | VISU_CAMERA_PHI);
+  reDrawNeeded =
+    visu_gl_view_setThetaPhiOmega(visu_ui_rendering_window_getGlView
+                                  (visu_ui_main_class_getDefaultRendering()),
+                                  values[0], values[1], 0.,
+                                  VISU_GL_CAMERA_THETA | VISU_GL_CAMERA_PHI);
   if (reDrawNeeded)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
-static void onOrientationChooser(GtkButton *button _U_, gpointer data _U_)
+static void onVisuUiOrientationChooser(GtkButton *button _U_, gpointer data _U_)
 {
   float values[2];
   gboolean reDrawNeeded;
+  VisuUiRenderingWindow *window;
   VisuData *dataObj;
+  VisuGlView *view;
 
-  dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
+  window = visu_ui_main_class_getDefaultRendering();
+  dataObj = visu_ui_rendering_window_getData(window);
+  view = visu_ui_rendering_window_getGlView(window);
   if (!orientationChooser)
     {
-      orientationChooser = orientationChooserNew
-	(orientationChooser_direction, TRUE, dataObj, GTK_WINDOW(observeWindow));
+      orientationChooser = visu_ui_orientation_chooser_new
+	(VISU_UI_ORIENTATION_DIRECTION, TRUE, dataObj, GTK_WINDOW(observeWindow));
 /*       gtk_window_set_modal(GTK_WINDOW(orientationChooser), TRUE); */
       values[0] = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinTheta));
       values[1] = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinPhi));
-      orientationChooserSet_anglesValues(ORIENTATION_CHOOSER(orientationChooser),
+      visu_ui_orientation_chooser_setAnglesValues(VISU_UI_ORIENTATION_CHOOSER(orientationChooser),
 					 values);
       g_signal_connect(G_OBJECT(orientationChooser), "values-changed",
 		       G_CALLBACK(onOrientationChanged), (gpointer)0);
@@ -738,10 +792,11 @@ static void onOrientationChooser(GtkButton *button _U_, gpointer data _U_)
       DBG_fprintf(stderr, "Gtk Observe: reset values on orientation.\n");
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinTheta), values[0]);
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPhi), values[1]);
-      reDrawNeeded = visu_data_setAngleOfView
-	(dataObj, values[0], values[1], 0., VISU_CAMERA_THETA | VISU_CAMERA_PHI);
+      reDrawNeeded = visu_gl_view_setThetaPhiOmega
+	(view, values[0], values[1], 0.,
+         VISU_GL_CAMERA_THETA | VISU_GL_CAMERA_PHI);
       if (reDrawNeeded)
-	VISU_ADD_REDRAW;
+	VISU_REDRAW_ADD;
     }
   DBG_fprintf(stderr, "Gtk Observe: orientation object destroy.\n");
   gtk_widget_destroy(orientationChooser);
