@@ -75,6 +75,11 @@
   #include <gdk/gdkwin32.h>
   #define IMPL_BUILTIN_WIN32
   #endif
+  #if SYSTEM_QUARTZ == 1
+  #include <agl.h>
+  #include <gdk/gdkquatrz.h>
+  #define IMPL_BUILTIN_QUARTZ
+  #endif
 #endif
 
 /**
@@ -83,13 +88,13 @@
  *
  * <para>This is a simple implementation of GtkGlExt to create an
  * OpenGL surface that is a full GtkWidget. When creating such a
- * widget, one should give then a RedrawMethod() to tell the widget
+ * widget, one should give then a VisuUiGlWidgetRedrawMethod() to tell the widget
  * how to redraw itself when needed.</para>
  *
  * <para>The current implementation is working on X11 (built-in or
  * with GtkGlExt) and Win32.</para>
  */
-struct _OpenGLWidget
+struct _VisuUiGlWidget
 {
   GtkWidget parent;
 
@@ -97,8 +102,8 @@ struct _OpenGLWidget
   gboolean dispose_has_run;
 
   /* Redraw method and user data. */
-  RedrawMethod redraw;
-  VisuData *redrawData;
+  VisuUiGlWidgetRedrawMethod redraw;
+  VisuGlView *redrawView;
 
   /* Default background pixbuf. */
   GdkPixbuf *backLogo;
@@ -121,86 +126,91 @@ struct _OpenGLWidget
   HGLRC context;
   HWND windowId;
 #endif
+#ifdef IMPL_BUILTIN_QUARTZ
+  NSWindow windowId;
+  AGLContext context;
+  AGLPixelFmtID pxlfmt;
+#endif
 };
 
-struct _OpenGLWidgetClass
+struct _VisuUiGlWidgetClass
 {
   GtkWidgetClass parent_class;
 
-  OpenGLWidget *contextCurrent;
+  VisuUiGlWidget *contextCurrent;
 };
 
-G_DEFINE_TYPE(OpenGLWidget, openGLWidget, GTK_TYPE_WIDGET)
+G_DEFINE_TYPE(VisuUiGlWidget, visu_ui_gl_widget, GTK_TYPE_WIDGET)
 
 /* Local variables. */
-static OpenGLWidgetClass *myClass = (OpenGLWidgetClass*)0;
+static VisuUiGlWidgetClass *myClass = (VisuUiGlWidgetClass*)0;
 
 /* Local callbacks. */
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static gboolean openGLWidgetEvent_expose(GtkWidget *widget, GdkEventExpose *event);
-static void openGLWidgetEvent_sizeRequest(GtkWidget *widget, GtkRequisition *requisition);
+static gboolean visu_ui_gl_widgetEvent_expose(GtkWidget *widget, GdkEventExpose *event);
+static void visu_ui_gl_widgetEvent_sizeRequest(GtkWidget *widget, GtkRequisition *requisition);
 #else
-static gboolean openGLWidgetEvent_draw(GtkWidget *widget, cairo_t *cr);
-static void openGLWidgetEvent_getWidth(GtkWidget *widget, gint *minWidth, gint *width);
-static void openGLWidgetEvent_getHeight(GtkWidget *widget, gint *minHeight, gint *height);
+static gboolean visu_ui_gl_widgetEvent_draw(GtkWidget *widget, cairo_t *cr);
+static void visu_ui_gl_widgetEvent_getWidth(GtkWidget *widget, gint *minWidth, gint *width);
+static void visu_ui_gl_widgetEvent_getHeight(GtkWidget *widget, gint *minHeight, gint *height);
 #endif
-static gboolean openGLWidgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event);
-static void openGLWidgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *allocation);
-static void openGLWidgetEvent_realise(GtkWidget *widget);
+static gboolean visu_ui_gl_widgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event);
+static void visu_ui_gl_widgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *allocation);
+static void visu_ui_gl_widgetEvent_realise(GtkWidget *widget);
 
 /* Initialisation methods. */
-static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDirect);
+static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean contextIsDirect);
 
 /* Freeing methods. */
-static void openGLWidgetEvent_dispose(GObject *obj);
-static void openGLWidgetEvent_finalize(GObject *obj);
-static void openGLWidgetFree_openGL(OpenGLWidget *render);
+static void visu_ui_gl_widgetEvent_dispose(GObject *obj);
+static void visu_ui_gl_widgetEvent_finalize(GObject *obj);
+static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render);
 
 /* Miscellaneous methods. */
-static void setViewport(OpenGLWidget *render, guint width,
+static void setViewport(VisuUiGlWidget *render, guint width,
 				     guint height, gboolean redraw);
-static void openGLWidgetSet_pixelFormat(OpenGLWidget *render);
+static void visu_ui_gl_widgetSet_pixelFormat(VisuUiGlWidget *render);
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render);
+static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render);
 #endif
 
-static void openGLWidget_class_init(OpenGLWidgetClass *class)
+static void visu_ui_gl_widget_class_init(VisuUiGlWidgetClass *class)
 {
   GtkWidgetClass *widget_class;
   GObjectClass *gobject_class;
 
   /* Dealing with GObject events. */
   gobject_class = G_OBJECT_CLASS(class);
-  gobject_class->dispose  = openGLWidgetEvent_dispose;
-  gobject_class->finalize = openGLWidgetEvent_finalize;
+  gobject_class->dispose  = visu_ui_gl_widgetEvent_dispose;
+  gobject_class->finalize = visu_ui_gl_widgetEvent_finalize;
 
   /* Dealing with widget events. */
   widget_class = GTK_WIDGET_CLASS(class);
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-  widget_class->expose_event  = openGLWidgetEvent_expose;
-  widget_class->size_request  = openGLWidgetEvent_sizeRequest;
+  widget_class->expose_event  = visu_ui_gl_widgetEvent_expose;
+  widget_class->size_request  = visu_ui_gl_widgetEvent_sizeRequest;
 #else
-  widget_class->draw          = openGLWidgetEvent_draw;
-  widget_class->get_preferred_width  = openGLWidgetEvent_getWidth;
-  widget_class->get_preferred_height = openGLWidgetEvent_getHeight;
+  widget_class->draw          = visu_ui_gl_widgetEvent_draw;
+  widget_class->get_preferred_width  = visu_ui_gl_widgetEvent_getWidth;
+  widget_class->get_preferred_height = visu_ui_gl_widgetEvent_getHeight;
 #endif
-  widget_class->visibility_notify_event = openGLWidgetEvent_visibility;
-  widget_class->realize       = openGLWidgetEvent_realise;
-  widget_class->size_allocate = openGLWidgetEvent_sizeAllocate;
+  widget_class->visibility_notify_event = visu_ui_gl_widgetEvent_visibility;
+  widget_class->realize       = visu_ui_gl_widgetEvent_realise;
+  widget_class->size_allocate = visu_ui_gl_widgetEvent_sizeAllocate;
 
-  class->contextCurrent = (OpenGLWidget*)0;
+  class->contextCurrent = (VisuUiGlWidget*)0;
 
   myClass = class;
 }
 
-static void openGLWidget_init(OpenGLWidget *render)
+static void visu_ui_gl_widget_init(VisuUiGlWidget *render)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (init) : create object %p.\n", (gpointer)render);
   render->sizeAllocation_has_run = FALSE;
   render->dispose_has_run = FALSE;
 
-  render->redraw = (RedrawMethod)0;
-  render->redrawData = (gpointer)0;
+  render->redraw = (VisuUiGlWidgetRedrawMethod)0;
+  render->redrawView  = (VisuGlView*)0;
 
   render->backLogo = (GdkPixbuf*)0;
 
@@ -228,11 +238,11 @@ static void openGLWidget_init(OpenGLWidget *render)
   gtk_widget_set_has_window(GTK_WIDGET(render), TRUE);
 }
 
-GtkWidget* openGLWidgetNew(gboolean contextIsDirect)
+GtkWidget* visu_ui_gl_widget_new(gboolean contextIsDirect)
 {
-  OpenGLWidget *render;
+  VisuUiGlWidget *render;
 
-  render = OPENGL_WIDGET(g_object_new(TYPE_OPENGL_WIDGET, NULL));
+  render = VISU_UI_GL_WIDGET(g_object_new(VISU_UI_TYPE_GL_WIDGET, NULL));
 
   render->isContextDirect = contextIsDirect;
 
@@ -240,66 +250,66 @@ GtkWidget* openGLWidgetNew(gboolean contextIsDirect)
 }
 
 /* Methods to deals with the events. */
-static void openGLWidgetEvent_dispose(GObject *obj)
+static void visu_ui_gl_widgetEvent_dispose(GObject *obj)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events) : dispose event for object %p.\n", (gpointer)obj);
 
-  if (OPENGL_WIDGET(obj)->dispose_has_run)
+  if (VISU_UI_GL_WIDGET(obj)->dispose_has_run)
     return;
-  OPENGL_WIDGET(obj)->dispose_has_run = TRUE;
+  VISU_UI_GL_WIDGET(obj)->dispose_has_run = TRUE;
 
-  if (OPENGL_WIDGET(obj)->backLogo)
-    g_object_unref(OPENGL_WIDGET(obj)->backLogo);
-  openGLWidgetFree_openGL(OPENGL_WIDGET(obj));
+  if (VISU_UI_GL_WIDGET(obj)->backLogo)
+    g_object_unref(VISU_UI_GL_WIDGET(obj)->backLogo);
+  visu_ui_gl_widgetFree_openGL(VISU_UI_GL_WIDGET(obj));
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(openGLWidget_parent_class)->dispose(obj);
+  G_OBJECT_CLASS(visu_ui_gl_widget_parent_class)->dispose(obj);
 }
-static void openGLWidgetEvent_finalize(GObject *obj)
+static void visu_ui_gl_widgetEvent_finalize(GObject *obj)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events): finalize event for object %p.\n", (gpointer)obj);
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(openGLWidget_parent_class)->finalize(obj);
+  G_OBJECT_CLASS(visu_ui_gl_widget_parent_class)->finalize(obj);
 }
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static gboolean openGLWidgetEvent_expose(GtkWidget *widget, GdkEventExpose *event _U_)
+static gboolean visu_ui_gl_widgetEvent_expose(GtkWidget *widget, GdkEventExpose *event _U_)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events): expose event for object %p.\n", (gpointer)widget);
-  openGLWidgetRedraw(OPENGL_WIDGET(widget));
+  visu_ui_gl_widget_redraw(VISU_UI_GL_WIDGET(widget));
 
   return FALSE;
 }
 #else
-static gboolean openGLWidgetEvent_draw(GtkWidget *widget, cairo_t *cr _U_)
+static gboolean visu_ui_gl_widgetEvent_draw(GtkWidget *widget, cairo_t *cr _U_)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events): draw event for object %p.\n", (gpointer)widget);
-  openGLWidgetRedraw(OPENGL_WIDGET(widget));
+  visu_ui_gl_widget_redraw(VISU_UI_GL_WIDGET(widget));
 
   return FALSE;
 }
 #endif
-static gboolean openGLWidgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event)
+static gboolean visu_ui_gl_widgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event)
 {
   if (event->state != GDK_VISIBILITY_UNOBSCURED)
     return FALSE;
 
   DBG_fprintf(stderr, "Gtk OpenGL (events): visibility event for object %p.\n", (gpointer)widget);
-  openGLWidgetRedraw(OPENGL_WIDGET(widget));
+  visu_ui_gl_widget_redraw(VISU_UI_GL_WIDGET(widget));
   DBG_fprintf(stderr, "Gtk OpenGL (events): visibility OK.\n");
 
   return FALSE;
 }
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static void openGLWidgetEvent_sizeRequest(GtkWidget *widget,
+static void visu_ui_gl_widgetEvent_sizeRequest(GtkWidget *widget,
 					  GtkRequisition *requisition)
 {
-  OpenGLWidget *render;
+  VisuUiGlWidget *render;
   GtkAllocation allocation;
 
   DBG_fprintf(stderr, "Gtk OpenGL (events): size request event.\n");
 
-  render = OPENGL_WIDGET(widget);
+  render = VISU_UI_GL_WIDGET(widget);
   if (render->sizeAllocation_has_run)
     {
       gtk_widget_get_allocation(widget, &allocation);
@@ -313,13 +323,13 @@ static void openGLWidgetEvent_sizeRequest(GtkWidget *widget,
     }
 
   /* Chain up to default that simply reads current requisition */
-/*   GTK_WIDGET_CLASS(openGLWidget_parent_class)->size_request(widget, requisition); */
+/*   GTK_WIDGET_CLASS(visu_ui_gl_widget_parent_class)->size_request(widget, requisition); */
 
   DBG_fprintf(stderr, "Gtk OpenGL (events): size request event (%dx%d).\n",
 	      requisition->width, requisition->height);
 }
 #else
-static void openGLWidgetEvent_getSize(GtkWidget *widget _U_, GtkOrientation orientation,
+static void visu_ui_gl_widgetEvent_getSize(GtkWidget *widget _U_, GtkOrientation orientation,
                                       gint *minSize, gint *size)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events): size request event.\n");
@@ -335,21 +345,21 @@ static void openGLWidgetEvent_getSize(GtkWidget *widget _U_, GtkOrientation orie
       *size = 450;
     }
 }
-static void openGLWidgetEvent_getWidth(GtkWidget *widget, gint *minWidth, gint *width)
+static void visu_ui_gl_widgetEvent_getWidth(GtkWidget *widget, gint *minWidth, gint *width)
 {
-  openGLWidgetEvent_getSize(widget, GTK_ORIENTATION_HORIZONTAL, minWidth, width);
+  visu_ui_gl_widgetEvent_getSize(widget, GTK_ORIENTATION_HORIZONTAL, minWidth, width);
 }
-static void openGLWidgetEvent_getHeight(GtkWidget *widget, gint *minHeight, gint *height)
+static void visu_ui_gl_widgetEvent_getHeight(GtkWidget *widget, gint *minHeight, gint *height)
 {
-  openGLWidgetEvent_getSize(widget, GTK_ORIENTATION_HORIZONTAL, minHeight, height);
+  visu_ui_gl_widgetEvent_getSize(widget, GTK_ORIENTATION_HORIZONTAL, minHeight, height);
 }
 #endif
-static void openGLWidgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *allocation)
+static void visu_ui_gl_widgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *allocation)
 {
-  OpenGLWidget *render;
+  VisuUiGlWidget *render;
   GtkAllocation wdAllocation;
 
-  render = OPENGL_WIDGET(widget);
+  render = VISU_UI_GL_WIDGET(widget);
   gtk_widget_get_allocation(widget, &wdAllocation);
   if ((wdAllocation.width  == allocation->width) &&
       (wdAllocation.height == allocation->height))
@@ -360,7 +370,7 @@ static void openGLWidgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *all
 
   render->sizeAllocation_has_run = TRUE;
   /* Chain up to default that simply reads current requisition */
-  GTK_WIDGET_CLASS(openGLWidget_parent_class)->size_allocate(widget, allocation);
+  GTK_WIDGET_CLASS(visu_ui_gl_widget_parent_class)->size_allocate(widget, allocation);
 
 #ifdef IMPL_BUILTIN_X11
   glXWaitX();
@@ -368,9 +378,9 @@ static void openGLWidgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *all
 
   setViewport(render, allocation->width, allocation->height, FALSE);
 }
-static void openGLWidgetEvent_realise(GtkWidget *widget)
+static void visu_ui_gl_widgetEvent_realise(GtkWidget *widget)
 {
-  OpenGLWidget *render;
+  VisuUiGlWidget *render;
   GdkWindowAttr attributes;
   gint attributes_mask;
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
@@ -386,10 +396,10 @@ static void openGLWidgetEvent_realise(GtkWidget *widget)
 
   gtk_widget_set_realized(widget, TRUE);
 
-  render = OPENGL_WIDGET(widget);
+  render = VISU_UI_GL_WIDGET(widget);
 
 #ifndef IMPL_BUILTIN_WIN32
-  openGLWidgetSet_pixelFormat(render);
+  visu_ui_gl_widgetSet_pixelFormat(render);
 #endif
 
   gtk_widget_get_allocation(widget, &allocation);
@@ -400,7 +410,7 @@ static void openGLWidgetEvent_realise(GtkWidget *widget)
   attributes.height = allocation.height;
   attributes.wclass = GDK_INPUT_OUTPUT;
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-  colormap = openGLWidgetGet_openGLColormap(render);
+  colormap = visu_ui_gl_widgetGet_openGLColormap(render);
   DBG_fprintf(stderr, "Gtk OpenGL (debug): colormap is %p.\n",
 	      (gpointer)colormap);
   attributes.visual = gdk_colormap_get_visual(colormap);
@@ -450,26 +460,32 @@ static void openGLWidgetEvent_realise(GtkWidget *widget)
 
   /* Initialize context for OpenGL, OS dependent. */
 #ifdef IMPL_BUILTIN_WIN32
-  openGLWidgetSet_pixelFormat(render);
+  visu_ui_gl_widgetSet_pixelFormat(render);
 #endif
-  openGLWidgetInit_context(render, render->isContextDirect);
-  openGLWidgetSet_current(render, FALSE);
+  visu_ui_gl_widgetInit_context(render, render->isContextDirect);
+  visu_ui_gl_widget_setCurrent(render, FALSE);
 }
 
-
-OpenGLWidget* openGLWidgetClassGet_currentContext()
+/**
+ * visu_ui_gl_widget_class_getCurrentContext:
+ *
+ * Class routine that returns the OpenGL widget which has the current context.
+ *
+ * Returns: (transfer none): the #VisuUiGlWidget with the current OpenGL context.
+ */
+VisuUiGlWidget* visu_ui_gl_widget_class_getCurrentContext()
 {
-  g_return_val_if_fail(myClass, (OpenGLWidget*)0);
+  g_return_val_if_fail(myClass, (VisuUiGlWidget*)0);
 
   return myClass->contextCurrent;
 }
 
-static void setViewport(OpenGLWidget *render, guint width,
+static void setViewport(VisuUiGlWidget *render, guint width,
 			guint height, gboolean redraw)
 {
-  g_return_if_fail(IS_OPENGL_WIDGET(render));
+  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
 
-  if (OPENGL_WIDGET_GET_CLASS(render)->contextCurrent != render)
+  if (VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent != render)
     return;
 
   DBG_fprintf(stderr, " | adjusting viewport to %dx%d.\n", width, height);
@@ -481,10 +497,10 @@ static void setViewport(OpenGLWidget *render, guint width,
       /* We clear the back buffer and swap because this buffer has
 	 still the wrong size. */
       glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-      openGLWidgetSwap_buffers(render);
+      visu_ui_gl_widget_swapBuffers(render);
     }
 }
-static void drawToEmpty(OpenGLWidget *render)
+static void drawToEmpty(VisuUiGlWidget *render)
 {
   int widthImg, heightImg;
   guchar *imageData;
@@ -506,7 +522,7 @@ static void drawToEmpty(OpenGLWidget *render)
   if (!render->backLogo)
     {
       DBG_fprintf(stderr, "Gtk OpenGL (action): load the pixbuf 'logo_grey.png'.\n");
-      render->backLogo = visuGtkCreate_pixbuf("logo_grey.png");
+      render->backLogo = visu_ui_createPixbuf("logo_grey.png");
     }
 
   glPushAttrib(GL_ENABLE_BIT);
@@ -556,22 +572,42 @@ static void drawToEmpty(OpenGLWidget *render)
     }
   glPopAttrib();
 }
-void openGLWidgetSet_redraw(OpenGLWidget *render, RedrawMethod method, VisuData *data)
+/**
+ * visu_ui_gl_widget_setRedraw:
+ * @render: a #VisuUiGlWidget object ;
+ * @method: (scope call): a redraw method ;
+ * @view: the #VisuGlView object.
+ *
+ * This method is used to defined a redraw method for the OpenGL area. By doing this
+ * the area will automatically redraw itself when necessary. Before doing it
+ * it calls visu_ui_gl_widget_setCurrent(), and after it calls
+ * visu_ui_gl_widget_swapBuffers().
+ */
+void visu_ui_gl_widget_setRedraw(VisuUiGlWidget *render,
+                                 VisuUiGlWidgetRedrawMethod method,
+                                 VisuGlView *view)
 {
-  g_return_if_fail(IS_OPENGL_WIDGET(render));
+  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
   
   DBG_fprintf(stderr, "Gtk OpenGL (action) : set redraw method for OpenGL area %p.\n", (gpointer)render);
-  render->redraw = method;
-  render->redrawData = data;
+  render->redraw      = method;
+  render->redrawView  = view;
 }
-void openGLWidgetRedraw(OpenGLWidget *render)
+/**
+ * visu_ui_gl_widget_redraw:
+ * @render: a #VisuUiGlWidget object.
+ *
+ * Force redraw on the given surface, if a redraw method have been given (see
+ * visu_ui_gl_widget_setRedraw()).
+ */
+void visu_ui_gl_widget_redraw(VisuUiGlWidget *render)
 {
 #if DEBUG == 1
   GTimer *timer;
   gulong fractionTimer;
 #endif
 
-  g_return_if_fail(IS_OPENGL_WIDGET(render));
+  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
 
 #if DEBUG == 1
   timer = g_timer_new();
@@ -580,14 +616,14 @@ void openGLWidgetRedraw(OpenGLWidget *render)
 
   DBG_fprintf(stderr, "Gtk OpenGL (action) : redraw OpenGL area for %p.\n", (gpointer)render);
   DBG_fprintf(stderr, " | set current.\n");
-  openGLWidgetSet_current(render, FALSE);
+  visu_ui_gl_widget_setCurrent(render, FALSE);
   DBG_fprintf(stderr, " | redraw inside.\n");
   if (render->redraw)
-    render->redraw((const char**)0, render->redrawData);
+    render->redraw(render->redrawView, (GList*)0);
   else
     drawToEmpty(render);
   DBG_fprintf(stderr, " | swap buffers.\n");
-  openGLWidgetSwap_buffers(render);
+  visu_ui_gl_widget_swapBuffers(render);
 #if DEBUG == 1
   g_timer_stop(timer);
   fprintf(stderr, "Gtk OpenGL: total redraw in %g micro-s.\n",
@@ -595,22 +631,36 @@ void openGLWidgetRedraw(OpenGLWidget *render)
   g_timer_destroy(timer);
 #endif
 }
-
-GArray* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
-				   int *height, gboolean offScreen, gboolean hasAlpha)
+/**
+ * visu_ui_gl_widget_getPixmapData:
+ * @render: a #VisuUiGlWidget object ;
+ * @width: a pointer to the desired width or -1 ;
+ * @height: a pointer to the desired height or -1 ;
+ * @offScreen: a boolean ;
+ * @hasAlpha: if TRUE, the returned data is RGBA, else only RGB.
+ *
+ * Create an image from the OpenGL area. The size can  be changed, using @width and
+ * @height. If these pointers contains positive values, then they are used to set the
+ * size for the image. If not, the current size is used and stored in these pointers.
+ * The boolean offScreen is used to tell if the image is taken from current context
+ * or if an offscreen pixmap is created for the rendering.
+ *
+ * Returns: (transfer full): image data, row by row.
+ */
+GArray* visu_ui_gl_widget_getPixmapData(VisuUiGlWidget *render, int *width,
+                                        int *height, gboolean offScreen,
+                                        gboolean hasAlpha)
 {
   GtkWidget *wd;
   GArray *image;
   VisuPixmapContext *dumpData;
-  VisuOpenGLView *view;
-  float *ext;
   GtkAllocation allocation;
 
-  g_return_val_if_fail(IS_OPENGL_WIDGET(render), (GArray*)0);
-  g_return_val_if_fail(OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render, (GArray*)0);
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GArray*)0);
+  g_return_val_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render, (GArray*)0);
   g_return_val_if_fail(render->redraw, (GArray*)0);
   g_return_val_if_fail(width && height, (GArray*)0);
-  g_return_val_if_fail(render->redrawData, (GArray*)0);
+  g_return_val_if_fail(render->redrawView, (GArray*)0);
 
   wd = GTK_WIDGET(render);
   gtk_widget_get_allocation(wd, &allocation);
@@ -619,7 +669,7 @@ GArray* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
     {
       *width = allocation.width;
       *height = allocation.height;
-      return visuOpenGLGet_pixmapData(*width, *height, hasAlpha);
+      return visu_pixmap_getData(*width, *height, hasAlpha);
     }
 
   /* If a method is given, then we draw
@@ -637,22 +687,20 @@ GArray* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
 		" free of any other windows.");
       *width = allocation.width;
       *height = allocation.height;
-      return visuOpenGLGet_pixmapData(*width, *height, hasAlpha);
+      return visu_pixmap_getData(*width, *height, hasAlpha);
     }
-  view = visu_data_getOpenGLView(render->redrawData);
   /* We set the glViewport of this new context. */
-  openGLInit_context();
-  openGLModelize(view->camera);
-  visu_data_setSizeOfView(render->redrawData, (guint)*width, (guint)*height);
-  ext = visu_data_getBoxExtens(render->redrawData);
-  openGLProject(view->window, view->camera, ext[1]);
-  visuExtensions_rebuildAllLists(render->redrawData);
+  visu_gl_initContext();
+  visu_gl_camera_modelize(render->redrawView->camera);
+  visu_gl_view_setViewport(render->redrawView, (guint)*width, (guint)*height);
+  visu_gl_window_project(render->redrawView->window, render->redrawView->camera);
+  visu_gl_ext_rebuildAll();
   /* We call the given draw method. */
-  render->redraw((const char**)0, render->redrawData);
+  render->redraw(render->redrawView, (GList*)0);
   /* We copy the pixmap into generic data. */
-  image = visuOpenGLGet_pixmapData((guint)*width, (guint)*height, hasAlpha);
+  image = visu_pixmap_getData((guint)*width, (guint)*height, hasAlpha);
   /* We change back the context to the current rendering area. */
-  openGLWidgetSet_current(render, TRUE);
+  visu_ui_gl_widget_setCurrent(render, TRUE);
   /* We free the pixmap context. */
   visu_pixmap_context_free(dumpData);
 
@@ -661,7 +709,7 @@ GArray* openGLWidgetGet_pixmapData(OpenGLWidget *render, int *width,
 
 /* OpenGL functions, OS dependent. */
 #ifdef IMPL_GTKGLEXT
-static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
+static void visu_ui_gl_widgetSet_pixelFormat(VisuUiGlWidget *render)
 {
   GdkScreen *screen;
 
@@ -674,10 +722,10 @@ static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
   DBG_fprintf(stderr, " | get a screen number %d.\n",
 	      gdk_x11_screen_get_screen_number(screen));
 
-  render->glconfig = visuOpenGLGet_glConfig(screen);
+  render->glconfig = visu_gl_getGLConfig(screen);
   DBG_fprintf(stderr, " | get a visual.\n");
 }
-static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDirect)
+static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean contextIsDirect)
 {
   GtkWidget *wd;
 
@@ -714,9 +762,9 @@ static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDir
       g_error("Cannot create a GtkGLExt context.\n");
     }
 }
-static void openGLWidgetFree_openGL(OpenGLWidget *render)
+static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 {
-  g_return_if_fail(IS_OPENGL_WIDGET(render));
+  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
 
   DBG_fprintf(stderr, "Gtk OpenGL (glext): freeing context & window.\n");
   if (render->glwindow)
@@ -724,45 +772,45 @@ static void openGLWidgetFree_openGL(OpenGLWidget *render)
   if (render->context)
     gdk_gl_context_destroy(render->context);
 }
-gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
+gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force)
 {
   gboolean res;
   GtkWidget *wd;
   
-  g_return_val_if_fail(IS_OPENGL_WIDGET(render), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
 
-  if (!force && OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render)
+  if (!force && VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render)
     return TRUE;
 
   DBG_fprintf(stderr, "Gtk OpenGL (glext): %p is set current.\n", (gpointer)render);
   res = gdk_gl_drawable_make_current(GDK_GL_DRAWABLE(render->glwindow),
 				     render->context);
-  openGLText_onNewContext();
+  visu_gl_text_onNewContext();
 
   if (!res)
     {
-      g_warning("Cannot make the openGLWidget object %p current.\n",
+      g_warning("Cannot make the visu_ui_gl_widget object %p current.\n",
 		(gpointer)render);
       return FALSE;
     }
   DBG_fprintf(stderr, "Gtk OpenGL (glext): OK context changed.\n");
 
-  OPENGL_WIDGET_GET_CLASS(render)->contextCurrent = render;
+  VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent = render;
 
   wd = GTK_WIDGET(render);
   setViewport(render, wd->allocation.width, wd->allocation.height, FALSE);
 
   return TRUE;
 }
-void openGLWidgetSwap_buffers(OpenGLWidget *render)
+void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
 {
-  g_return_if_fail(OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render);
+  g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
   DBG_fprintf(stderr, "Gtk OpenGL (glext): swap buffers of area %p.\n",
 	      (gpointer)render);
   gdk_gl_drawable_swap_buffers(GDK_GL_DRAWABLE(render->glwindow));
 }
-static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
+static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render)
 {
   g_return_val_if_fail(render->glconfig, (GdkColormap*)0);
 
@@ -770,7 +818,7 @@ static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
 }
 #endif
 #ifdef IMPL_BUILTIN_X11
-static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
+static void visu_ui_gl_widgetSet_pixelFormat(VisuUiGlWidget *render)
 {
   gint screenId;
   gboolean built;
@@ -783,6 +831,7 @@ static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
   else
     render->dpy = gdk_x11_get_default_xdisplay();
   DBG_fprintf(stderr, " | get the display %p.\n", (gpointer)render->dpy);
+  /* XSynchronize(render->dpy, True); */
 
   /* Get the screen id. */
   if (built)
@@ -792,18 +841,15 @@ static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
   screenId = gdk_screen_get_number(screen);
   DBG_fprintf(stderr, " | get a screen number %d.\n", screenId);
 
-  render->vinfo = visuOpenGLGet_visualInfo(render->dpy, screenId);
+  render->vinfo = visu_gl_getVisualInfo(render->dpy, screenId);
   DBG_fprintf(stderr, " | get a visual %d.\n", (int)render->vinfo->visualid);
   render->visual = gdk_x11_screen_lookup_visual(screen, render->vinfo->visualid);
 }
-static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDirect)
+static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean contextIsDirect)
 {
-  GtkWidget *wd;
-
   DBG_fprintf(stderr, "Gtk OpenGL (X11): create an OpenGL context (%d).\n",
 	      contextIsDirect);
 
-  wd = GTK_WIDGET(render);
   /* Check for GLX. */
   if (!glXQueryExtension(render->dpy, 0, 0))
     {
@@ -834,9 +880,9 @@ static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDir
       g_error("Cannot create a GLX context.\n");
     }
 }
-static void openGLWidgetFree_openGL(OpenGLWidget *render)
+static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 {
-  g_return_if_fail(IS_OPENGL_WIDGET(render));
+  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
 
   if (render->dpy)
     {
@@ -849,16 +895,16 @@ static void openGLWidgetFree_openGL(OpenGLWidget *render)
 /*       XCloseDisplay(render->dpy); */
     }
 }
-gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
+gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force)
 {
   int res;
   GtkWidget *wd;
   XID windowId;
   GtkAllocation alloc;
   
-  g_return_val_if_fail(IS_OPENGL_WIDGET(render), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
 
-  if (!force && OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render)
+  if (!force && VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render)
     return TRUE;
 
   DBG_fprintf(stderr, "Gtk OpenGL (X11): unset the context.\n");
@@ -878,13 +924,13 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
 		       render->context);
   if (!res)
     {
-      g_warning("Cannot make the openGLWidget object %p current.\n",
+      g_warning("Cannot make the visu_ui_gl_widget object %p current.\n",
 		(gpointer)render);
       return FALSE;
     }
   glXWaitX();
   DBG_fprintf(stderr, "Gtk OpenGL (X11): OK context changed.\n");
-  openGLText_onNewContext();
+  visu_gl_text_onNewContext();
 
   /* Now that the glx tunnel has been added, we need
      to specify again that we want a backing store because until now
@@ -894,7 +940,7 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
 /*   XChangeWindowAttributes(render->dpy, windowId, */
 /* 			  CWBackingStore, &wattrs); */
 
-  OPENGL_WIDGET_GET_CLASS(render)->contextCurrent = render;
+  VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent = render;
 
   wd = GTK_WIDGET(render);
   gtk_widget_get_allocation(wd, &alloc);
@@ -902,9 +948,9 @@ gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force)
 
   return TRUE;
 }
-void openGLWidgetSwap_buffers(OpenGLWidget *render)
+void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
 {
-  g_return_if_fail(OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render);
+  g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
   DBG_fprintf(stderr, "Gtk OpenGL (X11): swap buffers of area %p.\n", (gpointer)render);
   glXSwapBuffers(render->dpy,
@@ -912,9 +958,9 @@ void openGLWidgetSwap_buffers(OpenGLWidget *render)
   DBG_fprintf(stderr, "Gtk OpenGL (X11): swap OK.\n");
 }
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
+static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render)
 {
-  g_return_val_if_fail(IS_OPENGL_WIDGET(render), (GdkColormap*)0);
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GdkColormap*)0);
   g_return_val_if_fail(render->vinfo, (GdkColormap*)0);
 
   return gdk_colormap_new(gdkx_visual_get(render->vinfo->visualid), FALSE);
@@ -922,7 +968,7 @@ static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
 #endif
 #endif
 #ifdef IMPL_BUILTIN_WIN32
-static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
+static void visu_ui_gl_widgetSet_pixelFormat(VisuUiGlWidget *render)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (Win32): choose visual for %p.\n", render);
 
@@ -930,55 +976,141 @@ static void openGLWidgetSet_pixelFormat(OpenGLWidget *render)
   render->hdc = GetDC(render->windowId);
   DBG_fprintf(stderr, " | get the hdc %d.\n", (int)render->hdc);
 
-  visuOpenGLSetup_pixelFormat(render->hdc);
+  visu_gl_setupPixelFormat(render->hdc);
   
   render->visual = gdk_screen_get_system_visual(gdk_screen_get_default());
 }
-static void openGLWidgetInit_context(OpenGLWidget *render, gboolean contextIsDirect)
+static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean contextIsDirect)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (Win32): create an OpenGL context (%d).\n", contextIsDirect);
 
   /* Finaly, create the context. */
   render->context = wglCreateContext(render->hdc);
 }
-static void openGLWidgetFree_openGL(OpenGLWidget *render)
+static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 {
-  g_return_if_fail(IS_OPENGL_WIDGET(render));
+  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
 
   if (render->context)
     wglDeleteContext(render->context);
 /*   if (render->hdc) */
 /*     DeleteDC(render->hdc); */
 }
-gboolean openGLWidgetSet_current(OpenGLWidget *render, gboolean force _U_)
+gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force _U_)
 {
   GtkWidget *wd;
 
-  g_return_val_if_fail(IS_OPENGL_WIDGET(render), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
 
   DBG_fprintf(stderr, "Gtk OpenGL (action) : %p is set current.\n", (gpointer)render);
   wglMakeCurrent(NULL, NULL);
   wglMakeCurrent(render->hdc, render->context);
-  openGLText_onNewContext();
+  visu_gl_text_onNewContext();
 
-  OPENGL_WIDGET_GET_CLASS(render)->contextCurrent = render;
+  VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent = render;
 
   wd = GTK_WIDGET(render);
   setViewport(render, wd->allocation.width, wd->allocation.height, FALSE);
 
   return TRUE;
 }
-void openGLWidgetSwap_buffers(OpenGLWidget *render)
+void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
 {
-  g_return_if_fail(OPENGL_WIDGET_GET_CLASS(render)->contextCurrent == render);
+  g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
   DBG_fprintf(stderr, "Gtk OpenGL (action) : swap buffers of area %p.\n", (gpointer)render);
   SwapBuffers(render->hdc);
 }
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static GdkColormap* openGLWidgetGet_openGLColormap(OpenGLWidget *render)
+static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render)
 {
-  g_return_val_if_fail(IS_OPENGL_WIDGET(render), (GdkColormap*)0);
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GdkColormap*)0);
+  
+  return gdk_screen_get_system_colormap(gdk_screen_get_default());
+}
+#endif
+#endif
+#ifdef IMPL_BUILTIN_QUARTZ
+static AGLPixelFmtID visu_gl_setupPixelFormat()
+{
+  AGLPixelFmtID id;
+  int list[] = {
+    AGL_RGBA,
+    AGL_RED_SIZE, 1, AGL_GREEN_SIZE, 1, AGL_BLUE_SIZE, 1,
+    AGL_DEPTH_SIZE, 1,
+    AGL_DOUBLEBUFFER,
+    AGL_STEREO,
+    AGL_NONE
+  };
+
+  if ( (id = aglChoosePixelFmt(NULL, 0, list)) == NULL )
+    {
+      list[10] = AGL_NONE; 
+      if ( (id = aglChoosePixelFmt(NULL, 0, list)) == NULL )
+	{
+	  g_error("Cannot find a pixel format.");
+	}
+      DBG_fprintf(stderr, " | not a stereo buffer.\n");
+    }
+  else
+    DBG_fprintf(stderr, " | stereo buffer.\n");
+
+  return id;
+}
+static void visu_ui_gl_widgetSet_pixelFormat(VisuUiGlWidget *render)
+{
+  DBG_fprintf(stderr, "Gtk OpenGL (Quartz): choose visual for %p.\n", render);
+
+  render->windowId = (NSWindow)gdk_quartz_window_get_nswindow(GDK_WINDOW(GTK_WIDGET(render)->window));
+
+  render->pxlfmt = visu_gl_setupPixelFormat();
+  
+  render->visual = gdk_screen_get_system_visual(gdk_screen_get_default());
+}
+static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean contextIsDirect)
+{
+  DBG_fprintf(stderr, "Gtk OpenGL (Quartz): create an OpenGL context (%d).\n", contextIsDirect);
+
+  /* Finaly, create the context. */
+  render->context = aglCreateContext(render->pxlfmt, 0);
+}
+static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
+{
+  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+
+  if (render->context)
+    aglDestroyContext(render->context);
+/*   if (render->hdc) */
+/*     DeleteDC(render->hdc); */
+}
+gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force _U_)
+{
+  GtkWidget *wd;
+
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
+
+  DBG_fprintf(stderr, "Gtk OpenGL (Quartz): %p is set current.\n", (gpointer)render);
+  aglMakeCurrent((AGLDrawable)render->windowId, render->context);
+  /* visu_gl_text_onNewContext(); */
+
+  VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent = render;
+
+  wd = GTK_WIDGET(render);
+  setViewport(render, wd->allocation.width, wd->allocation.height, FALSE);
+
+  return TRUE;
+}
+void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
+{
+  g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
+
+  DBG_fprintf(stderr, "Gtk OpenGL (Quartz): swap buffers of area %p.\n", (gpointer)render);
+  aglSwapBuffers((AGLDrawable)render->windowId);
+}
+#if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
+static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render)
+{
+  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GdkColormap*)0);
   
   return gdk_screen_get_system_colormap(gdk_screen_get_default());
 }
