@@ -47,18 +47,22 @@
 
 #include <support.h>
 #include <visu_object.h>
+#include <gtk_main.h>
 #include <openGLFunctions/view.h>
 #include <coreTools/toolColor.h>
+#include <coreTools/toolMatrix.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 #include <extraGtkFunctions/gtk_lineObjectWidget.h>
 #include <extensions/box.h>
-#include <extensions/axes.h>
 #include <extensions/scale.h>
 #include <extensions/legend.h>
 
 /**
  * SECTION: panelAxes
- * @short_description: The tab where axes, box, scale and legend are setup.
+ * @short_description: The tab where axes, box, scale and legend are
+ * setup.
+ *
+ * <para>Nothing tunable here.</para>
  */
 
 /* Sensitive widget in this subpanel. */
@@ -71,60 +75,87 @@ static GtkWidget *entryScale;
 static GtkWidget *originespin[3];
 static GtkWidget *orientationspin[3];
 static GtkWidget *checkLegend;
-static GtkWidget *checkLengths, *checkBasis;
+static GtkWidget *checkLengths, *checkAxes; /* , *checkBasis */
+static GtkWidget *spinXPos, *spinYPos, *spinXLegPos, *spinYLegPos;
 static GtkWidget *lblScales;
 
 static gboolean disableCallbacks;
+static VisuGlExtAxes *currentAxes = NULL;
 
 /* Private functions. */
 static GtkWidget *createInteriorAxes();
 
 /* Local callbacks. */
-static void onBoxChecked(LineObject *line, gboolean used, gpointer data);
-static void onBoxRGBValueChanged(LineObject *line, float *rgb, gpointer data);
-static void onBoxLineWidthChanged(LineObject *line, gint width, gpointer data);
-static void onBoxStippleChanged(LineObject *line, gint stipple, gpointer data);
+static void onExtensionUsed(VisuUiLine *line, gboolean used, gpointer data);
+static void onBoxRGBValueChanged(VisuUiLine *line, float *rgb, gpointer data);
+static void onBoxLineWidthChanged(VisuUiLine *line, gint width, gpointer data);
+static void onBoxStippleChanged(VisuUiLine *line, gint stipple, gpointer data);
 static void onBoxLengthsToggled(GtkToggleButton *toggle, gpointer data);
-static void onAxesChecked(LineObject *line, gboolean used, gpointer data);
-static void onAxesWidthChanged(LineObject *line, gint width, gpointer user_data);
-static void onAxesRGBChanged(LineObject *line, float *rgb, gpointer data);
-static void onAxesStippleChanged(LineObject *line, gint stipple, gpointer data);
-static void onEnter(ToolPanel *toolPanel, gpointer data);
+static void onBoxLegPosChanged(GtkSpinButton *spin, gpointer data);
+static void onAxesToggled(GtkToggleButton *toggle, gpointer data);
+static void onAxesWidthChanged(VisuUiLine *line, gint width, gpointer user_data);
+static void onAxesRGBChanged(VisuUiLine *line, float *rgb, gpointer data);
+static void onAxesStippleChanged(VisuUiLine *line, gint stipple, gpointer data);
+static void onAxesPosChanged(GtkSpinButton *spin, gpointer data);
+static void onEnter(VisuUiPanel *visu_ui_panel, gpointer data);
 static void onResources(GObject *object, VisuData *dataObj, gpointer data);
-static void onScalesChecked(LineObject *line, gboolean used, gpointer data);
-static void onScalesWidthChanged(LineObject *line, gint width, gpointer user_data);
-static void onScalesRGBChanged(LineObject *line, float *rgb, gpointer data);
-static void onScalesStippleChanged(LineObject *line, gint stipple, gpointer data);
+static void onScalesWidthChanged(VisuUiLine *line, gint width, gpointer user_data);
+static void onScalesRGBChanged(VisuUiLine *line, float *rgb, gpointer data);
+static void onScalesStippleChanged(VisuUiLine *line, gint stipple, gpointer data);
 static void scaleDistanceChanged(GtkSpinButton *spin,gpointer data);
 static void scaleOriginChanged(GtkSpinButton *spin,gpointer data);
 static void scaleOrientationChanged(GtkSpinButton *spin,gpointer data);
 static void onLegendChanged(GtkEntry *entry, gpointer data);
 static void onUseLegendChanged(GtkToggleButton *toggle, gpointer data);
+static void onViewAvail(VisuObject *obj, VisuData *dataObj, VisuGlView *view, gpointer data);
 
-ToolPanel* panelAxes_init()
+/**
+ * visu_ui_panel_axes_init: (skip)
+ *
+ * Should be used in the list declared in externalModules.h to be loaded by
+ * V_Sim on start-up. This routine will create the #VisuUiPanel where the axes and the
+ * label stuffs can be tuned, such as their colour, create scales...
+ *
+ * Returns: a newly created #VisuUiPanel object.
+ */
+VisuUiPanel* visu_ui_panel_axes_init(VisuUiMain *ui _U_)
 {
-  panelAxes = toolPanelNew_withIconFromPath("Panel_axes", _("Box, axes and labels"),
-					    _("Frames/labels"), "stock-axes_20.png");
+  panelAxes = visu_ui_panel_newWithIconFromPath("Panel_axes", _("Box, axes and labels"),
+                                                _("Frames/labels"), "stock-axes_20.png");
   if (!panelAxes)
-    return (ToolPanel*)0;
-
-  /* Create the widgets required before interior creation. */
-  checkLengths = gtk_check_button_new_with_mnemonic(_("Show box _lengths"));
-  checkBasis = gtk_check_button_new();
+    return (VisuUiPanel*)0;
 
   gtk_container_add(GTK_CONTAINER(panelAxes), createInteriorAxes());
-  toolPanelSet_dockable(TOOL_PANEL(panelAxes), TRUE);
+  visu_ui_panel_setDockable(VISU_UI_PANEL(panelAxes), TRUE);
 
   /* Create the callbacks of all the sensitive widgets. */
   g_signal_connect(G_OBJECT(panelAxes), "page-entered",
 		   G_CALLBACK(onEnter), (gpointer)0);
-  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
+  g_signal_connect(VISU_OBJECT_INSTANCE, "dataRendered",
+		   G_CALLBACK(onViewAvail), (gpointer)0);
+  g_signal_connect(VISU_OBJECT_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(onResources), (gpointer)0);
 
   /* Private parameters. */
   disableCallbacks = FALSE;
 
-  return TOOL_PANEL(panelAxes);
+  return VISU_UI_PANEL(panelAxes);
+}
+/**
+ * visu_ui_panel_axes_setAxesExtension:
+ * @axes: (transfer full) (allow-none): a #VisuGlExtAxes object.
+ *
+ * Set the current axes extension handled by this #VisuUiPanel.
+ *
+ * Since: 3.7
+ **/
+void visu_ui_panel_axes_setAxesExtension(VisuGlExtAxes *axes)
+{
+  if (currentAxes)
+    g_object_unref(currentAxes);
+  currentAxes = axes;
+  if (axes)
+    g_object_ref(axes);
 }
 
 static GtkWidget *createInteriorAxes()
@@ -139,7 +170,6 @@ static GtkWidget *createInteriorAxes()
   float xyzDefault[3] = {0.f, 0.f, 0.f};
   float orientationDefault[3] = {1.f, 0.f, 0.f};
   int i;
-  GList *scales;
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
@@ -154,16 +184,26 @@ static GtkWidget *createInteriorAxes()
   align = gtk_alignment_new(0.5, 0.5, 1, 1);
   gtk_alignment_set_padding(GTK_ALIGNMENT(align), 0, 15, 0, 0);
   gtk_box_pack_start(GTK_BOX(vbox), align, FALSE, FALSE, 0);
-  lineBox = lineObjectNew(_("Bounding box"));
+  lineBox = visu_ui_line_new(_("Bounding box"));
   gtk_container_add(GTK_CONTAINER(align), lineBox);
-  vbox2 = lineObjectGet_optionVBox(LINE_OBJECT(lineBox));
+  vbox2 = visu_ui_line_getOptionBox(VISU_UI_LINE(lineBox));
+  checkLengths = gtk_check_button_new_with_mnemonic(_("Show box _lengths"));
   gtk_box_pack_start(GTK_BOX(vbox2), checkLengths, FALSE, FALSE, 0);
+  hbox = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("x pos.")), TRUE, TRUE, 0);
+  spinXLegPos = gtk_spin_button_new_with_range(0., 1., 0.1);
+  gtk_box_pack_start(GTK_BOX(hbox), spinXLegPos, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("y pos.")), TRUE, TRUE, 0);
+  spinYLegPos = gtk_spin_button_new_with_range(0., 1., 0.1);
+  gtk_box_pack_start(GTK_BOX(hbox), spinYLegPos, FALSE, FALSE, 0);
 /*   label = gtk_label_new(_("Draw basis set:")); */
 /*   gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5); */
 /*   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0); */
+  /* checkBasis = gtk_check_button_new(); */
 /*   gtk_box_pack_start(GTK_BOX(hbox), checkBasis, FALSE, FALSE, 0); */
   g_signal_connect(G_OBJECT(lineBox), "use-changed",
-		   G_CALLBACK(onBoxChecked), (gpointer)0);
+		   G_CALLBACK(onExtensionUsed), (gpointer)visu_gl_ext_box_getDefault());
   g_signal_connect(G_OBJECT(lineBox), "width-changed",
 		   G_CALLBACK(onBoxLineWidthChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(lineBox), "color-changed",
@@ -172,23 +212,44 @@ static GtkWidget *createInteriorAxes()
 		   G_CALLBACK(onBoxStippleChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(checkLengths), "toggled",
 		   G_CALLBACK(onBoxLengthsToggled), (gpointer)0);
+  g_signal_connect(G_OBJECT(spinXLegPos), "value-changed",
+		   G_CALLBACK(onBoxLegPosChanged), (gpointer)0);
+  g_signal_connect(G_OBJECT(spinYLegPos), "value-changed",
+		   G_CALLBACK(onBoxLegPosChanged), (gpointer)0);
 
   /*************/
   /* The Axes. */
   /*************/
-  lineAxes = lineObjectNew(_("Basis set"));
+  lineAxes = visu_ui_line_new(_("Basis set"));
   align = gtk_alignment_new(0.5, 0., 1, 1);
   gtk_alignment_set_padding(GTK_ALIGNMENT(align), 0, 15, 0, 0);
   gtk_container_add(GTK_CONTAINER(align), lineAxes);
   gtk_box_pack_start(GTK_BOX(vbox), align, FALSE, FALSE, 0);
+  vbox2 = visu_ui_line_getOptionBox(VISU_UI_LINE(lineAxes));
+  checkAxes = gtk_check_button_new_with_mnemonic(_("Use _box basis-set"));
+  gtk_box_pack_start(GTK_BOX(vbox2), checkAxes, TRUE, TRUE, 0);
+  hbox = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("x pos.")), TRUE, TRUE, 0);
+  spinXPos = gtk_spin_button_new_with_range(0., 1., 0.1);
+  gtk_box_pack_start(GTK_BOX(hbox), spinXPos, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("y pos.")), TRUE, TRUE, 0);
+  spinYPos = gtk_spin_button_new_with_range(0., 1., 0.1);
+  gtk_box_pack_start(GTK_BOX(hbox), spinYPos, FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(lineAxes), "use-changed",
-		   G_CALLBACK(onAxesChecked), (gpointer)0);
+		   G_CALLBACK(onExtensionUsed), (gpointer)currentAxes);
   g_signal_connect(G_OBJECT(lineAxes), "width-changed",
 		   G_CALLBACK(onAxesWidthChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(lineAxes), "color-changed",
 		   G_CALLBACK(onAxesRGBChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(lineAxes), "stipple-changed",
 		   G_CALLBACK(onAxesStippleChanged), (gpointer)0);
+  g_signal_connect(G_OBJECT(checkAxes), "toggled",
+		   G_CALLBACK(onAxesToggled), (gpointer)0);
+  g_signal_connect(G_OBJECT(spinXPos), "value-changed",
+		   G_CALLBACK(onAxesPosChanged), (gpointer)0);
+  g_signal_connect(G_OBJECT(spinYPos), "value-changed",
+		   G_CALLBACK(onAxesPosChanged), (gpointer)0);
 
   /**************/
   /* The legend */
@@ -202,8 +263,6 @@ static GtkWidget *createInteriorAxes()
   /* The drawn checkbox. */
   checkLegend = gtk_check_button_new();
   gtk_box_pack_start(GTK_BOX(hbox), checkLegend, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkLegend),
-			       visu_glExt_legend_getOn());
   g_signal_connect(G_OBJECT(checkLegend), "toggled",
                    G_CALLBACK(onUseLegendChanged), (gpointer)0);
 
@@ -217,14 +276,14 @@ static GtkWidget *createInteriorAxes()
   /*************************/
   /* Adding scale widgets. */
   /*************************/
-  lineScales = lineObjectNew(_("Label"));
+  lineScales = visu_ui_line_new(_("Label"));
   align = gtk_alignment_new(0.5, 0., 1, 1);
   gtk_alignment_set_padding(GTK_ALIGNMENT(align), 0, 15, 0, 0);
   gtk_container_add(GTK_CONTAINER(align), lineScales);
   gtk_box_pack_start(GTK_BOX(vbox), align, FALSE, FALSE, 0);
-  vbox2 = lineObjectGet_optionVBox(LINE_OBJECT(lineScales));
+  vbox2 = visu_ui_line_getOptionBox(VISU_UI_LINE(lineScales));
   g_signal_connect(G_OBJECT(lineScales), "use-changed",
-		   G_CALLBACK(onScalesChecked), (gpointer)0);
+		   G_CALLBACK(onExtensionUsed), (gpointer)visu_gl_ext_scale_getDefault());
   g_signal_connect(G_OBJECT(lineScales), "width-changed",
 		   G_CALLBACK(onScalesWidthChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(lineScales), "color-changed",
@@ -238,14 +297,13 @@ static GtkWidget *createInteriorAxes()
   gtk_label_set_use_markup(GTK_LABEL(lblScales), TRUE);
   gtk_box_pack_end(GTK_BOX(vbox2), lblScales, FALSE, FALSE, 10);
   gtk_widget_set_no_show_all(lblScales, TRUE);
-  if (visu_glExt_scale_getAll())
+  scale = visu_gl_ext_scale_getDefault();
+  if (visu_gl_ext_scale_getNArrows(scale) > 0)
     {
-      scales = visu_glExt_scale_getAll();
-      scale = VISU_GLEXT_SCALE(scales->data);
-      len = visu_glExt_scale_getLength(scale);
-      xyz = visu_glExt_scale_getOrigin(scale);
-      orientation = visu_glExt_scale_getOrientation(scale);
-      if (scales->next)
+      len = visu_gl_ext_scale_getLength(scale, 0);
+      xyz = visu_gl_ext_scale_getOrigin(scale, 0);
+      orientation = visu_gl_ext_scale_getOrientation(scale, 0);
+      if (visu_gl_ext_scale_getNArrows(scale) > 1)
         gtk_widget_show(lblScales);
     }
   else
@@ -322,102 +380,103 @@ static GtkWidget *createInteriorAxes()
 /*************/
 /* Callbacks */
 /*************/
-static void axesRedraw()
-{
-  VisuData *dataObj;
-
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelAxes));
-  if (!dataObj) 
-    return;
-  visu_glExt_axes_draw(dataObj);
-  VISU_ADD_REDRAW;
-}
-static void onAxesChecked(LineObject *line _U_, gboolean used, gpointer data _U_)
-{
-  if (disableCallbacks)
-    return;
-
-  visu_glExt_axes_setOn(used);
-  axesRedraw();
-}
-static void onAxesWidthChanged(LineObject *line _U_, gint width, gpointer data _U_)
-{
-  if (disableCallbacks)
-    return;
-
-  if (visu_glExt_axes_setLineWidth((float)width))
-    axesRedraw();
-}
-static void onAxesRGBChanged(LineObject *line _U_, float *rgb, gpointer data _U_)
-{
-  if (disableCallbacks)
-    return;
-
-  if (visu_glExt_axes_setRGBValues(rgb, TOOL_COLOR_MASK_RGBA))
-    axesRedraw();
-}
-static void onAxesStippleChanged(LineObject *line _U_, gint stipple, gpointer data _U_)
-{
-  if (disableCallbacks)
-    return;
-
-  if (visu_glExt_axes_setLineStipple(stipple))
-    axesRedraw();
-}
 static void onResources(GObject *object _U_, VisuData *dataObj _U_, gpointer data)
 {
   DBG_fprintf(stderr, "Panel Axes: catch the 'resourcesChanged'"
 	      " signal, updating.\n");
 
-  onEnter(TOOL_PANEL(panelAxes), data);
+  onEnter(VISU_UI_PANEL(panelAxes), data);
 }
-static void onEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
+static void onViewAvail(VisuObject *obj _U_, VisuData *dataObj,
+                        VisuGlView *view, gpointer data _U_)
 {
-  float *xyz, *orientation;
+  VisuBox *box;
+  VisuNodeArray *nodes;
+
+  DBG_fprintf(stderr, "Panel Axes: caught 'dataRendered' signal, attaching default axes.\n");
+  box = (dataObj)?visu_boxed_getBox(VISU_BOXED(dataObj)):(VisuBox*)0;
+  nodes = (dataObj)?VISU_NODE_ARRAY(dataObj):(VisuNodeArray*)0;
+
+  visu_ui_panel_axes_setAxesExtension((dataObj)?visu_gl_ext_axes_getDefault():(VisuGlExtAxes*)0);
+
+  if (visu_gl_ext_box_setBox(visu_gl_ext_box_getDefault(), box))
+    visu_gl_ext_box_draw(visu_gl_ext_box_getDefault());
+
+  visu_gl_ext_frame_setGlView(VISU_GL_EXT_FRAME(visu_gl_ext_box_legend_getDefault()), view);
+  if (visu_gl_ext_box_legend_setBox(visu_gl_ext_box_legend_getDefault(), box))
+    visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(visu_gl_ext_box_legend_getDefault()));
+
+  visu_gl_ext_frame_setGlView(VISU_GL_EXT_FRAME(visu_gl_ext_legend_getDefault()), view);
+  if (visu_gl_ext_legend_setNodes(visu_gl_ext_legend_getDefault(), nodes))
+    visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(visu_gl_ext_legend_getDefault()));
+
+  if (visu_gl_ext_scale_setGlView(visu_gl_ext_scale_getDefault(), view))
+    visu_gl_ext_scale_draw(visu_gl_ext_scale_getDefault());
+}
+static void onEnter(VisuUiPanel *visu_ui_panel _U_, gpointer data _U_)
+{
+  float *xyz, *orientation, xpos, ypos;
   VisuGlExtScale *scale;
   float xyzDefault[3] = {0.f, 0.f, 0.f};
   float orientationDefault[3] = {1.f, 0.f, 0.f};
   gchar *legend;
-  GList *scales;
+  VisuGlExtBox *box;
 
   disableCallbacks = TRUE;
 
   /* Set the box values. */
-  lineObjectSet_use(LINE_OBJECT(lineBox), visu_glExt_box_getOn());
-  lineObjectSet_width(LINE_OBJECT(lineBox), visu_glExt_box_getLineWidth());
-  lineObjectSet_color(LINE_OBJECT(lineBox), visu_glExt_box_getRGBValues());
-  lineObjectSet_stipple(LINE_OBJECT(lineBox), visu_glExt_box_getLineStipple());
+  box = visu_gl_ext_box_getDefault();
+  visu_ui_line_setUsed(VISU_UI_LINE(lineBox), visu_gl_ext_getActive(VISU_GL_EXT(box)));
+  visu_ui_line_setWidth(VISU_UI_LINE(lineBox), visu_gl_ext_box_getLineWidth(box));
+  visu_ui_line_setColor(VISU_UI_LINE(lineBox), visu_gl_ext_box_getRGB(box));
+  visu_ui_line_setStipple(VISU_UI_LINE(lineBox), visu_gl_ext_box_getLineStipple(box));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkLengths),
-			       visu_glExt_box_getShowLegend());
+			       visu_gl_ext_getActive(VISU_GL_EXT(visu_gl_ext_box_legend_getDefault())));
+  visu_gl_ext_frame_getPosition(VISU_GL_EXT_FRAME(visu_gl_ext_box_legend_getDefault()),
+                                &xpos, &ypos);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinXLegPos), xpos);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinYLegPos), ypos);
 
   /* Set the axes values. */
-  lineObjectSet_use(LINE_OBJECT(lineAxes), visu_glExt_axes_getOn());
-  lineObjectSet_width(LINE_OBJECT(lineAxes), visu_glExt_axes_getLineWidth());
-  lineObjectSet_color(LINE_OBJECT(lineAxes), visu_glExt_axes_getRGBValues());
-  lineObjectSet_stipple(LINE_OBJECT(lineAxes), visu_glExt_axes_getLineStipple());
+  if (currentAxes)
+    {
+      gtk_widget_set_sensitive(lineAxes, TRUE);
+      visu_ui_line_setUsed(VISU_UI_LINE(lineAxes),
+                           visu_gl_ext_getActive(VISU_GL_EXT(currentAxes)));
+      visu_ui_line_setWidth(VISU_UI_LINE(lineAxes),
+                            visu_gl_ext_axes_getLineWidth(currentAxes));
+      visu_ui_line_setColor(VISU_UI_LINE(lineAxes),
+                            visu_gl_ext_axes_getRGB(currentAxes));
+      visu_ui_line_setStipple(VISU_UI_LINE(lineAxes),
+                              visu_gl_ext_axes_getLineStipple(currentAxes));
+      visu_gl_ext_axes_getPosition(currentAxes, &xpos, &ypos);
+      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinXPos), xpos);
+      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinYPos), ypos);
+    }
+  else
+    gtk_widget_set_sensitive(lineAxes, FALSE);
 
   /* Set the scale class values. */
-  lineObjectSet_use(LINE_OBJECT(lineScales), visu_glExt_scale_getOn());
-  lineObjectSet_width(LINE_OBJECT(lineScales), visu_glExt_scale_getDefaultLineWidth());
-  lineObjectSet_color(LINE_OBJECT(lineScales), visu_glExt_scale_getDefaultRGBValues());
-  lineObjectSet_stipple(LINE_OBJECT(lineScales), visu_glExt_scale_getDefaultStipple());
+  scale = visu_gl_ext_scale_getDefault();
+  visu_ui_line_setUsed(VISU_UI_LINE(lineScales), visu_gl_ext_getActive(VISU_GL_EXT(scale)));
+  visu_ui_line_setWidth(VISU_UI_LINE(lineScales), visu_gl_ext_scale_getDefaultLineWidth());
+  visu_ui_line_setColor(VISU_UI_LINE(lineScales), visu_gl_ext_scale_getDefaultRGB());
+  visu_ui_line_setStipple(VISU_UI_LINE(lineScales), visu_gl_ext_scale_getDefaultStipple());
 
   /* To be removed. */
   gtk_widget_hide(lblScales);
-  scales = visu_glExt_scale_getAll();
-  if (scales)
+  if (visu_gl_ext_scale_getNArrows(scale) > 0)
     {
-      scale = VISU_GLEXT_SCALE(scales->data);
       DBG_fprintf(stderr, "Panel Axes: set scales values from %p.\n",
 		  (gpointer)scale);
-      xyz = visu_glExt_scale_getOrigin(scale);
-      orientation = visu_glExt_scale_getOrientation(scale);
+      xyz = visu_gl_ext_scale_getOrigin(scale, 0);
+      orientation = visu_gl_ext_scale_getOrientation(scale, 0);
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinScaleLength),
-				visu_glExt_scale_getLength(scale));
-      legend = (gchar*)visu_glExt_scale_getLegend(scale);
+				visu_gl_ext_scale_getLength(scale, 0));
+      legend = (gchar*)visu_gl_ext_scale_getLegend(scale, 0);
       if (!legend)
 	legend = "";
-      if (scales->next)
+      if (visu_gl_ext_scale_getNArrows(scale) > 1)
         gtk_widget_show(lblScales);
     }
   else
@@ -438,29 +497,88 @@ static void onEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
   gtk_entry_set_text(GTK_ENTRY(entryScale), legend);
       
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkLegend),
-			       visu_glExt_legend_getOn());
+			       visu_gl_ext_getActive(VISU_GL_EXT(visu_gl_ext_legend_getDefault())));
 
   disableCallbacks = FALSE;
 }
+static void onExtensionUsed(VisuUiLine *line _U_, gboolean used, gpointer data)
+{
+  if (disableCallbacks || !data)
+    return;
 
+  visu_gl_ext_setActive(VISU_GL_EXT(data), used);
+  if (VISU_IS_GL_EXT_SCALE(data))
+    visu_gl_ext_scale_draw(VISU_GL_EXT_SCALE(data));
+  else if (VISU_IS_GL_EXT_AXES(data))
+    visu_gl_ext_axes_draw(VISU_GL_EXT_AXES(data));
+  else if (VISU_IS_GL_EXT_BOX(data))
+    visu_gl_ext_box_draw(VISU_GL_EXT_BOX(data));
+  VISU_REDRAW_ADD;
+}
 
-static void scaleRedraw()
+static void onAxesWidthChanged(VisuUiLine *line _U_, gint width, gpointer data _U_)
+{
+  if (disableCallbacks || !currentAxes)
+    return;
+
+  if (visu_gl_ext_axes_setLineWidth(currentAxes, (float)width))
+    {
+      visu_gl_ext_axes_draw(currentAxes);
+      VISU_REDRAW_ADD;
+    }
+}
+static void onAxesRGBChanged(VisuUiLine *line _U_, float *rgb, gpointer data _U_)
+{
+  if (disableCallbacks || !currentAxes)
+    return;
+
+  if (visu_gl_ext_axes_setRGB(currentAxes, rgb, TOOL_COLOR_MASK_RGBA))
+    {
+      visu_gl_ext_axes_draw(currentAxes);
+      VISU_REDRAW_ADD;
+    }
+}
+static void onAxesStippleChanged(VisuUiLine *line _U_, gint stipple, gpointer data _U_)
+{
+  if (disableCallbacks || !currentAxes)
+    return;
+
+  if (visu_gl_ext_axes_setLineStipple(currentAxes, stipple))
+    {
+      visu_gl_ext_axes_draw(currentAxes);
+      VISU_REDRAW_ADD;
+    }
+}
+static void onAxesToggled(GtkToggleButton *toggle, gpointer data _U_)
 {
   VisuData *dataObj;
-  VisuOpenGLView *view;
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelAxes));
-  if (!dataObj) 
+  if (disableCallbacks || !currentAxes)
     return;
-  view = visu_data_getOpenGLView(dataObj);
-  visu_glExt_scale_drawAll(view->camera, MIN(view->window->width, view->window->height));
-  VISU_ADD_REDRAW;
+
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(panelAxes));
+  if (visu_gl_ext_axes_setBasisFromBox
+      (currentAxes,
+       (gtk_toggle_button_get_active(toggle))?visu_boxed_getBox(VISU_BOXED(dataObj)):(VisuBox*)0))
+    {
+      visu_gl_ext_axes_draw(currentAxes);
+      VISU_REDRAW_ADD;
+    }
 }
-static void onScalesChecked(LineObject *line _U_, gboolean used, gpointer data _U_)
+static void onAxesPosChanged(GtkSpinButton *spin _U_, gpointer data _U_)
 {
-  visu_glExt_scale_setOn(used);
-  scaleRedraw();
+  if (disableCallbacks || !currentAxes)
+    return;
+  
+  if (visu_gl_ext_axes_setPosition(currentAxes,
+                                   (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinXPos)),
+                                   (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinYPos))))
+    {
+      visu_gl_ext_axes_draw(currentAxes);
+      VISU_REDRAW_ADD;
+    }
 }
+
 static void scaleDistanceChanged(GtkSpinButton *spin, gpointer data _U_)
 {
   gboolean res;
@@ -470,10 +588,8 @@ static void scaleDistanceChanged(GtkSpinButton *spin, gpointer data _U_)
   if (disableCallbacks)
     return;
 
-  /* To be removed. */
-  if (visu_glExt_scale_getAll())
-    scale = VISU_GLEXT_SCALE(visu_glExt_scale_getAll()->data);
-  else
+  scale = visu_gl_ext_scale_getDefault();
+  if (visu_gl_ext_scale_getNArrows(scale) == 0)
     {
       xyz[0] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[0]));
       xyz[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[1]));
@@ -482,24 +598,28 @@ static void scaleDistanceChanged(GtkSpinButton *spin, gpointer data _U_)
       orientation[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[1]));
       orientation[2] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[2]));
       len = gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)) / 2.f;
-      scale = visu_glExt_scale_new(xyz, orientation, len, (const gchar*)0);
+      visu_gl_ext_scale_add(scale, xyz, orientation, len, (const gchar*)0);
     }
 
   DBG_fprintf(stderr, "Panel Box&axes: scale distance changed.\n");
-  res = visu_glExt_scale_setLength(scale, (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)));
+  res = visu_gl_ext_scale_setLength(scale, 0,
+                                    (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)));
   if (*gtk_entry_get_text(GTK_ENTRY(entryScale)) == '\0')
-    visu_glExt_scale_setLegend(scale, (const gchar*)0);
+    visu_gl_ext_scale_setLegend(scale, 0, (const gchar*)0);
   else
-    visu_glExt_scale_setLegend(scale, gtk_entry_get_text(GTK_ENTRY(entryScale)));
+    visu_gl_ext_scale_setLegend(scale, 0, gtk_entry_get_text(GTK_ENTRY(entryScale)));
 
   if (res)
-    scaleRedraw();
+    {
+      visu_gl_ext_scale_draw(scale);
+      VISU_REDRAW_ADD;
+    }
 }
 
 static void scaleOriginChanged(GtkSpinButton *spin, gpointer data)
 {
   gboolean res;
-  int xyzMask[3] = {VISU_GLEXT_XYZ_MASK_X, VISU_GLEXT_XYZ_MASK_Y, VISU_GLEXT_XYZ_MASK_Z};
+  int xyzMask[3] = {TOOL_XYZ_MASK_X, TOOL_XYZ_MASK_Y, TOOL_XYZ_MASK_Z};
   int val;
   VisuGlExtScale *scale;
   float xyz[3], orientation[3];
@@ -510,10 +630,8 @@ static void scaleOriginChanged(GtkSpinButton *spin, gpointer data)
   if (disableCallbacks)
     return;
 
-  /* To be removed. */
-  if (visu_glExt_scale_getAll())
-    scale = VISU_GLEXT_SCALE(visu_glExt_scale_getAll()->data);
-  else
+  scale = visu_gl_ext_scale_getDefault();
+  if (visu_gl_ext_scale_getNArrows(scale) == 0)
     {
       xyz[0] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[0]));
       xyz[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[1]));
@@ -522,23 +640,26 @@ static void scaleOriginChanged(GtkSpinButton *spin, gpointer data)
       orientation[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[1]));
       orientation[2] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[2]));
       xyz[val] += 1.f;
-      scale = visu_glExt_scale_new(xyz, orientation,
-		       gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinScaleLength)),
-		       (const gchar*)0);
+      visu_gl_ext_scale_add(scale, xyz, orientation,
+                            gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinScaleLength)),
+                            (const gchar*)0);
     }
 
   DBG_fprintf(stderr, "Panel Box&axes: scale origine %d change.\n", val);
   xyz[val] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin));
-  res = visu_glExt_scale_setOrigin(scale, xyz, xyzMask[val]);
+  res = visu_gl_ext_scale_setOrigin(scale, 0, xyz, xyzMask[val]);
 
   if (res)
-    scaleRedraw();
+    {
+      visu_gl_ext_scale_draw(scale);
+      VISU_REDRAW_ADD;
+    }
 }
 
 static void scaleOrientationChanged(GtkSpinButton *spin, gpointer data)
 {
   gboolean res;
-  int xyzMask[3] = {VISU_GLEXT_XYZ_MASK_X, VISU_GLEXT_XYZ_MASK_Y, VISU_GLEXT_XYZ_MASK_Z};
+  int xyzMask[3] = {TOOL_XYZ_MASK_X, TOOL_XYZ_MASK_Y, TOOL_XYZ_MASK_Z};
   int val;
   VisuGlExtScale *scale;
   float xyz[3], orientation[3];
@@ -549,10 +670,8 @@ static void scaleOrientationChanged(GtkSpinButton *spin, gpointer data)
   if (disableCallbacks)
     return;
 
-  /* To be removed. */
-  if (visu_glExt_scale_getAll())
-    scale = VISU_GLEXT_SCALE(visu_glExt_scale_getAll()->data);
-  else
+  scale = visu_gl_ext_scale_getDefault();
+  if (visu_gl_ext_scale_getNArrows(scale) == 0)
     {
       xyz[0] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[0]));
       xyz[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[1]));
@@ -561,36 +680,20 @@ static void scaleOrientationChanged(GtkSpinButton *spin, gpointer data)
       orientation[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[1]));
       orientation[2] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[2]));
       orientation[val] += 999.f;
-      scale = visu_glExt_scale_new(xyz, orientation,
-		       gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinScaleLength)),
-		       (const gchar*)0);
+      visu_gl_ext_scale_add(scale, xyz, orientation,
+                            gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinScaleLength)),
+                            (const gchar*)0);
     }
 
   DBG_fprintf(stderr, "Panel Box&axes: scale orientation %d changed.\n", val);
   xyz[val] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin));
-  res = visu_glExt_scale_setOrientation(scale, xyz, xyzMask[val]);
+  res = visu_gl_ext_scale_setOrientation(scale, 0, xyz, xyzMask[val]);
 
   if (res)
-    scaleRedraw();
-}
-static void onScalesWidthChanged(LineObject *line _U_, gint width, gpointer data _U_)
-{
-  if (visu_glExt_scale_setDefaultLineWidth(width))
-    scaleRedraw();
-}
-static void onScalesRGBChanged(LineObject *line _U_, float *rgb, gpointer data _U_)
-{
-  float rgba[4];
-
-  memcpy(rgba, rgb, sizeof(float) * 3);
-  rgba[3] = 1.f;
-  if (visu_glExt_scale_setDefaultRGBValues(rgba, TOOL_COLOR_MASK_RGBA))
-    scaleRedraw();
-}
-static void onScalesStippleChanged(LineObject *line _U_, gint stipple, gpointer data _U_)
-{
-  if (visu_glExt_scale_setDefaultStipple(stipple))
-    scaleRedraw();
+    {
+      visu_gl_ext_scale_draw(scale);
+      VISU_REDRAW_ADD;
+    }
 }
 static void onLegendChanged(GtkEntry *entry, gpointer data _U_)
 {
@@ -601,10 +704,8 @@ static void onLegendChanged(GtkEntry *entry, gpointer data _U_)
   if (disableCallbacks)
     return;
 
-  /* To be removed. */
-  if (visu_glExt_scale_getAll())
-    scale = VISU_GLEXT_SCALE(visu_glExt_scale_getAll()->data);
-  else
+  scale = visu_gl_ext_scale_getDefault();
+  if (visu_gl_ext_scale_getNArrows(scale) == 0)
     {
       xyz[0] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[0]));
       xyz[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(originespin[1]));
@@ -612,83 +713,113 @@ static void onLegendChanged(GtkEntry *entry, gpointer data _U_)
       orientation[0] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[0]));
       orientation[1] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[1]));
       orientation[2] = gtk_spin_button_get_value(GTK_SPIN_BUTTON(orientationspin[2]));
-      scale = visu_glExt_scale_new(xyz, orientation,
-		       gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinScaleLength)),
-		       (const gchar*)0);
+      visu_gl_ext_scale_add(scale, xyz, orientation,
+                            gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinScaleLength)),
+                            (const gchar*)0);
     }
 
   DBG_fprintf(stderr, "Panel Box&axes: scale legend changed.\n");
-  res = visu_glExt_scale_setLegend(scale, gtk_entry_get_text(entry));
+  res = visu_gl_ext_scale_setLegend(scale, 0, gtk_entry_get_text(entry));
 
   if (res)
-    scaleRedraw();
+    {
+      visu_gl_ext_scale_draw(scale);
+      VISU_REDRAW_ADD;
+    }
+}
+static void onScalesWidthChanged(VisuUiLine *line _U_, gint width, gpointer data _U_)
+{
+  if (visu_gl_ext_scale_setDefaultLineWidth(width))
+    {
+      visu_gl_ext_scale_draw(visu_gl_ext_scale_getDefault());
+      VISU_REDRAW_ADD;
+    }
+}
+static void onScalesRGBChanged(VisuUiLine *line _U_, float *rgb, gpointer data _U_)
+{
+  float rgba[4];
+
+  memcpy(rgba, rgb, sizeof(float) * 3);
+  rgba[3] = 1.f;
+  if (visu_gl_ext_scale_setDefaultRGB(rgba, TOOL_COLOR_MASK_RGBA))
+    {
+      visu_gl_ext_scale_draw(visu_gl_ext_scale_getDefault());
+      VISU_REDRAW_ADD;
+    }
+}
+static void onScalesStippleChanged(VisuUiLine *line _U_, gint stipple, gpointer data _U_)
+{
+  if (visu_gl_ext_scale_setDefaultStipple(stipple))
+    {
+      visu_gl_ext_scale_draw(visu_gl_ext_scale_getDefault());
+      VISU_REDRAW_ADD;
+    }
 }
 static void onUseLegendChanged(GtkToggleButton *toggle, gpointer data _U_)
 {
-  VisuData *dataObj;
-
   if (disableCallbacks)
     return;
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelAxes));
-
-  if (visu_glExt_legend_setOn(gtk_toggle_button_get_active(toggle)))
-    {
-      if (!dataObj) 
-	return;
-
-      visu_glExt_legend_draw(dataObj);
-    }
-  VISU_ADD_REDRAW;
+  visu_gl_ext_setActive(VISU_GL_EXT(visu_gl_ext_legend_getDefault()),
+                           gtk_toggle_button_get_active(toggle));
+  visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(visu_gl_ext_legend_getDefault()));
+  VISU_REDRAW_ADD;
 }
-static void boxRedraw()
-{
-  VisuData *dataObj;
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelAxes));
-  if (!dataObj) 
-    return;
-  visu_glExt_box_draw(dataObj);
-  visu_glExt_box_draw_legend(dataObj);
-  VISU_ADD_REDRAW;
-}
 static void onBoxLengthsToggled(GtkToggleButton *toggle, gpointer data _U_)
 {
   if (disableCallbacks)
     return;
 
-  visu_glExt_box_setShowLegend(gtk_toggle_button_get_active(toggle));
-  boxRedraw();
+  visu_gl_ext_setActive(VISU_GL_EXT(visu_gl_ext_box_legend_getDefault()),
+                           gtk_toggle_button_get_active(toggle));
+  visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(visu_gl_ext_box_legend_getDefault()));
+  VISU_REDRAW_ADD;
 }
-static void onBoxLineWidthChanged(LineObject *line _U_, gint width, gpointer data _U_)
+static void onBoxLineWidthChanged(VisuUiLine *line _U_, gint width, gpointer data _U_)
 {
   if (disableCallbacks)
     return;
 
-  if (visu_glExt_box_setLineWidth((float)width))
-    boxRedraw();
+  if (visu_gl_ext_box_setLineWidth(visu_gl_ext_box_getDefault(), (float)width))
+    {
+      visu_gl_ext_box_draw(visu_gl_ext_box_getDefault());
+      VISU_REDRAW_ADD;
+    }
 }
-static void onBoxStippleChanged(LineObject *line _U_, gint stipple, gpointer data _U_)
+static void onBoxStippleChanged(VisuUiLine *line _U_, gint stipple, gpointer data _U_)
 {
   if (disableCallbacks)
     return;
 
-  if (visu_glExt_box_setLineStipple(stipple))
-    boxRedraw();
+  if (visu_gl_ext_box_setLineStipple(visu_gl_ext_box_getDefault(), stipple))
+    {
+      visu_gl_ext_box_draw(visu_gl_ext_box_getDefault());
+      VISU_REDRAW_ADD;
+    }
 }
-static void onBoxRGBValueChanged(LineObject *line _U_, float *rgb, gpointer data _U_)
+static void onBoxRGBValueChanged(VisuUiLine *line _U_, float *rgb, gpointer data _U_)
 {
   if (disableCallbacks)
     return;
 
-  if (visu_glExt_box_setRGBValues(rgb, TOOL_COLOR_MASK_RGBA))
-    boxRedraw();
+  if (visu_gl_ext_box_setRGB(visu_gl_ext_box_getDefault(), rgb, TOOL_COLOR_MASK_RGBA))
+    {
+      visu_gl_ext_box_draw(visu_gl_ext_box_getDefault());
+      VISU_REDRAW_ADD;
+    }
 }
-static void onBoxChecked(LineObject *line _U_, gboolean used, gpointer data _U_)
+static void onBoxLegPosChanged(GtkSpinButton *spin _U_, gpointer data _U_)
 {
   if (disableCallbacks)
     return;
-
-  visu_glExt_box_setOn(used);
-  boxRedraw();
+  
+  if (visu_gl_ext_frame_setPosition
+      (VISU_GL_EXT_FRAME(visu_gl_ext_box_legend_getDefault()),
+       (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinXLegPos)),
+       (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinYLegPos))))
+    {
+      visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(visu_gl_ext_box_legend_getDefault()));
+      VISU_REDRAW_ADD;
+    }
 }
