@@ -45,17 +45,20 @@
 #define PANELDATAFILE_H
 
 #include <visu_data.h>
+#include <extraFunctions/dataFile.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 #include <coreTools/toolShade.h>
 
-ToolPanel* panelDataFileInit();
+VisuUiPanel* visu_ui_panel_colorization_init();
 
-gboolean panelDataFileLoad_file(VisuData *visuData, const gchar *file, gboolean *new);
+gboolean visu_ui_panel_colorization_load(VisuData *visuData, const gchar *file, gboolean *new);
 
-void panelDataFileSet_use(gboolean used);
-gboolean panelDataFileSet_presetShade(Shade *shade);
+void visu_ui_panel_colorization_setUsed(gboolean used);
+gboolean visu_ui_panel_colorization_setPresetShade(ToolShade *shade);
+void visu_ui_panel_colorization_setRangeMode(VisuColorizationInputScaleId mode);
+void visu_ui_panel_colorization_setManualRange(float min, float max, int column);
 
-void panelDataFileUpdate(VisuData *visuData);
+void visu_ui_panel_colorization_update(VisuData *visuData);
 
 #endif
 
