@@ -46,8 +46,10 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <support.h>
+#include <gtk_main.h>
 #include <visu_tools.h>
 #include <visu_object.h>
 #include <visu_gtk.h>
@@ -69,7 +71,8 @@ static GtkWidget *rangeFogStart, *rangeFogEnd;
 static GtkWidget *radioBgFog, *radioOtherFog;
 static GtkWidget *rgbBgColor[4];
 static GtkWidget *rgbFogColor[3];
-static GtkWidget *bgImageWd;
+static GtkWidget *bgImageWd, *checkFollowZoom;
+static gulong trans_signal, gross_signal;
 
 /* Private functions. */
 GtkWidget *createInteriorFogBgColor();
@@ -83,7 +86,7 @@ static void radioBgChanged(GtkToggleButton *button, gpointer data);
 static void changedRGBFogColor(GtkRange *rg, gpointer data);
 static void changedFogStart(GtkRange *rg, gpointer data);
 static void changedFogEnd(GtkRange *rg, gpointer data);
-static void onFogBgEnter(ToolPanel *toolPanel, gpointer data);
+static void onFogBgEnter(VisuUiPanel *visu_ui_panel, gpointer data);
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
 static void onBgImageSet(GtkFileChooserButton *filechooserbutton, gpointer data);
 #else
@@ -93,31 +96,64 @@ static void onBgImageSet(GtkDialog *dialog, gint response, gpointer data);
 static void onBgImageChoose(GtkButton *bt, gpointer data);
 #endif
 static void onBgImageUnset(GtkButton *bt, gpointer data);
+static void onBgImageFollow(GtkToggleButton *bt, gpointer data);
+static void onDataReady(VisuObject *obj, VisuData *dataObj,
+                        VisuGlView *view, gpointer data);
+static void onDataNotReady(VisuObject *obj, VisuData *dataObj,
+                           VisuGlView *view, gpointer data);
+static void onCameraChange(VisuGlView *view, gpointer data);
 
 static GtkWidget *panelFogBgColor;
 static int disableCallbacksFogBgColor;
 
-ToolPanel* panelFogBgColor_init()
+VisuUiPanel* visu_ui_panel_bg_init(VisuUiMain *ui _U_)
 {
   char *cl = _("Fog and background color");
   char *tl = _("Fog & bg");
 
-  panelFogBgColor = toolPanelNew_withIconFromPath("Panel_fog_and_bg_color", cl, tl,
+  panelFogBgColor = visu_ui_panel_newWithIconFromPath("Panel_fog_and_bg_color", cl, tl,
 						  "stock-fog_20.png");
   if (!panelFogBgColor)
-    return (ToolPanel*)0;
+    return (VisuUiPanel*)0;
   gtk_container_add(GTK_CONTAINER(panelFogBgColor), createInteriorFogBgColor());
-  toolPanelSet_dockable(TOOL_PANEL(panelFogBgColor), TRUE);
+  visu_ui_panel_setDockable(VISU_UI_PANEL(panelFogBgColor), TRUE);
 
   /* Create the callbacks of all the sensitive widgets. */
   createCallBacksFogBgColor();
   g_signal_connect(G_OBJECT(panelFogBgColor), "page-entered",
 		   G_CALLBACK(onFogBgEnter), (gpointer)0);
 
+  g_signal_connect(VISU_OBJECT_INSTANCE, "dataRendered",
+                   G_CALLBACK(onDataReady), (gpointer)0);
+  g_signal_connect(VISU_OBJECT_INSTANCE, "dataUnRendered",
+                   G_CALLBACK(onDataNotReady), (gpointer)0);
+
   /* Private parameters. */
   disableCallbacksFogBgColor = 0;
 
-  return TOOL_PANEL(panelFogBgColor);
+  return VISU_UI_PANEL(panelFogBgColor);
+}
+static void onDataReady(VisuObject *visu _U_, VisuData *dataObj,
+                        VisuGlView *view, gpointer data _U_)
+{
+  if (view && dataObj)
+    {
+      visu_gl_ext_bg_setGlView(visu_gl_ext_bg_getDefault(), view);
+      trans_signal =
+        g_signal_connect(G_OBJECT(view), "XsYsChanged",
+                         G_CALLBACK(onCameraChange), (gpointer)0);
+      gross_signal =
+        g_signal_connect(G_OBJECT(view), "GrossChanged",
+                         G_CALLBACK(onCameraChange), (gpointer)0);
+    }
+  else
+    visu_gl_ext_bg_setGlView(visu_gl_ext_bg_getDefault(), (VisuGlView*)0);
+}
+static void onDataNotReady(VisuObject *visu _U_, VisuData *dataObj _U_,
+                           VisuGlView *view, gpointer data _U_)
+{
+  g_signal_handler_disconnect(G_OBJECT(view), trans_signal);
+  g_signal_handler_disconnect(G_OBJECT(view), gross_signal);
 }
 
 static void update_preview_cb(GtkFileChooser *file_chooser, gpointer data)
@@ -232,6 +268,12 @@ GtkWidget *createInteriorFogBgColor()
   gtk_box_pack_start(GTK_BOX(hbox), bt, FALSE, FALSE, 5);
   g_signal_connect(G_OBJECT(bt), "clicked",
 		   G_CALLBACK(onBgImageUnset), (gpointer)bgImageWd);
+  hbox = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+  checkFollowZoom = gtk_check_button_new_with_mnemonic(_("Image size & position _follow the camera"));
+  g_signal_connect(G_OBJECT(checkFollowZoom), "toggled",
+		   G_CALLBACK(onBgImageFollow), (gpointer)0);
+  gtk_box_pack_end(GTK_BOX(hbox), checkFollowZoom, FALSE, FALSE, 0);
 
   hbox = gtk_hbox_new(FALSE, 0);
   label = gtk_label_new(_("Use fog:"));
@@ -329,18 +371,19 @@ static void fogRedraw()
 {
   VisuData *dataObj;
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelFogBgColor));
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(panelFogBgColor));
   if (!dataObj) 
     return;
-  visu_glExt_fog_create(dataObj);
-  VISU_ADD_REDRAW;
+  visu_gl_ext_fog_create(visu_ui_panel_getView(VISU_UI_PANEL(panelFogBgColor)),
+                         visu_boxed_getBox(VISU_BOXED(dataObj)));
+  VISU_REDRAW_ADD;
 }
 static void fogCheckChanged(GtkToggleButton *button, gpointer data _U_)
 {
   if (disableCallbacksFogBgColor)
     return;
 
-  visu_glExt_fog_setOn(gtk_toggle_button_get_active(button));
+  visu_gl_ext_fog_setOn(gtk_toggle_button_get_active(button));
   fogRedraw();
 }
 static void changedFogStart(GtkRange *rg, gpointer data _U_)
@@ -360,7 +403,7 @@ static void changedFogStart(GtkRange *rg, gpointer data _U_)
 #endif
   val[0]= val[0] / 100.;
   
-  if (visu_glExt_fog_setStartEndValues(val, VISU_GLEXT_FOG_MASK_START))
+  if (visu_gl_ext_fog_setStartEndValues(val, VISU_GL_EXT_FOG_MASK_START))
     fogRedraw();
 }
 static void changedFogEnd(GtkRange *rg, gpointer data)
@@ -381,7 +424,7 @@ static void changedFogEnd(GtkRange *rg, gpointer data)
   if (disableCallbacksFogBgColor)
     return;
 
-  if (visu_glExt_fog_setStartEndValues(val, VISU_GLEXT_FOG_MASK_END))
+  if (visu_gl_ext_fog_setStartEndValues(val, VISU_GL_EXT_FOG_MASK_END))
     fogRedraw();
 }
 static void radioBgChanged(GtkToggleButton *button, gpointer data _U_)
@@ -393,8 +436,8 @@ static void radioBgChanged(GtkToggleButton *button, gpointer data _U_)
 
   for (i = 0; i < 3; i++)
     gtk_widget_set_sensitive(rgbFogColor[i], !gtk_toggle_button_get_active(button));
-  if (visu_glExt_fog_setUseSpecificColor(!gtk_toggle_button_get_active(button)))
-    VISU_ADD_REDRAW;
+  if (visu_gl_ext_fog_setUseSpecificColor(!gtk_toggle_button_get_active(button)))
+    VISU_REDRAW_ADD;
 }
 static void changedRGBFogColor(GtkRange *rg, gpointer data)
 {
@@ -410,10 +453,10 @@ static void changedRGBFogColor(GtkRange *rg, gpointer data)
   adj = gtk_range_get_adjustment(rg);
   rgb[GPOINTER_TO_INT(data)] = (float)gtk_adjustment_get_value(adj);
   
-  if (visu_glExt_fog_setValues(rgb, rgbMask[GPOINTER_TO_INT(data)]))
-    VISU_ADD_REDRAW;
+  if (visu_gl_ext_fog_setValues(rgb, rgbMask[GPOINTER_TO_INT(data)]))
+    VISU_REDRAW_ADD;
 }
-static void onFogBgEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
+static void onFogBgEnter(VisuUiPanel *visu_ui_panel _U_, gpointer data _U_)
 {
   int i;
   float rgb[4];
@@ -421,17 +464,17 @@ static void onFogBgEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
   disableCallbacksFogBgColor = 1;
   DBG_fprintf(stderr, "Panel Fog & bg : refresh data on enter.\n");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkFogIsOn),
-			       visu_glExt_fog_getOn());
+			       visu_gl_ext_fog_getOn());
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioOtherFog),
-			       visu_glExt_fog_getUseSpecificColor());
-  visu_glExt_bg_getValues(rgb);
+			       visu_gl_ext_fog_getUseSpecificColor());
+  visu_gl_ext_bg_getRGBA(visu_gl_ext_bg_getDefault(), rgb);
   for (i = 0; i < 4; i++)
     gtk_range_set_value(GTK_RANGE(rgbBgColor[i]), (gdouble)rgb[i]);
-  visu_glExt_fog_getValues(rgb);
+  visu_gl_ext_fog_getValues(rgb);
   for (i = 0; i < 3; i++)
     gtk_range_set_value(GTK_RANGE(rgbFogColor[i]), (gdouble)rgb[i]);
-  gtk_range_set_value(GTK_RANGE(rangeFogStart), (gdouble)visu_glExt_fog_getStart() * 100.);
-  gtk_range_set_value(GTK_RANGE(rangeFogEnd), (gdouble)visu_glExt_fog_getEnd() * 100.);
+  gtk_range_set_value(GTK_RANGE(rangeFogStart), (gdouble)visu_gl_ext_fog_getStart() * 100.);
+  gtk_range_set_value(GTK_RANGE(rangeFogEnd), (gdouble)visu_gl_ext_fog_getEnd() * 100.);
   disableCallbacksFogBgColor = 0;
 }
 
@@ -451,8 +494,12 @@ static void changedRGBBgColor(GtkRange *rg, gpointer data)
   adj = gtk_range_get_adjustment(rg);
   rgb[GPOINTER_TO_INT(data)] = (float)gtk_adjustment_get_value(adj);
   
-  if (visu_glExt_bg_setValues(rgb, rgbMask[GPOINTER_TO_INT(data)]))
-    VISU_ADD_REDRAW;
+  if (visu_gl_ext_bg_setRGBA(visu_gl_ext_bg_getDefault(),
+                             rgb, rgbMask[GPOINTER_TO_INT(data)]))
+    {
+      visu_gl_ext_bg_draw(visu_gl_ext_bg_getDefault());
+      VISU_REDRAW_ADD;
+    }
 }
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 11
 static void onBgImageSet(GtkFileChooserButton *filechooserbutton, gpointer data _U_)
@@ -464,7 +511,7 @@ static void onBgImageSet(GtkFileChooserButton *filechooserbutton, gpointer data
   if (!filename)
     return;
   g_idle_add(loadBgFile, (gpointer)filename);
-  VISU_ADD_REDRAW;
+  VISU_REDRAW_ADD;
 }
 #else
 static void onBgImageSet(GtkDialog *dialog, gint response, gpointer data _U_)
@@ -476,7 +523,7 @@ static void onBgImageSet(GtkDialog *dialog, gint response, gpointer data _U_)
 
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
   g_idle_add(loadBgFile, (gpointer)filename);
-  VISU_ADD_REDRAW;
+  VISU_REDRAW_ADD;
 }
 #endif
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 6
@@ -489,7 +536,7 @@ static void onBgImageChoose(GtkButton *bt, gpointer data)
 
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(data));
   g_idle_add(loadBgFile, (gpointer)filename);
-  VISU_ADD_REDRAW;
+  VISU_REDRAW_ADD;
 }
 #endif
 static gboolean loadBgFile(gpointer data)
@@ -507,7 +554,7 @@ static gboolean loadBgFile(gpointer data)
   pixbuf = gdk_pixbuf_new_from_file(filename, &error);
   if (!pixbuf)
     {
-      visuGtkRaise_warning(_("Load image file"), error->message, (GtkWindow*)0);
+      visu_ui_raiseWarning(_("Load image file"), error->message, (GtkWindow*)0);
       g_error_free(error);
       g_free(filename);
       return FALSE;
@@ -522,25 +569,29 @@ static gboolean loadBgFile(gpointer data)
       g_free(title);
       title = (gchar*)0;
     }
-  visu_glExt_bg_setImage(gdk_pixbuf_get_pixels(pixbuf),
-	      gdk_pixbuf_get_width(pixbuf),
-	      gdk_pixbuf_get_height(pixbuf),
-	      gdk_pixbuf_get_has_alpha(pixbuf),
-	      title, fit);
+  visu_gl_ext_bg_setImage(visu_gl_ext_bg_getDefault(),
+                          gdk_pixbuf_get_pixels(pixbuf),
+                          gdk_pixbuf_get_width(pixbuf),
+                          gdk_pixbuf_get_height(pixbuf),
+                          gdk_pixbuf_get_has_alpha(pixbuf),
+                          title, fit);
   g_object_unref(pixbuf);
   g_free(title);
+  visu_gl_ext_bg_draw(visu_gl_ext_bg_getDefault());
 
   return FALSE;
 }
 static void onBgImageUnset(GtkButton *bt _U_, gpointer data)
 {
-  visu_glExt_bg_setImage((guchar*)0, 0, 0, FALSE, (const gchar*)0, TRUE);
+  visu_gl_ext_bg_setImage(visu_gl_ext_bg_getDefault(),
+                          (guchar*)0, 0, 0, FALSE, (const gchar*)0, TRUE);
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(data));
 #endif
-  VISU_ADD_REDRAW;
+  visu_gl_ext_bg_draw(visu_gl_ext_bg_getDefault());
+  VISU_REDRAW_ADD;
 }
-void panelFogBgColorSet_bgImage(const gchar *filename)
+void visu_ui_panel_bg_setImage(const gchar *filename)
 {
   gchar *path, *cur;
 
@@ -559,3 +610,23 @@ void panelFogBgColorSet_bgImage(const gchar *filename)
 
   loadBgFile(path);
 }
+static void onBgImageFollow(GtkToggleButton *bt, gpointer data _U_)
+{
+  VisuGlView *view;
+
+  view = visu_ui_panel_getView(VISU_UI_PANEL(panelFogBgColor));
+  g_return_if_fail(view);
+
+  visu_gl_ext_bg_setFollowCamera(visu_gl_ext_bg_getDefault(),
+                                 gtk_toggle_button_get_active(bt),
+                                 view->camera->gross, view->camera->xs, view->camera->ys);
+}
+static void onCameraChange(VisuGlView *view, gpointer data _U_)
+{
+  if (visu_gl_ext_bg_setCamera(visu_gl_ext_bg_getDefault(),
+                               view->camera->gross, view->camera->xs, view->camera->ys))
+    {
+      visu_gl_ext_bg_draw(visu_gl_ext_bg_getDefault());
+      VISU_REDRAW_ADD;
+    }
+}
