@@ -48,6 +48,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <GL/gl.h>
+
 #include <visu_gtk.h>
 #include <visu_tools.h>
 #include <visu_object.h>
@@ -61,7 +63,10 @@
 
 /**
  * SECTION: panelOpenGL
- * @short_description: The tab where OpenGL options like lights or quality are setup.
+ * @short_description: The tab where OpenGL options like lights or
+ * quality are setup.
+ *
+ * <para>Nothing tunable here.</para>
  */
 
 /* Sensitive widget in this subpanel. */
@@ -105,20 +110,20 @@ static void removeSelectedLightsClicked(GtkButton *button, gpointer data);
 static void renderingModeEdited(GtkCellRendererText *cellrenderertext,
 				gchar *path, gchar *text, gpointer user_data);
 #endif
-static void onOpenGLEnter(ToolPanel *toolPanel, gpointer data);
+static void onOpenGLEnter(VisuUiPanel *visu_ui_panel, gpointer data);
 
-ToolPanel* panelOpenGL_init()
+VisuUiPanel* visu_ui_panel_gl_init(VisuUiMain *ui _U_)
 {
   char *cl = _("Set OpenGL parameters");
   char *tl = _("OpenGL");
 
-  panelOpenGL = toolPanelNew_withIconFromPath("Panel_opengl", cl, tl,
+  panelOpenGL = visu_ui_panel_newWithIconFromPath("Panel_opengl", cl, tl,
 					      "stock-opengl_20.png");
   if (!panelOpenGL)
-    return (ToolPanel*)0;
+    return (VisuUiPanel*)0;
 
   gtk_container_add(GTK_CONTAINER(panelOpenGL), createInteriorOpenGL());
-  toolPanelSet_dockable(TOOL_PANEL(panelOpenGL), TRUE);
+  visu_ui_panel_setDockable(VISU_UI_PANEL(panelOpenGL), TRUE);
 
   /* Create the callbacks of all the sensitive widgets. */
   createCallBacksOpenGL();
@@ -129,7 +134,7 @@ ToolPanel* panelOpenGL_init()
   disableCallbacksOpenGL = 0;
   hboxStereo = (GtkWidget*)0;
 
-  return TOOL_PANEL(panelOpenGL);
+  return VISU_UI_PANEL(panelOpenGL);
 }
 
 enum {
@@ -151,7 +156,7 @@ enum {
 
 void light_store_in_list_store(gpointer data, gpointer user_data)
 {
-  Light *light0 = data;
+  VisuGlLight *light0 = data;
   GtkTreeIter iter;
   GtkListStore *list;
 
@@ -174,7 +179,7 @@ void light_tree_show_hide(GtkCellRendererToggle *cell_renderer,
   GtkTreePath* path = gtk_tree_path_new_from_string(string_path);
   GtkTreeIter iter;
   gboolean status;
-  Light *light0;
+  VisuGlLight *light0;
   GtkListStore *list;
 
   g_return_if_fail(user_data);
@@ -191,9 +196,9 @@ void light_tree_show_hide(GtkCellRendererToggle *cell_renderer,
 
   light0->enabled = status;
 
-  status = lightEnvironnementApply(openGLGet_currentLights());
+  status = visu_gl_lights_apply(visu_gl_getLights());
   if (status)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 
 void light_update(GtkCellRendererText *cellrenderertext _U_,
@@ -201,7 +206,7 @@ void light_update(GtkCellRendererText *cellrenderertext _U_,
 {
   GtkTreeIter iter;
   float new_value = atof(text);
-  Light *light0;
+  VisuGlLight *light0;
   gboolean status;
 
   if(gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(light_list_store),
@@ -218,9 +223,9 @@ void light_update(GtkCellRendererText *cellrenderertext _U_,
   else
     light0->position[GPOINTER_TO_INT(user_data)-LIGHT_POSITION0] = new_value;
 			 
-  status = lightEnvironnementApply(openGLGet_currentLights());
+  status = visu_gl_lights_apply(visu_gl_getLights());
   if (status)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 
 void light_sync_lists(GtkListStore *list)
@@ -228,7 +233,7 @@ void light_sync_lists(GtkListStore *list)
   g_return_if_fail(list);
 
   gtk_list_store_clear(list);
-  g_list_foreach(lightEnvironnementGet_lightList(openGLGet_currentLights()),
+  g_list_foreach(visu_gl_lights_getList(visu_gl_getLights()),
 		 light_store_in_list_store, (gpointer)list);  
 }
 
@@ -307,6 +312,8 @@ GtkWidget* make_renderingTreeView()
   const char** names;
   int i;
   GList *list;
+  VisuGlRenderingMode mode;
+  gchar *label;
   const char *modeName;
 
   /* Initialize the model that store the possibilities
@@ -315,7 +322,7 @@ GtkWidget* make_renderingTreeView()
   gtk_list_store_append(namesListStore, &iter);
   gtk_list_store_set(namesListStore, &iter,
 		     0, OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, -1);
-  names = openGLGet_allRenderingModesI18n();
+  names = visu_gl_rendering_getAllModeLabels();
   for (i = 0; names[i]; i++)
     {
       gtk_list_store_append(namesListStore, &iter);
@@ -327,24 +334,22 @@ GtkWidget* make_renderingTreeView()
   renderingListStore =
     gtk_list_store_new(RENDERING_N_PARAMETERS, G_TYPE_POINTER,
 		       G_TYPE_STRING, G_TYPE_STRING);
-  list = visuExtensions_getList();
-  while(list)
-    {
-      if (((VisuExtension*)list->data)->isSensitiveToRenderingMode)
-	{
-	  if (((VisuExtension*)list->data)->preferedRenderingMode ==
-	      followGeneralSetting)
-	    modeName = OPENGL_FOLLOW_GLOBAL_RENDERING_MODE;
-	  else
-	    modeName = names[((VisuExtension*)list->data)->preferedRenderingMode];
-	  gtk_list_store_append(renderingListStore, &iter);
-	  gtk_list_store_set(renderingListStore, &iter,
-			     RENDERING_POINTER_TO, list->data,
-			     RENDERING_NAME, ((VisuExtension*)list->data)->nameI18n,
-			     RENDERING_MODE, modeName, -1);
-	}
-      list = g_list_next(list);
-    }
+  for (list = visu_gl_ext_getAll(); list; list = g_list_next(list))
+    if (visu_gl_ext_getSensitiveToRenderingMode(VISU_GL_EXT(list->data)))
+      {
+        mode = visu_gl_ext_getPreferedRenderingMode(VISU_GL_EXT(list->data));
+        if (mode == VISU_GL_RENDERING_FOLLOW)
+          modeName = OPENGL_FOLLOW_GLOBAL_RENDERING_MODE;
+        else
+          modeName = names[mode];
+        g_object_get(G_OBJECT(list->data), "label", &label, NULL);
+        gtk_list_store_append(renderingListStore, &iter);
+        gtk_list_store_set(renderingListStore, &iter,
+                           RENDERING_POINTER_TO, list->data,
+                           RENDERING_NAME, label,
+                           RENDERING_MODE, modeName, -1);
+        g_free(label);
+      }
 
   renderingTreeView =
     gtk_tree_view_new_with_model(GTK_TREE_MODEL(renderingListStore));
@@ -366,6 +371,8 @@ GtkWidget* make_renderingTreeView()
 						    "text", RENDERING_MODE, NULL);
   gtk_tree_view_column_set_alignment(column, 0.5);
   gtk_tree_view_append_column(GTK_TREE_VIEW(renderingTreeView), column);
+
+  g_object_unref(namesListStore);
   
   return renderingTreeView;
 #else
@@ -375,7 +382,7 @@ GtkWidget* make_renderingTreeView()
   
 void addNewLightClicked(GtkButton *button _U_, gpointer data)
 {
-  Light *light0;
+  VisuGlLight *light0;
   GtkTreeIter iter;
   gboolean status;
 
@@ -383,14 +390,14 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
 
   if(gtk_tree_model_iter_n_children(GTK_TREE_MODEL(data), (GtkTreeIter*)0) >= GL_MAX_LIGHTS)
     {
-      visuGtkRaise_warning(_("OpenGL"),
+      visu_ui_raiseWarning(_("OpenGL"),
 			   _("The maximm number of lights allowed by OpenGL"
 			     " has been reached, can't add more."), (GtkWindow*)0);
       return;
     }
 
-  light0 = light_newDefault();
-  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light0);
+  light0 = visu_gl_light_newDefault();
+  status = visu_gl_lights_add(visu_gl_getLights(), light0);
 
   if (!status)
     return;
@@ -404,16 +411,16 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
 		     LIGHT_POSITION2, light0->position[2], 
 		     LIGHT_MULTIPLIER, light0->multiplier, -1);
 
-  status = lightEnvironnementApply(openGLGet_currentLights());
+  status = visu_gl_lights_apply(visu_gl_getLights());
   if (status)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 {
   GList *tmpLst, *selectedRows;
   GtkTreeIter iter;
   gboolean validIter, status;
-  Light *light0;
+  VisuGlLight *light0;
   GtkTreeIter *removableIter;
 
   g_return_if_fail(GTK_TREE_SELECTION(data));
@@ -434,7 +441,7 @@ void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 	  gtk_tree_model_get(GTK_TREE_MODEL(light_list_store), &iter,
 			     LIGHT_POINTER_TO, &light0,
 			     -1);
-	  lightEnvironnementDelete_light(openGLGet_currentLights(), light0);
+	  visu_gl_lights_remove(visu_gl_getLights(), light0);
 	  removableIter = g_malloc(sizeof(GtkTreeIter));
 	  *removableIter = iter;
 	  tmpLst->data = (gpointer)removableIter;
@@ -453,9 +460,9 @@ void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
     }  
   g_list_free(selectedRows);
 
-  status = lightEnvironnementApply(openGLGet_currentLights());
+  status = visu_gl_lights_apply(visu_gl_getLights());
   if (status)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 void selectionChanged(GtkTreeSelection *tree, gpointer data)
 {
@@ -517,13 +524,13 @@ GtkWidget *createInteriorOpenGL()
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   spinPrecision = gtk_spin_button_new_with_range(10, 500, 5);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPrecision),
-			    VisuOpenGLViewGet_precision() * 100.);
+			    visu_gl_view_class_getPrecision() * 100.);
   gtk_box_pack_start(GTK_BOX(hbox), spinPrecision, FALSE, FALSE, 2);
   label = gtk_label_new("%");
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   comboOpenGLRendering = gtk_combo_box_text_new();
-  names = openGLGet_allRenderingModesI18n();
-  ids = openGLGet_allRenderingModes();
+  names = visu_gl_rendering_getAllModeLabels();
+  ids = visu_gl_rendering_getAllModes();
   if (names && ids)
     for (i = 0; names[i] && ids[i]; i++)
       gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboOpenGLRendering), ids[i], names[i]);
@@ -542,12 +549,12 @@ GtkWidget *createInteriorOpenGL()
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   checkAntialiasing = gtk_check_button_new();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAntialiasing),
-			       (gboolean)openGLGet_antialias());
+			       (gboolean)visu_gl_getAntialias());
   gtk_box_pack_start(GTK_BOX(hbox), checkAntialiasing, FALSE, FALSE, 2);
 
   checkTransparency = gtk_check_button_new();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkTransparency),
-			       openGLGet_trueTransparency());
+			       visu_gl_getTrueTransparency());
   gtk_box_pack_end(GTK_BOX(hbox), checkTransparency, FALSE, FALSE, 2);
   label = gtk_label_new(_("Enhanced transparency:"));
   gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -558,7 +565,7 @@ GtkWidget *createInteriorOpenGL()
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   checkStereo = gtk_check_button_new();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStereo),
-			       openGLGet_stereo());
+			       visu_gl_getStereo());
   gtk_box_pack_start(GTK_BOX(hbox), checkStereo, FALSE, FALSE, 2);
   hboxStereo = hbox;
   /* Degrees. */
@@ -595,13 +602,13 @@ GtkWidget *createInteriorOpenGL()
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   checkImmediateDrawing = gtk_check_button_new();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkImmediateDrawing),
-			       openGLGet_immediate());
+			       visu_gl_getImmediate());
   gtk_box_pack_start(GTK_BOX(hbox), checkImmediateDrawing, FALSE, FALSE, 2);
   gtk_widget_show(checkImmediateDrawing);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
 
   /*********************/
-  /* Light parameters. */
+  /* VisuGlLight parameters. */
   /*********************/
   expanderLight = gtk_expander_new(_("<b>Light sources:</b>"));
   label = gtk_expander_get_label_widget(GTK_EXPANDER(expanderLight));
@@ -681,23 +688,23 @@ static void immediateDrawingCheckChanged(GtkToggleButton *button, gpointer data
   if (disableCallbacksOpenGL)
     return;
 
-  openGLSet_immediate(gtk_toggle_button_get_active(button));
+  visu_gl_setImmediate(gtk_toggle_button_get_active(button));
 }
 static void stereoCheckChanged(GtkToggleButton *button, gpointer data _U_)
 {
   if (disableCallbacksOpenGL)
     return;
 
-  openGLSet_stereo(gtk_toggle_button_get_active(button));
-  VISU_ADD_REDRAW;
+  visu_gl_setStereo(gtk_toggle_button_get_active(button));
+  VISU_REDRAW_ADD;
 }
 static void stereoSpinChanged(GtkSpinButton *button, gpointer data _U_)
 {
   if (disableCallbacksOpenGL)
     return;
 
-  if (openGLSet_stereoAngle((float)gtk_spin_button_get_value(button)))
-    VISU_ADD_REDRAW;
+  if (visu_gl_setStereoAngle((float)gtk_spin_button_get_value(button)))
+    VISU_REDRAW_ADD;
 }
 void comboOpenGLRenderingChanged(GtkComboBox *combobox, gpointer data _U_)
 {
@@ -708,92 +715,91 @@ void comboOpenGLRenderingChanged(GtkComboBox *combobox, gpointer data _U_)
 
   mode = (int)gtk_combo_box_get_active(combobox);
 
-  if (openGLSet_globalRenderingMode(mode))
-    VISU_ADD_REDRAW;
+  if (visu_gl_rendering_setGlobalMode(mode))
+    VISU_REDRAW_ADD;
 }
 static void antialisingCheckChanged(GtkToggleButton *button, gpointer data _U_)
 {
   if (disableCallbacksOpenGL)
     return;
 
-  if (openGLSet_antialias(gtk_toggle_button_get_active(button)))
-    VISU_ADD_REDRAW;
+  if (visu_gl_setAntialias(gtk_toggle_button_get_active(button)))
+    VISU_REDRAW_ADD;
 }
 static void onTransparencyChanged(GtkToggleButton *button, gpointer data _U_)
 {
   if (disableCallbacksOpenGL)
     return;
 
-  if (openGLSet_trueTransparency(gtk_toggle_button_get_active(button)))
-    VISU_ADD_REDRAW;
+  if (visu_gl_setTrueTransparency(gtk_toggle_button_get_active(button)))
+    VISU_REDRAW_ADD;
 }
 void precisionChanged(GtkButton *button _U_, gpointer user_data _U_)
 {
   float prec;
-  VisuData *dataObj;
+  VisuGlView *view;
 
   if (disableCallbacksOpenGL)
     return;
 
   prec = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinPrecision));
-  if (VisuOpenGLViewSet_precision(prec / 100.))
+  if (visu_gl_view_class_setPrecision(prec / 100.))
     {
-      dataObj = toolPanelGet_visuData(TOOL_PANEL(panelOpenGL));
-      visu_data_emitFacettesChanged(dataObj);
-      visu_data_createAllElements(dataObj); 
-      VISU_ADD_REDRAW;
+      view = visu_ui_panel_getView(VISU_UI_PANEL(panelOpenGL));
+      g_signal_emit_by_name(G_OBJECT(view), "DetailLevelChanged", NULL);      
+      VISU_REDRAW_ADD;
     }
 }
-static void onOpenGLEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
+static void onOpenGLEnter(VisuUiPanel *visu_ui_panel _U_, gpointer data _U_)
 {
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   const gchar **names;
   gchar *name;
   GtkTreeIter iter;
   gboolean valid;
-  VisuExtension *ext;
+  VisuGlExt *ext;
+  VisuGlRenderingMode mode;
 #endif
 
   if (hboxStereo)
-    gtk_widget_set_sensitive(hboxStereo, openGLGet_stereoCapability());
+    gtk_widget_set_sensitive(hboxStereo, visu_gl_getStereoCapability());
 
   disableCallbacksOpenGL = 1;
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkImmediateDrawing),
-			       openGLGet_immediate());
+			       visu_gl_getImmediate());
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboOpenGLRendering),
-			   openGLGet_globalRenderingOption());
+			   visu_gl_rendering_getGlobalMode());
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPrecision),
-			    VisuOpenGLViewGet_precision() * 100.);
+			    visu_gl_view_class_getPrecision() * 100.);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAntialiasing),
-			       (gboolean)openGLGet_antialias());
+			       (gboolean)visu_gl_getAntialias());
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkTransparency),
-			       openGLGet_trueTransparency());
+			       visu_gl_getTrueTransparency());
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStereo),
-			       openGLGet_stereo());
+			       visu_gl_getStereo());
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinStereoAngle),
-			    openGLGet_stereoAngle());
+			    visu_gl_getStereoAngle());
 
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
-  names = openGLGet_allRenderingModesI18n();
+  names = visu_gl_rendering_getAllModeLabels();
   valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(renderingListStore), &iter);
   while(valid)
     {
       gtk_tree_model_get(GTK_TREE_MODEL(renderingListStore), &iter,
 			 RENDERING_POINTER_TO, &ext,
 			 RENDERING_MODE, &name, -1);
-      if (ext->isSensitiveToRenderingMode)
+      if (visu_gl_ext_getSensitiveToRenderingMode(ext))
 	{
-	  if (ext->preferedRenderingMode < nb_renderingModes &&
-	      strcmp(names[ext->preferedRenderingMode], name))
+          mode = visu_gl_ext_getPreferedRenderingMode(ext);
+	  if (mode < VISU_GL_RENDERING_N_MODES && strcmp(names[mode], name))
 	    gtk_list_store_set(renderingListStore, &iter,
-			       RENDERING_MODE,
-			       names[ext->preferedRenderingMode], -1);
-	  else if (ext->preferedRenderingMode == followGeneralSetting &&
-		   strcmp(OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, name))
-	    gtk_list_store_set(renderingListStore, &iter,
-			       RENDERING_MODE,
-			       OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, -1);
+			       RENDERING_MODE, names[mode], -1);
+	  else if (mode == VISU_GL_RENDERING_FOLLOW &&
+                   strcmp(OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, name))
+	    gtk_list_store_set(renderingListStore, &iter, RENDERING_MODE,
+                               OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, -1);
 	}
+      g_free(name);
       valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(renderingListStore), &iter);
     }
 #endif
@@ -801,56 +807,56 @@ static void onOpenGLEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
 }
 void addPresetOneLightClicked(GtkButton *button _U_, gpointer data)
 {
-  Light *light;
+  VisuGlLight *light;
   gboolean status;
 
   g_return_if_fail(data);
 
-  status = lightEnvironnementEmpty_lightList(openGLGet_currentLights());
+  status = visu_gl_lights_removeAll(visu_gl_getLights());
 
-  light = light_newDefault();
-  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
+  light = visu_gl_light_newDefault();
+  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
 
   light_sync_lists(GTK_LIST_STORE(data)); 
 
-  status = lightEnvironnementApply(openGLGet_currentLights()) || status;
+  status = visu_gl_lights_apply(visu_gl_getLights()) || status;
   if (status)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 void addPresetFourLightsClicked(GtkButton *button _U_, gpointer data)
 {
-  Light *light;
+  VisuGlLight *light;
   gboolean status;
 
   g_return_if_fail(data);
 
-  status = lightEnvironnementEmpty_lightList(openGLGet_currentLights());
+  status = visu_gl_lights_removeAll(visu_gl_getLights());
 
-  light = light_newDefault();
+  light = visu_gl_light_newDefault();
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
 
-  light = light_newDefault();
+  light = visu_gl_light_newDefault();
   light->position[0] *= -1.;
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
 
-  light = light_newDefault();
+  light = visu_gl_light_newDefault();
   light->position[1] *= -1.;
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
 
-  light = light_newDefault();
+  light = visu_gl_light_newDefault();
   light->position[0] *= -1.;
   light->position[1] *= -1.;
   light->multiplier = 0.25;
-  status = lightEnvironnementAdd_light(openGLGet_currentLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
 
   light_sync_lists(GTK_LIST_STORE(data)); 
 
-  status = lightEnvironnementApply(openGLGet_currentLights()) || status;
+  status = visu_gl_lights_apply(visu_gl_getLights()) || status;
   if (status)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
 static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
@@ -861,7 +867,7 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
   GtkTreeIter iter;
   const char** names;
   int mode;
-  VisuExtension *ext;
+  VisuGlExt *ext;
 
   if (disableCallbacksOpenGL)
     return;
@@ -876,12 +882,12 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
   if (!strcmp(text, OPENGL_FOLLOW_GLOBAL_RENDERING_MODE))
     {
       valid = TRUE;
-      mode = followGeneralSetting;
+      mode = VISU_GL_RENDERING_FOLLOW;
     }
   else
     {
       valid = FALSE;
-      names = openGLGet_allRenderingModesI18n();
+      names = visu_gl_rendering_getAllModeLabels();
       for (mode = 0; names[mode] && !valid; mode++)
 	valid = !strcmp(text, names[mode]);
       mode -= 1;
@@ -890,19 +896,19 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
 
   gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 
 		     RENDERING_POINTER_TO, &ext, -1);
-  valid = visu_extension_setPreferedRenderingMode(ext, mode);
+  valid = visu_gl_ext_setPreferedRenderingMode(ext, mode);
 
-  if (mode == followGeneralSetting)
+  if (mode == VISU_GL_RENDERING_FOLLOW)
     gtk_list_store_set(list, &iter,
 		       RENDERING_MODE, OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, -1);
   else
     {
-      names = openGLGet_allRenderingModesI18n();
+      names = visu_gl_rendering_getAllModeLabels();
       gtk_list_store_set(list, &iter,
 			 RENDERING_MODE, names[mode], -1);
     }
 
-  if (valid && ext->used)
-    VISU_ADD_REDRAW;
+  if (valid && visu_gl_ext_getActive(ext))
+    VISU_REDRAW_ADD;
 }
 #endif
