@@ -96,29 +96,32 @@ static GtkWidget *entry_target_file;
 
 void surf_add_surf_to_target();
 
+#if GTK_MAJOR_VERSION < 3
 gboolean gtk_tree_model_iter_previous(GtkTreeModel *tree_model, GtkTreeIter *iter)
 {
   GtkTreePath *temp_to_free = gtk_tree_model_get_path(tree_model, iter);
 
+  if (!temp_to_free)
+    return FALSE;
+
   if(!gtk_tree_path_prev(temp_to_free))
     {
 /*       DBG_fprintf(stderr, "WARNING : custom gtk_tree_model_iter_previous couldn't retrieve previous element\n"); */
-      iter = NULL;
-      g_free(temp_to_free);
+      gtk_tree_path_free(temp_to_free);
       return FALSE;
     }
 
   if(!gtk_tree_model_get_iter(tree_model, iter, temp_to_free))
     {
 /*       DBG_fprintf(stderr, "WARNING : custom gtk_tree_model_iter_previous couldn't retrieve a valid iter\n"); */
-      iter = NULL;
-      g_free(temp_to_free);
+      gtk_tree_path_free(temp_to_free);
       return FALSE;
     }
 
-  g_free(temp_to_free);
+  gtk_tree_path_free(temp_to_free);
   return TRUE;
 }
+#endif
 
 /* Parses target surf file to retrieve dxx, ..., dzz,
    as well as each surface name, nb of vertex and nb of points. */
@@ -286,7 +289,7 @@ void surf_open_file_chooser()
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 				NULL);
-  gchar *directory = visuGtkGet_lastOpenDirectory();
+  gchar *directory = visu_ui_getLastOpenDirectory();
 
 
   if (directory)
@@ -317,7 +320,7 @@ void surf_open_file_chooser()
 	    {
 	      gtk_entry_set_text(GTK_ENTRY(entry_current_file), "");
 	      gtk_list_store_clear(list_store); 
-	      visuGtkRaise_warning(_("Loading a file"),
+	      visu_ui_raiseWarning(_("Loading a file"),
 				   _("Unable to parse the selected file."),
 				   (GtkWindow*)0);
 	    }
@@ -342,7 +345,7 @@ void surfmerge_target_file_chooser(GtkWidget *widget _U_, gpointer data _U_)
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 				NULL);
-  gchar *directory = visuGtkGet_lastOpenDirectory();
+  gchar *directory = visu_ui_getLastOpenDirectory();
 
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
@@ -634,7 +637,7 @@ gboolean surf_export_surf(GtkTreeModel *model, GtkTreePath *path _U_,
 	  g_free(old_surf_name);
 	  g_string_free(line, TRUE);
 	  g_io_channel_unref(file_to_read);
-	  visuGtkRaise_warning(_("Loading a file"),
+	  visu_ui_raiseWarning(_("Loading a file"),
 			       _("An unknown error occured. Your surf"
 				 " file is corrupted.\n"), (GtkWindow*)0);
 	  return TRUE;
@@ -654,7 +657,7 @@ gboolean surf_export_surf(GtkTreeModel *model, GtkTreePath *path _U_,
 	  g_free(old_surf_name);
 	  g_string_free(line, TRUE);
 	  g_io_channel_unref(file_to_read);
-	  visuGtkRaise_warning(_("Loading a file"),
+	  visu_ui_raiseWarning(_("Loading a file"),
 			       _("An unknown error occured. Your surf"
 				 " file is corrupted.\n"), (GtkWindow*)0);
 	  return TRUE;
@@ -677,7 +680,7 @@ gboolean surf_export_surf(GtkTreeModel *model, GtkTreePath *path _U_,
 	  g_free(old_surf_name);
 	  g_string_free(line, TRUE);
 	  g_io_channel_unref(file_to_read);
-	  visuGtkRaise_warning(_("Loading a file"),
+	  visu_ui_raiseWarning(_("Loading a file"),
 			       _("An unknown error occured. Your surf"
 				 " file is corrupted.\n"), (GtkWindow*)0);
 	  return TRUE;
@@ -697,7 +700,7 @@ gboolean surf_export_surf(GtkTreeModel *model, GtkTreePath *path _U_,
 	      g_free(old_surf_name);
 	      g_string_free(line, TRUE);
 	      g_io_channel_unref(file_to_read);
-	      visuGtkRaise_warning(_("Loading a file"),
+	      visu_ui_raiseWarning(_("Loading a file"),
 				   _("An unknown error occured. Your surf"
 				     " file is corrupted.\n"), (GtkWindow*)0);
 	      return TRUE;
@@ -732,7 +735,7 @@ void surf_gogogo()
 
   if(file_to_write == NULL)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Please choose a surf file to write\n"), (GtkWindow*)0);
       return;
     }
@@ -745,7 +748,7 @@ void surf_gogogo()
 
   if(total[0] == 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("No surface to write\n"), (GtkWindow*)0);
       return;
     }
@@ -778,7 +781,7 @@ void surf_gogogo()
 }
 
 /* See header file for more info */
-GtkWidget *surf_file_manager()
+GtkWidget *visu_ui_panel_surfaces_tools_fileWidget()
 {
   enum { DXX, DYX, DYY, DZX, DZY, DZZ };
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
@@ -1060,7 +1063,7 @@ gboolean pot2surf_quick_parse(char *file_name, float *pot_min, float *pot_max)
 
   if(file_to_parse == NULL)
     {
-      visuGtkRaise_warning(_("Loading a file"),
+      visu_ui_raiseWarning(_("Loading a file"),
 			   _("Can't open given file for reading"), (GtkWindow*)0);
       g_io_channel_unref(file_to_parse);
       return FALSE;
@@ -1073,7 +1076,7 @@ gboolean pot2surf_quick_parse(char *file_name, float *pot_min, float *pot_max)
 	g_io_channel_read_line_string (file_to_parse, line, &terminator_pos, NULL);
       if(last_op_status != G_IO_STATUS_NORMAL)
 	{
-	  visuGtkRaise_warning(_("Loading a file"),
+	  visu_ui_raiseWarning(_("Loading a file"),
 			       _("This file doesn't seem to be a correct pot file"),
 			       (GtkWindow*)0);	 
 	  g_io_channel_unref(file_to_parse);
@@ -1084,7 +1087,7 @@ gboolean pot2surf_quick_parse(char *file_name, float *pot_min, float *pot_max)
 	  sscanf(line->str, "%d %d %d", &na, &nb, &nc);
 	  if(na <= 0 || nb <= 0 || nc <= 0)
 	    {
-	      visuGtkRaise_warning(_("Loading a file"),
+	      visu_ui_raiseWarning(_("Loading a file"),
 				   _("Second line seem to contain incorrect values"),
 				   (GtkWindow*)0);	  
 	      g_io_channel_unref(file_to_parse);
@@ -1101,7 +1104,7 @@ gboolean pot2surf_quick_parse(char *file_name, float *pot_min, float *pot_max)
 	g_io_channel_read_line_string (file_to_parse, line, &terminator_pos, NULL);
       if(last_op_status != G_IO_STATUS_NORMAL)
 	{
-	  visuGtkRaise_warning(_("Loading a file"),
+	  visu_ui_raiseWarning(_("Loading a file"),
 			       _("This file doesn't seem to be a correct pot file"),
 			       (GtkWindow*)0);	  
 	  g_io_channel_unref(file_to_parse);
@@ -1142,7 +1145,7 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 /* 				GTK_STOCK_HELP, GTK_RESPONSE_HELP, */
 				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-  gchar *directory = visuGtkGet_lastOpenDirectory();
+  gchar *directory = visu_ui_getLastOpenDirectory();
 
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
@@ -1184,7 +1187,7 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 	      g_string_free(other_files, TRUE);
 
 	      directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-	      visuGtkSet_lastOpenDirectory(directory, VISU_DIR_SURFACE);
+	      visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
 	      g_free(directory);
 	      gtk_list_store_clear(pot2surf_list_store);
 	      gtk_widget_destroy(file_chooser);
@@ -1196,7 +1199,7 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 	case GTK_RESPONSE_CANCEL:
 	default:
 	  directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-	  visuGtkSet_lastOpenDirectory(directory, VISU_DIR_SURFACE);
+	  visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
 	  g_free(directory);
 	  gtk_widget_destroy (file_chooser);
 	  return;
@@ -1215,7 +1218,7 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 /* 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, */
 /* /\* 				GTK_STOCK_HELP, GTK_RESPONSE_HELP, *\/ */
 /* 				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL); */
-/*   gchar *directory = visuGtkGet_lastOpenDirectory(); */
+/*   gchar *directory = visu_ui_getLastOpenDirectory(); */
 
 /*   if (directory) */
 /*     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory); */
@@ -1237,7 +1240,7 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 /* 	    gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser)); */
 /* 	  gtk_entry_set_text(GTK_ENTRY(pot2surf_entry_source_instruc_file), selected_file); */
 /*       directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)); */
-/*       visuGtkSet_lastOpenDirectory(directory); */
+/*       visu_ui_setLastOpenDirectory(directory); */
 /*       g_free(directory); */
 /* 	  gtk_widget_destroy(file_chooser); */
 /* 	  return; */
@@ -1246,7 +1249,7 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 /* 	case GTK_RESPONSE_CANCEL: */
 /* 	default: */
 /*       directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)); */
-/*       visuGtkSet_lastOpenDirectory(directory); */
+/*       visu_ui_setLastOpenDirectory(directory); */
 /*       g_free(directory); */
 /* 	  gtk_widget_destroy (file_chooser); */
 /* 	  return; */
@@ -1265,7 +1268,7 @@ void pot2surf_select_surf_file(GtkWidget *widget _U_, gpointer data _U_)
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 /* 				GTK_STOCK_HELP, GTK_RESPONSE_HELP, */
 				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-  gchar *directory = visuGtkGet_lastOpenDirectory();
+  gchar *directory = visu_ui_getLastOpenDirectory();
 
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
@@ -1289,7 +1292,7 @@ void pot2surf_select_surf_file(GtkWidget *widget _U_, gpointer data _U_)
 	    gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser));
 	  gtk_entry_set_text(GTK_ENTRY(pot2surf_entry_target_surf_file), selected_file);
       directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-      visuGtkSet_lastOpenDirectory(directory, VISU_DIR_SURFACE);
+      visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
       g_free(directory);
 	  gtk_widget_destroy(file_chooser);
 	  return;
@@ -1298,7 +1301,7 @@ void pot2surf_select_surf_file(GtkWidget *widget _U_, gpointer data _U_)
 	case GTK_RESPONSE_CANCEL:
 	default:
       directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-      visuGtkSet_lastOpenDirectory(directory, VISU_DIR_SURFACE);
+      visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
       g_free(directory);
 	  gtk_widget_destroy (file_chooser);
 	  return;
@@ -1315,16 +1318,16 @@ void pot2surf_update_surf_name(GtkCellRendererText *cellrenderertext _U_,
   g_return_if_fail(gtk_tree_model_get_iter_from_string
 		   (GTK_TREE_MODEL(pot2surf_list_store), &iter, path));
 
-  DBG_fprintf(stderr, "Panel SurfacesTools: entered text '%s'.\n", text);
-  if (!strcmp(text, SURFACE_NAME_STR))
+  DBG_fprintf(stderr, "Panel VisuSurfacesTools: entered text '%s'.\n", text);
+  if (!strcmp(text, VISU_UI_SURFACE_NAME_STR))
     gtk_list_store_set(pot2surf_list_store, &iter,
-		       POT2SURF_NAME, SURFACE_NAME_CHOOSE, -1);
+		       POT2SURF_NAME, VISU_UI_SURFACE_NAME_CHOOSE, -1);
   else if (text && text[0])
     gtk_list_store_set(pot2surf_list_store, &iter,
 		       POT2SURF_NAME, g_strdelimit(text, " ", '_'), -1);
   else
     gtk_list_store_set(pot2surf_list_store, &iter,
-		       POT2SURF_NAME, SURFACE_NAME_CHOOSE, -1);
+		       POT2SURF_NAME, VISU_UI_SURFACE_NAME_CHOOSE, -1);
 }
 
 /* Callback for when the pot of a surf to build is changed in the gtk_tree_view */
@@ -1399,7 +1402,7 @@ void pot2surf_add_surf(GtkWidget *button _U_, gpointer data _U_)
 
   gtk_tree_selection_select_iter(tree_selection, &new_row);
   gtk_list_store_set(pot2surf_list_store, &new_row, 
-		     POT2SURF_NAME, SURFACE_NAME_CHOOSE,
+		     POT2SURF_NAME, VISU_UI_SURFACE_NAME_CHOOSE,
 		     POT2SURF_VALUE, 
 		     (atof(gtk_entry_get_text(GTK_ENTRY(pot2surf_potmin))) 
 		      + atof(gtk_entry_get_text(GTK_ENTRY(pot2surf_potmax)))) / 2, -1);
@@ -1428,7 +1431,7 @@ void pot2surf_special_add_surf(GtkWidget *button _U_, gpointer data _U_)
 
   values = (float*)0;
   name = (gchar*)0;
-  dialog = panelIsosurfacesGenerate_isoValues(&nbValues, &values, &name,
+  dialog = visu_ui_panel_surfaces_generateValues(&nbValues, &values, &name,
 					      pot_min, pot_max);
 
   if (!dialog)
@@ -1439,7 +1442,7 @@ void pot2surf_special_add_surf(GtkWidget *button _U_, gpointer data _U_)
     {
       gtk_list_store_append(pot2surf_list_store, &new_row);
       gtk_list_store_set(pot2surf_list_store, &new_row, 
-			 POT2SURF_NAME, (name && name[0])?name:SURFACE_NAME_CHOOSE,
+			 POT2SURF_NAME, (name && name[0])?name:VISU_UI_SURFACE_NAME_CHOOSE,
 			 POT2SURF_VALUE, values[i], -1);
     }
   if (nbValues)
@@ -1549,14 +1552,14 @@ gboolean pot2surf_build_instruc_file(const gchar *pot_file, const gchar *surf_fi
   FILE *instruc = NULL;
   if(instruc_file == NULL || strcmp(instruc_file, "") == 0)
     {
-      visuGtkRaise_warning(_("Loading a file"),
+      visu_ui_raiseWarning(_("Loading a file"),
 			   _("Please select an instruc file to write"),
 			   (GtkWindow*)0);
       return FALSE;
     }
   if((instruc = fopen(instruc_file, "w")) == NULL)
     {
-      visuGtkRaise_warning(_("Loading a file"),
+      visu_ui_raiseWarning(_("Loading a file"),
 			   _("Can't open selected instruc file for writing"),
 			   (GtkWindow*)0);
       return FALSE;
@@ -1582,7 +1585,7 @@ void pot2surf_select_instruc_file_to_save()
   GtkFileFilter *filter_instruc;
   GtkFileFilter *filter_none;
   GtkWidget* file_chooser;
-  char *directory = visuGtkGet_lastOpenDirectory();
+  char *directory = visu_ui_getLastOpenDirectory();
   int n=0;
   const gchar *pot_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_source_pot_file));
   const gchar *surf_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_target_surf_file));
@@ -1591,19 +1594,19 @@ void pot2surf_select_instruc_file_to_save()
   gtk_tree_model_foreach(GTK_TREE_MODEL(pot2surf_list_store), pot2surf_count_surf, &n);
   if(n == 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Please specify surfaces to draw"), (GtkWindow*)0);
       return;
     }
   if(strcmp(pot_file, "") == 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Please select a source pot file"), (GtkWindow*)0);
       return;
     }
   if(surf_file == NULL || strcmp(surf_file, "") == 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Please select a target surf file"), (GtkWindow*)0);
       return;
     }
@@ -1639,7 +1642,7 @@ void pot2surf_select_instruc_file_to_save()
 					gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser)), n))
 	   
 	  break;
-	visuGtkSet_lastOpenDirectory(gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_DIR_SURFACE);
+	visu_ui_setLastOpenDirectory(gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_UI_DIR_SURFACE);
 	g_string_free(default_file, TRUE);
 	gtk_widget_destroy(file_chooser);
 	return;
@@ -1689,19 +1692,19 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
   gtk_tree_model_foreach(GTK_TREE_MODEL(pot2surf_list_store), pot2surf_count_surf, &n);
   if(n == 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Please specify surfaces to draw"), (GtkWindow*)0);
       return FALSE;
     }
   if(pot_file == NULL || strcmp(pot_file, "") == 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Please select a source pot file"), (GtkWindow*)0);
       return FALSE;
     }
   if(surf_file == NULL || strcmp(surf_file, "") == 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Please select a target surf file"), (GtkWindow*)0);
       return FALSE;
     }
@@ -1719,15 +1722,15 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
     {
 /*       fprintf(stderr, "%s %f\n", surfaces[i].name, surfaces[i].value); */
       values[i] = surfaces[i].value;
-      if (strcmp(surfaces[i].name, SURFACE_NAME_CHOOSE))
+      if (strcmp(surfaces[i].name, VISU_UI_SURFACE_NAME_CHOOSE))
 	names[i] = surfaces[i].name;
       else
 	names[i] = (gchar*)0;
     }  
 
-  if(pot2surf_direct(surf_file, pot_file, n, values, (const gchar **)names) != 0)
+  if(visu_surfaces_createFromPotentialFile(surf_file, pot_file, n, values, (const gchar **)names) != 0)
     {
-      visuGtkRaise_warning(_("Saving a file"),
+      visu_ui_raiseWarning(_("Saving a file"),
 			   _("Error"), (GtkWindow*)0);
       for(i=0; i<n; i++)
 	g_free(names[i]);
@@ -1739,10 +1742,8 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
 
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data)))
     {
-      if(panelIsosurfacesLoad_file(surf_file, 0,
-				   visu_rendering_window_getVisuData
-				   (visu_uiMainClass_getDefaultRendering()),
-				   (GHashTable*)0, (double**)0) == 0)
+      if(visu_ui_panel_surfaces_loadFile(surf_file, (VisuBox*)0,
+                                         (GHashTable*)0, (VisuScalarFieldMethod*)0) == 0)
 	{
 	  for(i=0; i<n; i++)
 	    g_free(names[i]);
@@ -1819,7 +1820,7 @@ gboolean pot2surf_load_instruc_file(const gchar *instruc_filename)
   line = g_string_new("");
   if(instruc_file == NULL)
     {
-      visuGtkRaise_warning(_("Loading a file"),
+      visu_ui_raiseWarning(_("Loading a file"),
 			   _("Can't open selected file"), (GtkWindow*)0);
       return FALSE;
     }
@@ -1827,7 +1828,7 @@ gboolean pot2surf_load_instruc_file(const gchar *instruc_filename)
   if(g_io_channel_read_line_string(instruc_file, line, NULL, NULL) 
      != G_IO_STATUS_NORMAL)
     {
-      visuGtkRaise_warning(_("Loading a file"),
+      visu_ui_raiseWarning(_("Loading a file"),
 			   _("Line 1 must contain the full path to the .pot"
 			     " file to read\n"), (GtkWindow*)0);
       g_string_free(line, TRUE);
@@ -1839,7 +1840,7 @@ gboolean pot2surf_load_instruc_file(const gchar *instruc_filename)
   if(g_io_channel_read_line_string(instruc_file, line, NULL, NULL) 
      != G_IO_STATUS_NORMAL)
     {
-      visuGtkRaise_warning(_("Loading a file"),
+      visu_ui_raiseWarning(_("Loading a file"),
 			   _("Line 2 must contain the full path to the"
 			     " .surf file to read\n"), (GtkWindow*)0);
       g_string_free(line, TRUE);
@@ -1852,7 +1853,7 @@ gboolean pot2surf_load_instruc_file(const gchar *instruc_filename)
   if((g_io_channel_read_line_string(instruc_file, line, NULL, NULL) != G_IO_STATUS_NORMAL)
      || (sscanf(line->str, "%d", &n) != 1))
     {
-      visuGtkRaise_warning(_("Loading a file"),
+      visu_ui_raiseWarning(_("Loading a file"),
 			   _("Line 3 must contain the number of"
 			     " surfaces to build\n"), (GtkWindow*)0);
       g_string_free(line, TRUE);
@@ -1865,11 +1866,11 @@ gboolean pot2surf_load_instruc_file(const gchar *instruc_filename)
   surf_values = g_malloc(n*sizeof(gchar *));
   for(i=0; i<n; i++)
     {
-      surf_names[i] = g_malloc(MAX_LINE_LENGTH*sizeof(gchar));
+      surf_names[i] = g_malloc(TOOL_MAX_LINE_LENGTH*sizeof(gchar));
       if((g_io_channel_read_line_string(instruc_file, line, NULL, NULL) != G_IO_STATUS_NORMAL)
 	 || (sscanf(line->str, "%f %s", &surf_values[i], surf_names[i]) != 2))
 	{      
-	  visuGtkRaise_warning(_("Loading a file"),
+	  visu_ui_raiseWarning(_("Loading a file"),
 			       _("Lines must contain the value of the"
 				 " surface to build and its name\n"), (GtkWindow*)0);
 	  g_string_free(line, TRUE);
@@ -1920,7 +1921,7 @@ void pot2surf_select_instruc_file_to_load()
 				GTK_FILE_CHOOSER_ACTION_OPEN,
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-  char *directory = visuGtkGet_lastOpenDirectory();
+  char *directory = visu_ui_getLastOpenDirectory();
 
   if(directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
@@ -1939,7 +1940,7 @@ void pot2surf_select_instruc_file_to_load()
       case GTK_RESPONSE_ACCEPT:
 	if(!pot2surf_load_instruc_file(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser))))
 	  break;
-	visuGtkSet_lastOpenDirectory(gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_DIR_SURFACE);
+	visu_ui_setLastOpenDirectory(gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_UI_DIR_SURFACE);
 	gtk_widget_destroy(file_chooser);
 	return;
       case GTK_RESPONSE_CANCEL:
@@ -1950,7 +1951,7 @@ void pot2surf_select_instruc_file_to_load()
 }
 
 /* See header file for more info */
-GtkWidget* pot2surf_widget()
+GtkWidget* visu_ui_panel_surfaces_tools_convertWidget()
 {
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips = gtk_tooltips_new ();
@@ -2132,14 +2133,14 @@ GtkWidget* pot2surf_widget()
   return main_vbox;
 }
 
-void isosurfaces_convert_interface_destroy()
+void visu_ui_panel_surfaces_tools_init_destroy()
 {
   convert_w_opened = FALSE;
   gtk_widget_destroy(convert_window);
 }
 
 /* See header file for more info */
-void isosurfaces_convert_interface()
+void visu_ui_panel_surfaces_tools_init()
 {
   GtkWidget *main_vbox;
   GtkWidget *convert_notebook;
@@ -2164,9 +2165,9 @@ void isosurfaces_convert_interface()
 /*   gtk_window_set_modal(GTK_WINDOW(convert_window), TRUE); */
 /*   gtk_window_set_transient_for(GTK_WINDOW(convert_window), GTK_WINDOW(mainWindow)); */
 
-  gtk_notebook_append_page(GTK_NOTEBOOK(convert_notebook), pot2surf_widget(),
+  gtk_notebook_append_page(GTK_NOTEBOOK(convert_notebook), visu_ui_panel_surfaces_tools_convertWidget(),
 			   pot2surf_label);
-  gtk_notebook_append_page(GTK_NOTEBOOK(convert_notebook), surf_file_manager(), 
+  gtk_notebook_append_page(GTK_NOTEBOOK(convert_notebook), visu_ui_panel_surfaces_tools_fileWidget(), 
 			   merge_label);
  
   gtk_container_add(GTK_CONTAINER(convert_window), main_vbox);
@@ -2179,9 +2180,9 @@ void isosurfaces_convert_interface()
   gtk_container_add (GTK_CONTAINER (close_button_alignement), close_button);  
 
   g_signal_connect(convert_window, "destroy",
-		   G_CALLBACK(isosurfaces_convert_interface_destroy), NULL);
+		   G_CALLBACK(visu_ui_panel_surfaces_tools_init_destroy), NULL);
   g_signal_connect(close_button, "clicked",
-		   G_CALLBACK(isosurfaces_convert_interface_destroy), NULL);
+		   G_CALLBACK(visu_ui_panel_surfaces_tools_init_destroy), NULL);
 
   gtk_widget_show_all(convert_window);
 }
