@@ -48,6 +48,7 @@
 
 #include <gtk_main.h>
 
+#if GTK_MAJOR_VERSION < 3
 /**
  * gtk_tree_model_iter_previous:
  * @tree_model: the #GtkTreeModel to get the previous iteration from ;
@@ -60,9 +61,10 @@
  * Return value: TRUE if @iter has been changed to the next node.
  **/
 gboolean gtk_tree_model_iter_previous(GtkTreeModel *tree_model, GtkTreeIter *iter);
+#endif
 
 /**
- * surf_file_manager:
+ * visu_ui_panel_surfaces_tools_fileWidget:
  * 
  * Creates a widget containing an interface to merge surf files. 
  * Don't use two of them simultaneously,
@@ -70,23 +72,23 @@ gboolean gtk_tree_model_iter_previous(GtkTreeModel *tree_model, GtkTreeIter *ite
  * 
  * Return value: an allocated GtkWidget containing the interface.
  **/
-GtkWidget *surf_file_manager();
+GtkWidget *visu_ui_panel_surfaces_tools_fileWidget();
 
 /**
- * pot2surf_widget:
+ * visu_ui_panel_surfaces_tools_convertWidget:
  * 
  * Creates a widget containing the whole pot2surf frontend. Don't use two of them simultaneously,
  * they would conflict.
  * 
  * Return value: an allocated GtkWidget containing the interface.
  **/
-GtkWidget *pot2surf_widget();
+GtkWidget *visu_ui_panel_surfaces_tools_convertWidget();
 
 /**
- * isosurfaces_convert_interface:
+ * visu_ui_panel_surfaces_tools_init:
  * 
  * Opens a new window containing tools to operate on surf and pot files.
  **/
-void isosurfaces_convert_interface();
+void visu_ui_panel_surfaces_tools_init();
 
 #endif
