@@ -48,14 +48,14 @@
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
 /**
- * panelVibration_init:
+ * visu_ui_panel_vibration_init:
  *
  * Should be used in the list declared in externalModules.h to be loaded by
- * V_Sim on start-up. This routine will create the #ToolPanel where the box
+ * V_Sim on start-up. This routine will create the #VisuUiPanel where the box
  *
- * Returns: a newly created #ToolPanel object.
+ * Returns: a newly created #VisuUiPanel object.
  */
 
-ToolPanel* panelVibration_init();
+VisuUiPanel* visu_ui_panel_vibration_init();
 
 #endif
