@@ -51,12 +51,13 @@
 #include <visu_data.h>
 #include <coreTools/toolPhysic.h>
 #include <extraFunctions/vibration.h>
+#include <extraFunctions/extraNode.h>
 
 /*#define TESTNEW*/
 
 /**
  * SECTION:atomic_xyz
- * @short_description: Method to load ascii position file.
+ * @short_description: Method to load xyz position file.
  *
  * <para>XYZ formats are plain text format to store atomic
  * positions. This format is quite simple, first line must contain the
@@ -68,7 +69,9 @@
  * repeated as much time as required to store animation for instance.</para>
  */
 
-static gboolean loadXyz(VisuData *data, const gchar* filename, ToolFileFormat *format, int nSet, GError **error);
+static gboolean loadXyz(VisuData *data, const gchar* filename,
+                        ToolFileFormat *format, int nSet,
+                        GCancellable *cancel, GError **error);
 static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **error);
 
 #ifdef TESTNEW
@@ -86,16 +89,17 @@ static gboolean test_Routine(float* coords, float* dcoord, VisuElement **nodeTyp
  */
 void initAtomicXyz(VisuRendering *method)
 {
-  char *typeXYZ[] = {"*.xyz", (char*)0};
+  const gchar *typeXYZ[] = {"*.xyz", (char*)0};
 
   visu_rendering_addFileFormat(method, 0,
                                tool_file_format_new(_("'Element x y z' format"),
                                                     typeXYZ),
-                               100, loadXyz, (GDestroyNotify)0);
+                               100, loadXyz);
 }
 
 static gboolean loadXyz(VisuData *data, const gchar* filename,
-			ToolFileFormat *format _U_, int nSet, GError **error)
+			ToolFileFormat *format _U_, int nSet,
+                        GCancellable *cancel _U_, GError **error)
 {
   int res;
   GIOChannel *readFrom;
@@ -134,6 +138,227 @@ static gboolean loadXyz(VisuData *data, const gchar* filename,
   return TRUE;
 }
 
+static gboolean readNextLine(GIOChannel *flux, gboolean mandatory,
+                             GString *line, GIOStatus *status, GError **error)
+{
+  gsize terminator_pos;
+
+  /*if there are commentaries */
+  do
+    {
+      *status = g_io_channel_read_line_string(flux, line,
+                                             &terminator_pos, error);
+      if (*status != G_IO_STATUS_NORMAL)
+        {
+          if (*status == G_IO_STATUS_EOF)
+            {
+              if (*error)
+                g_error_free(*error);
+              *error = (GError*)0;
+              return !mandatory;
+            }
+          return FALSE;
+        };
+      g_strstrip(line->str);
+    }
+  while (line->str[0] == '#' || line->str[0] == '!' || line->str[0] == '\0');
+
+  return TRUE;
+}
+
+static ToolUnits readUnit(const gchar *line)
+{
+  ToolUnits unit;
+  gchar *tmpStr;
+  guint nNodes;
+
+  unit = TOOL_UNITS_UNDEFINED;
+
+  tmpStr = g_strdup(line);
+  if (sscanf(line, "%u %s", &nNodes, tmpStr) == 2)
+    unit = tool_physic_getUnitFromName(g_strstrip(tmpStr));
+  DBG_fprintf(stderr, " | units for the set is '%s' -> %d.\n",
+              tmpStr, unit);
+  g_free(tmpStr);
+
+  return unit;
+}
+static gboolean readReduced(const gchar *line)
+{
+  gboolean reduced;
+  gchar *tmpStr;
+  guint nNodes;
+
+  reduced = FALSE;
+  tmpStr = g_strdup(line);
+  if (sscanf(line, "%u %s", &nNodes, tmpStr) == 2)
+    reduced = (!g_ascii_strcasecmp(tmpStr, "reduced"));
+  DBG_fprintf(stderr, " | coordinates are reduced %d.\n", reduced);
+  g_free(tmpStr);
+
+  return reduced;
+}
+
+static float readEnergy(const gchar *line)
+{
+  gchar *tmpStr;
+  guint nNodes;
+  float ene;
+
+  tmpStr = g_strdup(line);
+  if (sscanf(line, "%u %s %f", &nNodes, tmpStr, &ene) != 3)
+    ene = G_MAXFLOAT;
+  else
+    ene *= 27.21138386;
+  g_free(tmpStr);
+  
+  DBG_fprintf(stderr, " | total energy for the set is %geV.\n", ene);
+  return ene;
+}
+
+static void readFree(GList *lst, GHashTable *elements, GString *line,
+                     VisuElement **nodeTypes, float *coords,
+                     float *dcoord, float *forces, GList *labels)
+{
+  GList *tmpLst;
+
+  if (line) g_string_free(line, TRUE);
+  g_hash_table_destroy(elements);
+  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
+    g_free(tmpLst->data);
+  if (lst) g_list_free(lst);
+  if (nodeTypes) g_free(nodeTypes);
+  if (coords) g_free(coords);
+  if (dcoord) g_free(dcoord);
+  if (forces) g_free(forces);
+  for (tmpLst = labels; tmpLst; tmpLst = g_list_next(tmpLst))
+    {
+      tmpLst = g_list_next(tmpLst);
+      g_free(tmpLst->data);
+    }
+  if (labels) g_list_free(labels);
+}
+
+static void readCoord(const gchar *line, guint iNodes, guint nNodes,
+                      float *xyz, float **dxyz, GHashTable *elements,
+                      VisuElement **nodeTypes, gchar **label, GError **error)
+{
+  guint nbcolumn;
+  float dxyz_[3];
+  gchar nomloc[TOOL_MAX_LINE_LENGTH];
+  VisuElement *type;
+  struct VisuMethAscii *infos;
+  int pos;
+
+  *label = (gchar*)0;
+  nbcolumn = sscanf(line, "%s %f %f %f %f %f %f",
+                    nomloc,  xyz + 3 * iNodes + 0, xyz + 3 * iNodes + 1,
+                    xyz + 3 * iNodes + 2, dxyz_ + 0, dxyz_ + 1, dxyz_ + 2);
+  if (nbcolumn < 4)
+    {
+      DBG_fprintf(stderr, "Atomic XYZ: can't read line values.\n");
+      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+                           _("Wrong XYZ format, 'Atom X Y Z' awaited."));
+    }
+  else if (((*dxyz) && nbcolumn != 7) ||
+           (!(*dxyz) && iNodes > 0 && nbcolumn == 7))
+    {
+      DBG_fprintf(stderr, "Atomic XYZ: can't read vibration values.\n");
+      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+                           _("Wrong XYZ + vibration format,"
+                             " 'Atom X Y Z vx vy vz' awaited."));
+    }
+  if (nbcolumn == 7)
+    {
+      if (!(*dxyz))
+        *dxyz = g_malloc(sizeof(float) * 3 * nNodes);
+      (*dxyz)[3 * iNodes + 0] = dxyz_[0];
+      (*dxyz)[3 * iNodes + 1] = dxyz_[1];
+      (*dxyz)[3 * iNodes + 2] = dxyz_[2];
+    }
+  if (*error)
+    return;
+
+  nomloc[8] = '\0';
+  type = visu_element_retrieveFromName(nomloc, (gboolean*)0);
+  if (!type)
+    {
+      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+                           _("Internal error, cannot create type for '%s'."),
+                           nomloc);
+      return;
+    }
+  nodeTypes[iNodes] = type;
+  infos = (struct VisuMethAscii*)
+    g_hash_table_lookup(elements, (gconstpointer)type);
+  if (!infos)
+    {
+      infos          = g_malloc(sizeof(struct VisuMethAscii));
+      infos->ele     = type;
+      infos->pos     = g_hash_table_size(elements);
+      infos->nbNodes = 1;
+      g_hash_table_insert(elements, (gpointer)type, (gpointer)infos);
+    }
+  else
+    infos->nbNodes += 1;
+
+  /* Store a possible comment. */
+  pos = 0;
+  if (nbcolumn == 4)
+    sscanf(line, "%s %f %f %f %n", nomloc, xyz + 3 * iNodes + 0,
+           xyz + 3 * iNodes + 1, xyz + 3 * iNodes + 2, &pos);
+  else
+    sscanf(line, "%s %f %f %f %f %f %f %n",
+           nomloc, xyz + 3 * iNodes + 0, xyz + 3 * iNodes + 1,
+           xyz + 3 * iNodes + 2, dxyz_ + 0, dxyz_ + 1, dxyz_ + 2, &pos);
+  if (line[pos] != '\0')
+    {
+      *label = g_strdup(line + pos + ((line[pos] == '#')?1:0));
+      g_strstrip(*label);
+      if ((*label)[0] == '\0')
+        {
+          g_free(*label);
+          *label = (gchar*)0;
+        }
+    }
+}
+
+static void readForces(GIOChannel *flux, GString *line, guint nNodes,
+                       float **forces, GIOStatus *status, GError **error)
+{
+  guint iNodes;
+  gchar nomloc[TOOL_MAX_LINE_LENGTH];
+
+  if (!strcmp(line->str, "forces"))
+    {
+      if (forces)
+        *forces = g_malloc(sizeof(float) * nNodes * 3);
+      for (iNodes = 0; iNodes < nNodes && *status == G_IO_STATUS_NORMAL; iNodes++)
+	{
+          if (!readNextLine(flux, TRUE, line, status, error))
+            {
+              *error = g_error_new(VISU_ERROR_RENDERING,
+                                   RENDERING_ERROR_FORMAT,
+                                   _("Missing forces (%d read but"
+                                     " %d declared).\n"), iNodes, nNodes);
+              return;
+            }
+          if (forces && sscanf(line->str, "%s %f %f %f",
+                               nomloc,  *forces + 3 * iNodes + 0,
+                               *forces + 3 * iNodes + 1,
+                               *forces + 3 * iNodes + 2) != 4)
+            {
+              *error = g_error_new(VISU_ERROR_RENDERING,
+                                   RENDERING_ERROR_FORMAT,
+                                   _("Cannot read forces in '%s'.\n"), line->str);
+              return;
+            }
+	}
+      /* Eat blank or commentary lines between Sets */
+      readNextLine(flux, FALSE, line, status, error);
+    }
+}
+
 /******************************************************************************/
 static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **error)
 {
@@ -143,26 +368,23 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   int i;
   int res, nNodes, iNodes, nNodesSet;
   int nSets;
-  char nomloc[MAX_LINE_LENGTH], *kwd, *tmpStr;
-  double xu, yu, zu;
-  double dx, dy, dz;
-  float *coords, *dcoord;
+  char *kwd;
+  float *coords, *dcoord, *forces;
   gchar *infoUTF8;
   GList *lst, *tmpLst;
   GHashTable *elements;
-  struct VisuMethAscii *infos;
-  float qpt[3], omega;
+  float qpt[3], omega, totalEnergy;
   double box[3], boxGeometry[6];
   int ntype;
   ToolUnits unit;
-  VisuElement *type;
-  VisuElement **types, **nodeTypes;
-  unsigned int *nattyp, natom;
-  gchar *pt;
-  VisuDataBoxBoundaries bc;
+  GArray *types, *nattyp;
+  VisuElement **nodeTypes;
+  guint natom;
+  gchar *pt, *label;
+  VisuBoxBoundaries bc;
   gboolean reduced;
-
-  int nbcolumn;
+  GList *nodeComments;
+  VisuBox *boxObj;
 
 #if DEBUG == 1
   GTimer *timer, *readTimer, *internalTimer;
@@ -170,15 +392,13 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   float time1, time2, time3;
 #endif
 
-  /* We read every line that corresponds to this schema : "%s %f %f %f %f %f %f" */
   DBG_fprintf(stderr, "Atomic xyz: reading file as an xyz file.\n");
 
   line = g_string_new("");
-  unit = unit_undefined;
+  unit = TOOL_UNITS_UNDEFINED;
   reduced = FALSE;
 
   /* Storage of number of elements per types. */
-  nbcolumn = 0;
   ntype = 0;
   elements = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
 
@@ -194,91 +414,65 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   time3 = 0.f;
 #endif
 
-  nSets     = 0;
-  nNodesSet = 0;
-  nodeTypes = (VisuElement**)0;
-  coords    = (float*)0;
-  dcoord    = (float*)0;
-  lst       = (GList*)0;
+  nSets        = 0;
+  nNodesSet    = 0;
+  nodeTypes    = (VisuElement**)0;
+  coords       = (float*)0;
+  dcoord       = (float*)0;
+  forces       = (float*)0;
+  lst          = (GList*)0;
+  nodeComments = (GList*)0;
+  totalEnergy  = G_MAXFLOAT;
   status = g_io_channel_read_line_string(flux, line, &terminator_pos, error);
 
   if ( status != G_IO_STATUS_NORMAL )
     {
-      g_string_free(line, TRUE);
-      g_hash_table_destroy(elements);
+      readFree(lst, elements, line, nodeTypes, coords, dcoord, forces, nodeComments);
       return -1;
     }
  
   while( status != ( G_IO_STATUS_EOF ) )
     { 
       DBG_fprintf(stderr, "Atomic xyz: read node set number %d.\n", nSets);
+
       /*The Number Of Nodes*/
       nNodes=0;
+      DBG_fprintf(stderr, "Atomic xyz: get n atoms from '%s'.\n", line->str);
       res = sscanf(line->str, "%d", &nNodes);
-      if (res != 1 && nSets > nSet)
-	break;
-
       if ( res != 1 ) 
 	{ 
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			       _("Wrong XYZ format, no number on first line.\n"));
-	  g_string_free(line, TRUE);
-	  g_hash_table_destroy(elements);
-	  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-	    g_free(tmpLst->data);
-	  g_list_free(lst);
-	  return -1;
+          readFree(lst, elements, line, nodeTypes, coords, dcoord, forces, nodeComments);
+	  return (nSets > 0)?1:-1;
 	}
-
       DBG_fprintf(stderr, " | number of declared nodes is %d.\n", nNodes);
-
+#if DEBUG == 1
       if (nSets == nSet)
-	{
-#if DEBUG == 1
-	  g_timer_start(readTimer);
-#endif
-	  tmpStr = g_strdup(line->str);
-	  if (sscanf(line->str, "%d %s", &nNodes, tmpStr) == 2)
-	    {
-	      g_strstrip(tmpStr);
-	      if (!strcmp(tmpStr, "atomic") || !strcmp(tmpStr, "atomicd0"))
-		unit = unit_bohr;
-	      else if (!strcmp(tmpStr, "bohr") || !strcmp(tmpStr, "bohrd0"))
-		unit = unit_bohr;
-	      else if (!strcmp(tmpStr, "angstroem") || !strcmp(tmpStr, "angstroemd0"))
-		unit = unit_angstroem;
-	      else if (!strcmp(tmpStr, "reduced") || !strcmp(tmpStr, "reducedd0"))
-		reduced = TRUE;
-	      else
-		g_warning("Unknown unit '%s'.", tmpStr);
-	    }
-	  g_free(tmpStr);
-	  DBG_fprintf(stderr, " | units for the set is '%s' -> %d.\n",
-		      tmpStr, unit);
-	}
-#if DEBUG == 1
+        g_timer_start(readTimer);
       else
 	g_timer_continue(internalTimer);
 #endif
+      if (nSets == nSet)
+        {
+          unit = readUnit(line->str);
+          reduced = readReduced(line->str);
+          totalEnergy = readEnergy(line->str);
+        }
 
       /*The Commentary line */
       if ( g_io_channel_read_line_string(flux, line, &terminator_pos, error) !=
 	   G_IO_STATUS_NORMAL )
 	{
-	  g_string_free(line, TRUE);   
-	  g_hash_table_destroy(elements);
-	  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-	    g_free(tmpLst->data);
-	  g_list_free(lst);
+          readFree(lst, elements, line, nodeTypes, coords, dcoord, forces, nodeComments);
 	  return -2;
 	}
-
       g_strstrip(line->str);
       DBG_fprintf(stderr, " | set the commentary to '%s'.\n", line->str);
       if (line->str[0] == '#')
 	infoUTF8 = g_locale_to_utf8(line->str + 1, -1, NULL, NULL, NULL);
       else
-	infoUTF8 = g_locale_to_utf8(line->str, -1, NULL, NULL, NULL);
+	infoUTF8 = g_locale_to_utf8(line->str,     -1, NULL, NULL, NULL);
       if (infoUTF8)
 	lst = g_list_append(lst, infoUTF8);
       else
@@ -290,126 +484,43 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	  nNodesSet = nNodes; 
 	  nodeTypes = g_malloc(sizeof(VisuElement*) * nNodes);
 	  coords    = g_malloc(sizeof(float) * 3 * nNodes);
-	  dcoord = (float*)0;
+	  dcoord    = (float*)0;
+          forces    = (float*)0;
 	  qpt[0] = 0.f;
 	  qpt[1] = 0.f;
 	  qpt[2] = 0.f;
 	}
       status = G_IO_STATUS_NORMAL;
       DBG_fprintf(stderr, " | read node coordinates.\n");
-      for (iNodes=0; iNodes<nNodes && status==G_IO_STATUS_NORMAL; iNodes++)
+      for (iNodes = 0; iNodes < nNodes && status == G_IO_STATUS_NORMAL; iNodes++)
 	{
-	  /*if there are commentaries */
-	  do
-	    {
-	      status = g_io_channel_read_line_string(flux, line,
-						     &terminator_pos, error);
-	      if (status != G_IO_STATUS_NORMAL)
-		{
-		  if (status == G_IO_STATUS_EOF)
-		    {
-		      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-					   _("Missing coordinates (%d read but"
-					     " %d declared).\n"), iNodes, nNodes);
-		    }
-		  DBG_fprintf(stderr, "Atomic XYZ: can't read a line (%s).\n", (*error)->message);
-		  g_string_free(line, TRUE);
-		  g_hash_table_destroy(elements);
-		  if (nSets == nSet)
-		    {
-		      g_free(nodeTypes);
-		      g_free(coords);
-		      g_free(dcoord);
-		      for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-			g_free(tmpLst->data);
-		      g_list_free(lst);
-		    };
-		  return 1;
-		};
-	    } while (line->str[0] == '#');
- 	
-	  /* if Reading the nSets, parse the data */
-	  if (nSets == nSet)
-	    {
-	      nbcolumn = sscanf(line->str, "%s %lf %lf %lf %lf %lf %lf",
-				nomloc, &xu, &yu, &zu, &dx, &dy, &dz);
-	      if (nbcolumn < 4)
-		{
-		  DBG_fprintf(stderr, "Atomic XYZ: can't read line values.\n");
-		  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-				       _("Wrong XYZ format, 'Atom X Y Z' awaited."));
-		}
-	      else if ((dcoord && nbcolumn != 7) ||
-		       (!dcoord && iNodes > 0 && nbcolumn == 7))
-		{
-		  DBG_fprintf(stderr, "Atomic XYZ: can't read vibration values.\n");
-		  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-				       _("Wrong XYZ + vibration format,"
-					 " 'Atom X Y Z vx vy vz' awaited."));
-		}
+          if (!readNextLine(flux, TRUE, line, &status, error))
+            {
+              *error = g_error_new(VISU_ERROR_RENDERING,
+                                   RENDERING_ERROR_FORMAT,
+                                   _("Missing coordinates (%d read but"
+                                     " %d declared).\n"), iNodes, nNodes);
+              readFree(lst, elements, line, nodeTypes, coords, dcoord, forces, nodeComments);
+              return 1;
+            }
+          
+          /* if Reading the nSets, parse the data */
+          if (nSets == nSet)
+            {
+              /* Read the coordinates. */
+              readCoord(line->str, iNodes, nNodes, coords, &dcoord,
+                        elements, nodeTypes, &label, error);
 	      if (*error)
 		{
-		  g_string_free(line, TRUE);
-		  g_hash_table_destroy(elements);
-		  if (nSets == nSet)
-		    {
-		      g_free(nodeTypes);
-		      g_free(coords);
-		      g_free(dcoord);
-		      for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-			g_free(tmpLst->data);
-		      g_list_free(lst);
-		    }
+                  readFree(lst, elements, line, nodeTypes, coords, dcoord, forces, nodeComments);
 		  return 1;			
-		} 
-	 
-	      /* Store the coordinates and mouvement*/
-	      coords[iNodes * 3 + 0] = xu;
-	      coords[iNodes * 3 + 1] = yu;
-	      coords[iNodes * 3 + 2] = zu;
-	      if ( nbcolumn == 7)
-		{
-		  if (!dcoord)
-		    dcoord = g_malloc(sizeof(float) * 3 * nNodes);
-		  dcoord[iNodes * 3 + 0] = dx;
-		  dcoord[iNodes * 3 + 1] = dy;
-		  dcoord[iNodes * 3 + 2] = dz;
 		}
-
-	      /* Store the elements. */
-	      nomloc[8] = '\0';
-
-	      type = visu_element_retrieveFromName(nomloc, (gboolean*)0);
-	      if (!type)
-		{
-                  g_warning("Cannot create a new type for '%s'.", nomloc);
-                  g_string_free(line, TRUE);
-                  g_hash_table_destroy(elements);
-                  if (nSets == nSet)
-                    {
-                      g_free(nodeTypes);
-                      g_free(coords);
-                      g_free(dcoord);
-                      for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-                        g_free(tmpLst->data);
-                      g_list_free(lst);
-                    }
-                  return 1;
-		}
-	      nodeTypes[iNodes] = type;
-	      infos = (struct VisuMethAscii*)g_hash_table_lookup(elements,
-							     (gconstpointer)type);
-	      if (!infos)
-		{
-		  infos = g_malloc(sizeof(struct VisuMethAscii));
-		  infos->ele = type;
-		  infos->pos = ntype;
-		  infos->nbNodes = 1;
-		  g_hash_table_insert(elements, (gpointer)type, (gpointer)infos);
-		  ntype++;
-		}
-	      else
-		infos->nbNodes += 1;
+              if (label)
+                {
+                  nodeComments = g_list_prepend(nodeComments, label);
+                  nodeComments = g_list_prepend(nodeComments,
+                                                GINT_TO_POINTER(iNodes));
+                }
 	    }
 #if DEBUG == 1
 	  if (nSets == nSet)
@@ -420,36 +531,26 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	}
 #if DEBUG == 1
       g_timer_stop(timer);
-#endif
-	
-      DBG_fprintf(stderr, " | read OK.\n");
+#endif      
+      /* Eat blank or commentary lines after coordinates. */
+      if (!readNextLine(flux, FALSE, line, &status, error))
+        {
+          readFree(lst, elements, line, nodeTypes, coords, dcoord, forces, nodeComments);
+          return 1;			
+        }
+      /* Maybe read forces (BigDFT addition). */
+      readForces(flux, line, nNodes, (nSets == nSet)?&forces:(float**)0, &status, error);
+      if (*error)
+        {
+          readFree(lst, elements, line, nodeTypes, coords, dcoord, forces, nodeComments);
+          return 1;			
+        }
       /* OK, one set of nodes have been read. */
       nSets++;
-      /* Eat blank or commentary lines between Sets */
-      do
-	{
-	  status = g_io_channel_read_line_string(flux, line, &terminator_pos, error);
-	  if (status != G_IO_STATUS_NORMAL && status != G_IO_STATUS_EOF)
-	    {
-	      g_string_free(line, TRUE);
-	      g_hash_table_destroy(elements);
-	      if (nSets == nSet)
-		{
-		  g_free(nodeTypes);
-		  g_free(coords);
-		  g_free(dcoord);
-		  for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
-		    g_free(tmpLst->data);
-		  g_list_free(lst);
-		}
-	      return 1;
-	    }
-	  g_strstrip(line->str);
-	}
-      while (status != G_IO_STATUS_EOF &&
-	     (line->str[0] == '#' || line->str[0] == '!' || line->str[0] == '\0'));
+      DBG_fprintf(stderr, " | read OK %d %d.\n", status, G_IO_STATUS_EOF);
     }
   g_string_free(line, TRUE);
+  ntype = g_hash_table_size(elements);
   DBG_fprintf(stderr, " | finish to read the file (ntype = %d).\n", ntype);
 #if DEBUG == 1
   g_timer_stop(timer);
@@ -465,52 +566,42 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   /* Allocate the space for the nodes. */
   if (ntype <= 0)
     {
-      g_hash_table_destroy(elements);
-      if (nodeTypes)
-	g_free(nodeTypes);
-      if (coords) {
-	g_free(coords);
-	g_free(dcoord);
-      }
-      tmpLst = lst;
-      while (tmpLst)
-	{
-	  g_free(tmpLst->data);
-	  tmpLst = g_list_next(tmpLst);
-	}
-      g_list_free(lst);
+      readFree(lst, elements, (GString*)0, nodeTypes, coords, dcoord, forces, nodeComments);
       *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			   _("The file contains no atom coordinates.\n"));
       return -1;
     }
-  types  = g_malloc(sizeof(VisuElement*) * ntype);
-  nattyp = g_malloc(sizeof(int) * ntype);
-  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
-  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
+  types  = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), ntype);
+  nattyp = g_array_sized_new(FALSE, FALSE, sizeof(guint), ntype);
+  g_array_set_size(types, ntype);
+  g_array_set_size(nattyp, ntype);
+  DBG_fprintf(stderr, "Atomic xyz: transfer to VisuData (%p %p).\n",
+              (gpointer)types, (gpointer)nattyp);
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToType, (gpointer)types);
+  DBG_fprintf(stderr, " | transfer to types OK.\n");
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)nattyp);
+  DBG_fprintf(stderr, " | transfer to nNodesPerEle OK.\n");
   g_hash_table_destroy(elements);
 
-  DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
+  DBG_fprintf(stderr, " | populate nodes.\n");
   /* Begin the storage into VisuData. */
   visu_data_setNSubset(data, nSets);
 
-  res = visu_data_setPopulation(data, ntype, nattyp, types);
-  if (!res)
-    {
-      g_error("Can't store the nodes in the VisuData object.");
-    }
+  visu_node_array_allocate(VISU_NODE_ARRAY(data), types, nattyp);
   DBG_fprintf(stderr, "Atomic xyz: there are %d types in this file.\n", ntype);
   if (DEBUG)
     {
       for (i = 0; i < ntype; i++)
-	DBG_fprintf(stderr, " | %d atom(s) for type %d.\n", nattyp[i], i);
+	DBG_fprintf(stderr, " | %d atom(s) for type %d.\n",
+                    g_array_index(nattyp, guint, i), i);
     }
   natom = 0;
-  for (i = 0; i < ntype; i++) natom += nattyp[i];
-  g_free(nattyp);
-  g_free(types);
+  for (i = 0; i < ntype; i++) natom += g_array_index(nattyp, guint, i);
+  g_array_free(nattyp, TRUE);
+  g_array_free(types, TRUE);
 
   /* Set the commentary. */
-  bc = VISU_DATA_BOX_FREE;
+  bc = VISU_BOX_FREE;
   tmpLst = lst;
   for (i = 0; i < nSets; i++)
     {
@@ -520,11 +611,11 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	  kwd = strstr((char*)tmpLst->data, "periodic");
 	  if (kwd && sscanf(kwd + 8, "%lf %lf %lf",
 				    box, box + 1, box + 2) == 3)
-	    bc = VISU_DATA_BOX_PERIODIC;
+	    bc = VISU_BOX_PERIODIC;
 	  kwd = strstr((char*)tmpLst->data, "surface");
 	  if (kwd && sscanf(kwd + 8, "%lf %lf %lf",
 				    box, box + 1, box + 2) == 3)
-	    bc = VISU_DATA_BOX_SURFACE_ZX;
+	    bc = VISU_BOX_SURFACE_ZX;
 	}
 
       visu_data_setFileCommentary(data, (gchar*)tmpLst->data, i);
@@ -532,8 +623,9 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
       tmpLst = g_list_next(tmpLst);
     }
   g_list_free(lst);
-         
-  if (bc != VISU_DATA_BOX_FREE)
+  
+  boxObj = (VisuBox*)0;
+  if (bc != VISU_BOX_FREE)
     {
       DBG_fprintf(stderr, "Atomic xyz: the elements are in %fx%fx%f.\n",
 		  box[0], box[1], box[2]);
@@ -543,7 +635,9 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
       boxGeometry[3] = 0.;
       boxGeometry[4] = 0.;
       boxGeometry[5] = box[2];
-      visu_data_setBoxGeometry(data, boxGeometry, bc);
+      boxObj = visu_box_new(boxGeometry, bc);
+      visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj), FALSE);
+      g_object_unref(boxObj);
     }
 
   /* Store the coordinates */
@@ -559,14 +653,15 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   g_free(nodeTypes);
   g_free(coords);
 
-  if (bc != VISU_DATA_BOX_PERIODIC)
-    visu_data_setTightBox(data);
+  if (bc != VISU_BOX_PERIODIC)
+    boxObj = visu_data_setTightBox(data);
 
-  visu_data_applyBoxGeometry(data);
-  visu_data_setUnit(data, unit);
+  visu_box_setMargin(boxObj, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
+                     visu_data_getAllNodeExtens(data, boxObj), TRUE);
+  visu_box_setUnit(boxObj, unit);
 
   /* create the structure for phonons */
-  if (nbcolumn == 7)
+  if (dcoord)
     {
       visu_vibration_init(data, nSets, natom);
       for (i = 0; i < nSets; i++)
@@ -583,6 +678,29 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
       g_free(dcoord);
     }
 
+  /* Store the forces, if any. */
+  if (forces)
+    {
+      visu_rendering_atomic_setForces(data, forces);
+      g_free(forces);
+    }
+  /* We apply the comments, if any. */
+  visu_extra_node_addLabel(data);
+  if (nodeComments)
+    {
+      for (tmpLst = nodeComments; tmpLst; tmpLst = g_list_next(tmpLst))
+        {
+          visu_extra_node_setLabel(data, GPOINTER_TO_INT(tmpLst->data),
+                             tmpLst->next->data);
+          g_free(tmpLst->next->data);
+          tmpLst = g_list_next(tmpLst);
+        }
+      g_list_free(nodeComments);
+    }
+  /* Add some other meta data. */
+  if (totalEnergy != G_MAXFLOAT)
+    g_object_set(G_OBJECT(data), "totalEnergy", totalEnergy, NULL);
+
 #if DEBUG == 1
   g_timer_stop(timer);
   fprintf(stderr, "Atomic XYZ: parse all file    in %g micro-s.\n", time1);
