@@ -82,17 +82,19 @@ typedef struct AsciiKeywordData_
   gboolean reduced;
   gboolean angdeg;
   ToolUnits unit;
-  VisuDataBoxBoundaries bc;
+  VisuBoxBoundaries bc;
 } AsciiKeywordData;
 typedef struct AsciiMetaData_
 {
   guint nqpt;
   gdouble totalEnergy;
+  gboolean forces;
 } AsciiMetaData;
 
 static double readTotalEnergy(const gchar *str);
 static gboolean loadAscii(VisuData *data, const gchar* filename,
-			  ToolFileFormat *format, int nSet, GError **error);
+			  ToolFileFormat *format, int nSet,
+                          GCancellable *cancel, GError **error);
 static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error);
 static gboolean readFile_is_comment(char *str, AsciiKeywordData *kw,
 				    AsciiMetaData *md);
@@ -107,12 +109,12 @@ static gboolean readFile_is_comment(char *str, AsciiKeywordData *kw,
  */
 void initAtomicAscii(VisuRendering *method)
 {
-  char *typeASCII[] = {"*.ascii", (char*)0};
+  const gchar *typeASCII[] = {"*.ascii", (char*)0};
 
   visu_rendering_addFileFormat(method, 0,
                                tool_file_format_new(_("'x y z Element' format"),
                                                     typeASCII),
-                               50, loadAscii, (GDestroyNotify)0);
+                               50, loadAscii);
 }
 
 /******************************************************************************/
@@ -139,18 +141,18 @@ static gboolean readFile_is_comment(char *str, AsciiKeywordData *kw,
 		     !g_ascii_strcasecmp(tokens[i], "atomicd0") ||
 		     !g_ascii_strcasecmp(tokens[i], "bohr") ||
 		     !g_ascii_strcasecmp(tokens[i], "bohrd0"))
-	      kw->unit = unit_bohr;
+	      kw->unit = TOOL_UNITS_BOHR;
 	    else if (!g_ascii_strcasecmp(tokens[i], "angstroem") ||
 		     !g_ascii_strcasecmp(tokens[i], "angstroemd0"))
-	      kw->unit = unit_angstroem;
+	      kw->unit = TOOL_UNITS_ANGSTROEM;
 	    else if (!g_ascii_strcasecmp(tokens[i], "periodic"))
-	      kw->bc = VISU_DATA_BOX_PERIODIC;
+	      kw->bc = VISU_BOX_PERIODIC;
 	    else if (!g_ascii_strcasecmp(tokens[i], "surface"))
-	      kw->bc = VISU_DATA_BOX_SURFACE_ZX;
+	      kw->bc = VISU_BOX_SURFACE_ZX;
 	    else if (!g_ascii_strcasecmp(tokens[i], "surfaceXY"))
-	      kw->bc = VISU_DATA_BOX_SURFACE_XY;
+	      kw->bc = VISU_BOX_SURFACE_XY;
 	    else if (!g_ascii_strcasecmp(tokens[i], "freeBC"))
-	      kw->bc = VISU_DATA_BOX_FREE;
+	      kw->bc = VISU_BOX_FREE;
 	  }
       g_strfreev(tokens);
     }
@@ -166,6 +168,8 @@ static gboolean readFile_is_comment(char *str, AsciiKeywordData *kw,
 	      md->nqpt += 1;
 	    else if (!g_ascii_strncasecmp(tokens[i], "totalEnergy", 11))
 	      md->totalEnergy = readTotalEnergy(str + 10);
+	    else if (!g_ascii_strncasecmp(tokens[i], "forces", 6))
+	      md->forces = TRUE;
 	  }
       g_strfreev(tokens);
     }
@@ -257,6 +261,44 @@ static gboolean readQpt(gchar *str, float qpt[4], float *disp, guint natom)
   return TRUE;
 }
 
+static gboolean readForces(gchar *str, float *forces, guint natom)
+{
+  gchar **values;
+  gchar *ptr;
+  guint j, k;
+
+  ptr = strstr(str, "forces");
+  if (!ptr)
+    return FALSE;
+  ptr = strstr(ptr, "=");
+  if (!ptr)
+    {
+      g_warning("syntax error for meta data 'forces' in '%s'.", str);
+      return FALSE;
+    }
+
+  DBG_fprintf(stderr, "Atomic ASCII: read forces from '%s'\n", ptr);
+  memset(forces, 0, sizeof(float) * 6 * natom);
+  values = g_strsplit_set(ptr + 1, " [];\n\r\\\t", -1);
+  for (k = 0, j = 0; values[j] && k < 6 * natom; j++)
+    if (values[j][0] != '\0')
+      {
+	if (sscanf(values[j], "%f", forces + k) == 1)
+	  k += 1;
+	if (DEBUG && k % 3 == 2)
+	  DBG_fprintf(stderr, " | f[%d] = (%g,%g,%g)\n", k / 3,
+		      forces[(k / 3) * 3 + 0],
+                      forces[(k / 3) * 3 + 1],
+                      forces[(k / 3) * 3 + 2]);
+      }
+  if (k != natom * 3)
+    g_warning("Can't read enough force values,"
+	      " %d read while %d were awaited.", k, natom * 3);
+  g_strfreev(values);
+
+  return TRUE;
+}
+
 gboolean continuousLine(GString *line)
 {
   gsize len;
@@ -295,12 +337,12 @@ void visu_meth_asciiFree(gpointer data)
  */
 void visu_meth_asciiValToType(gpointer key _U_, gpointer value, gpointer data)
 {
-  VisuElement **tab;
   struct VisuMethAscii *infos;
   
-  tab = *(VisuElement***)data;
   infos = (struct VisuMethAscii *)value;
-  tab[infos->pos] = infos->ele;
+  DBG_fprintf(stderr, " | %d -> '%s' (%p).\n", infos->pos,
+              infos->ele->name, (gpointer)infos->ele);
+  g_array_index((GArray*)data, VisuElement*, infos->pos) = infos->ele;
 }
 /**
  * visu_meth_asciiValToNb:
@@ -315,17 +357,17 @@ void visu_meth_asciiValToType(gpointer key _U_, gpointer value, gpointer data)
  */
 void visu_meth_asciiValToNb(gpointer key _U_, gpointer value, gpointer data)
 {
-  int *tab;
   struct VisuMethAscii *infos;
   
-  tab = *(int**)data;
   infos = (struct VisuMethAscii *)value;
-  tab[infos->pos] = infos->nbNodes;
+  DBG_fprintf(stderr, " | %d -> %d.\n", infos->pos, infos->nbNodes);
+  g_array_index((GArray*)data, guint, infos->pos) = infos->nbNodes;
 }
 /******************************************************************************/
 
 static gboolean loadAscii(VisuData *data, const gchar* filename,
-			  ToolFileFormat *format _U_, int nSet _U_, GError **error)
+			  ToolFileFormat *format _U_, int nSet _U_,
+                          GCancellable *cancel _U_, GError **error)
 {
   int res;
   GIOChannel *readFrom;
@@ -371,13 +413,13 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   GString *line, *bufLine;
   gsize term;
   double xu, yu, zu;
-  unsigned int i, iph;
-  int res, pos;
-  char nomloc[MAX_LINE_LENGTH];
+  guint i, iph;
+  int pos;
+  char nomloc[TOOL_MAX_LINE_LENGTH];
   VisuElement *type;
-  VisuElement **types;
-  unsigned int *nattyp;
-  unsigned int ntype, nbLine, natom;
+  GArray *types;
+  GArray *nattyp;
+  guint ntype, nbLine, natom;
   GHashTable *elements;
   struct VisuMethAscii *infos;
   double boxGeometry[6], abc[3], ang[3];
@@ -385,9 +427,10 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   gchar *infoUTF8, **nodeComments;
   gboolean hasNodeComments;
   GIOStatus status;
-  float qpt[4], *dcoord;
+  float qpt[4], *dcoord, *forces;
   AsciiKeywordData kw;
   AsciiMetaData md;
+  VisuBox *box;
     
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
 
@@ -465,11 +508,13 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   /* 1st pass to count ntype */
   kw.reduced     = FALSE;
   kw.angdeg      = FALSE;
-  kw.unit        = unit_undefined;
-  kw.bc          = VISU_DATA_BOX_PERIODIC;
+  kw.unit        = TOOL_UNITS_UNDEFINED;
+  kw.bc          = VISU_BOX_PERIODIC;
   md.nqpt        = 0;
   md.totalEnergy = 999.;
+  md.forces      = FALSE;
   dcoord  = (float*)0;
+  forces  = (float*)0;
   nbLine  = 4;
   ntype   = 0;
   elements = g_hash_table_new_full(g_direct_hash, g_direct_equal,
@@ -521,24 +566,24 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
 			   _("The file contains no atom coordinates.\n"));
       return 1;
     }
+  DBG_fprintf(stderr, "Atomic ASCII: transfer to VisuData.\n");
   /* Allocate the space for the nodes. */
-  types  = g_malloc(sizeof(VisuElement*) * ntype);
-  nattyp = g_malloc(sizeof(int) * ntype);
-  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
-  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
+  types  = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), ntype);
+  nattyp = g_array_sized_new(FALSE, FALSE, sizeof(guint), ntype);
+  g_array_set_size(types, ntype);
+  g_array_set_size(nattyp, ntype);
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToType, (gpointer)types);
+  g_hash_table_foreach(elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)nattyp);
   g_hash_table_destroy(elements);
   natom = 0;
-  for (i = 0; i < ntype; i++) natom += nattyp[i];
+  for (i = 0; i < ntype; i++) natom += g_array_index(nattyp, guint, i);
 
-  res = visu_data_setPopulation(data, ntype, nattyp, types);
-  if (!res)
-    {
-      g_error("Can't store the nodes in the VisuData object.");
-    }
-  g_free(nattyp);
-  g_free(types);
+  visu_node_array_allocate(VISU_NODE_ARRAY(data), types, nattyp);
+  g_array_free(nattyp, TRUE);
+  g_array_free(types, TRUE);
          
   /* We build boxGeometry according to angdeg flag. */
+  DBG_fprintf(stderr, "Atomic ASCII: build the box if any.\n");
   if (kw.angdeg)
     {
       abc[0] = boxGeometry[0];
@@ -548,7 +593,7 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       ang[1] = boxGeometry[4];
       ang[2] = boxGeometry[5];
 
-      if (sin(ang[2] == 0.f))
+      if (sin(ang[2]) == 0.f)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			       _("Wrong (ab) angle, should be"
@@ -571,7 +616,9 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       boxGeometry[5] *= (ang[1] < 0.)?-1.:+1.;
     }
   /* Always set the given box, in case coordinates are reduced. */
-  visu_data_setBoxGeometry(data, boxGeometry, kw.bc);
+  box = visu_box_new(boxGeometry, kw.bc);
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(box), FALSE);
+  g_object_unref(box);
   /* Test phonons. */
   if (md.nqpt > 0)
     {
@@ -580,7 +627,14 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       visu_vibration_init(data, md.nqpt, natom);
       dcoord = g_malloc(sizeof(float) * (natom * 6));
     }
+  if (md.forces)
+    {
+      DBG_fprintf(stderr, "Atomic ASCII: initialise forces storage for %d data.\n",
+		  natom * 6);
+      forces = g_malloc(sizeof(float) * (natom * 6));
+    }
 
+  DBG_fprintf(stderr, "Atomic ASCII: reread file for node positions.\n");
   /* Allocate the storage of the node comments. */
   nodeComments = g_malloc(sizeof(gchar*) * natom);
   hasNodeComments = FALSE;
@@ -611,17 +665,20 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
 	      visu_vibration_setDisplacements(data, iph, dcoord, TRUE);
 	      iph += 1;
 	    }
+
+          if (md.forces && readForces(line->str, forces, natom))
+            visu_rendering_atomic_setForces(data, forces);
 	  
 	  continue;
 	}
      
       pos = 0;
-      res = sscanf(line->str, "%lf %lf %lf %s %n", &xu, &yu, &zu, nomloc, &pos);
+      sscanf(line->str, "%lf %lf %lf %s %n", &xu, &yu, &zu, nomloc, &pos);
       nomloc[8] = '\0';
       type = visu_element_lookup(nomloc);
       if (!type)
 	{
-	  g_warning("INTERNAL ERROR! The input file must"
+	  g_warning("The input file must"
 		    " have been modified when loading since"
 		    " at the second reading the element '%s'"
 		    " seems to be new.\n", nomloc);
@@ -633,7 +690,7 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
       xyz[1] = uvw[1] = (float)yu;
       xyz[2] = uvw[2] = (float)zu;
       if (kw.reduced)
-	visu_data_convertBoxCoordinatestoXYZ(data, xyz, uvw);
+	visu_box_convertBoxCoordinatestoXYZ(box, xyz, uvw);
       visu_data_addNodeFromElement(data, type, xyz, FALSE, FALSE);
 
       /* Store a possible comment. */
@@ -658,22 +715,23 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   g_string_free(bufLine, TRUE);
 
   /* In free boundary conditions, find the bounding box. */
-  if (kw.bc != VISU_DATA_BOX_PERIODIC)
+  if (kw.bc != VISU_BOX_PERIODIC)
     visu_data_setTightBox(data);
 
   /* We finish with the box description. */
   DBG_fprintf(stderr, "Atomic ASCII: apply the box geometry and set the unit.\n");
-  visu_data_applyBoxGeometry(data);
-  visu_data_setUnit(data, kw.unit);
+  visu_box_setMargin(box, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
+                     visu_data_getAllNodeExtens(data, box), TRUE);
+  visu_box_setUnit(box, kw.unit);
 
   /* We apply the comments, if any. */
+  visu_extra_node_addLabel(data);
   if (hasNodeComments)
     {
-      extraNodeAdd_label(data);
       for (i = 0; i < natom; i++)
 	if (nodeComments[i])
 	  {
-	    extraNodeSet_label(data, i, nodeComments[i]);
+	    visu_extra_node_setLabel(data, i, nodeComments[i]);
 	    g_free(nodeComments[i]);
 	  }
     }
@@ -685,6 +743,8 @@ static int read_ascii_file(VisuData *data, GIOChannel *flux, GError **error)
   
   if (md.nqpt > 0)
     g_free(dcoord);
+  if (md.forces)
+    g_free(forces);
 
   DBG_fprintf(stderr, "Atomic ASCII: parse done.\n");
 
