@@ -51,9 +51,11 @@
 #include "coreTools/toolOptions.h"
 #include "coreTools/toolShade.h"
 #include "coreTools/toolPhysic.h"
+#include "extraFunctions/plane.h"
 #include "extraFunctions/surfaces.h"
 #include "extraFunctions/scalarFields.h"
-#include "extensions/extInfos.h"
+#include "extraFunctions/map.h"
+#include "extensions/infos.h"
 
 G_BEGIN_DECLS
 
@@ -63,6 +65,7 @@ G_BEGIN_DECLS
  * @planesList: TODO
  * @surfsList: TODO
  * @fieldsList: TODO
+ * @mapsList: TODO
  * @shade: TODO
  * @mapPlaneId: TODO
  * @logScale: TODO
@@ -78,42 +81,38 @@ struct _VisuBasicCLISet
 {
   gchar *colorFile;
 
-  Plane **planesList;
+  VisuPlane **planesList;
 
-  Surfaces **surfsList;
+  VisuSurfaces **surfsList;
   GList *fieldsList;
 
-  Shade *shade;
+  VisuMap **mapsList;
+
+  ToolShade *shade;
 
   gint *mapPlaneId;
   ToolMatrixScalingFlag logScale;
   guint nIsolines;
-  float* isoLinesColor;
+  ToolColor* isoLinesColor;
 
   gchar *bgImage;
 };
 
-void initVisuBasic(void);
-
-/* Load related methods. */
-gboolean visu_basic_getLoadCancel(void);
-void visu_basic_setLoadCancel(gboolean status);
-void visu_basic_setLoadMessageFunc(GFunc func, gpointer data);
-void visu_basic_setLoadMessage(const gchar *mess);
-gboolean visu_basic_loadData(VisuData *data, ToolFileFormat *format,
-				    int nSet, GError **error);
+void visu_basic_init(void);
 
 /* Common parse routines. */
-gchar* visu_basic_parseConfigFiles(void);
-gboolean visu_basic_applyCommandLine(VisuData *data, VisuBasicCLISet *set,
-				    GError **error);
+gchar* visu_basic_parseConfigFiles(VisuGlView *view);
+gboolean visu_basic_applyCommandLine(VisuData *data, VisuGlView *view,
+                                     VisuBasicCLISet *set, GError **error);
 gboolean visu_basic_showOptionHelp(gboolean force);
 
 /* Export routines. */
-void visu_basic_createExtensions(VisuData *data, VisuBasicCLISet *set, gboolean rebuild);
+void visu_basic_createExtensions(VisuData *data, VisuGlView *view,
+                                 VisuBasicCLISet *set, gboolean rebuild);
 VisuData* visu_basic_setDataFromCommandLine(void);
-void visu_basic_setExtInfos(VisuData *dataObj, VisuGlExtInfosDrawMethod method,
-			   int *nodes, VisuDataNode *data);
+void visu_basic_setExtInfos(VisuData *dataObj, VisuGlView *view,
+                            VisuGlExtInfosDrawMethod method,
+                            int *nodes, VisuDataNode *data);
 int visu_basic_mainExport(void);
 
 /* Some resources. */
@@ -133,7 +132,7 @@ gboolean visu_basic_setPreferedUnit(ToolUnits unit);
  */
 #define VISU_WEB_SITE      "http://inac.cea.fr/L_Sim/V_Sim"
 
-/* Main pathes. */
+/* Main paths. */
 void visu_basic_setExePath(const gchar *exePath);
 /**
  * V_SIM_DATA_DIR:
