@@ -50,33 +50,55 @@
 #include <unistd.h> /* For the access markers R_OK, W_OK ... */
 #include <math.h>
 
-gchar* getValidPath(GList **pathList, char *fileName, int accessMode)
+/**
+ * tool_getValidPath:
+ * @pathList: (element-type filename): a pointer to a GList with all the possible path,
+ * @filenames: (array zero-terminated=1) (element-type filename): an array of strings,
+ * @accessMode: a value from R_OK, W_OK and X_OK as described in unistd.h.
+ *
+ * @pathList contains a list of directories (first is most prefered)
+ * and fileName is the file name which one likes have informations on. This routine
+ * look for the first directory where fileName can be writen or read (depending
+ * on accessMode parameter). The pointer to the GList indicates at the end the
+ * first valid entry in the GList.
+ *
+ * Returns: (transfer full): the first valid complete path (from
+ * @pathList plus an entry of @filenames) if one can be found depnding
+ * on @accessMode or NULL if none found. Free it with g_free() after
+ * use.
+ */
+gchar* tool_getValidPath(GList **pathList, const char **filenames, int accessMode)
 {
   gchar *validPath;
   int fileOk;
+  guint i;
 
   validPath = (char*)0;
   /* look for a directory to save or read a file. */
   fileOk = 0;
   while (*pathList && !fileOk)
     {
-      validPath = g_build_filename((gchar*)(*pathList)->data, fileName, NULL);
-      DBG_fprintf(stderr, "Visu Tools : test access (%d) for '%s' ... ", accessMode, validPath);
-      fileOk = !access((char*)validPath, accessMode); /* return 0 if success */
-      if (!fileOk)
-	{
-	  /* if access mode is write access and the file does not already exist :
-	     we test if the directory has written permitions. */
-	  if ( accessMode == W_OK && !g_file_test(validPath, G_FILE_TEST_EXISTS) )
-	    fileOk = !access((char*)(*pathList)->data, accessMode); /* return 0 if success */
-	  if (!fileOk)
-	    {
-	      DBG_fprintf(stderr, " failed.\n");
-	      g_free(validPath);
-	      *pathList = g_list_next(*pathList);
-	    }
-	}
-      
+      for (i = 0; filenames[i]; i++)
+        {
+          validPath = g_build_filename((gchar*)(*pathList)->data, filenames[i], NULL);
+          DBG_fprintf(stderr, "Visu Tools : test access (%d) for '%s' ... ",
+                      accessMode, validPath);
+          fileOk = !access((char*)validPath, accessMode); /* return 0 if success */
+          if (fileOk)
+            break;
+        
+          /* if access mode is write access and the file does not already exist :
+             we test if the directory has written permitions. */
+          if ( accessMode == W_OK && !g_file_test(validPath, G_FILE_TEST_EXISTS) )
+            fileOk = !access((char*)(*pathList)->data, accessMode);
+
+          if (fileOk)
+            break;
+
+          DBG_fprintf(stderr, " failed.\n");
+          g_free(validPath);
+        }
+      *pathList = g_list_next(*pathList);
     }
   if (fileOk)
     {
@@ -84,18 +106,37 @@ gchar* getValidPath(GList **pathList, char *fileName, int accessMode)
       return validPath;
     }
   else
-      return (gchar*)0;
+    return (gchar*)0;
 }
 
-
-float fModulo(float a, int b) {
+/**
+ * tool_modulo_float:
+ * @a: a float ;
+ * @b: an int.
+ * 
+ * This function is just like a%b except it works with a float @a argument. 
+ * @a can be negative, but the return value of the function is always positive.
+ *
+ * Returns: the new float value after the modulo.
+*/
+float tool_modulo_float(float a, int b) {
   float fb = (float)b;
   while(a < fb) a += fb;
   while(a >= fb) a -= fb;
   return a;
 }
 
-gchar* normalize_path(const gchar* path)
+/**
+ * tool_path_normalize:
+ * @path: a string, NULL terminated.
+ *
+ * This function normalizes the path, i.e. it removes all . and .. It should
+ * work also on Windows. It must take an absolute path as argument, if not it is converted
+ * assuming the current working directory.
+ *
+ * Returns: a newly created string.
+ */
+gchar* tool_path_normalize(const gchar* path)
 {
 #if SYSTEM_X11 == 1
 #define FILE_SYSTEM_SEP "/"
@@ -164,6 +205,17 @@ gchar* normalize_path(const gchar* path)
 }
 
 #if GLIB_MINOR_VERSION < 5
+/**
+ * g_file_set_contents:
+ * @fileName: a string ;
+ * @str: a string ;
+ * @len: a length or -1 ;
+ * @error: a location for an error.
+ *
+ * Compiled only if Glib is lower than 2.5.
+ *
+ * Returns: TRUE on success.
+ */
 gboolean g_file_set_contents(const gchar *fileName, const gchar *str,
 			     gsize len _U_, GError **error _U_)
 {
@@ -197,8 +249,19 @@ static gchar* tagLookup(const gchar *tag, const gchar *buffer)
     return ptTag;
   return tagLookup(tag, ptTag + strlen(tag));
 }
-
-gboolean visuToolsSubstitute_XML(GString *output, const gchar *filename,
+/**
+ * tool_XML_substitute:
+ * @output: a GString to store the substitution ;
+ * @filename: the file to read the data from ;
+ * @tag: the tag to substitute ;
+ * @error: a location to store possible errors.
+ *
+ * Read @filename (must be XML file) and remove the @tag zone from
+ * it. At that place, it puts the contain of @output.
+ *
+ * Returns: TRUE if no error occured.
+ */
+gboolean tool_XML_substitute(GString *output, const gchar *filename,
 				 const gchar *tag, GError **error)
 {
   gchar *contents, *ptStart, *ptStop;
@@ -221,6 +284,7 @@ gboolean visuToolsSubstitute_XML(GString *output, const gchar *filename,
 	g_string_prepend_len(output, contents, (gssize)(ptStart - contents));
       else
 	{
+          g_string_prepend(output, "  ");
 	  ptStop = tagLookup("</v_sim>", contents);
 	  if (ptStop)
 	    g_string_prepend_len(output, contents, (gssize)(ptStop - contents));
@@ -236,13 +300,12 @@ gboolean visuToolsSubstitute_XML(GString *output, const gchar *filename,
 				   " encoding=\"utf-8\"?>\n<v_sim>");
 		}
 	    }
-	  g_string_prepend(output, "\n");
 	}
 
       g_free(tgStart);
     }
   else
-    g_string_prepend(output, "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<v_sim>\n");
+    g_string_prepend(output, "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<v_sim>\n  ");
 
   /* If file does exist, we add the remaining parts. */
   if (contents && ptStart)
